(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[    145795,       3420]
NotebookOptionsPosition[    140356,       3274]
NotebookOutlinePosition[    140758,       3291]
CellTagsIndexPosition[    140715,       3288]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[StyleBox["Evaluation time\n\[CapitalDelta]t < 2 min",
 FontColor->RGBColor[0, 0, 1]]], "Text",
 CellChangeTimes->{{3.5749416987827597`*^9, 3.57494176969971*^9}, {
  3.574941802165905*^9, 3.574941866327519*^9}, {3.574943490448987*^9, 
  3.574943500939139*^9}, {3.575255844265176*^9, 3.575255848239403*^9}},
 FontSize->36,
 Background->RGBColor[1, 0.9, 0.8]],

Cell[TextData[{
 StyleBox["In the 3D case, the diamond cell of silicon is characterized by 3 \
basis of two atoms each.\n\nAccording to what we wrote in Section 2.2.1.5 to \
evaluate the susceptivity ",
  FontColor->RGBColor[0, 0, 1]],
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Chi]", "g"], TraditionalForm]],
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[", we have to\ncalculate the unit cell scattering factor F(",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["g",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["), based on the FourierTransform of the\nelectronic density \
\[Rho](",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["r",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[") of the single silicon atom.\n\nFor representing in a clearer way \
the physics behind this calculations,\nwe begin considering simply a 1D cell \
with just two atoms of silicon.\n\nClearly we can consider different \
positions for the two atoms and compare the results we get. \nIn this case ",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["g ",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[" is a scalar. Then in the next notebook \
(Chap2-1-2D-Polar-Rho-Susce-check.nb)\nwe will consider a more advanced \
situation in two dimensions.\n\nThe structure of the notebook is as follows:\n\
\n- Preliminary Definitions: we introduce useful quantities and constants;\n\n\
- Part I: we evaluate the above cited quantities considering the two atoms in \
the cell or around one node (@ -1/8",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["a",
  FontSlant->"Italic",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[" and +1/8",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["a",
  FontSlant->"Italic",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[" position) or inside the cell (@ +1/8",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["a",
  FontSlant->"Italic",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[" and +7/8",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["a",
  FontSlant->"Italic",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[" position),\nreminding that the coordinate of the j-th cell are 0 \
and ",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["a",
  FontSlant->"Italic",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[" for the considered cell;\n\n- Part II: we evaluate the above \
cited quantities considering the two atoms as a unique U-shaped electronic \
density;\n\n- Part III: we check the previous results calculating the Fourier \
coefficients of expansion by mean of the equation:\n\n",
  FontColor->RGBColor[0, 0, 1]],
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["c", "n"], 
    StyleBox["  ",
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox["=",
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox[" ",
     FontColor->RGBColor[1, 0, 0]], 
    RowBox[{
     FractionBox["1", "L"], 
     StyleBox[" ",
      FontColor->RGBColor[1, 0, 0]], 
     RowBox[{
      SubscriptBox["F", "0"], 
      StyleBox["[",
       FontColor->RGBColor[1, 0, 0]], 
      RowBox[{
       StyleBox["n",
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox[" ",
        FontColor->RGBColor[1, 0, 0]], 
       FractionBox[
        RowBox[{"2", " ", "\[Pi]"}], "L"]}], 
      StyleBox["]",
       FontColor->RGBColor[1, 0, 0]]}]}]}], TraditionalForm]],
  FontColor->RGBColor[0, 0, 1]]
}], "Text",
 CellChangeTimes->{{3.49778539303125*^9, 3.497785455890625*^9}, {
   3.49778633871875*^9, 3.497786388953125*^9}, {3.497786527234375*^9, 
   3.49778661515625*^9}, {3.49785659690625*^9, 3.49785661915625*^9}, {
   3.497877632046875*^9, 3.49787765253125*^9}, {3.49795909240625*^9, 
   3.497959230109375*^9}, {3.49795926353125*^9, 3.497959309984375*^9}, {
   3.497959346203125*^9, 3.497959376125*^9}, 3.49796052334375*^9, 
   3.497960754703125*^9, {3.4979610276875*^9, 3.49796110215625*^9}, {
   3.498106285*^9, 3.498106289875*^9}, {3.49810640334375*^9, 
   3.498106411421875*^9}, {3.4981151435*^9, 3.498115157859375*^9}, {
   3.49882848628125*^9, 3.498828487*^9}, {3.498828539921875*^9, 
   3.498828598578125*^9}, {3.498828658234375*^9, 3.49882867534375*^9}, {
   3.498831697578125*^9, 3.498831706359375*^9}, {3.498912272328125*^9, 
   3.498912312546875*^9}, {3.49891364478125*^9, 3.49891370509375*^9}, {
   3.553259738203125*^9, 3.553259926421875*^9}, {3.553259962046875*^9, 
   3.55325997528125*^9}, {3.553260014421875*^9, 3.55326001809375*^9}, {
   3.55326027565625*^9, 3.553260324890625*^9}, {3.553260362625*^9, 
   3.553260445953125*^9}, {3.55326047903125*^9, 3.55326065671875*^9}, {
   3.553261039640625*^9, 3.55326107021875*^9}, {3.553774510391384*^9, 
   3.55377462397139*^9}, {3.55377465931855*^9, 3.553774844985372*^9}, {
   3.553774891356955*^9, 3.553775190164221*^9}, 3.553783907589079*^9, {
   3.553784275529397*^9, 3.5537842894851007`*^9}, {3.553827985700789*^9, 
   3.553828009040845*^9}, {3.553828129654746*^9, 3.553828157169492*^9}, {
   3.574941962425593*^9, 3.574941962729019*^9}, {3.574945714109519*^9, 
   3.574945746304599*^9}, {3.574945811677092*^9, 3.574945971211494*^9}, {
   3.574946028016472*^9, 3.5749461021582003`*^9}, {3.5752558622982073`*^9, 
   3.5752558678305235`*^9}, {3.5752561659635754`*^9, 
   3.5752561715528955`*^9}, {3.575256785563015*^9, 3.5752573200785875`*^9}, {
   3.5752574036383667`*^9, 3.575257433751089*^9}},
 FontSize->24,
 Background->RGBColor[1, 1, 0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"SetOptions", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "Plot", ",", "ListPlot", ",", "DiscretePlot", ",", "ContourPlot", ",", 
      "Plot3D"}], "}"}], ",", 
    RowBox[{"ImageSize", "\[Rule]", "700"}], ",", 
    RowBox[{"LabelStyle", "\[Rule]", 
     RowBox[{"(", 
      RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}], ")"}]}], ",", 
    RowBox[{"AxesStyle", "\[Rule]", 
     RowBox[{"Directive", "[", 
      RowBox[{"20", ",", 
       RowBox[{"Thickness", "[", "0.005", "]"}], ",", "Blue"}], "]"}]}]}], 
   "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.431404133265625*^9, 3.431404152625*^9}, {
   3.431404184828125*^9, 3.43140419784375*^9}, {3.431404229828125*^9, 
   3.431404286*^9}, {3.431404358734375*^9, 3.431404362015625*^9}, 
   3.43140449659375*^9, {3.431404585328125*^9, 3.431404586390625*^9}, {
   3.431404647765625*^9, 3.431404694953125*^9}, {3.43140617875*^9, 
   3.4314062495625*^9}, {3.431406282875*^9, 3.4314063513125*^9}, {
   3.43140679328125*^9, 3.43140680225*^9}, {3.4314068341875*^9, 
   3.431406876078125*^9}, {3.48396135521875*^9, 3.483961362359375*^9}, {
   3.48396582775*^9, 3.48396583034375*^9}, {3.4840494269375*^9, 
   3.48404942946875*^9}, {3.484104769703125*^9, 3.484104774828125*^9}, {
   3.484122942015625*^9, 3.48412294471875*^9}, {3.489318163125*^9, 
   3.48931816853125*^9}, {3.497696376359375*^9, 3.497696384640625*^9}, {
   3.497696431390625*^9, 3.497696435203125*^9}, {3.497789769765625*^9, 
   3.49778977328125*^9}, {3.498828771625*^9, 3.498828772171875*^9}, {
   3.498830949421875*^9, 3.498830953265625*^9}, 3.5750892780656548`*^9},
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Preliminary", " ", "Definitions"}]], "Text",
 CellChangeTimes->{{3.553775858737446*^9, 3.5537758682010927`*^9}, 
   3.553775900523551*^9, {3.55377598764578*^9, 3.553776019276904*^9}, 
   3.5750892780781717`*^9, {3.5751076077872753`*^9, 3.5751076981413517`*^9}, {
   3.5752560447476425`*^9, 3.5752560470887766`*^9}, {3.575256377680685*^9, 
   3.575256380479845*^9}},
 FontFamily->"Times New Roman",
 FontSize->36,
 FontColor->RGBColor[0, 0, 1],
 Background->RGBColor[1, 0.9, 0.8]],

Cell[BoxData[
 RowBox[{
  RowBox[{"Needs", "[", "\"\<Notation`\>\"", "]"}], "  "}]], "Input",
 CellChangeTimes->{
  3.3935991603113327`*^9, {3.499857585765625*^9, 3.4998575875*^9}, {
   3.499945519546875*^9, 3.499945521*^9}, 3.55210564625*^9, 
   3.5750892780658627`*^9},
 FontSize->24],

Cell[BoxData[
 RowBox[{
  RowBox[{"DynamicSymbolize", "[", 
   RowBox[{"f_", ",", "k_"}], "]"}], ":=", 
  RowBox[{"Symbolize", "[", 
   RowBox[{
    StyleBox["ParsedBoxWrapper",
     FontColor->RGBColor[1, 0, 0]], "[", 
    RowBox[{"SubscriptBox", "[", 
     RowBox[{"f", ",", "k"}], "]"}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.55210539890625*^9, 3.552105403*^9}, {
   3.552105527421875*^9, 3.5521055556875*^9}, {3.552105629890625*^9, 
   3.552105639921875*^9}, 3.55247335309375*^9, 3.5750892780661716`*^9},
 FontSize->24],

Cell[BoxData[
 RowBox[{"DynamicSymbolize", "[", 
  RowBox[{"\"\<a\>\"", ",", "\"\<0\>\""}], "]"}]], "Input",
 CellChangeTimes->{{3.409561442890625*^9, 3.40956144328125*^9}, {
   3.433757607109375*^9, 3.433757629078125*^9}, {3.433836019828125*^9, 
   3.433836021421875*^9}, {3.433836066546875*^9, 3.43383607190625*^9}, {
   3.49759654940625*^9, 3.497596552953125*^9}, {3.49759662575*^9, 
   3.49759662609375*^9}, 3.575089278066414*^9},
 FontSize->24],

Cell[BoxData[
 RowBox[{"DynamicSymbolize", "[", 
  RowBox[{"\"\<width\>\"", ",", "\"\<at\>\""}], "]"}]], "Input",
 CellChangeTimes->{{3.409561442890625*^9, 3.40956144328125*^9}, {
   3.433757607109375*^9, 3.433757629078125*^9}, {3.433836019828125*^9, 
   3.433836021421875*^9}, {3.433836066546875*^9, 3.43383607190625*^9}, {
   3.49759654940625*^9, 3.497596552953125*^9}, {3.553248923953125*^9, 
   3.55324892759375*^9}, {3.553249008921875*^9, 3.5532490105625*^9}, 
   3.575089278066654*^9},
 FontSize->24],

Cell[BoxData[
 RowBox[{"DynamicSymbolize", "[", 
  RowBox[{"\"\<CG\>\"", ",", "\"\<1\>\""}], "]"}]], "Input",
 CellChangeTimes->{{3.409561442890625*^9, 3.40956144328125*^9}, {
   3.433757607109375*^9, 3.433757629078125*^9}, {3.433836019828125*^9, 
   3.433836021421875*^9}, {3.433836066546875*^9, 3.43383607190625*^9}, {
   3.49759654940625*^9, 3.497596552953125*^9}, {3.553248923953125*^9, 
   3.55324892759375*^9}, {3.553249008921875*^9, 3.5532490105625*^9}, {
   3.55325904046875*^9, 3.553259042859375*^9}, 3.55339862647843*^9, 
   3.553398759815813*^9, 3.553398801621751*^9, 3.575089278066834*^9},
 FontSize->24],

Cell[BoxData[
 RowBox[{"DynamicSymbolize", "[", 
  RowBox[{"\"\<CG\>\"", ",", "\"\<2\>\""}], "]"}]], "Input",
 CellChangeTimes->{{3.409561442890625*^9, 3.40956144328125*^9}, {
   3.433757607109375*^9, 3.433757629078125*^9}, {3.433836019828125*^9, 
   3.433836021421875*^9}, {3.433836066546875*^9, 3.43383607190625*^9}, {
   3.49759654940625*^9, 3.497596552953125*^9}, {3.553248923953125*^9, 
   3.55324892759375*^9}, {3.553249008921875*^9, 3.5532490105625*^9}, {
   3.55325904046875*^9, 3.553259042859375*^9}, {3.55339862647843*^9, 
   3.553398635398357*^9}, 3.553398762879931*^9, 3.5533988306189003`*^9, 
   3.575089278067068*^9},
 FontSize->24],

Cell[BoxData[
 RowBox[{"DynamicSymbolize", "[", 
  RowBox[{"\"\<CG\>\"", ",", "\"\<3\>\""}], "]"}]], "Input",
 CellChangeTimes->{{3.409561442890625*^9, 3.40956144328125*^9}, {
   3.433757607109375*^9, 3.433757629078125*^9}, {3.433836019828125*^9, 
   3.433836021421875*^9}, {3.433836066546875*^9, 3.43383607190625*^9}, {
   3.49759654940625*^9, 3.497596552953125*^9}, {3.553248923953125*^9, 
   3.55324892759375*^9}, {3.553249008921875*^9, 3.5532490105625*^9}, {
   3.55325904046875*^9, 3.553259042859375*^9}, {3.55339862647843*^9, 
   3.5533986546778593`*^9}, {3.5533988325395193`*^9, 3.553398834497785*^9}, 
   3.575089278067244*^9},
 FontSize->24],

Cell[BoxData[
 RowBox[{"DynamicSymbolize", "[", 
  RowBox[{"\"\<r\>\"", ",", "\"\<e\>\""}], "]"}]], "Input",
 CellChangeTimes->{{3.409561442890625*^9, 3.40956144328125*^9}, {
   3.433757607109375*^9, 3.433757629078125*^9}, {3.433836019828125*^9, 
   3.433836021421875*^9}, {3.433836066546875*^9, 3.43383607190625*^9}, {
   3.49759654940625*^9, 3.497596552953125*^9}, {3.55325156884375*^9, 
   3.553251569421875*^9}, 3.575089278067485*^9},
 FontSize->24],

Cell[BoxData[
 RowBox[{"DynamicSymbolize", "[", 
  RowBox[{"\"\<k\>\"", ",", "\"\<x\>\""}], "]"}]], "Input",
 CellChangeTimes->{{3.409561442890625*^9, 3.40956144328125*^9}, {
   3.433757607109375*^9, 3.433757629078125*^9}, {3.433836019828125*^9, 
   3.433836021421875*^9}, {3.433836066546875*^9, 3.433836093015625*^9}, {
   3.4975965945625*^9, 3.497596608140625*^9}, {3.49759664871875*^9, 
   3.497596655125*^9}, {3.497597152046875*^9, 3.49759716015625*^9}, 
   3.57508927806768*^9},
 FontSize->24],

Cell[BoxData[
 RowBox[{"DynamicSymbolize", "[", 
  RowBox[{"\"\<g\>\"", ",", "\"\<x\>\""}], "]"}]], "Input",
 CellChangeTimes->{{3.409561442890625*^9, 3.40956144328125*^9}, {
   3.433757607109375*^9, 3.433757629078125*^9}, {3.433836019828125*^9, 
   3.433836021421875*^9}, {3.433836066546875*^9, 3.433836093015625*^9}, {
   3.4975965945625*^9, 3.497596608140625*^9}, {3.49759664871875*^9, 
   3.497596655125*^9}, {3.497597152046875*^9, 3.49759716015625*^9}, {
   3.553398035133032*^9, 3.5533980356325912`*^9}, 3.575089278067902*^9},
 FontSize->24],

Cell[BoxData[
 RowBox[{"DynamicSymbolize", "[", 
  RowBox[{"\"\<FT\>\"", ",", "\"\<at\>\""}], "]"}]], "Input",
 CellChangeTimes->{{3.409561442890625*^9, 3.40956144328125*^9}, {
   3.433757607109375*^9, 3.433757629078125*^9}, {3.433836019828125*^9, 
   3.433836021421875*^9}, {3.433836066546875*^9, 3.433836093015625*^9}, {
   3.4975965945625*^9, 3.497596608140625*^9}, {3.49759664871875*^9, 
   3.497596655125*^9}, {3.497597163359375*^9, 3.497597170765625*^9}, {
   3.4975972363125*^9, 3.497597239953125*^9}, 3.4975973785*^9, {
   3.55325116075*^9, 3.553251168125*^9}, 3.5750892780681353`*^9},
 FontSize->24],

Cell[BoxData[
 RowBox[{"DynamicSymbolize", "[", 
  RowBox[{"\"\<dueFT\>\"", ",", "\"\<at\>\""}], "]"}]], "Input",
 CellChangeTimes->{{3.409561442890625*^9, 3.40956144328125*^9}, {
   3.433757607109375*^9, 3.433757629078125*^9}, {3.433836019828125*^9, 
   3.433836021421875*^9}, {3.433836066546875*^9, 3.433836093015625*^9}, {
   3.4975965945625*^9, 3.497596608140625*^9}, {3.49759664871875*^9, 
   3.497596655125*^9}, {3.497597163359375*^9, 3.497597170765625*^9}, {
   3.4975972363125*^9, 3.497597239953125*^9}, 3.4975973785*^9, {
   3.55325116075*^9, 3.553251168125*^9}, {3.553764889584547*^9, 
   3.5537648903989677`*^9}, 3.575089278068342*^9},
 FontSize->24],

Cell[BoxData[
 RowBox[{
  RowBox[{"FullForm", "[", 
   SubscriptBox["a", "0"], "]"}], "        ", 
  RowBox[{"(*", " ", 
   RowBox[{"just", " ", "for", " ", "checking"}], " ", "*)"}]}]], "Input",
 CellChangeTimes->{{3.552473381453125*^9, 3.55247346678125*^9}, {
   3.553251670625*^9, 3.55325167375*^9}, 3.575089278068636*^9, {
   3.575256213881316*^9, 3.575256229840229*^9}, {3.575347348458397*^9, 
   3.5753473567589483`*^9}, {3.575347440675716*^9, 3.575347441579814*^9}},
 FontSize->24],

Cell[BoxData[
 RowBox[{
  RowBox[{"FullForm", "[", 
   SubscriptBox["k", "x"], "]"}], "        ", 
  RowBox[{"(*", " ", 
   RowBox[{"just", " ", "for", " ", "checking"}], " ", "*)"}]}]], "Input",
 CellChangeTimes->{{3.552473381453125*^9, 3.55247346678125*^9}, 
   3.553258953546875*^9, 3.5750892780691757`*^9, {3.5751077945461473`*^9, 
   3.5751078057297688`*^9}, {3.575256235776569*^9, 3.575256238816743*^9}, {
   3.575347438856586*^9, 3.575347439306465*^9}},
 FontSize->24],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"FullForm", "[", 
    SubscriptBox["g", "x"], "]"}], ";"}], "  "}]], "Input",
 CellChangeTimes->{{3.552473381453125*^9, 3.55247346678125*^9}, 
   3.553258953546875*^9, {3.553398054080247*^9, 3.553398054570187*^9}, 
   3.57508927806961*^9, 3.575107786217371*^9},
 FontSize->24],

Cell[BoxData[
 RowBox[{
  RowBox[{"FullForm", "[", 
   SubscriptBox["r", "e"], "]"}], " ", ";"}]], "Input",
 CellChangeTimes->{{3.552473381453125*^9, 3.55247346678125*^9}, {
   3.5532489511875*^9, 3.553248956921875*^9}, {3.55325163925*^9, 
   3.553251647515625*^9}, 3.5532589575*^9, 3.575089278070013*^9, 
   3.575107787106781*^9},
 FontSize->24],

Cell[BoxData[
 RowBox[{
  RowBox[{"FullForm", "[", 
   SubscriptBox["CG", "1"], "]"}], " ", ";"}]], "Input",
 CellChangeTimes->{{3.552473381453125*^9, 3.55247346678125*^9}, {
   3.5532489511875*^9, 3.553248956921875*^9}, {3.55325163925*^9, 
   3.553251647515625*^9}, 3.5532589575*^9, {3.55339888766541*^9, 
   3.553398909660925*^9}, 3.57508927807041*^9, 3.575107787789613*^9},
 FontSize->24],

Cell[BoxData[
 RowBox[{
  RowBox[{"FullForm", "[", 
   SubscriptBox["CG", "2"], "]"}], " ", ";"}]], "Input",
 CellChangeTimes->{{3.552473381453125*^9, 3.55247346678125*^9}, {
   3.5532489511875*^9, 3.553248956921875*^9}, {3.55325163925*^9, 
   3.553251647515625*^9}, 3.5532589575*^9, {3.55339888766541*^9, 
   3.553398909660925*^9}, {3.553399029063242*^9, 3.553399029565949*^9}, 
   3.5750892780708237`*^9, 3.575107788330275*^9},
 FontSize->24],

Cell[BoxData[
 RowBox[{
  RowBox[{"FullForm", "[", 
   SubscriptBox["CG", "3"], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.553398954993819*^9, 3.553399002679202*^9}, 
   3.575089278071204*^9, 3.575107788955925*^9},
 FontSize->24],

Cell[BoxData[
 RowBox[{
  RowBox[{"FullForm", "[", 
   SubscriptBox["width", "at"], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.552473381453125*^9, 3.55247346678125*^9}, {
   3.5532489511875*^9, 3.553248956921875*^9}, {3.553249023671875*^9, 
   3.553249025453125*^9}, 3.5532589613125*^9, 3.575089278071628*^9, 
   3.57510779000064*^9},
 FontSize->24],

Cell[BoxData[
 RowBox[{
  RowBox[{"FullForm", "[", 
   SubscriptBox["dueFT", "at"], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.552473381453125*^9, 3.55247346678125*^9}, {
   3.5532489511875*^9, 3.553248956921875*^9}, {3.553249023671875*^9, 
   3.553249025453125*^9}, {3.553251189890625*^9, 3.553251192515625*^9}, {
   3.553258966234375*^9, 3.553258968125*^9}, {3.55376491355591*^9, 
   3.55376491422805*^9}, 3.575089278072031*^9, 3.575107790744379*^9},
 FontSize->24],

Cell[BoxData[
 RowBox[{
  RowBox[{"FullForm", "[", 
   SubscriptBox["FT", "at"], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.552473381453125*^9, 3.55247346678125*^9}, {
   3.5532489511875*^9, 3.553248956921875*^9}, {3.553249023671875*^9, 
   3.553249025453125*^9}, {3.553251189890625*^9, 3.553251192515625*^9}, {
   3.553258966234375*^9, 3.553258968125*^9}, 3.5750892780724287`*^9, 
   3.575107791438198*^9},
 FontSize->24],

Cell[BoxData[
 RowBox[{"\[Lambda]", "=", " ", 
  RowBox[{"0.709", "*", 
   SuperscriptBox["10", 
    RowBox[{"-", "10"}]], "           ", 
   RowBox[{"(*", " ", 
    RowBox[{
    "useful", " ", "for", " ", "calculating", " ", "V", " ", "in", " ", "2.2",
      ".96"}], " ", "*)"}]}]}]], "Input",
 CellChangeTimes->{{3.553251693359375*^9, 3.553251707828125*^9}, {
   3.5532606916875*^9, 3.553260734890625*^9}, 3.5750892780728893`*^9, {
   3.5752562447130795`*^9, 3.575256248880318*^9}},
 FontSize->18],

Cell[BoxData[
 RowBox[{
  SubscriptBox["r", "e"], " ", "=", " ", 
  RowBox[{"2.81", "*", 
   SuperscriptBox["10", 
    RowBox[{"-", "15"}]], "          ", 
   RowBox[{"(*", " ", 
    RowBox[{
    "useful", " ", "for", " ", "calculatin", " ", "V", " ", "in", " ", "2.2", 
     ".96"}], " ", "*)"}]}]}]], "Input",
 CellChangeTimes->{{3.553251745171875*^9, 3.553251770484375*^9}, {
   3.553260739625*^9, 3.55326074265625*^9}, 3.5750892780733757`*^9, {
   3.575256251800485*^9, 3.575256255624704*^9}},
 FontSize->18],

Cell[BoxData[
 RowBox[{
  SubscriptBox["a", "0"], "=", 
  RowBox[{
   FractionBox["54", "10"], " ", "*", 
   SuperscriptBox["10", 
    RowBox[{"-", "10"}]], "   ", 
   RowBox[{"(*", " ", 
    RowBox[{
    "standard", " ", "cell", " ", "length", " ", "in", " ", "Si", " ", 
     "lattice"}], " ", "*)"}]}]}]], "Input",
 CellChangeTimes->{
  3.428806436828125*^9, {3.49779294684375*^9, 3.49779297634375*^9}, {
   3.497869819046875*^9, 3.49786982121875*^9}, 3.49787091496875*^9, 
   3.497871298296875*^9, 3.49787700834375*^9, 3.497878390828125*^9, {
   3.497955756671875*^9, 3.49795577359375*^9}, {3.498912202515625*^9, 
   3.498912211421875*^9}, 3.575089278073929*^9, 3.5750925195363913`*^9, {
   3.5752562644662094`*^9, 3.575256272081645*^9}},
 FontSize->24],

Cell[BoxData[
 RowBox[{
  SubscriptBox["width", "at"], "=", 
  RowBox[{
   FractionBox["1", "4"], "*", 
   SubscriptBox["a", "0"], "          ", 
   StyleBox[
    RowBox[{"(*", " ", 
     RowBox[{
     "the", " ", "diameter", " ", "of", " ", "Si", " ", "atom", " ", "is", 
      " ", 
      RowBox[{"1", "/", "16"}], " ", "of", " ", "the", " ", "cell", " ", 
      "size"}], " ", "*)"}],
    FontSize->18]}]}]], "Input",
 CellChangeTimes->{
  3.428806436828125*^9, {3.49779294684375*^9, 3.49779297634375*^9}, {
   3.497869819046875*^9, 3.49786982121875*^9}, 3.49787091496875*^9, 
   3.497871298296875*^9, 3.49787700834375*^9, 3.497878390828125*^9, {
   3.497953938734375*^9, 3.49795396325*^9}, {3.497954341171875*^9, 
   3.4979543555625*^9}, {3.4979557270625*^9, 3.49795579690625*^9}, {
   3.49891221725*^9, 3.49891222303125*^9}, 3.49891240484375*^9, {
   3.553249039609375*^9, 3.553249041109375*^9}, {3.553249140625*^9, 
   3.553249141453125*^9}, {3.553250452125*^9, 3.55325047184375*^9}, {
   3.553259182640625*^9, 3.553259190546875*^9}, {3.55378431495898*^9, 
   3.553784315762269*^9}, 3.575089278074808*^9, {3.575256309666795*^9, 
   3.575256318642308*^9}},
 FontSize->18],

Cell[BoxData[
 RowBox[{
  RowBox[{"N", "[", "%", "]"}], "/", "2"}]], "Input",
 CellChangeTimes->{{3.553259944484375*^9, 3.55325994828125*^9}, {
   3.574943268157281*^9, 3.574943278675415*^9}, 3.575089278075193*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["CG", "1"], " ", "=", " ", 
   RowBox[{
   "position", " ", "of", " ", "the", " ", "center", " ", "of", " ", 
    "gravity", " ", "of", " ", "the", " ", "first", " ", "atom"}]}], ",", " ", 
  RowBox[{"near", " ", "the", " ", "origin"}], ",", " ", 
  RowBox[{"positive", " ", "axis"}]}]], "Text",
 CellChangeTimes->{{3.553775829351016*^9, 3.5537758395558577`*^9}, 
   3.575089278075678*^9},
 FontFamily->"Times New Roman",
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  SubscriptBox["CG", "1"], " ", "=", 
  RowBox[{"N", "[", 
   RowBox[{
    FractionBox["1", "2"], "*", 
    FractionBox["1", "4"], "*", 
    SubscriptBox["a", "0"]}], "]"}], "   "}]], "Input",
 CellChangeTimes->{{3.553399171863435*^9, 3.55339917870542*^9}, {
   3.553399220329187*^9, 3.553399231455578*^9}, 3.55339927878718*^9, {
   3.553775575947589*^9, 3.5537756788945*^9}, {3.553775816643363*^9, 
   3.553775823386682*^9}, 3.5537773469258823`*^9, {3.553784323415254*^9, 
   3.553784327813511*^9}, 3.575089278075964*^9},
 FontSize->24],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["CG", "2"], " ", "=", " ", 
   RowBox[{
   "position", " ", "of", " ", "the", " ", "center", " ", "of", " ", 
    "gravity", " ", "of", " ", "the", " ", "twin", " ", "atom"}]}], ",", " ", 
  RowBox[{
  "near", " ", "the", " ", "end", " ", "of", " ", "the", " ", "cell"}], ",", 
  " ", 
  RowBox[{"positive", " ", "axis"}]}]], "Text",
 CellChangeTimes->{{3.553775858737446*^9, 3.553775887029492*^9}, 
   3.575089278076418*^9},
 FontFamily->"Times New Roman",
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  SubscriptBox["CG", "2"], "  ", "=", " ", 
  RowBox[{"N", "[", 
   RowBox[{
    SubscriptBox["a", "0"], " ", "-", " ", 
    RowBox[{
     FractionBox["1", "2"], "*", 
     FractionBox["1", "4"], "*", 
     SubscriptBox["a", "0"]}]}], "]"}], "  "}]], "Input",
 CellChangeTimes->{{3.553399171863435*^9, 3.55339917870542*^9}, {
   3.55339921209041*^9, 3.553399270236249*^9}, {3.553775661320633*^9, 
   3.5537757182901907`*^9}, 3.553775864541885*^9, {3.5537773554150667`*^9, 
   3.5537773563875027`*^9}, {3.553777979895907*^9, 3.553777986679528*^9}, {
   3.553778092492845*^9, 3.5537780947709513`*^9}, {3.553784332428948*^9, 
   3.553784333333254*^9}, 3.575089278076706*^9},
 FontSize->24],

Cell[BoxData[
 RowBox[{"coord1CG", " ", "and", " ", "coord2CG", "  ", "to", " ", 
  "highlight", " ", "the", " ", "CG"}]], "Text",
 CellChangeTimes->{{3.553775858737446*^9, 3.5537758682010927`*^9}, 
   3.553775900523551*^9, {3.55377598764578*^9, 3.553776019276904*^9}, 
   3.5750892780781717`*^9, {3.5751076077872753`*^9, 3.5751076981413517`*^9}, {
   3.5752564951214027`*^9, 3.5752564958794456`*^9}},
 FontFamily->"Times New Roman",
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{"coord1CG", "=", " ", 
  RowBox[{"{", 
   StyleBox[
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["CG", "1"]}], " ", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       SubscriptBox["CG", "1"], " ", ",", "0"}], "}"}]}],
    FontColor->RGBColor[0, 0, 1]], 
   StyleBox["}",
    FontColor->RGBColor[0, 0, 1]]}]}]], "Input",
 CellChangeTimes->{{3.5532558944375*^9, 3.553255930078125*^9}, {
   3.553256014546875*^9, 3.5532560378125*^9}, {3.55325619003125*^9, 
   3.5532561939375*^9}, {3.553260771296875*^9, 3.55326078178125*^9}, {
   3.553399360326522*^9, 3.553399381742526*^9}, {3.553399655295185*^9, 
   3.553399658339883*^9}, {3.553775920199477*^9, 3.5537759535185328`*^9}, {
   3.5537760240363703`*^9, 3.5537760303828087`*^9}, {3.575088953701936*^9, 
   3.5750889575765467`*^9}, 3.5750892780785503`*^9, {3.575092572317623*^9, 
   3.575092574376072*^9}},
 FontSize->18],

Cell[BoxData[
 RowBox[{"coord1CGb", "=", " ", 
  RowBox[{"{", 
   StyleBox[
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SubscriptBox["CG", "1"]}], " ", "+", 
        SubscriptBox["a", "0"]}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SubscriptBox["CG", "1"], " ", "+", 
        SubscriptBox["a", "0"]}], ",", "0"}], "}"}]}],
    FontColor->RGBColor[0, 0, 1]], 
   StyleBox["}",
    FontColor->RGBColor[0, 0, 1]]}]}]], "Input",
 CellChangeTimes->{{3.5532558944375*^9, 3.553255930078125*^9}, {
   3.553256014546875*^9, 3.5532560378125*^9}, {3.55325619003125*^9, 
   3.5532561939375*^9}, {3.553260771296875*^9, 3.55326078178125*^9}, {
   3.553399360326522*^9, 3.553399381742526*^9}, {3.553399655295185*^9, 
   3.553399658339883*^9}, {3.553775920199477*^9, 3.5537759535185328`*^9}, {
   3.5537760240363703`*^9, 3.5537760303828087`*^9}, {3.575088953701936*^9, 
   3.5750889575765467`*^9}, 3.5750892780785503`*^9, {3.575092572317623*^9, 
   3.575092574376072*^9}, {3.575095812667405*^9, 3.575095840817519*^9}},
 FontSize->18],

Cell[BoxData[
 RowBox[{"coord1CGc", "=", " ", 
  RowBox[{"{", 
   StyleBox[
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SubscriptBox["CG", "1"]}], " ", "+", 
        RowBox[{"2", " ", 
         SubscriptBox["a", "0"]}]}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SubscriptBox["CG", "1"], " ", "+", 
        RowBox[{"2", " ", 
         SubscriptBox["a", "0"]}]}], ",", "0"}], "}"}]}],
    FontColor->RGBColor[0, 0, 1]], 
   StyleBox["}",
    FontColor->RGBColor[0, 0, 1]]}]}]], "Input",
 CellChangeTimes->{{3.5532558944375*^9, 3.553255930078125*^9}, {
   3.553256014546875*^9, 3.5532560378125*^9}, {3.55325619003125*^9, 
   3.5532561939375*^9}, {3.553260771296875*^9, 3.55326078178125*^9}, {
   3.553399360326522*^9, 3.553399381742526*^9}, {3.553399655295185*^9, 
   3.553399658339883*^9}, {3.553775920199477*^9, 3.5537759535185328`*^9}, {
   3.5537760240363703`*^9, 3.5537760303828087`*^9}, {3.575088953701936*^9, 
   3.5750889575765467`*^9}, 3.5750892780785503`*^9, {3.575092572317623*^9, 
   3.575092574376072*^9}, {3.575095812667405*^9, 3.575095840817519*^9}, {
   3.575095902194502*^9, 3.575095909358046*^9}},
 FontSize->18],

Cell[BoxData[
 RowBox[{"coord2CG", "=", " ", 
  RowBox[{"{", 
   StyleBox[
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       SubscriptBox["CG", "1"], " ", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       SubscriptBox["CG", "2"], " ", ",", "0"}], "}"}]}],
    FontColor->RGBColor[0, 0, 1]], 
   StyleBox["}",
    FontColor->RGBColor[0, 0, 1]]}]}]], "Input",
 CellChangeTimes->{{3.5532558944375*^9, 3.553255930078125*^9}, {
   3.553256014546875*^9, 3.5532560378125*^9}, {3.55325619003125*^9, 
   3.5532561939375*^9}, {3.553256358875*^9, 3.553256411640625*^9}, 
   3.553399414585566*^9, {3.553399600589871*^9, 3.553399629538187*^9}, {
   3.553399665232847*^9, 3.553399673677108*^9}, {3.553399873972548*^9, 
   3.553399878744467*^9}, {3.553775942449402*^9, 3.553775956494639*^9}, 
   3.553776027270911*^9, 3.57508927807897*^9, {3.575092579071204*^9, 
   3.575092580042322*^9}, {3.575092843183379*^9, 3.57509285863472*^9}},
 FontSize->18],

Cell[BoxData[
 RowBox[{"coord2CGb", "=", " ", 
  RowBox[{"{", 
   StyleBox[
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SubscriptBox["CG", "1"], " ", "+", 
        SubscriptBox["a", "0"]}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SubscriptBox["CG", "2"], " ", "+", 
        SubscriptBox["a", "0"]}], ",", "0"}], "}"}]}],
    FontColor->RGBColor[0, 0, 1]], 
   StyleBox["}",
    FontColor->RGBColor[0, 0, 1]]}]}]], "Input",
 CellChangeTimes->{{3.5532558944375*^9, 3.553255930078125*^9}, {
   3.553256014546875*^9, 3.5532560378125*^9}, {3.55325619003125*^9, 
   3.5532561939375*^9}, {3.553256358875*^9, 3.553256411640625*^9}, 
   3.553399414585566*^9, {3.553399600589871*^9, 3.553399629538187*^9}, {
   3.553399665232847*^9, 3.553399673677108*^9}, {3.553399873972548*^9, 
   3.553399878744467*^9}, {3.553775942449402*^9, 3.553775956494639*^9}, 
   3.553776027270911*^9, 3.57508927807897*^9, {3.575092579071204*^9, 
   3.575092580042322*^9}, {3.575092843183379*^9, 3.57509285863472*^9}, {
   3.5750961655329313`*^9, 3.575096192654778*^9}},
 FontSize->18],

Cell[BoxData[
 RowBox[{"coord2CGc", "=", " ", 
  RowBox[{"{", 
   StyleBox[
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SubscriptBox["CG", "1"], " ", "+", 
        RowBox[{"2", 
         SubscriptBox["a", "0"]}]}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SubscriptBox["CG", "2"], " ", "+", 
        RowBox[{"2", 
         SubscriptBox["a", "0"]}]}], ",", "0"}], "}"}]}],
    FontColor->RGBColor[0, 0, 1]], 
   StyleBox["}",
    FontColor->RGBColor[0, 0, 1]]}]}]], "Input",
 CellChangeTimes->{{3.5532558944375*^9, 3.553255930078125*^9}, {
   3.553256014546875*^9, 3.5532560378125*^9}, {3.55325619003125*^9, 
   3.5532561939375*^9}, {3.553256358875*^9, 3.553256411640625*^9}, 
   3.553399414585566*^9, {3.553399600589871*^9, 3.553399629538187*^9}, {
   3.553399665232847*^9, 3.553399673677108*^9}, {3.553399873972548*^9, 
   3.553399878744467*^9}, {3.553775942449402*^9, 3.553775956494639*^9}, 
   3.553776027270911*^9, 3.57508927807897*^9, {3.575092579071204*^9, 
   3.575092580042322*^9}, {3.575092843183379*^9, 3.57509285863472*^9}, {
   3.5750961655329313`*^9, 3.575096221231661*^9}},
 FontSize->18]
}, Open  ]],

Cell[CellGroupData[{

Cell["Part I", "Text",
 CellChangeTimes->{{3.49795814646875*^9, 3.4979581888125*^9}, {
   3.49795824053125*^9, 3.497958316*^9}, {3.497959406296875*^9, 
   3.497959420546875*^9}, {3.498043168328125*^9, 3.498043187546875*^9}, {
   3.498106516515625*^9, 3.49810655075*^9}, 3.498811881546875*^9, {
   3.498827995140625*^9, 3.49882799565625*^9}, 3.49882868975*^9, 
   3.552473872765625*^9, {3.552473968390625*^9, 3.55247402665625*^9}, {
   3.553260807015625*^9, 3.553260815*^9}, {3.553753211917671*^9, 
   3.5537532471483917`*^9}, {3.5537532772628927`*^9, 3.553753310106073*^9}, {
   3.553775339564728*^9, 3.553775388928371*^9}, {3.5538272658268547`*^9, 
   3.553827271558619*^9}, {3.553827318764749*^9, 3.553827365915971*^9}, {
   3.553827426142563*^9, 3.553827457019126*^9}, 3.553828090670125*^9, {
   3.553828174641241*^9, 3.553828202866152*^9}, {3.574943132840713*^9, 
   3.57494313890244*^9}, {3.574943229021974*^9, 3.57494323680661*^9}, {
   3.574943304707011*^9, 3.5749433047071123`*^9}, {3.5750891979997683`*^9, 
   3.575089219260971*^9}, 3.575096334352598*^9, 3.575096473118904*^9, {
   3.575256082096779*^9, 3.5752560828788233`*^9}},
 FontFamily->"Times New Roman",
 FontSize->36,
 FontColor->RGBColor[0, 0, 1],
 Background->RGBColor[1, 0.9, 0.8]],

Cell[TextData[{
 "I consider one cell containing two silicon atoms.\n\nWe have different \
chances dealing with the electronic density.\n\nTo consider the electronic \
density of a single atom centred in the origin; usually\nin the handlebar, \
the two atoms are symmetrically located with respect to the origin\nwith \
distance 1/8 of the cell size (for the first one).\n\nThe cell has ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["a", "0"], "=", 
   RowBox[{"5.42883", " ", "*", 
    RowBox[{
     SuperscriptBox["10", 
      RowBox[{"-", "10"}]], "  ", "[", "m", "]"}], " "}]}]],
  CellChangeTimes->{
   3.428806436828125*^9, {3.49779294684375*^9, 3.49779297634375*^9}, {
    3.497869819046875*^9, 3.49786982121875*^9}, 3.49787091496875*^9, 
    3.497871298296875*^9, 3.49787700834375*^9, 3.497878390828125*^9, {
    3.497955756671875*^9, 3.49795577359375*^9}},
  FontSize->24],
 "cell parameter \nThe diameter of the silicon atom (spherical construct) is ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["width", "at"], "=", 
   RowBox[{
    FractionBox["1", "4"], "*", 
    SubscriptBox["a", "0"], " "}]}]],
  CellChangeTimes->{
   3.428806436828125*^9, {3.49779294684375*^9, 3.49779297634375*^9}, {
    3.497869819046875*^9, 3.49786982121875*^9}, 3.49787091496875*^9, 
    3.497871298296875*^9, 3.49787700834375*^9, 3.497878390828125*^9, {
    3.497953938734375*^9, 3.49795396325*^9}, {3.497954341171875*^9, 
    3.4979543555625*^9}, {3.4979557270625*^9, 3.49795579690625*^9}},
  FontSize->24],
 "=",
 Cell[BoxData[
  RowBox[{" ", "1.35`*^-10"}]], "Output",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  CellChangeTimes->{3.553259953875*^9, 3.55326010959375*^9, 
   3.553343244823125*^9, 3.553399742570649*^9, 3.553753155890566*^9, 
   3.55375468513898*^9, 3.553754848631722*^9, 3.553762521707066*^9, 
   3.553763649549182*^9, 3.553767738278607*^9, 3.553769976959447*^9, 
   3.553775778166173*^9, 3.553777335076611*^9, 3.553784364093465*^9, 
   3.5749416303325367`*^9, 3.574943205652384*^9},
  FontSize->24],
 " [m]  \nThe center of mass of the first atom is therefore @ ",
 Cell[BoxData[
  RowBox[{
   FractionBox["1", "8"], "*", 
   SubscriptBox["a", "0"], " "}]],
  CellChangeTimes->{
   3.428806436828125*^9, {3.49779294684375*^9, 3.49779297634375*^9}, {
    3.497869819046875*^9, 3.49786982121875*^9}, 3.49787091496875*^9, 
    3.497871298296875*^9, 3.49787700834375*^9, 3.497878390828125*^9, {
    3.497953938734375*^9, 3.49795396325*^9}, {3.497954341171875*^9, 
    3.4979543555625*^9}, {3.4979557270625*^9, 3.49795579690625*^9}},
  FontSize->24],
 "= ",
 Cell[BoxData["6.75`*^-11"],
  CellChangeTimes->{3.5532556198125*^9, 3.553257029671875*^9, 
   3.553259242578125*^9, 3.553260109671875*^9}],
 " [m]\n\nI have two options for the second atom of the cell:\n\na. \
symetrically located on the opposite side of the origin, i.e. at1= ",
 Cell[BoxData[
  RowBox[{"+", 
   FractionBox["1", "8"]}]],
  CellChangeTimes->{{3.55323332190625*^9, 3.553233452296875*^9}, {
    3.553233546296875*^9, 3.553233643078125*^9}, {3.553233674296875*^9, 
    3.55323369940625*^9}, {3.553233745359375*^9, 3.5532337625*^9}, 
    3.55323385990625*^9, {3.553233929109375*^9, 3.55323393034375*^9}, {
    3.5532340236875*^9, 3.553234031234375*^9}, {3.55323531940625*^9, 
    3.553235327859375*^9}, {3.553235393484375*^9, 3.55323544403125*^9}, {
    3.553236356890625*^9, 3.5532363763125*^9}, {3.553249517125*^9, 
    3.5532495475*^9}, {3.55324962609375*^9, 3.553249654703125*^9}, {
    3.553251430734375*^9, 3.5532514450625*^9}, {3.553252686609375*^9, 
    3.553252692265625*^9}, {3.55325957378125*^9, 3.5532595796875*^9}, {
    3.55326007428125*^9, 3.553260080015625*^9}, {3.55326017065625*^9, 
    3.553260171640625*^9}, {3.553260240109375*^9, 3.553260240484375*^9}}],
 "*",
 Cell[BoxData[
  SubscriptBox["a", "0"]],
  CellChangeTimes->{
   3.428806436828125*^9, {3.49779294684375*^9, 3.49779297634375*^9}, {
    3.497869819046875*^9, 3.49786982121875*^9}, 3.49787091496875*^9, 
    3.497871298296875*^9, 3.49787700834375*^9, 3.497878390828125*^9, {
    3.497953938734375*^9, 3.49795396325*^9}, {3.497954341171875*^9, 
    3.4979543555625*^9}, {3.4979557270625*^9, 3.49795579690625*^9}},
  FontSize->24],
 " ed at2 = ",
 Cell[BoxData[
  RowBox[{"-", 
   FractionBox["1", "8"]}]],
  CellChangeTimes->{{3.55323332190625*^9, 3.553233452296875*^9}, {
    3.553233546296875*^9, 3.553233643078125*^9}, {3.553233674296875*^9, 
    3.55323369940625*^9}, {3.553233745359375*^9, 3.5532337625*^9}, 
    3.55323385990625*^9, {3.553233929109375*^9, 3.55323393034375*^9}, {
    3.5532340236875*^9, 3.553234031234375*^9}, {3.55323531940625*^9, 
    3.553235327859375*^9}, {3.553235393484375*^9, 3.55323544403125*^9}, {
    3.553236356890625*^9, 3.5532363763125*^9}, {3.553249517125*^9, 
    3.5532495475*^9}, {3.55324962609375*^9, 3.553249654703125*^9}, {
    3.553251430734375*^9, 3.5532514450625*^9}, {3.553252686609375*^9, 
    3.553252692265625*^9}, {3.55325957378125*^9, 3.5532595796875*^9}, {
    3.55326007428125*^9, 3.553260080015625*^9}, {3.55326017065625*^9, 
    3.553260171640625*^9}, {3.553260240109375*^9, 3.553260240484375*^9}}],
 Cell[BoxData[
  RowBox[{"*", 
   SubscriptBox["a", "0"]}]],
  CellChangeTimes->{
   3.428806436828125*^9, {3.49779294684375*^9, 3.49779297634375*^9}, {
    3.497869819046875*^9, 3.49786982121875*^9}, 3.49787091496875*^9, 
    3.497871298296875*^9, 3.49787700834375*^9, 3.497878390828125*^9, {
    3.497953938734375*^9, 3.49795396325*^9}, {3.497954341171875*^9, 
    3.4979543555625*^9}, {3.4979557270625*^9, 3.49795579690625*^9}},
  FontSize->24],
 "\nb. inside the cell on the opposite side, i.e.  at1 = ",
 Cell[BoxData[
  RowBox[{"+", 
   FractionBox["1", "8"]}]],
  CellChangeTimes->{{3.55323332190625*^9, 3.553233452296875*^9}, {
    3.553233546296875*^9, 3.553233643078125*^9}, {3.553233674296875*^9, 
    3.55323369940625*^9}, {3.553233745359375*^9, 3.5532337625*^9}, 
    3.55323385990625*^9, {3.553233929109375*^9, 3.55323393034375*^9}, {
    3.5532340236875*^9, 3.553234031234375*^9}, {3.55323531940625*^9, 
    3.553235327859375*^9}, {3.553235393484375*^9, 3.55323544403125*^9}, {
    3.553236356890625*^9, 3.5532363763125*^9}, {3.553249517125*^9, 
    3.5532495475*^9}, {3.55324962609375*^9, 3.553249654703125*^9}, {
    3.553251430734375*^9, 3.5532514450625*^9}, {3.553252686609375*^9, 
    3.553252692265625*^9}, {3.55325957378125*^9, 3.5532595796875*^9}, {
    3.55326007428125*^9, 3.553260080015625*^9}, {3.55326017065625*^9, 
    3.553260171640625*^9}, {3.553260240109375*^9, 3.553260240484375*^9}}],
 "*",
 Cell[BoxData[
  SubscriptBox["a", "0"]],
  CellChangeTimes->{
   3.428806436828125*^9, {3.49779294684375*^9, 3.49779297634375*^9}, {
    3.497869819046875*^9, 3.49786982121875*^9}, 3.49787091496875*^9, 
    3.497871298296875*^9, 3.49787700834375*^9, 3.497878390828125*^9, {
    3.497953938734375*^9, 3.49795396325*^9}, {3.497954341171875*^9, 
    3.4979543555625*^9}, {3.4979557270625*^9, 3.49795579690625*^9}},
  FontSize->24],
 " ed  at2 = ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"+", 
    FractionBox["7", "8"]}], "*", 
   SubscriptBox["a", "0"]}]],
  CellChangeTimes->{{3.55323332190625*^9, 3.553233452296875*^9}, {
    3.553233546296875*^9, 3.553233643078125*^9}, {3.553233674296875*^9, 
    3.55323369940625*^9}, {3.553233745359375*^9, 3.5532337625*^9}, 
    3.55323385990625*^9, {3.553233929109375*^9, 3.55323393034375*^9}, {
    3.5532340236875*^9, 3.553234031234375*^9}, {3.55323531940625*^9, 
    3.553235327859375*^9}, {3.553235393484375*^9, 3.55323544403125*^9}, {
    3.553236356890625*^9, 3.5532363763125*^9}, {3.553249517125*^9, 
    3.5532495475*^9}, {3.55324962609375*^9, 3.553249654703125*^9}, {
    3.553251430734375*^9, 3.5532514450625*^9}, {3.553252686609375*^9, 
    3.553252692265625*^9}, {3.55325957378125*^9, 3.5532595796875*^9}, {
    3.55326007428125*^9, 3.553260080015625*^9}, {3.55326017065625*^9, 
    3.553260171640625*^9}, {3.553260240109375*^9, 3.553260240484375*^9}}]
}], "Text",
 CellChangeTimes->{{3.49795814646875*^9, 3.4979581888125*^9}, {
   3.49795824053125*^9, 3.497958316*^9}, {3.497959406296875*^9, 
   3.497959420546875*^9}, {3.498043168328125*^9, 3.498043187546875*^9}, {
   3.498106516515625*^9, 3.49810655075*^9}, 3.498811881546875*^9, {
   3.498827995140625*^9, 3.49882799565625*^9}, 3.49882868975*^9, 
   3.552473872765625*^9, {3.552473968390625*^9, 3.55247402665625*^9}, {
   3.553260807015625*^9, 3.553260815*^9}, {3.553753211917671*^9, 
   3.5537532471483917`*^9}, {3.5537532772628927`*^9, 3.553753310106073*^9}, {
   3.553775339564728*^9, 3.553775388928371*^9}, {3.5538272658268547`*^9, 
   3.553827271558619*^9}, {3.553827318764749*^9, 3.553827365915971*^9}, {
   3.553827426142563*^9, 3.553827457019126*^9}, 3.553828090670125*^9, {
   3.553828174641241*^9, 3.553828202866152*^9}, {3.574943132840713*^9, 
   3.57494313890244*^9}, {3.574943229021974*^9, 3.57494323680661*^9}, {
   3.574943304707011*^9, 3.5749433047071123`*^9}, {3.5750891979997683`*^9, 
   3.575089219260971*^9}, 3.575096334352598*^9, 3.575096473118904*^9, {
   3.575256103776019*^9, 3.575256103960029*^9}, {3.5752576646152935`*^9, 
   3.575257709158841*^9}, {3.575257782423032*^9, 3.575257843126504*^9}, {
   3.5752578804546385`*^9, 3.5752581512341266`*^9}, {3.5752581923994813`*^9, 
   3.5752581943095903`*^9}},
 FontFamily->"Times New Roman",
 FontSize->26,
 FontColor->GrayLevel[0],
 Background->GrayLevel[0.85]],

Cell["\<\
First of all we see the case a. and a case b.with a simple scatch...\
\>", "Text",
 CellChangeTimes->{{3.49795814646875*^9, 3.4979581888125*^9}, {
   3.49795824053125*^9, 3.497958316*^9}, {3.497959406296875*^9, 
   3.497959420546875*^9}, {3.498043168328125*^9, 3.498043187546875*^9}, {
   3.498106516515625*^9, 3.49810655075*^9}, 3.498811881546875*^9, {
   3.498827995140625*^9, 3.49882799565625*^9}, 3.49882868975*^9, 
   3.552473872765625*^9, {3.552473968390625*^9, 3.55247402665625*^9}, {
   3.553260807015625*^9, 3.553260815*^9}, {3.553753211917671*^9, 
   3.5537532471483917`*^9}, {3.5537532772628927`*^9, 3.553753310106073*^9}, {
   3.553775339564728*^9, 3.553775388928371*^9}, {3.5538272658268547`*^9, 
   3.553827271558619*^9}, {3.553827318764749*^9, 3.553827365915971*^9}, {
   3.553827426142563*^9, 3.553827457019126*^9}, 3.553828090670125*^9, {
   3.553828174641241*^9, 3.553828202866152*^9}, {3.574943132840713*^9, 
   3.57494313890244*^9}, {3.574943229021974*^9, 3.57494323680661*^9}, {
   3.574943304707011*^9, 3.5749433047071123`*^9}, {3.5750891979997683`*^9, 
   3.575089219260971*^9}, 3.575096334352598*^9, {3.575096473118904*^9, 
   3.575096549237656*^9}, {3.5752581595596027`*^9, 3.575258181038831*^9}},
 FontFamily->"Times New Roman",
 FontSize->26,
 FontColor->GrayLevel[0],
 Background->GrayLevel[0.85]],

Cell["For the case a,", "Text",
 CellChangeTimes->{{3.49795814646875*^9, 3.4979581888125*^9}, {
   3.49795824053125*^9, 3.497958316*^9}, {3.497959406296875*^9, 
   3.497959420546875*^9}, {3.498043168328125*^9, 3.498043187546875*^9}, {
   3.498106516515625*^9, 3.49810655075*^9}, 3.498811881546875*^9, {
   3.498827995140625*^9, 3.49882799565625*^9}, 3.49882868975*^9, 
   3.552473872765625*^9, {3.552473968390625*^9, 3.55247402665625*^9}, {
   3.553260807015625*^9, 3.553260815*^9}, {3.553753211917671*^9, 
   3.5537532471483917`*^9}, {3.5537532772628927`*^9, 3.553753310106073*^9}, {
   3.553775339564728*^9, 3.553775388928371*^9}, {3.5538272658268547`*^9, 
   3.553827271558619*^9}, {3.553827318764749*^9, 3.553827365915971*^9}, {
   3.553827426142563*^9, 3.553827457019126*^9}, 3.553828090670125*^9, {
   3.553828174641241*^9, 3.553828202866152*^9}, {3.574943132840713*^9, 
   3.57494313890244*^9}, {3.574943229021974*^9, 3.57494323680661*^9}, {
   3.574943304707011*^9, 3.5749433047071123`*^9}, {3.5750891979997683`*^9, 
   3.575089219260971*^9}, 3.575096334352598*^9, {3.575096473118904*^9, 
   3.575096549237656*^9}, {3.5752581595596027`*^9, 3.5752581905423746`*^9}, {
   3.575343501811928*^9, 3.5753435022339163`*^9}},
 FontFamily->"Times New Roman",
 FontSize->26,
 FontColor->GrayLevel[0],
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"Graphics", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"Thick", ",", 
       RowBox[{"Line", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", 
            RowBox[{
             RowBox[{"-", 
              SubscriptBox["a", "0"]}], "/", "15"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", 
            RowBox[{
             SubscriptBox["a", "0"], "/", "15"}]}], "}"}]}], "}"}], "]"}]}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"Thick", ",", 
       RowBox[{"Line", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"0", "+", 
             SubscriptBox["a", "0"]}], ",", 
            RowBox[{
             RowBox[{"-", 
              SubscriptBox["a", "0"]}], "/", "15"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"0", " ", "+", 
             SubscriptBox["a", "0"]}], ",", 
            RowBox[{
             SubscriptBox["a", "0"], "/", "15"}]}], "}"}]}], "}"}], "]"}]}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"Thick", ",", 
       RowBox[{"Line", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"0", "+", 
             RowBox[{"2", " ", 
              SubscriptBox["a", "0"]}]}], ",", 
            RowBox[{
             RowBox[{"-", 
              SubscriptBox["a", "0"]}], "/", "15"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"0", " ", "+", 
             RowBox[{"2", " ", 
              SubscriptBox["a", "0"]}]}], ",", 
            RowBox[{
             SubscriptBox["a", "0"], "/", "15"}]}], "}"}]}], "}"}], "]"}]}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"PointSize", "[", "Large", "]"}], ",", "Orange", ",", 
       RowBox[{"Point", "[", "coord1CG", "]"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"PointSize", "[", "Large", "]"}], ",", "Red", ",", 
       RowBox[{"Point", "[", "coord1CGb", "]"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"PointSize", "[", "Large", "]"}], ",", "Blue", ",", 
       RowBox[{"Point", "[", "coord1CGc", "]"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"Thick", ",", 
       RowBox[{"Line", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", 
             SubscriptBox["a", "0"]}], ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            SubscriptBox["a", "0"], ",", "0"}], "}"}]}], "}"}], "]"}]}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"Thick", ",", 
       RowBox[{"Line", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            SubscriptBox["a", "0"], ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"2", " ", 
             SubscriptBox["a", "0"]}], ",", "0"}], "}"}]}], "}"}], "]"}]}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"Thick", ",", 
       RowBox[{"Line", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"2", 
             SubscriptBox["a", "0"]}], ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"3", " ", 
             SubscriptBox["a", "0"]}], ",", "0"}], "}"}]}], "}"}], "]"}]}], 
      "}"}]}], "\[IndentingNewLine]", "}"}], "]"}], " "}]], "Input",
 CellChangeTimes->{
  3.575090500550215*^9, {3.575092454949616*^9, 3.575092477155217*^9}, {
   3.5750926033963947`*^9, 3.575092610045735*^9}, {3.575092642120648*^9, 
   3.575092647372718*^9}, {3.575092692791471*^9, 3.5750927163497066`*^9}, {
   3.575095671108225*^9, 3.575095695249464*^9}, {3.575095735796382*^9, 
   3.575095783115345*^9}, {3.5750958584840603`*^9, 3.575095892380879*^9}, {
   3.575095987443829*^9, 3.575096072853794*^9}, {3.575107833029068*^9, 
   3.575107845815899*^9}}],

Cell["and, for the case b,", "Text",
 CellChangeTimes->{{3.49795814646875*^9, 3.4979581888125*^9}, {
   3.49795824053125*^9, 3.497958316*^9}, {3.497959406296875*^9, 
   3.497959420546875*^9}, {3.498043168328125*^9, 3.498043187546875*^9}, {
   3.498106516515625*^9, 3.49810655075*^9}, 3.498811881546875*^9, {
   3.498827995140625*^9, 3.49882799565625*^9}, 3.49882868975*^9, 
   3.552473872765625*^9, {3.552473968390625*^9, 3.55247402665625*^9}, {
   3.553260807015625*^9, 3.553260815*^9}, {3.553753211917671*^9, 
   3.5537532471483917`*^9}, {3.5537532772628927`*^9, 3.553753310106073*^9}, {
   3.553775339564728*^9, 3.553775388928371*^9}, {3.5538272658268547`*^9, 
   3.553827271558619*^9}, {3.553827318764749*^9, 3.553827365915971*^9}, {
   3.553827426142563*^9, 3.553827457019126*^9}, 3.553828090670125*^9, {
   3.553828174641241*^9, 3.553828202866152*^9}, {3.574943132840713*^9, 
   3.57494313890244*^9}, {3.574943229021974*^9, 3.57494323680661*^9}, {
   3.574943304707011*^9, 3.5749433047071123`*^9}, {3.5750891979997683`*^9, 
   3.575089219260971*^9}, 3.575096334352598*^9, {3.575096473118904*^9, 
   3.575096549237656*^9}, {3.5752581595596027`*^9, 3.575258202623066*^9}, {
   3.575343491673175*^9, 3.5753435076700783`*^9}},
 FontFamily->"Times New Roman",
 FontSize->26,
 FontColor->GrayLevel[0],
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"Graphics", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"Thick", ",", 
       RowBox[{"Line", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", 
            RowBox[{
             RowBox[{"-", 
              SubscriptBox["a", "0"]}], "/", "15"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", 
            RowBox[{
             SubscriptBox["a", "0"], "/", "15"}]}], "}"}]}], "}"}], "]"}]}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"Thick", ",", 
       RowBox[{"Line", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"0", "+", 
             SubscriptBox["a", "0"]}], ",", 
            RowBox[{
             RowBox[{"-", 
              SubscriptBox["a", "0"]}], "/", "15"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"0", " ", "+", 
             SubscriptBox["a", "0"]}], ",", 
            RowBox[{
             SubscriptBox["a", "0"], "/", "15"}]}], "}"}]}], "}"}], "]"}]}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"Thick", ",", 
       RowBox[{"Line", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"0", "+", 
             RowBox[{"2", " ", 
              SubscriptBox["a", "0"]}]}], ",", 
            RowBox[{
             RowBox[{"-", 
              SubscriptBox["a", "0"]}], "/", "15"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"0", " ", "+", 
             RowBox[{"2", " ", 
              SubscriptBox["a", "0"]}]}], ",", 
            RowBox[{
             SubscriptBox["a", "0"], "/", "15"}]}], "}"}]}], "}"}], "]"}]}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"PointSize", "[", "Large", "]"}], ",", "Orange", ",", 
       RowBox[{"Point", "[", "coord2CG", "]"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"PointSize", "[", "Large", "]"}], ",", "Red", ",", 
       RowBox[{"Point", "[", "coord2CGb", "]"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"PointSize", "[", "Large", "]"}], ",", "Blue", ",", 
       RowBox[{"Point", "[", "coord2CGc", "]"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"Thick", ",", 
       RowBox[{"Line", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", 
             SubscriptBox["a", "0"]}], ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            SubscriptBox["a", "0"], ",", "0"}], "}"}]}], "}"}], "]"}]}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"Thick", ",", 
       RowBox[{"Line", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            SubscriptBox["a", "0"], ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"2", " ", 
             SubscriptBox["a", "0"]}], ",", "0"}], "}"}]}], "}"}], "]"}]}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"Thick", ",", 
       RowBox[{"Line", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"2", 
             SubscriptBox["a", "0"]}], ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"3", " ", 
             SubscriptBox["a", "0"]}], ",", "0"}], "}"}]}], "}"}], "]"}]}], 
      "}"}]}], "\[IndentingNewLine]", "}"}], "]"}], " "}]], "Input",
 CellChangeTimes->{
  3.575090500550215*^9, {3.575092454949616*^9, 3.575092477155217*^9}, {
   3.5750926033963947`*^9, 3.575092610045735*^9}, {3.575092642120648*^9, 
   3.575092647372718*^9}, {3.575092692791471*^9, 3.5750927163497066`*^9}, {
   3.575095671108225*^9, 3.575095695249464*^9}, {3.575095735796382*^9, 
   3.575095783115345*^9}, {3.5750958584840603`*^9, 3.575095892380879*^9}, {
   3.575095987443829*^9, 3.575096072853794*^9}, {3.575096145334983*^9, 
   3.575096145785367*^9}, {3.575096269616613*^9, 3.575096274259282*^9}, {
   3.575107851025537*^9, 3.575107857800099*^9}}]
}, Open  ]],

Cell["\<\
We represent the electronic density function \[Rho][x] of the silicon atom by \
the following function
containing a coefficient coefnorm to be determined,
by imposing the normalization  of the electronic density (in the case of \
silicon Z=14).
Clearly, the period of  Sin[x]^2n is one half of the period of  Sin[x].\
\>", "Text",
 CellChangeTimes->{{3.49795814646875*^9, 3.4979581888125*^9}, {
   3.49795824053125*^9, 3.497958316*^9}, {3.497959406296875*^9, 
   3.497959420546875*^9}, {3.498043168328125*^9, 3.498043187546875*^9}, {
   3.498106516515625*^9, 3.49810655075*^9}, 3.498811881546875*^9, {
   3.498827995140625*^9, 3.49882799565625*^9}, 3.49882868975*^9, 
   3.552473872765625*^9, {3.552473968390625*^9, 3.55247402665625*^9}, {
   3.553260807015625*^9, 3.553260815*^9}, {3.553753211917671*^9, 
   3.5537532471483917`*^9}, {3.5537532772628927`*^9, 3.553753310106073*^9}, {
   3.553775339564728*^9, 3.553775388928371*^9}, {3.5538272658268547`*^9, 
   3.553827271558619*^9}, {3.553827318764749*^9, 3.553827365915971*^9}, {
   3.553827426142563*^9, 3.553827457019126*^9}, 3.553828090670125*^9, {
   3.553828174641241*^9, 3.553828202866152*^9}, {3.574943132840713*^9, 
   3.57494313890244*^9}, {3.574943229021974*^9, 3.57494323680661*^9}, {
   3.574943304707011*^9, 3.5749433047071123`*^9}, {3.5750891979997683`*^9, 
   3.575089219260971*^9}, 3.575096334352598*^9, {3.575096387660264*^9, 
   3.57509638997435*^9}, {3.575096422064083*^9, 3.5750964514221077`*^9}, {
   3.5752582118785954`*^9, 3.5752582306306677`*^9}},
 FontFamily->"Times New Roman",
 FontSize->26,
 FontColor->GrayLevel[0],
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Rho]", "[", "x_", "]"}], "=", 
  RowBox[{"coefnorm", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"Sin", "[", 
      RowBox[{"2", " ", "\[Pi]", " ", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"x", "+", 
          RowBox[{
           SubscriptBox["width", "at"], "/", "2"}]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"2", "*", 
          SubscriptBox["width", "at"]}], ")"}]}]}], "]"}], ")"}], "^", 
    "6"}]}]}]], "Input",
 CellChangeTimes->{{3.428806000296875*^9, 3.4288060590625*^9}, 
   3.49779292540625*^9, {3.497849788171875*^9, 3.497849791703125*^9}, {
   3.497849829203125*^9, 3.497849845859375*^9}, {3.49785269434375*^9, 
   3.497852696*^9}, {3.49785405859375*^9, 3.497854061765625*^9}, {
   3.49785507915625*^9, 3.497855079515625*^9}, 3.497856711921875*^9, {
   3.4978570273125*^9, 3.49785702796875*^9}, {3.4978689468125*^9, 
   3.497868950515625*^9}, {3.497868984640625*^9, 3.4978689888125*^9}, {
   3.4978770133125*^9, 3.49787701775*^9}, {3.497944703328125*^9, 
   3.497944735046875*^9}, {3.497944849859375*^9, 3.49794485071875*^9}, {
   3.497953876109375*^9, 3.49795387746875*^9}, 3.49795399771875*^9, 
   3.49795567959375*^9, {3.4979612845*^9, 3.49796133075*^9}, {
   3.49796154209375*^9, 3.4979615465625*^9}, {3.497962578046875*^9, 
   3.497962589390625*^9}, 3.497962635921875*^9, 3.498043147984375*^9, {
   3.498043273671875*^9, 3.498043279375*^9}, {3.49804346625*^9, 
   3.49804347503125*^9}, {3.498043753203125*^9, 3.49804375465625*^9}, {
   3.498043808703125*^9, 3.498043812453125*^9}, 3.498046689875*^9, {
   3.498047494171875*^9, 3.49804751059375*^9}, {3.55149477534375*^9, 
   3.551494781296875*^9}, {3.551494824203125*^9, 3.55149484725*^9}, 
   3.551494880015625*^9, {3.55149728784375*^9, 3.551497289421875*^9}, {
   3.5532316476875*^9, 3.553231647859375*^9}, {3.553231859171875*^9, 
   3.55323187140625*^9}, {3.55324905078125*^9, 3.55324907203125*^9}, {
   3.553250599953125*^9, 3.5532506140625*^9}, {3.5533432490792913`*^9, 
   3.553343251245709*^9}},
 FontSize->24],

Cell[BoxData[
 RowBox[{"coe", "=", " ", 
  RowBox[{"Solve", "[", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"Integrate", "[", 
      RowBox[{
       RowBox[{"\[Rho]", "[", "x", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", 
          FractionBox[
           SubscriptBox["width", "at"], "2"]}], ",", 
         FractionBox[
          SubscriptBox["width", "at"], "2"]}], " ", "}"}]}], "]"}], 
     "\[Equal]", "14"}], ",", "coefnorm"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.428806000296875*^9, 3.4288060590625*^9}, 
   3.49779292540625*^9, {3.497849788171875*^9, 3.497849791703125*^9}, {
   3.497849829203125*^9, 3.497849845859375*^9}, {3.49785269434375*^9, 
   3.497852696*^9}, {3.49785405859375*^9, 3.497854061765625*^9}, {
   3.49785507915625*^9, 3.497855079515625*^9}, 3.497856711921875*^9, {
   3.4978570273125*^9, 3.49785702796875*^9}, {3.4978689468125*^9, 
   3.497868950515625*^9}, {3.497868984640625*^9, 3.4978689888125*^9}, {
   3.4978770133125*^9, 3.49787701775*^9}, {3.497944703328125*^9, 
   3.497944735046875*^9}, {3.497944849859375*^9, 3.49794485071875*^9}, {
   3.497953876109375*^9, 3.49795387746875*^9}, 3.49795399771875*^9, 
   3.49795567959375*^9, {3.497957553046875*^9, 3.497957577671875*^9}, {
   3.497957677421875*^9, 3.497957715078125*^9}, 3.4979579236875*^9, {
   3.497958027453125*^9, 3.497958039140625*^9}, {3.498043420171875*^9, 
   3.498043448296875*^9}, {3.498043784078125*^9, 3.498043818203125*^9}, {
   3.4980474783125*^9, 3.498047485234375*^9}, {3.553247442828125*^9, 
   3.553247488109375*^9}, {3.553247561296875*^9, 3.553247562859375*^9}, {
   3.553248550875*^9, 3.553248554203125*^9}},
 FontSize->24],

Cell["Simple check.", "Text",
 CellChangeTimes->{{3.553753419543477*^9, 3.553753476721383*^9}, {
  3.553753514339069*^9, 3.553753556975505*^9}, {3.553753594228037*^9, 
  3.553753639319337*^9}, {3.553776476521082*^9, 3.5537766675327187`*^9}, {
  3.553783813271534*^9, 3.5537838254436207`*^9}, {3.574944471895488*^9, 
  3.574944519174021*^9}, {3.574944597242223*^9, 3.574944628498501*^9}, {
  3.574944676006432*^9, 3.5749446837424583`*^9}},
 FontFamily->"Times New Roman",
 FontSize->26,
 FontColor->GrayLevel[0],
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"Integrate", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Rho]", "[", "x", "]"}], " ", "/.", " ", 
     RowBox[{"coefnorm", "\[Rule]", " ", 
      RowBox[{"coe", "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1", ",", "2"}], "]"}], "]"}]}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"x", ",", 
      RowBox[{"-", 
       FractionBox[
        SubscriptBox["width", "at"], "2"]}], ",", 
      FractionBox[
       SubscriptBox["width", "at"], "2"]}], " ", "}"}]}], "]"}], "//", " ", 
  "N"}]], "Input",
 CellChangeTimes->{{3.55324753528125*^9, 3.55324754540625*^9}, {
  3.553247619859375*^9, 3.553247641625*^9}, {3.553247699390625*^9, 
  3.553247701078125*^9}, {3.55324773346875*^9, 3.55324777775*^9}, {
  3.55324858065625*^9, 3.5532485835625*^9}},
 FontSize->24],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Rho]1", "[", "x_", "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"\[Rho]", "[", "x", "]"}], "/.", " ", 
   RowBox[{"coefnorm", "\[Rule]", " ", 
    RowBox[{"coe", "[", 
     RowBox[{"[", 
      RowBox[{"1", ",", "1", ",", "2"}], "]"}], "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.553251009671875*^9, 3.553251053140625*^9}},
 FontSize->24],

Cell[TextData[{
 "To evaluate the coefficients ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[Chi]", "g"], " ", 
    RowBox[{"(", 
     StyleBox[
      RowBox[{"2.2", ".87"}], "Text"], 
     StyleBox[")", "Text"]}], "  ", "it", " ", "is", " ", "convenient", " "}],
    TraditionalForm]]],
 "to consider the electronic density centered at the origin of the cell.\nWe \
will examine later an alternative path."
}], "Text",
 CellChangeTimes->{{3.553753419543477*^9, 3.553753476721383*^9}, {
  3.553753514339069*^9, 3.553753556975505*^9}, {3.553753594228037*^9, 
  3.553753639319337*^9}, {3.553776476521082*^9, 3.5537766675327187`*^9}, {
  3.553783813271534*^9, 3.5537838254436207`*^9}, {3.5749447602150183`*^9, 
  3.574944765764537*^9}, {3.574945033859393*^9, 3.5749450376377974`*^9}, {
  3.575258237068036*^9, 3.575258245198501*^9}},
 FontFamily->"Times New Roman",
 FontSize->26,
 FontColor->GrayLevel[0],
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Rho]1", "[", "x_", "]"}], " ", "=", " ", 
  RowBox[{
   RowBox[{"\[Rho]", "[", "x", "]"}], "/.", " ", 
   RowBox[{"coefnorm", "\[Rule]", " ", 
    RowBox[{"coe", "[", 
     RowBox[{"[", 
      RowBox[{"1", ",", "1", ",", "2"}], "]"}], "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.553251009671875*^9, 3.553251053140625*^9}, 
   3.5537773096955347`*^9},
 FontSize->24],

Cell["\<\
The width of the silicon atom is indicated by the following  two red dots\
\>", "Text",
 CellChangeTimes->{{3.553753419543477*^9, 3.553753476721383*^9}, {
  3.553753514339069*^9, 3.553753556975505*^9}, {3.553753594228037*^9, 
  3.553753639319337*^9}, {3.553776476521082*^9, 3.5537766675327187`*^9}, {
  3.553783813271534*^9, 3.5537838254436207`*^9}, {3.5749447602150183`*^9, 
  3.574944765764537*^9}, {3.574944961816679*^9, 3.5749449981278048`*^9}},
 FontFamily->"Times New Roman",
 FontSize->26,
 FontColor->GrayLevel[0],
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{"graph\[Rho]1", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"\[Rho]1", "[", "x", "]"}], " ", ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["width", "at"]}], "/", "2"}], ",", 
      RowBox[{
       SubscriptBox["width", "at"], "/", "2"}]}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"Epilog", "->", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"PointSize", "[", "0.01", "]"}], ",", "Red", ",", 
       RowBox[{"Point", "[", "coord1CG", "]"}]}], "}"}]}], ",", 
    RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}]], "Input",
 CellChangeTimes->{
  3.4288042703125*^9, {3.49778604878125*^9, 3.49778605965625*^9}, 
   3.4977861058125*^9, {3.49785387028125*^9, 3.497853884921875*^9}, 
   3.49785671559375*^9, {3.497857394734375*^9, 3.497857397078125*^9}, 
   3.49786902040625*^9, 3.4978770305*^9, {3.497944771953125*^9, 
   3.49794477259375*^9}, {3.4979448625625*^9, 3.4979448636875*^9}, {
   3.4979540598125*^9, 3.497954172265625*^9}, {3.497955714734375*^9, 
   3.497955717125*^9}, {3.49795838578125*^9, 3.497958388171875*^9}, 
   3.497961577203125*^9, {3.497961713953125*^9, 3.497961715859375*^9}, {
   3.497961849203125*^9, 3.49796195371875*^9}, {3.497962691828125*^9, 
   3.497962719796875*^9}, {3.4979630325*^9, 3.49796307140625*^9}, {
   3.49796322521875*^9, 3.49796323203125*^9}, {3.497963678203125*^9, 
   3.49796369953125*^9}, {3.497963735796875*^9, 3.497963738140625*^9}, {
   3.497964055828125*^9, 3.497964059265625*^9}, {3.49796409296875*^9, 
   3.497964095546875*^9}, {3.497965051734375*^9, 3.497965055*^9}, {
   3.49804353478125*^9, 3.498043555296875*^9}, {3.498043595328125*^9, 
   3.4980435973125*^9}, {3.49804363465625*^9, 3.49804364075*^9}, 
   3.498043686078125*^9, {3.498043725515625*^9, 3.49804374590625*^9}, {
   3.49804385228125*^9, 3.498043854109375*^9}, 3.498043985703125*^9, 
   3.4980440170625*^9, 3.498046689890625*^9, 3.4980475526875*^9, {
   3.55149489528125*^9, 3.55149489840625*^9}, {3.551495004671875*^9, 
   3.55149501709375*^9}, {3.551497540078125*^9, 3.5514975621875*^9}, {
   3.5514976541875*^9, 3.551497654796875*^9}, 3.5514979865*^9, {
   3.551498275953125*^9, 3.5514982804375*^9}, {3.551498313609375*^9, 
   3.551498354703125*^9}, 3.5514984259375*^9, {3.551498623046875*^9, 
   3.5514986278125*^9}, {3.55149871228125*^9, 3.551498712859375*^9}, {
   3.551498783921875*^9, 3.55149879471875*^9}, 3.551498872234375*^9, {
   3.55158288580766*^9, 3.5515828866717463`*^9}, {3.551767493671875*^9, 
   3.551767503609375*^9}, {3.551767559015625*^9, 3.551767560015625*^9}, {
   3.551767594671875*^9, 3.551767598328125*^9}, 3.551767963671875*^9, {
   3.553231775125*^9, 3.553231781015625*^9}, {3.55323182396875*^9, 
   3.553231833640625*^9}, {3.553231882578125*^9, 3.55323189565625*^9}, {
   3.553249080578125*^9, 3.55324908346875*^9}, 3.55325096315625*^9, 
   3.553251023390625*^9, 3.55325109021875*^9, {3.55325594278125*^9, 
   3.553256004140625*^9}, {3.55325604009375*^9, 3.55325604071875*^9}, 
   3.553256202015625*^9, {3.553776408942176*^9, 3.55377643997792*^9}},
 FontSize->24],

Cell["\<\
As the function is intrinsically periodic, we could  take advantage of the \
following command
to restrict the domain of the electronc  density\
\>", "Text",
 CellChangeTimes->{{3.553753419543477*^9, 3.553753476721383*^9}, {
  3.553753514339069*^9, 3.553753556975505*^9}, {3.553753594228037*^9, 
  3.553753639319337*^9}, {3.553776476521082*^9, 3.5537766675327187`*^9}, {
  3.553776782357346*^9, 3.553776823902068*^9}, {3.553776893748953*^9, 
  3.5537768945932207`*^9}, {3.5537770827883577`*^9, 3.553777155219255*^9}},
 FontFamily->"Times New Roman",
 FontSize->26,
 FontColor->GrayLevel[0],
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Rho]p", "[", "x_", "]"}], ":=", 
  RowBox[{"Piecewise", "[", 
   RowBox[{"{", "    ", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\[Rho]1", "[", "x", "]"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SubscriptBox["width", "at"]}], "/", "2"}], "\[LessEqual]", "x", 
        "\[LessEqual]", 
        RowBox[{
         SubscriptBox["width", "at"], "/", "2"}]}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     "                                                       ", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SubscriptBox["width", "at"]}], "/", "2"}], " ", "\[LessEqual]", " ",
         "x", " ", "\[GreaterEqual]", " ", 
        RowBox[{
         SubscriptBox["width", "at"], "/", "2"}]}]}], "}"}]}], 
    "\[IndentingNewLine]", "                                    ", "}"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.551498491640625*^9, 3.5514986003125*^9}, 
   3.55149887221875*^9, {3.551767390609375*^9, 3.5517674035625*^9}, {
   3.55176789890625*^9, 3.55176795065625*^9}, {3.551767999828125*^9, 
   3.551768017375*^9}, 3.5517681059375*^9, {3.553231940296875*^9, 
   3.553231952640625*^9}, {3.553231999359375*^9, 3.553232080390625*^9}, {
   3.553249092765625*^9, 3.553249100859375*^9}, 3.55325110878125*^9, {
   3.553776866432743*^9, 3.553776868500639*^9}},
 FontSize->24],

Cell[BoxData[
 RowBox[{"graph\[Rho]p", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"\[Rho]p", "[", "x", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", 
      RowBox[{
       RowBox[{"-", "3"}], 
       SubscriptBox["width", "at"]}], ",", 
      RowBox[{"3", 
       SubscriptBox["width", "at"]}]}], " ", "}"}], ",", 
    RowBox[{"Epilog", "->", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"PointSize", "[", "0.01", "]"}], ",", "Red", ",", 
       RowBox[{"Point", "[", "coord1CG", "]"}]}], "}"}]}], ",", 
    RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}]], "Input",
 CellChangeTimes->{
  3.4288042703125*^9, {3.49778604878125*^9, 3.49778605965625*^9}, 
   3.4977861058125*^9, {3.49785387028125*^9, 3.497853884921875*^9}, 
   3.49785671559375*^9, {3.497857394734375*^9, 3.497857397078125*^9}, 
   3.49786902040625*^9, 3.4978770305*^9, {3.497944771953125*^9, 
   3.49794477259375*^9}, {3.4979448625625*^9, 3.4979448636875*^9}, {
   3.4979540598125*^9, 3.497954172265625*^9}, {3.497955714734375*^9, 
   3.497955717125*^9}, {3.49795838578125*^9, 3.497958388171875*^9}, 
   3.497961577203125*^9, {3.497961713953125*^9, 3.497961715859375*^9}, {
   3.497961849203125*^9, 3.49796195371875*^9}, {3.497962691828125*^9, 
   3.497962719796875*^9}, {3.4979630325*^9, 3.49796307140625*^9}, {
   3.49796322521875*^9, 3.49796323203125*^9}, {3.497963678203125*^9, 
   3.49796369953125*^9}, {3.497963735796875*^9, 3.497963738140625*^9}, {
   3.497964055828125*^9, 3.497964059265625*^9}, {3.49796409296875*^9, 
   3.497964095546875*^9}, {3.497965051734375*^9, 3.497965055*^9}, {
   3.49804353478125*^9, 3.498043555296875*^9}, {3.498043595328125*^9, 
   3.4980435973125*^9}, {3.49804363465625*^9, 3.49804364075*^9}, 
   3.498043686078125*^9, {3.498043725515625*^9, 3.49804374590625*^9}, {
   3.49804385228125*^9, 3.498043854109375*^9}, 3.498043985703125*^9, 
   3.4980440170625*^9, 3.498046689890625*^9, 3.4980475526875*^9, {
   3.55149489528125*^9, 3.55149489840625*^9}, {3.551495004671875*^9, 
   3.55149501709375*^9}, {3.551497540078125*^9, 3.5514975621875*^9}, {
   3.5514976541875*^9, 3.551497654796875*^9}, 3.5514979865*^9, {
   3.551498275953125*^9, 3.5514982804375*^9}, {3.551498313609375*^9, 
   3.551498354703125*^9}, 3.5514984259375*^9, {3.551498623046875*^9, 
   3.5514986278125*^9}, {3.55149871228125*^9, 3.551498712859375*^9}, {
   3.551498783921875*^9, 3.55149879471875*^9}, 3.551498872234375*^9, {
   3.55158288580766*^9, 3.5515828866717463`*^9}, {3.551767493671875*^9, 
   3.551767503609375*^9}, {3.551767559015625*^9, 3.551767560015625*^9}, {
   3.551767594671875*^9, 3.551767598328125*^9}, 3.551767963671875*^9, {
   3.553232093328125*^9, 3.553232114203125*^9}, {3.55324910453125*^9, 
   3.553249107359375*^9}, 3.55325610815625*^9, 3.553256212375*^9, {
   3.553777183128254*^9, 3.553777232802731*^9}},
 FontSize->24],

Cell[TextData[{
 "Among the various possibilities regarding the definition of the FT we have \
chosen\n\n",
 Cell[BoxData[
  RowBox[{"\t ", 
   RowBox[{
    RowBox[{"F", 
     RowBox[{"(", "\[Omega]", ")"}]}], "=", " ", 
    RowBox[{
     SubsuperscriptBox["\[Integral]", 
      RowBox[{"-", "\[Infinity]"}], "\[Infinity]"], 
     RowBox[{"f", 
      RowBox[{"(", "x", ")"}], 
      SuperscriptBox["e", "i\[Omega]x"], " ", "dx"}]}]}]}]], "Text",
  CellChangeTimes->{{3.553750551441822*^9, 3.5537505594330397`*^9}}],
 "\n\nand\n\n",
 Cell[BoxData[
  RowBox[{"           ", 
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", "x", ")"}]}], "=", 
    RowBox[{
     RowBox[{"1", "/", 
      RowBox[{"(", 
       RowBox[{"2", " ", "\[Pi]"}], ")"}]}], " ", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", 
       RowBox[{"-", "\[Infinity]"}], "\[Infinity]"], 
      RowBox[{"F", 
       RowBox[{"(", "\[Omega]", ")"}], 
       SuperscriptBox["e", 
        RowBox[{"-", "i\[Omega]x"}]], " ", "d\[Omega]"}]}]}]}]}]], "Text",
  CellChangeTimes->{{3.553750551441822*^9, 3.5537505594330397`*^9}}],
 ",\n\nin our case \[Omega] = ",
 Cell[BoxData[
  SubscriptBox["g", "x"]], "Input",
  CellChangeTimes->{{3.481001763312841*^9, 3.48100179025881*^9}, {
    3.4810018259402733`*^9, 3.4810018281991377`*^9}, 3.481002082124165*^9, {
    3.481002118911682*^9, 3.481002131067219*^9}, {3.481002194106564*^9, 
    3.481002196919539*^9}, {3.481002527406123*^9, 3.481002572078869*^9}, {
    3.481002767103146*^9, 3.48100298801945*^9}, {3.48100945135767*^9, 
    3.481009473760816*^9}, {3.481024658821968*^9, 3.481024659686016*^9}, {
    3.481210836970812*^9, 3.48121086500147*^9}, {3.4812645359106483`*^9, 
    3.4812645431625843`*^9}, {3.481288876335642*^9, 3.481288883106428*^9}, {
    3.481346420242552*^9, 3.4813464414352503`*^9}, 3.4813464915825367`*^9, {
    3.481346539256961*^9, 3.481346592577322*^9}, {3.481346697650846*^9, 
    3.481346737781479*^9}, 3.4972688164375*^9, 3.497269677765625*^9, {
    3.4972700479375*^9, 3.49727006065625*^9}, {3.497349793359375*^9, 
    3.497349866609375*^9}, {3.497350186171875*^9, 3.4973501984375*^9}, 
    3.49735073321875*^9, 3.49752423409375*^9, {3.497524603109375*^9, 
    3.49752461078125*^9}, {3.497524722765625*^9, 3.497524756953125*^9}, {
    3.497524859671875*^9, 3.497524878296875*^9}, {3.497526379953125*^9, 
    3.497526389421875*^9}, {3.497597337203125*^9, 3.49759735246875*^9}, {
    3.49759739434375*^9, 3.497597400515625*^9}, {3.49897815*^9, 
    3.498978157*^9}, {3.4990040203125*^9, 3.49900403603125*^9}, {
    3.499004145109375*^9, 3.4990041596875*^9}, {3.49916645034375*^9, 
    3.499166466*^9}, 3.499324277265625*^9, {3.49932443321875*^9, 
    3.499324434078125*^9}, {3.499325565359375*^9, 3.499325568421875*^9}, 
    3.499430386359375*^9, 3.499435892453125*^9, {3.499524490035037*^9, 
    3.499524501421846*^9}, {3.499524783782597*^9, 3.499524803126767*^9}, {
    3.499524834765884*^9, 3.499524956395052*^9}, {3.499525031168552*^9, 
    3.499525107509087*^9}, {3.499525153602892*^9, 3.4995251561980762`*^9}, {
    3.499582086164734*^9, 3.499582089972714*^9}, {3.499582185932995*^9, 
    3.499582192408908*^9}, {3.4995822822983027`*^9, 3.4995824039406643`*^9}, {
    3.499582494360783*^9, 3.499582550277582*^9}, {3.4995826542132263`*^9, 
    3.4995826763908253`*^9}, 3.499582715102212*^9, {3.499598836671875*^9, 
    3.499598849921875*^9}, {3.499608029140625*^9, 3.4996080315625*^9}, {
    3.499769634953125*^9, 3.49976967396875*^9}, 3.499770699515625*^9, {
    3.49977074928125*^9, 3.499770789953125*^9}, {3.499771024859375*^9, 
    3.499771051828125*^9}, {3.49977189534375*^9, 3.499771898046875*^9}, {
    3.500021736530417*^9, 3.500021744056431*^9}, {3.500099837477235*^9, 
    3.500099868264522*^9}, {3.500105749414968*^9, 3.5001057498622627`*^9}, {
    3.55204614034375*^9, 3.55204617309375*^9}, {3.552046215828125*^9, 
    3.552046227046875*^9}, 3.5520463241875*^9, {3.552046654328125*^9, 
    3.552046656609375*^9}, {3.552046831421875*^9, 3.552046833453125*^9}, {
    3.552047259265625*^9, 3.552047262375*^9}, {3.55210335371875*^9, 
    3.552103367984375*^9}, {3.5524751661875*^9, 3.55247518640625*^9}, 
    3.553251219671875*^9, {3.553398097704089*^9, 3.553398098274935*^9}},
  FontSize->24],
 "\n"
}], "Text",
 CellChangeTimes->{{3.553753419543477*^9, 3.553753476721383*^9}, {
  3.553753514339069*^9, 3.553753556975505*^9}, {3.553753594228037*^9, 
  3.553753639319337*^9}, {3.553753675149734*^9, 3.553753703681539*^9}, {
  3.553753780424994*^9, 3.553753911022949*^9}, {3.553777415704143*^9, 
  3.553777436295158*^9}, {3.553777484398322*^9, 3.553777530946208*^9}, {
  3.5537838447981157`*^9, 3.553783877309123*^9}},
 FontFamily->"Times New Roman",
 FontSize->26,
 FontColor->GrayLevel[0],
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  SubscriptBox["FT", "at"], "=", 
  RowBox[{"(", 
   RowBox[{"Timing", "[", 
    RowBox[{"FourierTransform", "[", 
     RowBox[{
      RowBox[{"\[Rho]p", "[", "x", "]"}], ",", "x", ",", 
      SubscriptBox["g", "x"], 
      StyleBox[",",
       FontColor->RGBColor[0, 0, 1]], 
      RowBox[{"FourierParameters", "->", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}]}]}], "]"}], "]"}], ")"}]}]], "Input",
 CellChangeTimes->{{3.481001763312841*^9, 3.48100179025881*^9}, {
   3.4810018259402733`*^9, 3.4810018281991377`*^9}, 3.481002082124165*^9, {
   3.481002118911682*^9, 3.481002131067219*^9}, {3.481002194106564*^9, 
   3.481002196919539*^9}, {3.481002527406123*^9, 3.481002572078869*^9}, {
   3.481002767103146*^9, 3.48100298801945*^9}, {3.48100945135767*^9, 
   3.481009473760816*^9}, {3.481024658821968*^9, 3.481024659686016*^9}, {
   3.481210836970812*^9, 3.48121086500147*^9}, {3.4812645359106483`*^9, 
   3.4812645431625843`*^9}, {3.481288876335642*^9, 3.481288883106428*^9}, {
   3.481346420242552*^9, 3.4813464414352503`*^9}, 3.4813464915825367`*^9, {
   3.481346539256961*^9, 3.481346592577322*^9}, {3.481346697650846*^9, 
   3.481346737781479*^9}, 3.4972688164375*^9, 3.497269677765625*^9, {
   3.4972700479375*^9, 3.49727006065625*^9}, {3.497349793359375*^9, 
   3.497349866609375*^9}, {3.497350186171875*^9, 3.4973501984375*^9}, 
   3.49735073321875*^9, 3.49752423409375*^9, {3.497524603109375*^9, 
   3.49752461078125*^9}, {3.497524722765625*^9, 3.497524756953125*^9}, {
   3.497524859671875*^9, 3.497524878296875*^9}, {3.497526379953125*^9, 
   3.497526389421875*^9}, {3.497597337203125*^9, 3.49759735246875*^9}, {
   3.49759739434375*^9, 3.497597400515625*^9}, {3.49897815*^9, 
   3.498978157*^9}, {3.4990040203125*^9, 3.49900403603125*^9}, {
   3.499004145109375*^9, 3.4990041596875*^9}, {3.49916645034375*^9, 
   3.499166466*^9}, 3.499324277265625*^9, {3.49932443321875*^9, 
   3.499324434078125*^9}, {3.499325565359375*^9, 3.499325568421875*^9}, 
   3.499430386359375*^9, 3.499435892453125*^9, {3.499524490035037*^9, 
   3.499524501421846*^9}, {3.499524783782597*^9, 3.499524803126767*^9}, {
   3.499524834765884*^9, 3.499524956395052*^9}, {3.499525031168552*^9, 
   3.499525107509087*^9}, {3.499525153602892*^9, 3.4995251561980762`*^9}, {
   3.499582086164734*^9, 3.499582089972714*^9}, {3.499582185932995*^9, 
   3.499582192408908*^9}, {3.4995822822983027`*^9, 3.4995824039406643`*^9}, {
   3.499582494360783*^9, 3.499582550277582*^9}, {3.4995826542132263`*^9, 
   3.4995826763908253`*^9}, 3.499582715102212*^9, {3.499598836671875*^9, 
   3.499598849921875*^9}, {3.499608029140625*^9, 3.4996080315625*^9}, {
   3.499769634953125*^9, 3.49976967396875*^9}, 3.499770699515625*^9, {
   3.49977074928125*^9, 3.499770789953125*^9}, {3.499771024859375*^9, 
   3.499771051828125*^9}, {3.49977189534375*^9, 3.499771898046875*^9}, {
   3.500021736530417*^9, 3.500021744056431*^9}, {3.500099837477235*^9, 
   3.500099868264522*^9}, {3.500105749414968*^9, 3.5001057498622627`*^9}, {
   3.55204614034375*^9, 3.55204617309375*^9}, {3.552046215828125*^9, 
   3.552046227046875*^9}, 3.5520463241875*^9, {3.552046654328125*^9, 
   3.552046656609375*^9}, {3.552046831421875*^9, 3.552046833453125*^9}, {
   3.552047259265625*^9, 3.552047262375*^9}, {3.55210335371875*^9, 
   3.552103367984375*^9}, {3.5524751661875*^9, 3.55247518640625*^9}, 
   3.553251219671875*^9, {3.553398097704089*^9, 3.553398098274935*^9}, {
   3.5537775458785553`*^9, 3.553777574275655*^9}},
 FontSize->18,
 CellID->53852264],

Cell[BoxData[
 RowBox[{
  SubscriptBox["FT", "at"], "[", 
  RowBox[{"[", "2", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.553232549046875*^9, 3.553232580203125*^9}, 
   3.553251236234375*^9},
 FontSize->18],

Cell[BoxData[
 RowBox[{
  RowBox[{
   StyleBox["Let",
    FontWeight->"Plain"], 
   StyleBox[" ",
    FontWeight->"Plain"], 
   StyleBox["us",
    FontWeight->"Plain"], 
   StyleBox[" ",
    FontWeight->"Plain"], 
   StyleBox["calculate",
    FontWeight->"Plain"], 
   StyleBox[" ",
    FontWeight->"Plain"], 
   StyleBox["the",
    FontWeight->"Plain"], 
   StyleBox[" ",
    FontWeight->"Plain"], 
   RowBox[{
    StyleBox[
     SubscriptBox["FT", "at"],
     FontWeight->"Bold"], 
    StyleBox[" ",
     FontWeight->"Bold"], 
    StyleBox["@",
     FontWeight->"Bold"], "certain"}], " ", "values", " ", "of", 
   StyleBox[" ",
    FontWeight->"Bold"], 
   StyleBox["g",
    FontWeight->"Bold"]}], 
  StyleBox[" ",
   FontWeight->"Bold"], "..."}]], "Text",
 CellChangeTimes->{{3.553260861796875*^9, 3.553260880921875*^9}, {
  3.55326095890625*^9, 3.553260971875*^9}, {3.553398246128132*^9, 
  3.553398291961837*^9}, {3.5752582659696894`*^9, 3.5752583088171396`*^9}},
 FontFamily->"Times New Roman",
 FontSize->26,
 FontColor->GrayLevel[0],
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{"Limit", "[", 
  RowBox[{
   RowBox[{
    SubscriptBox["FT", "at"], "[", 
    RowBox[{"[", "2", "]"}], "]"}], ",", " ", 
   RowBox[{
    SubscriptBox["g", "x"], " ", "\[Rule]", "0"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5532323323125*^9, 3.553232383328125*^9}, {
   3.553251242421875*^9, 3.553251250046875*^9}, {3.5533981255386744`*^9, 
   3.5533981260102367`*^9}, 3.553398329812833*^9},
 FontSize->24],

Cell[BoxData[
 RowBox[{
  RowBox[{"Limit", "[", 
   RowBox[{
    RowBox[{
     SubscriptBox["FT", "at"], "[", 
     RowBox[{"[", "2", "]"}], "]"}], ",", " ", 
    RowBox[{
     SubscriptBox["g", "x"], " ", "\[Rule]", 
     FractionBox[
      RowBox[{"2", " ", "\[Pi]"}], 
      SubscriptBox["a", "0"]]}]}], "]"}], "//", "N"}]], "Input",
 CellChangeTimes->{{3.5532323323125*^9, 3.553232383328125*^9}, {
   3.553232425828125*^9, 3.553232456546875*^9}, {3.5532512575*^9, 
   3.553251261296875*^9}, 3.553251339828125*^9, {3.5533981296512403`*^9, 
   3.553398129729288*^9}, 3.5533983519414883`*^9},
 FontSize->24],

Cell[BoxData[
 RowBox[{
  RowBox[{"Limit", "[", 
   RowBox[{
    RowBox[{
     SubscriptBox["FT", "at"], "[", 
     RowBox[{"[", "2", "]"}], "]"}], ",", " ", 
    RowBox[{
     SubscriptBox["g", "x"], " ", "\[Rule]", 
     RowBox[{"2", " ", "*", " ", 
      FractionBox[
       RowBox[{"2", " ", "\[Pi]"}], 
       SubscriptBox["a", "0"]]}]}]}], "]"}], "//", "N", 
  "          "}]], "Input",
 CellChangeTimes->{{3.5532323323125*^9, 3.553232383328125*^9}, {
   3.553232425828125*^9, 3.553232456546875*^9}, {3.5532512575*^9, 
   3.5532513319375*^9}, {3.553398133170833*^9, 3.553398133228321*^9}, 
   3.5533983563555727`*^9, {3.574947418797392*^9, 3.5749474420010223`*^9}, 
   3.5753474642418613`*^9},
 FontSize->24],

Cell[" ...after  some attempts, we find convenient  nterm1=50", "Text",
 CellChangeTimes->{{3.553777643614771*^9, 3.553777661656756*^9}, {
  3.5752583161915617`*^9, 3.5752583223669147`*^9}},
 FontFamily->"Times New Roman",
 FontSize->26,
 FontColor->GrayLevel[0],
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"nterm1", "=", "50"}], ";"}], "            "}]], "Input",
 CellChangeTimes->{{3.55325954446875*^9, 3.55325955696875*^9}, {
  3.553753924126307*^9, 3.5537539372097483`*^9}, {3.5537548074246197`*^9, 
  3.553754811983869*^9}, {3.5537776027509937`*^9, 3.55377763834305*^9}},
 FontSize->24],

Cell[BoxData[
 RowBox[{
  SubscriptBox["coef$tab$50FT", "at"], "=", " ", 
  RowBox[{
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"Limit", "[", 
      RowBox[{
       RowBox[{
        SubscriptBox["FT", "at"], "[", 
        RowBox[{"[", "2", "]"}], "]"}], ",", " ", 
       RowBox[{
        SubscriptBox["g", "x"], " ", "\[Rule]", 
        RowBox[{"n", "  ", 
         FractionBox[
          RowBox[{"2", " ", "\[Pi]"}], 
          SubscriptBox["a", "0"]]}]}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"n", ",", 
       RowBox[{"-", "nterm1"}], ",", "nterm1"}], "}"}]}], "]"}], "//", 
   "N"}]}]], "Input",
 CellChangeTimes->{{3.5532323323125*^9, 3.553232383328125*^9}, {
  3.553232425828125*^9, 3.55323251878125*^9}, {3.553232588921875*^9, 
  3.55323259021875*^9}, {3.553233253515625*^9, 3.553233254453125*^9}, {
  3.55323393575*^9, 3.5532339373125*^9}, {3.553236095828125*^9, 
  3.553236099984375*^9}, {3.553236160828125*^9, 3.55323616578125*^9}, {
  3.553249281984375*^9, 3.553249283984375*^9}, {3.55324960325*^9, 
  3.55324960446875*^9}, {3.553251364921875*^9, 3.553251411*^9}, {
  3.553252667828125*^9, 3.5532526681875*^9}, {3.553259518484375*^9, 
  3.553259536875*^9}, {3.553398138359424*^9, 3.553398140819633*^9}, {
  3.553754177079156*^9, 3.5537541787979593`*^9}},
 FontSize->24],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["coef$func$F50FT", "at"], "[", "n_", "]"}], ":=", " ", 
  RowBox[{
   RowBox[{"Limit", "[", 
    RowBox[{
     RowBox[{
      SubscriptBox["FT", "at"], "[", 
      RowBox[{"[", "2", "]"}], "]"}], ",", " ", 
     RowBox[{
      SubscriptBox["g", "x"], " ", "\[Rule]", 
      RowBox[{"n", "  ", 
       FractionBox[
        RowBox[{"2", " ", "\[Pi]"}], 
        SubscriptBox["a", "0"]]}]}]}], "]"}], "//", "N"}]}]], "Input",
 CellChangeTimes->{{3.5532323323125*^9, 3.553232383328125*^9}, {
  3.553232425828125*^9, 3.55323251878125*^9}, {3.553232588921875*^9, 
  3.55323259021875*^9}, {3.553233253515625*^9, 3.553233254453125*^9}, {
  3.55323393575*^9, 3.5532339373125*^9}, {3.553236095828125*^9, 
  3.553236099984375*^9}, {3.553236160828125*^9, 3.55323616578125*^9}, {
  3.553249281984375*^9, 3.553249283984375*^9}, {3.55324960325*^9, 
  3.55324960446875*^9}, {3.553251364921875*^9, 3.553251411*^9}, {
  3.553252667828125*^9, 3.5532526681875*^9}, {3.553259518484375*^9, 
  3.553259536875*^9}, {3.553397723996784*^9, 3.553397796722617*^9}, {
  3.5533981458934393`*^9, 3.553398146333048*^9}, {3.553754197028943*^9, 
  3.553754201863378*^9}},
 FontSize->24],

Cell[BoxData[
 RowBox[{"Vol1D", "=", " ", 
  RowBox[{
   RowBox[{"-", 
    FractionBox["1", 
     SubscriptBox["a", "0"]]}], 
   FractionBox[
    RowBox[{
     SubscriptBox["r", "e"], " ", 
     SuperscriptBox["\[Lambda]", "2"]}], "\[Pi]"]}]}]], "Input",
 CellChangeTimes->{
  3.553235597390625*^9, {3.553251523203125*^9, 3.553251554421875*^9}, {
   3.553251837703125*^9, 3.55325188546875*^9}, {3.553259297875*^9, 
   3.553259303359375*^9}, 3.553260996109375*^9},
 FontSize->24],

Cell[TextData[{
 "We have two options now...\n\ni) we reconstruct the ( 2.2.98) in the case \
that the two silicon atoms\nare  @  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["CG", "1"], " "}]], "Input",
  CellChangeTimes->{{3.553399171863435*^9, 3.55339917870542*^9}, {
    3.553399220329187*^9, 3.553399231455578*^9}, 3.55339927878718*^9, {
    3.553775575947589*^9, 3.5537756788945*^9}, {3.553775816643363*^9, 
    3.553775823386682*^9}, 3.5537773469258823`*^9},
  FontSize->24],
 " and ",
 Cell[BoxData[
  SubscriptBox["CG", "2"]], "Input",
  CellChangeTimes->{{3.553399171863435*^9, 3.55339917870542*^9}, {
    3.553399220329187*^9, 3.553399231455578*^9}, 3.55339927878718*^9, {
    3.553775575947589*^9, 3.5537756788945*^9}, {3.553775816643363*^9, 
    3.553775823386682*^9}, 3.5537773469258823`*^9},
  FontSize->24]
}], "Text",
 CellChangeTimes->{{3.553261113984375*^9, 3.553261152046875*^9}, {
   3.5537540034918547`*^9, 3.553754062388558*^9}, {3.5537643309436693`*^9, 
   3.553764348539936*^9}, {3.5537777025606623`*^9, 3.553777783320912*^9}, {
   3.553777822966282*^9, 3.553777871746028*^9}, {3.553777902635889*^9, 
   3.553777949928587*^9}, {3.553778272869059*^9, 3.553778272869199*^9}, 
   3.553826860073675*^9, {3.57494749397497*^9, 3.574947543203638*^9}, 
   3.57509737173516*^9, {3.575097405161908*^9, 3.5750974067037497`*^9}, {
   3.5750975248979187`*^9, 3.575097544770369*^9}, {3.575258333072527*^9, 
   3.575258361343144*^9}},
 FontFamily->"Times New Roman",
 FontSize->26,
 FontColor->GrayLevel[0],
 Background->GrayLevel[0.85]],

Cell[" We can create a function...", "Text",
 CellChangeTimes->{{3.553777643614771*^9, 3.553777661656756*^9}, {
  3.5537781750300694`*^9, 3.553778186471857*^9}, {3.575258372702794*^9, 
  3.5752583829983826`*^9}},
 FontFamily->"Times New Roman",
 FontSize->26,
 FontColor->GrayLevel[0],
 Background->GrayLevel[0.85]],

Cell[" We can creta a function", "Text",
 CellChangeTimes->{{3.553777643614771*^9, 3.553777661656756*^9}, {
  3.5537781750300694`*^9, 3.553778186471857*^9}},
 FontSize->24],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Chi]func50", "[", "x_", "]"}], "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"ExpToTrig", "[", 
     RowBox[{"Sum", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Exp", "[", 
         RowBox[{"I", " ", 
          FractionBox[
           RowBox[{"2", "  ", "\[Pi]", " ", "n", " ", "x"}], 
           SubscriptBox["a", "0"]]}], "]"}], "*", 
        RowBox[{
         SubscriptBox["coef$func$F50FT", "at"], "[", "n", "]"}], "*", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Exp", "[", 
           RowBox[{
            RowBox[{"-", "I"}], " ", 
            FractionBox[
             RowBox[{"2", "  ", "\[Pi]", " ", "n"}], "8"]}], "]"}], " ", "+", 
          " ", 
          RowBox[{"Exp", "[", 
           RowBox[{
            RowBox[{"-", "I"}], " ", 
            FractionBox[
             RowBox[{"2", " ", "\[Pi]", " ", "n", " ", "7", " "}], "8"]}], 
           "]"}]}], ")"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"n", ",", 
         RowBox[{"-", "nterm1"}], ",", "nterm1"}], "}"}]}], "]"}], "]"}], "//",
     "N"}], " ", "//", "Chop"}]}]], "Input",
 CellChangeTimes->{{3.55323332190625*^9, 3.553233452296875*^9}, {
   3.553233546296875*^9, 3.553233643078125*^9}, {3.553233674296875*^9, 
   3.55323369940625*^9}, {3.553233745359375*^9, 3.5532337625*^9}, 
   3.55323385990625*^9, {3.553233929109375*^9, 3.55323393034375*^9}, {
   3.5532340236875*^9, 3.553234031234375*^9}, {3.55323531940625*^9, 
   3.553235327859375*^9}, {3.553235393484375*^9, 3.55323544403125*^9}, {
   3.553236356890625*^9, 3.5532363763125*^9}, {3.553249517125*^9, 
   3.5532495475*^9}, {3.55324962609375*^9, 3.553249654703125*^9}, {
   3.553251430734375*^9, 3.5532514450625*^9}, {3.553252686609375*^9, 
   3.553252692265625*^9}, {3.55325957378125*^9, 3.5532595796875*^9}, {
   3.55326007428125*^9, 3.553260080015625*^9}, {3.55326017065625*^9, 
   3.553260171640625*^9}, {3.553260240109375*^9, 3.553260240484375*^9}, {
   3.5533441132964077`*^9, 3.553344122765182*^9}, {3.553397813566637*^9, 
   3.553397841979066*^9}, {3.5537542298623123`*^9, 3.5537542330103817`*^9}, {
   3.553754445962132*^9, 3.5537544473885517`*^9}, {3.5537844991241293`*^9, 
   3.5537845374771957`*^9}},
 FontSize->18],

Cell[" ...ore a table  (less convenient)", "Text",
 CellChangeTimes->{{3.553777643614771*^9, 3.553777661656756*^9}, {
  3.5537781750300694`*^9, 3.553778214834873*^9}, {3.5752583797031946`*^9, 
  3.5752583799432077`*^9}},
 FontFamily->"Times New Roman",
 FontSize->26,
 FontColor->GrayLevel[0],
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Chi]tab50", "[", "x_", "]"}], "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"ExpToTrig", "[", 
     RowBox[{"Sum", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Exp", "[", 
         RowBox[{"I", " ", 
          FractionBox[
           RowBox[{"2", "  ", "\[Pi]", " ", "n", " ", "x"}], 
           SubscriptBox["a", "0"]]}], "]"}], "*", 
        RowBox[{
         SubscriptBox["coef$tab$50FT", "at"], "[", 
         RowBox[{"[", 
          RowBox[{"n", "+", "nterm1", "+", "1"}], "]"}], "]"}], "*", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Exp", "[", 
           RowBox[{
            RowBox[{"-", "I"}], " ", 
            FractionBox[
             RowBox[{"2", "  ", "\[Pi]", " ", "n"}], "8"]}], "]"}], " ", "+", 
          " ", 
          RowBox[{"Exp", "[", 
           RowBox[{
            RowBox[{"-", "I"}], " ", 
            FractionBox[
             RowBox[{"2", " ", "\[Pi]", " ", "n", " ", "7", " "}], "8"]}], 
           "]"}]}], ")"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"n", ",", 
         RowBox[{"-", "nterm1"}], ",", "nterm1"}], "}"}]}], "]"}], "]"}], "//",
     "N"}], " ", "//", "Chop"}]}]], "Input",
 CellChangeTimes->{{3.55323332190625*^9, 3.553233452296875*^9}, {
   3.553233546296875*^9, 3.553233643078125*^9}, {3.553233674296875*^9, 
   3.55323369940625*^9}, {3.553233745359375*^9, 3.5532337625*^9}, 
   3.55323385990625*^9, {3.553233929109375*^9, 3.55323393034375*^9}, {
   3.5532340236875*^9, 3.553234031234375*^9}, {3.55323531940625*^9, 
   3.553235327859375*^9}, {3.553235393484375*^9, 3.55323544403125*^9}, {
   3.553236356890625*^9, 3.5532363763125*^9}, {3.553249517125*^9, 
   3.5532495475*^9}, {3.55324962609375*^9, 3.553249654703125*^9}, {
   3.553251430734375*^9, 3.5532514450625*^9}, {3.553252686609375*^9, 
   3.553252692265625*^9}, {3.55325957378125*^9, 3.5532595796875*^9}, {
   3.55326007428125*^9, 3.553260080015625*^9}, {3.55326017065625*^9, 
   3.553260171640625*^9}, {3.553260240109375*^9, 3.553260240484375*^9}, {
   3.5533441132964077`*^9, 3.553344122765182*^9}, {3.5537542437890453`*^9, 
   3.5537542583883343`*^9}, {3.553754456925062*^9, 3.5537544573042583`*^9}, {
   3.553784553859783*^9, 3.553784563823162*^9}},
 FontSize->18],

Cell[TextData[{
 "ii) as alternative, the two atoms may be @ ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["CG", "1"], " "}]], "Input",
  CellChangeTimes->{{3.553399171863435*^9, 3.55339917870542*^9}, {
    3.553399220329187*^9, 3.553399231455578*^9}, 3.55339927878718*^9, {
    3.553775575947589*^9, 3.5537756788945*^9}, {3.553775816643363*^9, 
    3.553775823386682*^9}, 3.5537773469258823`*^9},
  FontSize->24],
 " and ",
 Cell[BoxData[
  RowBox[{"-", " "}]], "Input",
  CellChangeTimes->{{3.553399171863435*^9, 3.55339917870542*^9}, {
    3.553399220329187*^9, 3.553399231455578*^9}, 3.55339927878718*^9, {
    3.553775575947589*^9, 3.5537756788945*^9}, {3.553775816643363*^9, 
    3.553775823386682*^9}, 3.5537773469258823`*^9},
  FontSize->24],
 Cell[BoxData[
  RowBox[{
   SubscriptBox["CG", "1"], " ", ",", 
   StyleBox[
    RowBox[{"therefore", "..."}],
    FontFamily->"Times New Roman",
    FontWeight->"Plain"]}]], "Input",
  CellChangeTimes->{{3.553399171863435*^9, 3.55339917870542*^9}, {
    3.553399220329187*^9, 3.553399231455578*^9}, 3.55339927878718*^9, {
    3.553775575947589*^9, 3.5537756788945*^9}, {3.553775816643363*^9, 
    3.553775823386682*^9}, 3.5537773469258823`*^9},
  FontSize->24]
}], "Text",
 CellChangeTimes->{{3.553261113984375*^9, 3.553261152046875*^9}, {
  3.5537540034918547`*^9, 3.553754062388558*^9}, {3.5537643309436693`*^9, 
  3.553764348539936*^9}, {3.5537777025606623`*^9, 3.553777783320912*^9}, {
  3.553777822966282*^9, 3.553777871746028*^9}, {3.553777902635889*^9, 
  3.553777949928587*^9}, {3.553778242444338*^9, 3.553778248033565*^9}, {
  3.5537782878097887`*^9, 3.553778336154874*^9}, {3.553778594940938*^9, 
  3.5537785959746313`*^9}, {3.5750975488504257`*^9, 3.5750975499751263`*^9}, {
  3.575258403616562*^9, 3.5752584246957674`*^9}},
 FontFamily->"Times New Roman",
 FontSize->26,
 FontColor->GrayLevel[0],
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Chi]func50sim", "[", "x_", "]"}], "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"ExpToTrig", "[", 
     RowBox[{"Sum", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         SubscriptBox["coef$func$F50FT", "at"], "[", "n", "]"}], "*", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Exp", "[", 
           RowBox[{
            RowBox[{"-", "I"}], " ", 
            FractionBox[
             RowBox[{"2", "  ", "\[Pi]", " ", "n"}], "8"]}], "]"}], " ", "+", 
          " ", 
          RowBox[{"Exp", "[", 
           RowBox[{
            RowBox[{"+", "I"}], " ", 
            FractionBox[
             RowBox[{"2", " ", "\[Pi]", " ", "n", " "}], "8"]}], "]"}]}], 
         ")"}], "*", 
        RowBox[{"Exp", "[", 
         RowBox[{"I", " ", 
          FractionBox[
           RowBox[{"2", "  ", "\[Pi]", " ", "n", " ", "x"}], 
           SubscriptBox["a", "0"]]}], "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"n", ",", 
         RowBox[{"-", "nterm1"}], ",", "nterm1"}], "}"}]}], "]"}], "]"}], "//",
     "N"}], " ", "//", "Chop"}]}]], "Input",
 CellChangeTimes->{{3.55323332190625*^9, 3.553233452296875*^9}, {
   3.553233546296875*^9, 3.553233643078125*^9}, {3.553233674296875*^9, 
   3.55323369940625*^9}, {3.553233745359375*^9, 3.5532337625*^9}, 
   3.55323385990625*^9, {3.553233929109375*^9, 3.55323393034375*^9}, {
   3.5532340236875*^9, 3.553234031234375*^9}, {3.55323531940625*^9, 
   3.553235327859375*^9}, {3.553235393484375*^9, 3.55323544403125*^9}, {
   3.553236356890625*^9, 3.5532363763125*^9}, {3.553249517125*^9, 
   3.5532495475*^9}, {3.55324962609375*^9, 3.553249654703125*^9}, {
   3.553251430734375*^9, 3.5532514450625*^9}, {3.553252686609375*^9, 
   3.553252692265625*^9}, {3.55325957378125*^9, 3.5532595796875*^9}, {
   3.55326007428125*^9, 3.553260080015625*^9}, {3.553260164421875*^9, 
   3.55326016515625*^9}, {3.553397940295739*^9, 3.553397952681242*^9}, 
   3.5537543809682827`*^9, {3.5537544752376738`*^9, 3.5537544766902113`*^9}, {
   3.5537845747719173`*^9, 3.553784579042276*^9}},
 FontSize->18],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Chi]tab50sim", "[", "x_", "]"}], "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"ExpToTrig", "[", 
     RowBox[{"Sum", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         SubscriptBox["coef$tab$50FT", "at"], "[", 
         RowBox[{"[", 
          RowBox[{"n", "+", "nterm1", "+", "1"}], "]"}], "]"}], "*", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Exp", "[", 
           RowBox[{
            RowBox[{"-", "I"}], " ", 
            FractionBox[
             RowBox[{"2", "  ", "\[Pi]", " ", "n"}], "8"]}], "]"}], " ", "+", 
          " ", 
          RowBox[{"Exp", "[", 
           RowBox[{
            RowBox[{"+", "I"}], " ", 
            FractionBox[
             RowBox[{"2", " ", "\[Pi]", " ", "n", " "}], "8"]}], "]"}]}], 
         ")"}], "*", 
        RowBox[{"Exp", "[", 
         RowBox[{"I", " ", 
          FractionBox[
           RowBox[{"2", "  ", "\[Pi]", " ", "n", " ", "x"}], 
           SubscriptBox["a", "0"]]}], "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"n", ",", 
         RowBox[{"-", "nterm1"}], ",", "nterm1"}], "}"}]}], "]"}], "]"}], "//",
     "N"}], " ", "//", "Chop"}]}]], "Input",
 CellChangeTimes->{{3.55323332190625*^9, 3.553233452296875*^9}, {
   3.553233546296875*^9, 3.553233643078125*^9}, {3.553233674296875*^9, 
   3.55323369940625*^9}, {3.553233745359375*^9, 3.5532337625*^9}, 
   3.55323385990625*^9, {3.553233929109375*^9, 3.55323393034375*^9}, {
   3.5532340236875*^9, 3.553234031234375*^9}, {3.55323531940625*^9, 
   3.553235327859375*^9}, {3.553235393484375*^9, 3.55323544403125*^9}, {
   3.553236356890625*^9, 3.5532363763125*^9}, {3.553249517125*^9, 
   3.5532495475*^9}, {3.55324962609375*^9, 3.553249654703125*^9}, {
   3.553251430734375*^9, 3.5532514450625*^9}, {3.553252686609375*^9, 
   3.553252692265625*^9}, {3.55325957378125*^9, 3.5532595796875*^9}, {
   3.55326007428125*^9, 3.553260080015625*^9}, {3.553260164421875*^9, 
   3.55326016515625*^9}, {3.5537543506515417`*^9, 3.55375435908845*^9}, {
   3.553754480724078*^9, 3.553754481054173*^9}, {3.553784586201262*^9, 
   3.553784591193762*^9}},
 FontSize->18],

Cell["\<\
Now we can multiply with the coefficient Vol1D and easily observe that the \
cases i) and ii) describe
the same cell (as expected) so they are equivalent.\
\>", "Text",
 CellChangeTimes->{{3.553261113984375*^9, 3.553261152046875*^9}, {
   3.5537540034918547`*^9, 3.553754062388558*^9}, {3.5537643309436693`*^9, 
   3.553764348539936*^9}, {3.5537777025606623`*^9, 3.553777783320912*^9}, {
   3.553777822966282*^9, 3.553777871746028*^9}, {3.553777902635889*^9, 
   3.553777949928587*^9}, {3.553778272869059*^9, 3.553778272869199*^9}, 
   3.553826860073675*^9, {3.57494749397497*^9, 3.574947543203638*^9}, {
   3.57509737173516*^9, 3.5750973773052464`*^9}, {3.575097898045354*^9, 
   3.5750979664479713`*^9}, {3.575107742229279*^9, 3.575107746024671*^9}, {
   3.5752584583116903`*^9, 3.5752585229023848`*^9}},
 FontFamily->"Times New Roman",
 FontSize->26,
 FontColor->GrayLevel[0],
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"Vol1D", "*", 
    RowBox[{"\[Chi]func50", "[", "x", "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"-", 
      SubscriptBox["a", "0"]}], ",", 
     SubscriptBox["a", "0"]}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}], ",", "\[IndentingNewLine]", 
   RowBox[{"Epilog", "->", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"PointSize", "[", "0.01", "]"}], ",", "Red", ",", 
      RowBox[{"Point", "[", "coord2CG", "]"}]}], "}"}]}], ",", 
   RowBox[{"PlotPoints", "\[Rule]", "500"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.553233790828125*^9, 3.553233829390625*^9}, {
   3.55323390053125*^9, 3.553233906671875*^9}, {3.55323409775*^9, 
   3.55323409971875*^9}, {3.553235468375*^9, 3.55323547075*^9}, {
   3.553249909921875*^9, 3.553249924453125*^9}, {3.55325006259375*^9, 
   3.55325007190625*^9}, 3.55325150846875*^9, {3.553252120078125*^9, 
   3.553252146703125*^9}, 3.55325229884375*^9, 3.55325245796875*^9, {
   3.5532525145*^9, 3.5532525275625*^9}, {3.55325269825*^9, 
   3.553252698828125*^9}, {3.553256132015625*^9, 3.553256151140625*^9}, {
   3.55325629571875*^9, 3.553256300671875*^9}, 3.553256426703125*^9, 
   3.553259368796875*^9, {3.55326020821875*^9, 3.55326020896875*^9}, 
   3.5533979773347178`*^9, {3.553754523532002*^9, 3.553754524981373*^9}, {
   3.553754634078079*^9, 3.553754635092478*^9}, {3.5537784179046926`*^9, 
   3.5537784290270643`*^9}},
 FontSize->18],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"Vol1D", "*", 
    RowBox[{"\[Chi]func50sim", "[", "x", "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"-", 
      SubscriptBox["a", "0"]}], ",", 
     SubscriptBox["a", "0"]}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}], ",", "\[IndentingNewLine]", 
   RowBox[{"Epilog", "->", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"PointSize", "[", "0.01", "]"}], ",", "Red", ",", 
      RowBox[{"Point", "[", "coord1CG", "]"}]}], "}"}]}], ",", 
   RowBox[{"PlotPoints", "\[Rule]", "500"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.553233790828125*^9, 3.553233829390625*^9}, {
   3.55323390053125*^9, 3.553233906671875*^9}, {3.55323409775*^9, 
   3.55323409971875*^9}, {3.553235468375*^9, 3.55323547075*^9}, {
   3.553249909921875*^9, 3.553249924453125*^9}, {3.55325006259375*^9, 
   3.55325007190625*^9}, 3.55325150846875*^9, {3.553252120078125*^9, 
   3.553252146703125*^9}, 3.55325229884375*^9, 3.55325245796875*^9, {
   3.5532525145*^9, 3.5532525275625*^9}, {3.55325269825*^9, 
   3.553252698828125*^9}, {3.553256132015625*^9, 3.553256151140625*^9}, {
   3.55325629571875*^9, 3.553256300671875*^9}, 3.553256426703125*^9, 
   3.553259368796875*^9, {3.55326020821875*^9, 3.55326020896875*^9}, {
   3.553754529059514*^9, 3.553754529760747*^9}, {3.553754646020442*^9, 
   3.553754647719242*^9}, 3.553778439959203*^9},
 FontSize->18],

Cell["q.e.d.", "Text",
 CellChangeTimes->{{3.553261113984375*^9, 3.553261152046875*^9}, {
   3.5537540034918547`*^9, 3.553754062388558*^9}, {3.5537643309436693`*^9, 
   3.553764348539936*^9}, {3.5537777025606623`*^9, 3.553777783320912*^9}, {
   3.553777822966282*^9, 3.553777871746028*^9}, {3.553777902635889*^9, 
   3.553777949928587*^9}, {3.553778272869059*^9, 3.553778272869199*^9}, 
   3.553826860073675*^9, {3.57494749397497*^9, 3.574947543203638*^9}, {
   3.57509737173516*^9, 3.5750973773052464`*^9}, {3.575097898045354*^9, 
   3.5750979664479713`*^9}, {3.575107742229279*^9, 3.575107746024671*^9}, {
   3.5752584583116903`*^9, 3.57525854799082*^9}},
 FontFamily->"Times New Roman",
 FontSize->26,
 FontColor->GrayLevel[0],
 Background->GrayLevel[0.85]],

Cell[CellGroupData[{

Cell["Part II", "Text",
 CellChangeTimes->{
  3.5532355989375*^9, {3.553258656921875*^9, 3.5532587594375*^9}, {
   3.553258796640625*^9, 3.55325884934375*^9}, {3.553763675668995*^9, 
   3.553763676089476*^9}, {3.553827279529264*^9, 3.553827300511937*^9}, {
   3.5538273836431704`*^9, 3.553827409025343*^9}, {3.553827501493021*^9, 
   3.553827579968416*^9}, {3.55382761186236*^9, 3.553827632315133*^9}, {
   3.553827665416727*^9, 3.5538276667725697`*^9}, {3.553828240212757*^9, 
   3.553828307642337*^9}, {3.575108443158297*^9, 3.575108495744261*^9}, {
   3.575256096703614*^9, 3.5752560976946707`*^9}},
 FontFamily->"Times New Roman",
 FontSize->36,
 FontColor->RGBColor[0, 0, 1],
 Background->RGBColor[1, 0.9, 0.8]],

Cell[TextData[{
 "Now we consider a more complicated situation.\n\nLet us imagine the there \
are always two atoms inside the cell but let us add\nthat their electronic \
density is equivalent to a single  U-shaped function. This\nmeans that the \
effective representation of the two atoms is equivalent to the\na single \
structure U-shaped (with two ",
 StyleBox["horns",
  FontSlant->"Italic"],
 ").\n\nThis implies that it is more difficult to calculate the \
FourierTransform. Let us face this problem..."
}], "Text",
 CellChangeTimes->{
  3.5532355989375*^9, {3.553258656921875*^9, 3.5532587594375*^9}, {
   3.553258796640625*^9, 3.55325884934375*^9}, {3.553763675668995*^9, 
   3.553763676089476*^9}, {3.553827279529264*^9, 3.553827300511937*^9}, {
   3.5538273836431704`*^9, 3.553827409025343*^9}, {3.553827501493021*^9, 
   3.553827579968416*^9}, {3.55382761186236*^9, 3.553827632315133*^9}, {
   3.553827665416727*^9, 3.5538276667725697`*^9}, {3.553828240212757*^9, 
   3.553828307642337*^9}, {3.575108443158297*^9, 3.575108495744261*^9}, {
   3.575256100047806*^9, 3.5752561002158155`*^9}, {3.575258627039341*^9, 
   3.5752587945509224`*^9}},
 FontSize->24,
 Background->GrayLevel[0.85]]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Rho]5", "[", "x_", "]"}], "=", 
  RowBox[{"coefnorm", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"Sin", "[", 
      RowBox[{"2", " ", "\[Pi]", " ", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"x", "+", "0"}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"2", "*", 
          SubscriptBox["width", "at"]}], ")"}]}]}], "]"}], ")"}], "^", 
    "6"}]}]}]], "Input",
 CellChangeTimes->{{3.428806000296875*^9, 3.4288060590625*^9}, 
   3.49779292540625*^9, {3.497849788171875*^9, 3.497849791703125*^9}, {
   3.497849829203125*^9, 3.497849845859375*^9}, {3.49785269434375*^9, 
   3.497852696*^9}, {3.49785405859375*^9, 3.497854061765625*^9}, {
   3.49785507915625*^9, 3.497855079515625*^9}, 3.497856711921875*^9, {
   3.4978570273125*^9, 3.49785702796875*^9}, {3.4978689468125*^9, 
   3.497868950515625*^9}, {3.497868984640625*^9, 3.4978689888125*^9}, {
   3.4978770133125*^9, 3.49787701775*^9}, {3.497944703328125*^9, 
   3.497944735046875*^9}, {3.497944849859375*^9, 3.49794485071875*^9}, {
   3.497953876109375*^9, 3.49795387746875*^9}, 3.49795399771875*^9, 
   3.49795567959375*^9, {3.4979612845*^9, 3.49796133075*^9}, {
   3.49796154209375*^9, 3.4979615465625*^9}, {3.497962578046875*^9, 
   3.497962589390625*^9}, 3.497962635921875*^9, 3.498043147984375*^9, {
   3.498043273671875*^9, 3.498043279375*^9}, {3.49804346625*^9, 
   3.49804347503125*^9}, {3.498043753203125*^9, 3.49804375465625*^9}, {
   3.498043808703125*^9, 3.498043812453125*^9}, 3.498046689875*^9, {
   3.498047494171875*^9, 3.49804751059375*^9}, {3.55149477534375*^9, 
   3.551494781296875*^9}, {3.551494824203125*^9, 3.55149484725*^9}, 
   3.551494880015625*^9, {3.55149728784375*^9, 3.551497289421875*^9}, {
   3.5532316476875*^9, 3.553231647859375*^9}, {3.553231859171875*^9, 
   3.55323187140625*^9}, {3.55324905078125*^9, 3.55324907203125*^9}, {
   3.553250599953125*^9, 3.5532506140625*^9}, {3.5533432490792913`*^9, 
   3.553343251245709*^9}, {3.553768232527438*^9, 3.55376826212148*^9}},
 FontSize->24],

Cell[BoxData[
 RowBox[{
  RowBox[{"coe", "=", 
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Integrate", "[", 
       RowBox[{
        RowBox[{"\[Rho]5", "[", "x", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"x", ",", "0", ",", 
          RowBox[{
           SubscriptBox["width", "at"], "/", "1"}]}], "}"}]}], "]"}], 
      "\[Equal]", "14"}], ",", "coefnorm"}], "]"}]}], "\n"}]], "Input",
 CellChangeTimes->{{3.5537669006131907`*^9, 3.5537669047774553`*^9}, {
   3.55376694925909*^9, 3.553766954054886*^9}, 3.553767119280113*^9, {
   3.553768273941498*^9, 3.553768289552157*^9}, {3.553770027794999*^9, 
   3.553770029462254*^9}, {3.55377059715172*^9, 3.553770599433737*^9}, {
   3.55377139975844*^9, 3.5537714007617483`*^9}},
 FontSize->18],

Cell["\<\
Let\[CloseCurlyQuote]s check that the above introduced function is properly \
normalized @ Z = 14 (Si).\
\>", "Text",
 CellChangeTimes->{{3.49795814646875*^9, 3.4979581888125*^9}, {
   3.49795824053125*^9, 3.497958316*^9}, {3.497959406296875*^9, 
   3.497959420546875*^9}, {3.498043168328125*^9, 3.498043187546875*^9}, {
   3.498106516515625*^9, 3.49810655075*^9}, 3.498811881546875*^9, {
   3.498827995140625*^9, 3.49882799565625*^9}, 3.49882868975*^9, 
   3.552473872765625*^9, {3.552473968390625*^9, 3.55247402665625*^9}, {
   3.553260807015625*^9, 3.553260815*^9}, {3.553753211917671*^9, 
   3.5537532471483917`*^9}, {3.5537532772628927`*^9, 3.553753310106073*^9}, {
   3.553775339564728*^9, 3.553775388928371*^9}, {3.5538272658268547`*^9, 
   3.553827271558619*^9}, {3.553827318764749*^9, 3.553827365915971*^9}, {
   3.553827426142563*^9, 3.553827457019126*^9}, 3.553828090670125*^9, {
   3.553828174641241*^9, 3.553828202866152*^9}, {3.574943132840713*^9, 
   3.57494313890244*^9}, {3.574943229021974*^9, 3.57494323680661*^9}, {
   3.574943304707011*^9, 3.5749433047071123`*^9}, {3.5750891979997683`*^9, 
   3.575089219260971*^9}, 3.575096334352598*^9, {3.575096473118904*^9, 
   3.575096549237656*^9}, {3.5752581595596027`*^9, 3.575258181038831*^9}, {
   3.575258941359319*^9, 3.575258960486413*^9}},
 FontFamily->"Times New Roman",
 FontSize->26,
 FontColor->GrayLevel[0],
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Integrate", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"\[Rho]5", "[", "x", "]"}], "/.", 
      RowBox[{"coefnorm", "\[Rule]", 
       RowBox[{"coe", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "1", ",", "2"}], "]"}], "]"}]}]}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "0"}], ",", 
       RowBox[{
        SubscriptBox["width", "at"], "/", "1"}]}], "}"}]}], "]"}], "//", 
   "N"}], "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{{3.5537669006131907`*^9, 3.5537669092107563`*^9}, {
   3.553766959867608*^9, 3.553766965352017*^9}, 3.553767122119419*^9, {
   3.553768306947383*^9, 3.553768316098216*^9}},
 FontSize->18],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Rho]2", "[", "x_", "]"}], ":=", 
  RowBox[{
   RowBox[{"\[Rho]5", "[", "x", "]"}], "/.", 
   RowBox[{"coefnorm", "\[Rule]", 
    RowBox[{"coe", "[", 
     RowBox[{"[", 
      RowBox[{"1", ",", "1", ",", "2"}], "]"}], "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.5537669006131907`*^9, 3.5537669092107563`*^9}, {
  3.5537671233030033`*^9, 3.5537671473768787`*^9}, {3.553768322449093*^9, 
  3.5537683229387712`*^9}},
 FontSize->18],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Rho]p2", "[", "x_", "]"}], ":=", 
  RowBox[{"Piecewise", "[", 
   RowBox[{"{", "    ", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\[Rho]2", "[", "x", "]"}], " ", ",", 
       RowBox[{"0", "\[LessEqual]", "x", "\[LessEqual]", 
        SubscriptBox["width", "at"]}]}], "}"}], ",", "\[IndentingNewLine]", 
     "                                            ", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        SubscriptBox["width", "at"], " ", "\[LessEqual]", " ", "x", " ", 
        "\[LessEqual]", " ", 
        RowBox[{
         SubscriptBox["a", "0"], " ", "-", 
         SubscriptBox["width", "at"]}]}]}], "}"}], ",", "\[IndentingNewLine]",
      "                                            ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\[Rho]2", "[", "x", "]"}], ",", 
       RowBox[{
        RowBox[{
         SubscriptBox["a", "0"], " ", "-", 
         SubscriptBox["width", "at"]}], "\[LessEqual]", "x", "\[LessEqual]", 
        SubscriptBox["a", "0"]}]}], "}"}]}], "\[IndentingNewLine]", 
    "                                       ", "}"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.551498491640625*^9, 3.5514986003125*^9}, 
   3.55149887221875*^9, {3.551767390609375*^9, 3.5517674035625*^9}, {
   3.55176789890625*^9, 3.55176795065625*^9}, {3.551767999828125*^9, 
   3.551768017375*^9}, 3.5517681059375*^9, 3.553256913359375*^9, {
   3.553256965921875*^9, 3.553256975875*^9}, 3.553257130765625*^9, {
   3.553257186828125*^9, 3.553257189875*^9}, {3.553257288734375*^9, 
   3.5532573164375*^9}},
 FontSize->18],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Rho]p2", "[", "x_", "]"}], ":=", 
  RowBox[{
   RowBox[{"\[Rho]p2", "[", 
    RowBox[{"x", "-", 
     SubscriptBox["Sa", "0"]}], "]"}], "/;", 
   RowBox[{"x", ">", 
    SubscriptBox["a", "0"]}]}]}]], "Input",
 CellChangeTimes->{{3.553768845100535*^9, 3.5537688873714943`*^9}},
 FontSize->18],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Rho]p2", "[", "x_", "]"}], ":=", 
  RowBox[{
   RowBox[{"\[Rho]p2", "[", 
    RowBox[{"x", "+", 
     SubscriptBox["a", "0"]}], "]"}], "/;", 
   RowBox[{"x", "<", "0"}]}]}]], "Input",
 CellChangeTimes->{{3.553768845100535*^9, 3.553768855451737*^9}, 
   3.5537688921959457`*^9},
 FontSize->18],

Cell[BoxData[
 RowBox[{"aq", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"\[Rho]p2", "[", "x", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", 
      RowBox[{
       RowBox[{"-", "1"}], "*", 
       SubscriptBox["a", "0"]}], ",", 
      RowBox[{"1", "*", 
       SubscriptBox["a", "0"]}]}], " ", "}"}], ",", 
    RowBox[{"Epilog", "->", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"PointSize", "[", "0.01", "]"}], ",", "Red", ",", 
       RowBox[{"Point", "[", "coord2CG", "]"}]}], "}"}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}]], "Input",
 CellChangeTimes->{
  3.4288042703125*^9, {3.49778604878125*^9, 3.49778605965625*^9}, 
   3.4977861058125*^9, {3.49785387028125*^9, 3.497853884921875*^9}, 
   3.49785671559375*^9, {3.497857394734375*^9, 3.497857397078125*^9}, 
   3.49786902040625*^9, 3.4978770305*^9, {3.497944771953125*^9, 
   3.49794477259375*^9}, {3.4979448625625*^9, 3.4979448636875*^9}, {
   3.4979540598125*^9, 3.497954172265625*^9}, {3.497955714734375*^9, 
   3.497955717125*^9}, {3.49795838578125*^9, 3.497958388171875*^9}, 
   3.497961577203125*^9, {3.497961713953125*^9, 3.497961715859375*^9}, {
   3.497961849203125*^9, 3.49796195371875*^9}, {3.497962691828125*^9, 
   3.497962719796875*^9}, {3.4979630325*^9, 3.49796307140625*^9}, {
   3.49796322521875*^9, 3.49796323203125*^9}, {3.497963678203125*^9, 
   3.49796369953125*^9}, {3.497963735796875*^9, 3.497963738140625*^9}, {
   3.497964055828125*^9, 3.497964059265625*^9}, {3.49796409296875*^9, 
   3.497964095546875*^9}, {3.497965051734375*^9, 3.497965055*^9}, {
   3.49804353478125*^9, 3.498043555296875*^9}, {3.498043595328125*^9, 
   3.4980435973125*^9}, {3.49804363465625*^9, 3.49804364075*^9}, 
   3.498043686078125*^9, {3.498043725515625*^9, 3.49804374590625*^9}, {
   3.49804385228125*^9, 3.498043854109375*^9}, 3.498043985703125*^9, 
   3.4980440170625*^9, 3.498046689890625*^9, 3.4980475526875*^9, {
   3.55149489528125*^9, 3.55149489840625*^9}, {3.551495004671875*^9, 
   3.55149501709375*^9}, {3.551497540078125*^9, 3.5514975621875*^9}, {
   3.5514976541875*^9, 3.551497654796875*^9}, 3.5514979865*^9, {
   3.551498275953125*^9, 3.5514982804375*^9}, {3.551498313609375*^9, 
   3.551498354703125*^9}, 3.5514984259375*^9, {3.551498623046875*^9, 
   3.5514986278125*^9}, {3.55149871228125*^9, 3.551498712859375*^9}, {
   3.551498783921875*^9, 3.55149879471875*^9}, 3.551498872234375*^9, {
   3.55158288580766*^9, 3.5515828866717463`*^9}, {3.551767493671875*^9, 
   3.551767503609375*^9}, {3.551767559015625*^9, 3.551767560015625*^9}, {
   3.551767594671875*^9, 3.551767598328125*^9}, 3.551767963671875*^9, 
   3.553256982484375*^9, {3.553257338390625*^9, 3.553257343859375*^9}, {
   3.553257431625*^9, 3.5532574321875*^9}, 3.553767213558557*^9, 
   3.5537672646063223`*^9, {3.553768355582003*^9, 3.5537683622791243`*^9}, {
   3.553768916359557*^9, 3.553768917539007*^9}, {3.5537714715590143`*^9, 
   3.553771474985599*^9}, {3.553771513891637*^9, 3.5537715164408617`*^9}, {
   3.553784651534971*^9, 3.553784665638814*^9}},
 FontSize->24],

Cell["On the positive x-axis we see the two horns of the function.", "Text",
 CellChangeTimes->{{3.49795814646875*^9, 3.4979581888125*^9}, {
   3.49795824053125*^9, 3.497958316*^9}, {3.497959406296875*^9, 
   3.497959420546875*^9}, {3.498043168328125*^9, 3.498043187546875*^9}, {
   3.498106516515625*^9, 3.49810655075*^9}, 3.498811881546875*^9, {
   3.498827995140625*^9, 3.49882799565625*^9}, 3.49882868975*^9, 
   3.552473872765625*^9, {3.552473968390625*^9, 3.55247402665625*^9}, {
   3.553260807015625*^9, 3.553260815*^9}, {3.553753211917671*^9, 
   3.5537532471483917`*^9}, {3.5537532772628927`*^9, 3.553753310106073*^9}, {
   3.553775339564728*^9, 3.553775388928371*^9}, {3.5538272658268547`*^9, 
   3.553827271558619*^9}, {3.553827318764749*^9, 3.553827365915971*^9}, {
   3.553827426142563*^9, 3.553827457019126*^9}, 3.553828090670125*^9, {
   3.553828174641241*^9, 3.553828202866152*^9}, {3.574943132840713*^9, 
   3.57494313890244*^9}, {3.574943229021974*^9, 3.57494323680661*^9}, {
   3.574943304707011*^9, 3.5749433047071123`*^9}, {3.5750891979997683`*^9, 
   3.575089219260971*^9}, 3.575096334352598*^9, {3.575096473118904*^9, 
   3.575096549237656*^9}, {3.5752581595596027`*^9, 3.575258181038831*^9}, {
   3.575258975016244*^9, 3.575258998670597*^9}},
 FontFamily->"Times New Roman",
 FontSize->26,
 FontColor->GrayLevel[0],
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  SubscriptBox["dueFT", "at"], "=", 
  RowBox[{"Timing", "[", 
   RowBox[{"FourierTransform", "[", 
    RowBox[{
     RowBox[{"\[Rho]p2", "[", "x", "]"}], ",", "x", ",", 
     SubscriptBox["g", "x"], 
     StyleBox[",",
      FontColor->RGBColor[0, 0, 1]], 
     RowBox[{"FourierParameters", "->", 
      RowBox[{"{", 
       RowBox[{"1", ",", "1"}], "}"}]}]}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{3.5537649867081633`*^9},
 FontSize->18],

Cell[BoxData[
 RowBox[{
  RowBox[{"Limit", "[", 
   RowBox[{
    RowBox[{
     SubscriptBox["dueFT", "at"], "[", 
     RowBox[{"[", "2", "]"}], "]"}], ",", 
    RowBox[{
     SubscriptBox["g", "x"], " ", "\[Rule]", "0"}]}], "]"}], 
  "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{{3.553762022200302*^9, 3.553762058704142*^9}, 
   3.553762277885459*^9, 3.553763515414506*^9, 3.55376505098954*^9},
 FontSize->18],

Cell[BoxData[
 RowBox[{
  RowBox[{"Limit", "[", 
   RowBox[{
    RowBox[{
     SubscriptBox["dueFT", "at"], "[", 
     RowBox[{"[", "2", "]"}], "]"}], ",", 
    RowBox[{
     SubscriptBox["g", "x"], " ", "\[Rule]", "  ", 
     FractionBox[
      RowBox[{"2", " ", "\[Pi]"}], 
      SubscriptBox["a", "0"]]}]}], "]"}], "//", "N"}]], "Input",
 CellChangeTimes->{{3.553762022200302*^9, 3.553762027781721*^9}, {
   3.5537620612407827`*^9, 3.553762062335894*^9}, {3.5537622812269363`*^9, 
   3.553762302266633*^9}, 3.553763520333001*^9, 3.553765054187447*^9},
 FontSize->18],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Limit", "[", 
    RowBox[{
     RowBox[{
      SubscriptBox["dueFT", "at"], "[", 
      RowBox[{"[", "2", "]"}], "]"}], ",", 
     RowBox[{
      SubscriptBox["g", "x"], " ", "\[Rule]", 
      RowBox[{"2", "*", 
       FractionBox[
        RowBox[{"2", " ", "\[Pi]"}], 
        SubscriptBox["a", "0"]]}]}]}], "]"}], "//", "N"}]}]], "Input",
 CellChangeTimes->{{3.553762022200302*^9, 3.553762066016841*^9}, {
   3.553762284742817*^9, 3.553762320511552*^9}, 3.5537635251648493`*^9, 
   3.5537650573021193`*^9},
 FontSize->18],

Cell[BoxData[
 RowBox[{
  SubscriptBox["coef$tab2$50FT", "at"], "=", " ", 
  RowBox[{
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"n", ",", 
       RowBox[{"Limit", "[", 
        RowBox[{
         RowBox[{
          SubscriptBox["dueFT", "at"], "[", 
          RowBox[{"[", "2", "]"}], "]"}], ",", " ", 
         RowBox[{
          SubscriptBox["g", "x"], " ", "\[Rule]", 
          RowBox[{"n", "  ", 
           FractionBox[
            RowBox[{"2", " ", "\[Pi]"}], 
            SubscriptBox["a", "0"]]}]}]}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"n", ",", 
       RowBox[{"-", "nterm1"}], ",", "nterm1"}], "}"}]}], "]"}], "//", 
   "N"}]}]], "Input",
 CellChangeTimes->{{3.5532323323125*^9, 3.553232383328125*^9}, {
  3.553232425828125*^9, 3.55323251878125*^9}, {3.553232588921875*^9, 
  3.55323259021875*^9}, {3.553233253515625*^9, 3.553233254453125*^9}, {
  3.55323393575*^9, 3.5532339373125*^9}, {3.553236095828125*^9, 
  3.553236099984375*^9}, {3.553236160828125*^9, 3.55323616578125*^9}, {
  3.553249281984375*^9, 3.553249283984375*^9}, {3.55324960325*^9, 
  3.55324960446875*^9}, {3.553251364921875*^9, 3.553251411*^9}, {
  3.553252667828125*^9, 3.5532526681875*^9}, {3.553259518484375*^9, 
  3.553259536875*^9}, {3.553398138359424*^9, 3.553398140819633*^9}, {
  3.553754177079156*^9, 3.5537541787979593`*^9}, {3.5537718163220673`*^9, 
  3.55377186287658*^9}},
 FontSize->24],

Cell[BoxData[
 RowBox[{
  RowBox[{"nterm1", "=", "50"}], ";"}]], "Input",
 CellChangeTimes->{{3.553762093074861*^9, 3.553762097748625*^9}, {
  3.553769435197905*^9, 3.553769436031226*^9}, {3.5537706570955544`*^9, 
  3.553770657708028*^9}, {3.5537707024285917`*^9, 3.553770726745496*^9}, {
  3.553771242148036*^9, 3.5537712426805153`*^9}, {3.575347486628652*^9, 
  3.5753474884245653`*^9}},
 FontSize->18],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["coeffuncdueFT", "at"], "[", "n_", "]"}], ":=", 
  RowBox[{
   RowBox[{"Limit", "[", 
    RowBox[{
     RowBox[{
      SubscriptBox["dueFT", "at"], "[", 
      RowBox[{"[", "2", "]"}], "]"}], ",", 
     RowBox[{
      SubscriptBox["g", "x"], " ", "\[Rule]", 
      RowBox[{"n", "  ", 
       FractionBox[
        RowBox[{"2", " ", "\[Pi]"}], 
        SubscriptBox["a", "0"]]}]}]}], "]"}], "//", "N"}]}]], "Input",
 CellChangeTimes->{{3.553762093074861*^9, 3.553762126026986*^9}, {
   3.553762167991078*^9, 3.55376218964124*^9}, 3.5537622365956984`*^9, 
   3.553762408366288*^9, 3.553763556004435*^9, {3.553765083488873*^9, 
   3.5537650953917513`*^9}},
 FontSize->18],

Cell[BoxData[
 RowBox[{"Vol1D", "=", " ", 
  RowBox[{
   RowBox[{"-", 
    FractionBox["1", 
     SubscriptBox["a", "0"]]}], 
   FractionBox[
    RowBox[{
     SubscriptBox["r", "e"], " ", 
     SuperscriptBox["\[Lambda]", "2"]}], "\[Pi]"]}]}]], "Input",
 CellChangeTimes->{
  3.553235597390625*^9, {3.553251523203125*^9, 3.553251554421875*^9}, {
   3.553251837703125*^9, 3.55325188546875*^9}, {3.553259297875*^9, 
   3.553259303359375*^9}, 3.553260996109375*^9},
 FontSize->24],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Chi]funcdue50", "[", "x_", "]"}], "=", 
  RowBox[{
   RowBox[{
    RowBox[{"ExpToTrig", "[", 
     RowBox[{"Sum", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Exp", "[", 
         RowBox[{"I", " ", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"2", " ", "\[Pi]", " ", "n", " ", "x"}], ")"}], "/", 
           SubscriptBox["a", "0"]}]}], "]"}], "*", 
        RowBox[{
         SubscriptBox["coeffuncdueFT", "at"], "[", "n", "]"}], "*", 
        RowBox[{"(", 
         RowBox[{"Exp", "[", 
          RowBox[{
           RowBox[{"-", "I"}], " ", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"2", " ", "\[Pi]", " ", "n", " ", "8"}], ")"}], "/", 
            "8"}]}], "]"}], ")"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"n", ",", 
         RowBox[{"-", "nterm1"}], ",", "nterm1"}], "}"}]}], "]"}], "]"}], "//",
     "N"}], "//", "Chop"}]}]], "Input",
 CellChangeTimes->{{3.553769595368762*^9, 3.553769631262694*^9}, {
  3.553769905949944*^9, 3.55376991178036*^9}, {3.5537704101564503`*^9, 
  3.5537704151483717`*^9}, {3.553771097358181*^9, 3.553771102295986*^9}, {
  3.553771330467588*^9, 3.553771331894312*^9}, {3.553771362129407*^9, 
  3.5537713631343393`*^9}, {3.5537847407279787`*^9, 3.553784744696533*^9}},
 FontSize->18],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"Vol1D", "*", 
    RowBox[{"\[Chi]funcdue50", "[", "x", "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"-", 
      SubscriptBox["a", "0"]}], ",", 
     SubscriptBox["a", "0"]}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}], ",", "\[IndentingNewLine]", 
   RowBox[{"Epilog", "->", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"PointSize", "[", "0.01", "]"}], ",", "Red", ",", 
      RowBox[{"Point", "[", "coord2CG", "]"}]}], "}"}]}], ",", 
   RowBox[{"PlotPoints", "\[Rule]", "500"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.553233790828125*^9, 3.553233829390625*^9}, {
   3.55323390053125*^9, 3.553233906671875*^9}, {3.55323409775*^9, 
   3.55323409971875*^9}, {3.553235468375*^9, 3.55323547075*^9}, {
   3.553249909921875*^9, 3.553249924453125*^9}, {3.55325006259375*^9, 
   3.55325007190625*^9}, 3.55325150846875*^9, {3.553252120078125*^9, 
   3.553252146703125*^9}, 3.55325229884375*^9, 3.55325245796875*^9, {
   3.5532525145*^9, 3.5532525275625*^9}, {3.55325269825*^9, 
   3.553252698828125*^9}, {3.553256132015625*^9, 3.553256151140625*^9}, {
   3.55325629571875*^9, 3.553256300671875*^9}, 3.553256426703125*^9, 
   3.553259368796875*^9, {3.55326020821875*^9, 3.55326020896875*^9}, 
   3.5533979773347178`*^9, {3.553754523532002*^9, 3.553754524981373*^9}, {
   3.553754634078079*^9, 3.553754635092478*^9}, {3.553762849794499*^9, 
   3.553762856882823*^9}, {3.553764834014532*^9, 3.5537648362131166`*^9}, {
   3.553765164501225*^9, 3.5537651685172873`*^9}, {3.5537686737459183`*^9, 
   3.553768679342163*^9}, {3.553769144186157*^9, 3.553769153087062*^9}, {
   3.5537692176318197`*^9, 3.553769218205139*^9}, {3.5537702739963284`*^9, 
   3.553770274255484*^9}, {3.553771272370907*^9, 3.55377127578743*^9}, 
   3.553784785613023*^9},
 FontSize->18],

Cell[CellGroupData[{

Cell["Part III", "Text",
 CellChangeTimes->{
  3.5532355989375*^9, {3.553258656921875*^9, 3.5532587594375*^9}, {
   3.553258796640625*^9, 3.55325884934375*^9}, {3.553763675668995*^9, 
   3.553763676089476*^9}, {3.5537719682980347`*^9, 3.553771985673956*^9}, {
   3.553772034435471*^9, 3.553772035687415*^9}, {3.5537720661717978`*^9, 
   3.55377212627013*^9}, {3.553772343671762*^9, 3.553772359107634*^9}, {
   3.553828318948316*^9, 3.553828381540613*^9}, {3.5538284330237093`*^9, 
   3.5538284334058247`*^9}, {3.5538284636143093`*^9, 
   3.5538284752584143`*^9}, {3.553828520391618*^9, 3.553828540643159*^9}, {
   3.575108128855081*^9, 3.575108141104501*^9}, {3.575108322993868*^9, 
   3.575108323487466*^9}, {3.575256116007718*^9, 3.575256117070779*^9}},
 FontFamily->"Times New Roman",
 FontSize->36,
 FontColor->RGBColor[0, 0, 1],
 Background->RGBColor[1, 0.9, 0.8]],

Cell[TextData[{
 "We can get the useful equation for the Fourier coefficients:\n\n",
 Cell[BoxData[
  FormBox[
   StyleBox[
    RowBox[{
     SubscriptBox["c", "n"], "  ", "=", " ", 
     RowBox[{
      FractionBox["1", "L"], 
      StyleBox[" ",
       FontColor->RGBColor[1, 0, 0]], 
      RowBox[{
       SubscriptBox["F", "0"], 
       StyleBox["[",
        FontColor->RGBColor[1, 0, 0]], 
       RowBox[{
        StyleBox["n",
         FontColor->RGBColor[1, 0, 0]], 
        StyleBox[" ",
         FontColor->RGBColor[1, 0, 0]], 
        FractionBox[
         RowBox[{"2", " ", "\[Pi]"}], "L"]}], 
       StyleBox["]",
        FontColor->RGBColor[1, 0, 0]]}]}]}],
    FontColor->GrayLevel[0]], TraditionalForm]],
  FontColor->RGBColor[1, 0, 0]],
 "  \n\nLet us calculate the coefficients ",
 Cell[BoxData[
  FormBox[
   StyleBox[
    SubscriptBox["c", "n"],
    FontColor->GrayLevel[0]], TraditionalForm]],
  FontColor->RGBColor[1, 0, 0]],
 " of the Fourier expansion related to the U-shaped electronic density.\n\n\
The \[Chi] confirms the data in Part I and Part II."
}], "Text",
 CellChangeTimes->{
  3.5532355989375*^9, {3.553258656921875*^9, 3.5532587594375*^9}, {
   3.553258796640625*^9, 3.55325884934375*^9}, {3.553763675668995*^9, 
   3.553763676089476*^9}, {3.5537719682980347`*^9, 3.553771985673956*^9}, {
   3.553772034435471*^9, 3.553772035687415*^9}, {3.5537720661717978`*^9, 
   3.55377212627013*^9}, {3.553772343671762*^9, 3.553772359107634*^9}, {
   3.553828318948316*^9, 3.553828381540613*^9}, {3.5538284330237093`*^9, 
   3.5538284334058247`*^9}, {3.5538284636143093`*^9, 
   3.5538284752584143`*^9}, {3.553828520391618*^9, 3.553828540643159*^9}, {
   3.575108128855081*^9, 3.575108141104501*^9}, {3.575108322993868*^9, 
   3.575108323487466*^9}, 3.575256113873596*^9, {3.5752594110741854`*^9, 
   3.575259474198796*^9}},
 FontFamily->"Times New Roman",
 FontSize->24,
 Background->GrayLevel[0.85]]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Rho]pcoef", "[", "m_", "]"}], "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    FractionBox["1", 
     RowBox[{"(", 
      SubscriptBox["a", "0"], ")"}]], " ", 
    RowBox[{"Integrate", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"\[Rho]p2", "[", "x", "]"}], 
       RowBox[{"Exp", "[", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", 
         FractionBox[
          RowBox[{"2", " ", "\[Pi]"}], 
          SubscriptBox["a", "0"]], " ", "m", " ", "x"}], "]"}]}], " ", ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", "0", ",", 
        SubscriptBox["a", "0"]}], "}"}]}], "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4977845411875*^9, 3.49778455453125*^9}, 
   3.49778590590625*^9, {3.49787031784375*^9, 3.49787032003125*^9}, {
   3.497871937328125*^9, 3.4978719393125*^9}, {3.497877034265625*^9, 
   3.497877045921875*^9}, {3.4978777676875*^9, 3.497877771515625*^9}, {
   3.497956136140625*^9, 3.497956143921875*^9}, 3.497962101890625*^9, {
   3.4979646226875*^9, 3.4979646295*^9}, {3.49796525903125*^9, 
   3.49796526528125*^9}, {3.49804413359375*^9, 3.498044188484375*^9}, {
   3.49804668990625*^9, 3.49804668990625*^9}, {3.498047568421875*^9, 
   3.49804757196875*^9}, {3.551583107481226*^9, 3.551583152279571*^9}, {
   3.551768201703125*^9, 3.55176820990625*^9}, {3.552045533390625*^9, 
   3.55204553815625*^9}, {3.552474224421875*^9, 3.552474229578125*^9}, 
   3.553257495609375*^9},
 FontSize->18],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ntermx1", "=", " ", "50"}], ";"}], "   "}]], "Input",
 CellChangeTimes->{{3.428805952859375*^9, 3.428805953796875*^9}, 
   3.497790041265625*^9, {3.497872552578125*^9, 3.49787255678125*^9}, {
   3.497878751484375*^9, 3.497878752171875*^9}, {3.497958456328125*^9, 
   3.497958459125*^9}, {3.49795850165625*^9, 3.497958509921875*^9}, 
   3.497958636109375*^9, {3.551583386908333*^9, 3.5515834150336246`*^9}, {
   3.5517689236875*^9, 3.55176892559375*^9}, {3.55325539653125*^9, 
   3.55325539765625*^9}, {3.55325774984375*^9, 3.553257750859375*^9}, 
   3.55325779746875*^9},
 FontSize->24],

Cell[BoxData[
 RowBox[{"Do", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"limit\[Rho]pcoef", "[", "kk", "]"}], "=", 
    RowBox[{"Limit", "[", 
     RowBox[{
      RowBox[{"\[Rho]pcoef", "[", "m", "]"}], ",", 
      RowBox[{"m", "\[Rule]", "kk"}], ",", 
      RowBox[{"Direction", "\[Rule]", 
       RowBox[{"-", "1"}]}]}], "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"kk", ",", 
     RowBox[{"-", "ntermx1"}], ",", "ntermx1"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.497785910640625*^9, 3.497785911875*^9}, {
   3.497789488453125*^9, 3.497789495515625*^9}, 3.497851175*^9, {
   3.497872168921875*^9, 3.497872200640625*^9}, {3.4978725600625*^9, 
   3.497872563453125*^9}, {3.49787259540625*^9, 3.4978725961875*^9}, {
   3.497964689515625*^9, 3.497964692046875*^9}, {3.49804422484375*^9, 
   3.498044239484375*^9}, {3.498046689921875*^9, 3.498046689921875*^9}, {
   3.4980475730625*^9, 3.49804757359375*^9}, {3.552474388265625*^9, 
   3.552474411078125*^9}},
 FontSize->24],

Cell[BoxData[
 RowBox[{"Do", "[", 
  RowBox[{
   RowBox[{"Print", "[", 
    RowBox[{"{", 
     RowBox[{"kk", ",", 
      RowBox[{"Chop", "[", 
       RowBox[{
        SubscriptBox["a", "0"], "*", 
        RowBox[{"N", "[", 
         RowBox[{"limit\[Rho]pcoef", "[", "kk", "]"}], "]"}]}], "]"}]}], 
     "}"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"kk", ",", 
     RowBox[{"-", "ntermx1"}], ",", "ntermx1"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.428807411671875*^9, 3.428807420390625*^9}, {
   3.4977715176875*^9, 3.497771518328125*^9}, {3.497772150734375*^9, 
   3.49777215484375*^9}, {3.49778591253125*^9, 3.497785913640625*^9}, {
   3.4977895053125*^9, 3.4977895100625*^9}, {3.49787220571875*^9, 
   3.497872209109375*^9}, {3.497872565984375*^9, 3.497872569609375*^9}, {
   3.49796469515625*^9, 3.49796469790625*^9}, {3.498044251625*^9, 
   3.498044256359375*^9}, {3.498046689921875*^9, 3.498046689921875*^9}, {
   3.49804757421875*^9, 3.498047574796875*^9}, 3.5517689348125*^9, {
   3.552047635109375*^9, 3.55204765134375*^9}, {3.55247445515625*^9, 
   3.5524744585*^9}, {3.552474504609375*^9, 3.55247452640625*^9}, {
   3.553766620345311*^9, 3.553766621600258*^9}},
 FontSize->24],

Cell["\<\
Let\[CloseCurlyQuote]s plot the Fourier Coefficients...\
\>", "Text",
 CellChangeTimes->{{3.551584959555848*^9, 3.551584970267025*^9}, 
   3.551768680171875*^9, {3.55176900090625*^9, 3.551769002203125*^9}, 
   3.55204570290625*^9, 3.552047902484375*^9, 3.5524748724375*^9, {
   3.553255498140625*^9, 3.55325550059375*^9}, {3.55325785421875*^9, 
   3.553257864*^9}, 3.553784851824059*^9, {3.5752594860794754`*^9, 
   3.5752594913267756`*^9}},
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{"DiscretePlot", "[", 
  RowBox[{
   RowBox[{
    SubscriptBox["a", "0"], "*", 
    RowBox[{"limit\[Rho]pcoef", "[", "m", "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"m", ",", 
     RowBox[{"-", "ntermx1"}], ",", "ntermx1", ",", "1"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}], ",", "\[IndentingNewLine]", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"PointSize", "[", "0.01", "]"}]}], ",", 
   RowBox[{"PlotLabel", "\[Rule]", " ", "\"\<coefficienti di Fourier\>\""}]}],
   "]"}]], "Input",
 CellChangeTimes->{{3.498830789328125*^9, 3.49883081171875*^9}, {
   3.498830863421875*^9, 3.498830871296875*^9}, {3.498830911046875*^9, 
   3.49883093903125*^9}, {3.498830978640625*^9, 3.4988309796875*^9}, {
   3.552474482609375*^9, 3.552474486875*^9}, {3.553255455046875*^9, 
   3.55325546090625*^9}, {3.5532565415625*^9, 3.553256545234375*^9}, {
   3.5537722689765863`*^9, 3.553772271248589*^9}, {3.5537723031707993`*^9, 
   3.553772303574485*^9}, 3.553828511859182*^9},
 FontSize->18],

Cell[BoxData[
 RowBox[{
  RowBox[{"twoatomsreconstructed", "[", 
   RowBox[{"x_", ",", "ntermx_"}], "]"}], ":=", "\[IndentingNewLine]", 
  RowBox[{"Sum", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"N", "[", 
      RowBox[{"limit\[Rho]pcoef", "[", "m", "]"}], "]"}], 
     RowBox[{"Exp", "[", 
      RowBox[{"\[ImaginaryI]", " ", 
       FractionBox[
        RowBox[{"2", " ", "\[Pi]"}], 
        SubscriptBox["a", "0"]], " ", "m", " ", "x"}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"m", ",", 
      RowBox[{"-", "ntermx"}], ",", "ntermx", ",", "1"}], "}"}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.4977846765625*^9, 3.49778468925*^9}, 
   3.49778591696875*^9, {3.497790098984375*^9, 3.497790107625*^9}, 
   3.497851247328125*^9, {3.4978722359375*^9, 3.497872243625*^9}, 
   3.497877119921875*^9, {3.497956206296875*^9, 3.497956230015625*^9}, {
   3.497964733078125*^9, 3.497964746265625*^9}, {3.49804435278125*^9, 
   3.498044379703125*^9}, {3.4980466899375*^9, 3.4980466899375*^9}, {
   3.498047581515625*^9, 3.498047582359375*^9}, {3.55158393296852*^9, 
   3.5515839339627743`*^9}, 3.551768633875*^9, {3.55247460209375*^9, 
   3.552474606171875*^9}, {3.552474841828125*^9, 3.5524748549375*^9}},
 FontSize->24],

Cell["twoatomsreconstructed[x, 50]", "Text",
 CellChangeTimes->{{3.551584959555848*^9, 3.551584970267025*^9}, 
   3.551768680171875*^9, {3.55176900090625*^9, 3.551769002203125*^9}, 
   3.55204570290625*^9, 3.552047902484375*^9, 3.5524748724375*^9, {
   3.553255498140625*^9, 3.55325550059375*^9}, {3.55325785421875*^9, 
   3.553257864*^9}, 3.553784851824059*^9},
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ntermx1", "=", "50"}], ";"}], "   "}]], "Input",
 CellChangeTimes->{{3.428805952859375*^9, 3.428805953796875*^9}, 
   3.497790041265625*^9, {3.497871850125*^9, 3.49787186378125*^9}, {
   3.551583906613091*^9, 3.551583907878812*^9}, {3.5515849098069477`*^9, 
   3.551584914468207*^9}, {3.55176901425*^9, 3.551769015296875*^9}, {
   3.553255509125*^9, 3.553255509921875*^9}, {3.55325788025*^9, 
   3.553257881234375*^9}, 3.5753474990973797`*^9},
 FontSize->24],

Cell["Now only Cos-terms appear....", "Text",
 CellChangeTimes->{{3.55210326834375*^9, 3.55210329003125*^9}, {
  3.5752593537679076`*^9, 3.5752593613583417`*^9}},
 FontFamily->"Times New Roman",
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{"twoatomsevenfunction", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"ExpToTrig", "[", 
    RowBox[{"twoatomsreconstructed", "[", 
     RowBox[{"x", ",", "ntermx1"}], "]"}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.49787224809375*^9, 3.497872253078125*^9}, 
   3.49796475559375*^9, {3.49804440078125*^9, 3.498044411578125*^9}, {
   3.4980466899375*^9, 3.4980466899375*^9}, 3.498047585875*^9, {
   3.498049256078125*^9, 3.498049260109375*^9}, 3.55176911434375*^9, 
   3.552045717640625*^9, 3.552102932265625*^9, {3.5524746964375*^9, 
   3.552474702203125*^9}, {3.552474888578125*^9, 3.552474914859375*^9}, {
   3.553255109859375*^9, 3.553255161578125*^9}, {3.553255209453125*^9, 
   3.55325521509375*^9}},
 FontSize->24],

Cell[BoxData[
 RowBox[{"graphtwoatoms", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"Vol1D", "*", 
     SubscriptBox["a", "0"], "*", "twoatomsevenfunction"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", 
      RowBox[{
       SubscriptBox["a", "0"], "/", "1"}]}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
    RowBox[{"PlotPoints", "\[Rule]", "500"}], ",", 
    RowBox[{"PlotLabel", "\[Rule]", 
     RowBox[{"{", "\"\<Somma parziale  con 50 termini\>\"", "}"}]}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Hue", "[", "0.03", "]"}], "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4978512726875*^9, 3.497851283875*^9}, 
   3.497872260125*^9, {3.497872310390625*^9, 3.497872334546875*^9}, {
   3.49787712753125*^9, 3.497877130953125*^9}, {3.497877959171875*^9, 
   3.497877961453125*^9}, 3.497956241875*^9, 3.49796475821875*^9, {
   3.4980444443125*^9, 3.49804446215625*^9}, {3.498044733015625*^9, 
   3.49804473346875*^9}, {3.498044781859375*^9, 3.49804479678125*^9}, 
   3.498046689953125*^9, {3.498049228421875*^9, 3.498049232453125*^9}, {
   3.498049267046875*^9, 3.4980492711875*^9}, 3.4980494680625*^9, 
   3.49810709121875*^9, {3.551584005731084*^9, 3.5515840124204206`*^9}, {
   3.55176872721875*^9, 3.551768748625*^9}, {3.551769042859375*^9, 
   3.5517690636875*^9}, 3.551769124734375*^9, {3.55247494009375*^9, 
   3.552474973921875*^9}, {3.55247501121875*^9, 3.55247501428125*^9}, {
   3.553254977875*^9, 3.5532550053125*^9}, {3.5532550615*^9, 
   3.553255080125*^9}, {3.5532552733125*^9, 3.553255356453125*^9}, {
   3.5532579200625*^9, 3.553257923859375*^9}, {3.553772529194261*^9, 
   3.553772535675271*^9}, {3.553772574912265*^9, 3.553772576887972*^9}},
 FontSize->24]
},
CellGrouping->Manual,
WindowSize->{1904, 946},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
Magnification->0.7999999523162842,
FrontEndVersion->"8.0 for Microsoft Windows (64-bit) (February 23, 2011)",
StyleDefinitions->"StyleZo2.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[557, 20, 370, 6, 92, "Text"],
Cell[930, 28, 5317, 122, 618, "Text"],
Cell[6250, 152, 1674, 33, 75, "Input"],
Cell[CellGroupData[{
Cell[7949, 189, 503, 10, 56, "Text"],
Cell[8455, 201, 286, 7, 33, "Input"],
Cell[8744, 210, 533, 13, 33, "Input"],
Cell[9280, 225, 449, 8, 33, "Input"],
Cell[9732, 235, 506, 9, 33, "Input"],
Cell[10241, 246, 616, 10, 33, "Input"],
Cell[10860, 258, 646, 11, 33, "Input"],
Cell[11509, 271, 650, 11, 33, "Input"],
Cell[12162, 284, 453, 8, 33, "Input"],
Cell[12618, 294, 498, 9, 33, "Input"],
Cell[13119, 305, 547, 9, 33, "Input"],
Cell[13669, 316, 608, 10, 33, "Input"],
Cell[14280, 328, 661, 11, 33, "Input"],
Cell[14944, 341, 488, 10, 33, "Input"],
Cell[15435, 353, 475, 10, 33, "Input"],
Cell[15913, 365, 322, 8, 33, "Input"],
Cell[16238, 375, 346, 8, 33, "Input"],
Cell[16587, 385, 391, 8, 33, "Input"],
Cell[16981, 395, 444, 9, 33, "Input"],
Cell[17428, 406, 232, 6, 33, "Input"],
Cell[17663, 414, 352, 8, 33, "Input"],
Cell[18018, 424, 470, 9, 33, "Input"],
Cell[18491, 435, 425, 9, 33, "Input"],
Cell[18919, 446, 500, 12, 27, "Input"],
Cell[19422, 460, 512, 13, 27, "Input"],
Cell[19937, 475, 757, 18, 59, "Input"],
Cell[20697, 495, 1176, 26, 43, "Input"],
Cell[21876, 523, 214, 4, 24, "Input"],
Cell[22093, 529, 517, 13, 44, "Text"],
Cell[22613, 544, 561, 13, 59, "Input"],
Cell[23177, 559, 553, 15, 44, "Text"],
Cell[23733, 576, 710, 16, 59, "Input"],
Cell[24446, 594, 478, 9, 44, "Text"],
Cell[24927, 605, 948, 23, 27, "Input"],
Cell[25878, 630, 1110, 27, 27, "Input"],
Cell[26991, 659, 1220, 30, 27, "Input"],
Cell[28214, 691, 954, 22, 27, "Input"],
Cell[29171, 715, 1121, 27, 27, "Input"],
Cell[30295, 744, 1171, 29, 27, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[31503, 778, 1252, 20, 56, "Text"],
Cell[32758, 800, 9386, 181, 441, "Text"],
Cell[42147, 983, 1335, 22, 46, "Text"],
Cell[43485, 1007, 1328, 21, 46, "Text"],
Cell[44816, 1030, 4244, 122, 178, "Input"],
Cell[49063, 1154, 1331, 21, 46, "Text"],
Cell[50397, 1177, 4340, 123, 178, "Input"]
}, Open  ]],
Cell[54752, 1303, 1636, 28, 123, "Text"],
Cell[56391, 1333, 2057, 40, 33, "Input"],
Cell[58451, 1375, 1677, 33, 59, "Input"],
Cell[60131, 1410, 541, 10, 46, "Text"],
Cell[60675, 1422, 828, 23, 100, "Input"],
Cell[61506, 1447, 376, 10, 33, "Input"],
Cell[61885, 1459, 948, 23, 75, "Text"],
Cell[62836, 1484, 403, 11, 33, "Input"],
Cell[63242, 1497, 562, 11, 46, "Text"],
Cell[63807, 1510, 3115, 55, 62, "Input"],
Cell[66925, 1567, 630, 13, 72, "Text"],
Cell[67558, 1582, 1434, 36, 90, "Input"],
Cell[68995, 1620, 2843, 51, 33, "Input"],
Cell[71841, 1673, 4770, 90, 286, "Text"],
Cell[76614, 1765, 3538, 58, 27, "Input",
 CellID->53852264],
Cell[80155, 1825, 208, 6, 27, "Input"],
Cell[80366, 1833, 1071, 39, 46, "Text"],
Cell[81440, 1874, 430, 11, 33, "Input"],
Cell[81873, 1887, 608, 16, 62, "Input"],
Cell[82484, 1905, 714, 19, 62, "Input"],
Cell[83201, 1926, 293, 6, 46, "Text"],
Cell[83497, 1934, 331, 7, 33, "Input"],
Cell[83831, 1943, 1301, 31, 62, "Input"],
Cell[85135, 1976, 1203, 27, 62, "Input"],
Cell[86341, 2005, 478, 14, 67, "Input"],
Cell[86822, 2021, 1547, 32, 124, "Text"],
Cell[88372, 2055, 315, 7, 46, "Text"],
Cell[88690, 2064, 172, 3, 32, "Text"],
Cell[88865, 2069, 2232, 50, 45, "Input"],
Cell[91100, 2121, 323, 7, 46, "Text"],
Cell[91426, 2130, 2251, 51, 45, "Input"],
Cell[93680, 2183, 1890, 42, 47, "Text"],
Cell[95573, 2227, 2095, 48, 45, "Input"],
Cell[97671, 2277, 2139, 50, 45, "Input"],
Cell[99813, 2329, 919, 17, 72, "Text"],
Cell[100735, 2348, 1472, 30, 48, "Input"],
Cell[102210, 2380, 1419, 29, 48, "Input"],
Cell[103632, 2411, 760, 13, 46, "Text"],
Cell[CellGroupData[{
Cell[104417, 2428, 716, 13, 56, "Text"],
Cell[105136, 2443, 1198, 22, 208, "Text"]
}, Open  ]],
Cell[106349, 2468, 2036, 38, 33, "Input"],
Cell[108388, 2508, 772, 19, 48, "Input"],
Cell[109163, 2529, 1420, 24, 46, "Text"],
Cell[110586, 2555, 715, 20, 48, "Input"],
Cell[111304, 2577, 465, 12, 27, "Input"],
Cell[111772, 2591, 1602, 37, 88, "Input"],
Cell[113377, 2630, 328, 10, 27, "Input"],
Cell[113708, 2642, 329, 10, 27, "Input"],
Cell[114040, 2654, 3088, 55, 62, "Input"],
Cell[117131, 2711, 1369, 21, 46, "Text"],
Cell[118503, 2734, 470, 14, 27, "Input"],
Cell[118976, 2750, 418, 12, 48, "Input"],
Cell[119397, 2764, 569, 15, 45, "Input"],
Cell[119969, 2781, 593, 17, 67, "Input"],
Cell[120565, 2800, 1430, 34, 62, "Input"],
Cell[121998, 2836, 404, 8, 27, "Input"],
Cell[122405, 2846, 718, 20, 45, "Input"],
Cell[123126, 2868, 478, 14, 67, "Input"],
Cell[123607, 2884, 1316, 34, 27, "Input"],
Cell[124926, 2920, 1844, 35, 48, "Input"],
Cell[CellGroupData[{
Cell[126795, 2959, 869, 15, 56, "Text"],
Cell[127667, 2976, 1923, 50, 193, "Text"]
}, Open  ]],
Cell[129605, 3029, 1470, 33, 46, "Input"],
Cell[131078, 3064, 633, 12, 33, "Input"],
Cell[131714, 3078, 978, 22, 33, "Input"],
Cell[132695, 3102, 1200, 26, 33, "Input"],
Cell[133898, 3130, 496, 10, 44, "Text"],
Cell[134397, 3142, 1020, 21, 48, "Input"],
Cell[135420, 3165, 1226, 27, 91, "Input"],
Cell[136649, 3194, 407, 7, 44, "Text"],
Cell[137059, 3203, 505, 10, 33, "Input"],
Cell[137567, 3215, 239, 5, 44, "Text"],
Cell[137809, 3222, 749, 14, 33, "Input"],
Cell[138561, 3238, 1791, 34, 62, "Input"]
}
]
*)

(* End of internal cache information *)
