(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    132525,       3248]
NotebookOptionsPosition[    126595,       3100]
NotebookOutlinePosition[    127081,       3119]
CellTagsIndexPosition[    127038,       3116]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[StyleBox["Evaluation time\n\[CapitalDelta]t  < 40 min",
 FontColor->RGBColor[0, 0, 1]]], "Text",
 CellChangeTimes->{{3.552825182304793*^9, 3.552825225090515*^9}, 
   3.552826287262672*^9, {3.5529856190149317`*^9, 3.55298562337449*^9}, {
   3.552985761083598*^9, 3.552985763576391*^9}, {3.552988399163571*^9, 
   3.5529884045767927`*^9}, {3.573990446026321*^9, 3.573990455736479*^9}, {
   3.575285221453306*^9, 3.5752852271806335`*^9}},
 FontSize->24,
 Background->RGBColor[1, 0.9, 0.8]],

Cell[TextData[{
 StyleBox["Series expansion of the approximated susceptibility after the \
deformation ",
  FontColor->RGBColor[0, 0, 1]],
 Cell[BoxData[
  StyleBox["\[Chi]",
   FontFamily->"Courier",
   FontSize->22]], "None",
  FontFamily->"Times New Roman",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["\[CloseCurlyQuote], \nby means of the Fourier coefficients of the \
susceptibility ",
  FontColor->RGBColor[0, 0, 1]],
 Cell[BoxData[
  StyleBox["\[Chi]",
   FontFamily->"Courier",
   FontSize->22]], "None",
  FontFamily->"Times New Roman",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[".\n\nThis notebook is an extension to a 2D case of the previous \
one (see Chap2-3-Chi-1D-Deformation.nb).\n\nLet us begin with some remarks \
from Chapter 2 of the text.\n\nThe electric susceptibility \[Chi] of a \
perfect crystal equals the atomic density \[Rho] \nup to a multiplicative \
constant (see Section 2.2). \nFor sake of simplicity, here we make no \
dinstiction between the quantities \[Chi] and \[Rho]\n(as already done in \
Chap2-3-Chi-1D-Deformation.nb).\n\nThe deformation of a crystal lattice is \
represented by mean of \n an invertible transformation g of the following \
form: r'=g[r]=r+u[r].   \n\nThe electric susceptibility after the deformation \
is represented by a function \[Chi]'\ndefined as ",
  FontColor->RGBColor[0, 0, 1]],
 Cell[BoxData[
  StyleBox["\[Chi]",
   FontFamily->"Courier",
   FontSize->22]], "None",
  FontFamily->"Times New Roman",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["'[r]:=\[Chi][",
  FontColor->RGBColor[0, 0, 1]],
 Cell[BoxData[
  SuperscriptBox["g", 
   RowBox[{"-", "1"}]]],
  FontFamily->"Times New Roman",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["[r]].\n\nUnder the assumption that the function u[r] assumes small \
values (in comparison\nto the interplanar distances), we can approximate ",
  FontColor->RGBColor[0, 0, 1]],
 Cell[BoxData[
  SuperscriptBox["g", 
   RowBox[{"-", "1"}]]],
  FontFamily->"Times New Roman",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["[r]\[TildeEqual] r-u[r], so that the \nfollowing approximation \
holds:\n\n",
  FontColor->RGBColor[0, 0, 1]],
 Cell[BoxData[
  StyleBox["\[Chi]",
   FontFamily->"Courier",
   FontSize->22]], "None",
  FontFamily->"Times New Roman",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["'[r]=\[Chi][",
  FontColor->RGBColor[0, 0, 1]],
 Cell[BoxData[
  SuperscriptBox["g", 
   RowBox[{"-", "1"}]]],
  FontFamily->"Times New Roman",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["[r]]\[TildeEqual]\[Chi][r-u[r]]=:",
  FontColor->RGBColor[0, 0, 1]],
 Cell[BoxData[
  FormBox[
   OverscriptBox[
    StyleBox["\[Chi]",
     FontFamily->"Courier"], "~"], TraditionalForm]], "None",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["[r]. \n\nAccording to such an approximation, if \n\n\[Chi][r]=",
  FontColor->RGBColor[0, 0, 1]],
 Cell[BoxData[
  FormBox[
   RowBox[{
    UnderscriptBox["\[Sum]", 
     StyleBox[
      RowBox[{" ", "g"}],
      FontSize->15,
      FontWeight->"Bold",
      FontSlant->"Plain"]], 
    RowBox[{
     SubscriptBox[
      StyleBox["\[Chi]",
       FontFamily->"Courier New"], 
      StyleBox["g",
       FontSize->15,
       FontWeight->"Bold"]], 
     SuperscriptBox["e", 
      RowBox[{" ", 
       RowBox[{"\[ImaginaryI]", " ", 
        RowBox[{
         StyleBox["g",
          FontSize->15,
          FontWeight->"Bold"], " ", "\[CenterDot]", " ", 
         StyleBox["r",
          FontSize->15,
          FontWeight->"Bold",
          FontSlant->"Plain"]}]}]}]]}]}], TraditionalForm]],
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["             (1)\n\nis the Fourier expansion of ",
  FontColor->RGBColor[0, 0, 1]],
 Cell[BoxData[
  StyleBox["\[Chi]",
   FontFamily->"Courier",
   FontSize->22]], "None",
  FontFamily->"Times New Roman",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[" (cf. Subsection 2.3.1), then the exact susceptibility after the \
deformation ",
  FontColor->RGBColor[0, 0, 1]],
 Cell[BoxData[
  StyleBox["\[Chi]",
   FontFamily->"Courier",
   FontSize->22]], "None",
  FontFamily->"Times New Roman",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["' \ncan be estimated by means of the partial sums of the \
corresponding series expansion:\n\n",
  FontColor->RGBColor[0, 0, 1]],
 Cell[BoxData[
  FormBox[
   OverscriptBox[
    StyleBox["\[Chi]",
     FontFamily->"Courier"], "~"], TraditionalForm]], "None",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["[r]=\[Chi][r-u[r]]=",
  FontColor->RGBColor[0, 0, 1]],
 Cell[BoxData[
  FormBox[
   RowBox[{
    UnderscriptBox["\[Sum]", 
     StyleBox[
      RowBox[{" ", "g"}],
      FontSize->15,
      FontWeight->"Bold",
      FontSlant->"Plain"]], 
    SubscriptBox[
     StyleBox["\[Chi]",
      FontFamily->"Courier New"], 
     StyleBox["g",
      FontSize->15,
      FontWeight->"Bold"]]}], TraditionalForm]],
  FontColor->RGBColor[0, 0, 1]],
 Cell[BoxData[
  FormBox[
   RowBox[{" ", 
    SuperscriptBox["e", 
     RowBox[{" ", 
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{
        StyleBox["g",
         FontSize->15,
         FontWeight->"Bold"], " ", "\[CenterDot]", " ", 
        RowBox[{"(", 
         StyleBox[
          RowBox[{
           StyleBox["r", "Text",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
           StyleBox["-",
            FontWeight->"Plain"], 
           RowBox[{
            StyleBox["u",
             FontWeight->"Plain"], 
            StyleBox["[",
             FontWeight->"Plain"], 
            StyleBox["r",
             FontWeight->"Bold",
             FontSlant->"Plain"], 
            StyleBox["]",
             FontWeight->"Plain"]}]}],
          FontFamily->"Courier New",
          FontSize->15], 
         StyleBox[")",
          FontFamily->"Courier New",
          FontSize->15]}]}]}]}]]}], TraditionalForm]],
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[" \n\nof the approximated susceptibility after the\n displacement \
u[r].",
  FontColor->RGBColor[0, 0, 1]]
}], "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10001.},
 CellChangeTimes->{{3.43609917853125*^9, 3.436099224875*^9}, {
   3.451201105219131*^9, 3.4512011607417097`*^9}, {3.451202261049141*^9, 
   3.4512022642358913`*^9}, {3.451380513178369*^9, 3.45138054907161*^9}, {
   3.451380621354679*^9, 3.4513806318446302`*^9}, {3.451380663944434*^9, 
   3.451380665324871*^9}, 3.451380835741723*^9, {3.451380883232542*^9, 
   3.451380932025751*^9}, {3.45138098428447*^9, 3.451381101560313*^9}, {
   3.451381137605834*^9, 3.4513812892934093`*^9}, {3.451381335947049*^9, 
   3.4513813424192867`*^9}, {3.451381406000942*^9, 3.4513815693796167`*^9}, {
   3.451381599587194*^9, 3.4513816160378428`*^9}, {3.451381648755763*^9, 
   3.451381662300729*^9}, {3.451381704127902*^9, 3.45138171648451*^9}, {
   3.451382259750657*^9, 3.451382312554418*^9}, {3.4513832778456984`*^9, 
   3.4513833884064627`*^9}, {3.4513834207689877`*^9, 
   3.4513834284008837`*^9}, {3.45138347707425*^9, 3.451383535066996*^9}, {
   3.451383600079137*^9, 3.451383608542776*^9}, {3.451383641804398*^9, 
   3.4513836594058237`*^9}, {3.4513837085029287`*^9, 
   3.4513837950532207`*^9}, {3.451383842090927*^9, 3.451383869607256*^9}, {
   3.451383972789274*^9, 3.451384074278797*^9}, {3.451384120558514*^9, 
   3.4513841250309677`*^9}, {3.451623575273048*^9, 3.451623576629842*^9}, {
   3.451623723281217*^9, 3.4516237502320232`*^9}, {3.4516252629844713`*^9, 
   3.451625277865951*^9}, 3.4516301683616*^9, {3.451630274543489*^9, 
   3.451630319368353*^9}, {3.45163038029524*^9, 3.4516304496679487`*^9}, {
   3.45163048058594*^9, 3.451630508022175*^9}, {3.451630543243938*^9, 
   3.451630554396184*^9}, {3.4516305844061337`*^9, 3.4516305965389*^9}, {
   3.451630671518499*^9, 3.45163074097786*^9}, {3.451630789384632*^9, 
   3.451630834297195*^9}, {3.451630882513088*^9, 3.451630887383438*^9}, {
   3.451630958466445*^9, 3.4516310233802843`*^9}, {3.451631107681582*^9, 
   3.45163115383357*^9}, {3.4516357609731703`*^9, 3.451635762360878*^9}, {
   3.451635972151944*^9, 3.451636005181984*^9}, {3.4516402816594057`*^9, 
   3.4516402868771152`*^9}, {3.451718418411845*^9, 3.451718532230791*^9}, {
   3.451718572022703*^9, 3.451718636750465*^9}, {3.45171873269027*^9, 
   3.45171874852979*^9}, 3.451718817600716*^9, 3.451719631281345*^9, {
   3.4517197104528837`*^9, 3.4517200758146763`*^9}, {3.451720168016982*^9, 
   3.451720322906805*^9}, 3.451720357930373*^9, {3.451720392408083*^9, 
   3.4517204987574453`*^9}, {3.451720545320046*^9, 3.45172055124533*^9}, {
   3.451721255481255*^9, 3.451721275242407*^9}, {3.4517271352554398`*^9, 
   3.451727156645337*^9}, {3.4517274572440367`*^9, 3.451727461141712*^9}, {
   3.451727558386169*^9, 3.4517275648990917`*^9}, {3.451727605239909*^9, 
   3.451727641435083*^9}, 3.451729695420402*^9, {3.451729750634655*^9, 
   3.451729873244254*^9}, {3.451730002795368*^9, 3.4517300120559387`*^9}, {
   3.45911542234375*^9, 3.45911547275*^9}, {3.459115723375*^9, 
   3.459115747234375*^9}, {3.459115777421875*^9, 3.45911580071875*^9}, {
   3.459115838765625*^9, 3.4591158911875*^9}, {3.459116171578125*^9, 
   3.459116177234375*^9}, {3.4591162725625*^9, 3.459116291234375*^9}, {
   3.459116326796875*^9, 3.459116403703125*^9}, {3.45911644571875*^9, 
   3.459116532390625*^9}, {3.45911656446875*^9, 3.4591166079375*^9}, {
   3.459116653375*^9, 3.459116755828125*^9}, {3.45911682465625*^9, 
   3.459116869296875*^9}, {3.459116900890625*^9, 3.459116947375*^9}, {
   3.459117026890625*^9, 3.459117030734375*^9}, {3.459117113984375*^9, 
   3.45911717959375*^9}, {3.45911742165625*^9, 3.45911745671875*^9}, {
   3.459117496234375*^9, 3.459117656375*^9}, {3.459117804515625*^9, 
   3.4591178465*^9}, {3.459117889671875*^9, 3.459117943828125*^9}, {
   3.459117976109375*^9, 3.45911821184375*^9}, {3.459118252421875*^9, 
   3.4591183270625*^9}, {3.45911839728125*^9, 3.45911849109375*^9}, {
   3.459118552953125*^9, 3.45911865771875*^9}, {3.459118706015625*^9, 
   3.459118713484375*^9}, {3.459118798359375*^9, 3.4591188668125*^9}, {
   3.459118963578125*^9, 3.459119082375*^9}, {3.459119116703125*^9, 
   3.459119161234375*^9}, {3.459119315609375*^9, 3.459119323359375*^9}, {
   3.459119359296875*^9, 3.4591193660625*^9}, {3.4591587146875*^9, 
   3.4591587818125*^9}, {3.4591588135625*^9, 3.459158919328125*^9}, {
   3.459158956921875*^9, 3.45915908328125*^9}, {3.459159129515625*^9, 
   3.459159129859375*^9}, {3.459159340984375*^9, 3.459159340984375*^9}, {
   3.459159386828125*^9, 3.459159388625*^9}, {3.459160295890625*^9, 
   3.459160319921875*^9}, {3.4591603538125*^9, 3.459160395921875*^9}, {
   3.459160459703125*^9, 3.459160459703125*^9}, {3.459160812296875*^9, 
   3.45916081290625*^9}, 3.45916085278125*^9, {3.459160936375*^9, 
   3.459160937671875*^9}, 3.45916106203125*^9, {3.459170302734375*^9, 
   3.459170322953125*^9}, {3.459246987390625*^9, 3.459247070375*^9}, 
   3.45955491*^9, {3.506949795451168*^9, 3.506949843195879*^9}, {
   3.507189118468401*^9, 3.50718912417351*^9}, {3.507380145166683*^9, 
   3.50738016704178*^9}, {3.575285240479394*^9, 3.575285352212785*^9}, {
   3.5752853995004897`*^9, 3.575285525364689*^9}},
 FontFamily->"Times New Roman",
 FontSize->22,
 FontColor->GrayLevel[0],
 Background->RGBColor[1, 1, 0.85]],

Cell[TextData[{
 StyleBox["The above mentioned estimate by means of partial sums is the aim \
of this notebook, \nwhere we consider t",
  FontColor->RGBColor[0, 0, 1],
  Background->RGBColor[1, 1, 0.85]],
 StyleBox["he case of a 2D lattice, whose points are located at the centers\n\
of rectangular primitive cells with edge lengths ",
  FontSize->22,
  FontColor->RGBColor[0, 0, 1],
  Background->RGBColor[1, 1, 0.85]],
 StyleBox["a",
  FontFamily->"Courier New",
  FontColor->RGBColor[0, 0, 1],
  Background->RGBColor[1, 1, 0.85]],
 StyleBox[" and ",
  FontColor->RGBColor[0, 0, 1],
  Background->RGBColor[1, 1, 0.85]],
 StyleBox["b",
  FontFamily->"Courier New",
  FontColor->RGBColor[0, 0, 1],
  Background->RGBColor[1, 1, 0.85]],
 StyleBox[" (each lattice point corresponds to an atom).\n\nThus, setting the \
origin at a lattice point and fixing the cartesian reference frame with axes \
parallel to\nthe primitive vectors of the lattice, the primitive cell \
containing one lattice point at the origin is  given by\nthe rectangle ",
  FontSize->22,
  FontColor->RGBColor[0, 0, 1],
  Background->RGBColor[1, 1, 0.85]],
 StyleBox["[-",
  FontColor->RGBColor[0, 0, 1],
  Background->RGBColor[1, 1, 0.85]],
 Cell[BoxData[
  FractionBox["a", "2"]],
  CellChangeTimes->{
   3.4589913816875*^9, {3.458991419078125*^9, 3.458991453234375*^9}},
  FontFamily->"Times New Roman",
  FontColor->RGBColor[0, 0, 1],
  Background->RGBColor[1, 1, 0.85]],
 StyleBox[", ",
  FontColor->RGBColor[0, 0, 1],
  Background->RGBColor[1, 1, 0.85]],
 Cell[BoxData[
  FractionBox["a", "2"]],
  CellChangeTimes->{
   3.4589913816875*^9, {3.458991419078125*^9, 3.458991453234375*^9}},
  FontFamily->"Times New Roman",
  FontColor->RGBColor[0, 0, 1],
  Background->RGBColor[1, 1, 0.85]],
 StyleBox["]\[Times][-",
  FontColor->RGBColor[0, 0, 1],
  Background->RGBColor[1, 1, 0.85]],
 Cell[BoxData[
  FractionBox["b", "2"]],
  CellChangeTimes->{
   3.4589913816875*^9, {3.458991419078125*^9, 3.458991453234375*^9}},
  FontFamily->"Times New Roman",
  FontColor->RGBColor[0, 0, 1],
  Background->RGBColor[1, 1, 0.85]],
 StyleBox[", ",
  FontColor->RGBColor[0, 0, 1],
  Background->RGBColor[1, 1, 0.85]],
 Cell[BoxData[
  FractionBox["b", "2"]],
  CellChangeTimes->{
   3.4589913816875*^9, {3.458991419078125*^9, 3.458991453234375*^9}},
  FontFamily->"Times New Roman",
  FontColor->RGBColor[0, 0, 1],
  Background->RGBColor[1, 1, 0.85]],
 StyleBox["].",
  FontColor->RGBColor[0, 0, 1],
  Background->RGBColor[1, 1, 0.85]],
 StyleBox["\n",
  FontFamily->"Courier New",
  FontColor->RGBColor[0, 0, 1],
  Background->RGBColor[1, 1, 0.85]],
 StyleBox["\nWe represent the electric susceptibility (of the perfect \
crystal) ",
  FontSize->22,
  FontColor->RGBColor[0, 0, 1],
  Background->RGBColor[1, 1, 0.85]],
 StyleBox["\[Chi]",
  FontFamily->"Courier New",
  FontColor->RGBColor[0, 0, 1],
  Background->RGBColor[1, 1, 0.85]],
 StyleBox[" by means of the following function, which is periodic \nin the \
variables ",
  FontSize->22,
  FontColor->RGBColor[0, 0, 1],
  Background->RGBColor[1, 1, 0.85]],
 StyleBox["x",
  FontFamily->"Courier New",
  FontColor->RGBColor[0, 0, 1],
  Background->RGBColor[1, 1, 0.85]],
 StyleBox[" and ",
  FontSize->22,
  FontColor->RGBColor[0, 0, 1],
  Background->RGBColor[1, 1, 0.85]],
 StyleBox["y",
  FontFamily->"Courier New",
  FontColor->RGBColor[0, 0, 1],
  Background->RGBColor[1, 1, 0.85]],
 StyleBox[" with periods ",
  FontSize->22,
  FontColor->RGBColor[0, 0, 1],
  Background->RGBColor[1, 1, 0.85]],
 StyleBox["a",
  FontFamily->"Courier New",
  FontColor->RGBColor[0, 0, 1],
  Background->RGBColor[1, 1, 0.85]],
 StyleBox[" and ",
  FontColor->RGBColor[0, 0, 1],
  Background->RGBColor[1, 1, 0.85]],
 StyleBox["b",
  FontFamily->"Courier New",
  FontColor->RGBColor[0, 0, 1],
  Background->RGBColor[1, 1, 0.85]],
 StyleBox[", respectively:\n\n",
  FontSize->22,
  FontColor->RGBColor[0, 0, 1],
  Background->RGBColor[1, 1, 0.85]],
 Cell[BoxData[
  RowBox[{
   RowBox[{
    StyleBox["\[Chi]",
     FontFamily->"Courier New"], "[", 
    RowBox[{"x", ",", "y"}], "]"}], ":=", 
   RowBox[{"Z", "*", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"Sin", "[", 
       FractionBox[
        RowBox[{"\[Pi]", " ", "x"}], "a"], "]"}], ")"}], "^", "6"}], "*", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"Sin", "[", 
       FractionBox[
        RowBox[{"\[Pi]", " ", "y"}], "b"], "]"}], ")"}], "^", "6"}]}]}]],
  CellChangeTimes->{
   3.4589913816875*^9, {3.458991419078125*^9, 3.458991453234375*^9}},
  FontFamily->"Times New Roman",
  FontColor->RGBColor[0, 0, 1],
  Background->RGBColor[1, 1, 0.85]],
 StyleBox["\n\nThis is supposed to be the definition of \[Rho]",
  FontColor->RGBColor[0, 0, 1],
  Background->RGBColor[1, 1, 0.85]],
 StyleBox[" bus as we have already said, we don\[CloseCurlyQuote]t \
distinguish it from \[Chi].\nNote: ",
  FontSize->22,
  FontColor->RGBColor[0, 0, 1],
  Background->RGBColor[1, 1, 0.85]],
 StyleBox["Z",
  FontFamily->"Courier New",
  FontSize->22,
  FontColor->RGBColor[0, 0, 1],
  Background->RGBColor[1, 1, 0.85]],
 StyleBox[" is the number of electrons per atom.\n\nThen we consider the \
linear deformation\n",
  FontSize->22,
  FontColor->RGBColor[0, 0, 1],
  Background->RGBColor[1, 1, 0.85]],
 StyleBox["\n",
  FontColor->RGBColor[0, 0, 1],
  Background->RGBColor[1, 1, 0.85]],
 Cell[BoxData[
  RowBox[{
   RowBox[{"u", "[", 
    RowBox[{"x", ",", "y"}], "]"}], ":=", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"\[Epsilon]", 
      StyleBox[" ",
       FontFamily->"Courier New",
       FontSize->16], "x"}], ",", 
     RowBox[{"\[Epsilon]", 
      StyleBox[" ",
       FontFamily->"Courier New",
       FontSize->16], "y"}]}], ")"}], " "}]],
  FontFamily->"Times New Roman",
  FontColor->RGBColor[0, 0, 1],
  Background->RGBColor[1, 1, 0.85]],
 StyleBox[" ",
  FontColor->RGBColor[0, 0, 1],
  Background->RGBColor[1, 1, 0.85]],
 StyleBox[" \n\n(where ",
  FontSize->22,
  FontColor->RGBColor[0, 0, 1],
  Background->RGBColor[1, 1, 0.85]],
 StyleBox["\[Epsilon]",
  FontFamily->"Courier New",
  FontColor->RGBColor[0, 0, 1],
  Background->RGBColor[1, 1, 0.85]],
 StyleBox[" is a ",
  FontSize->22,
  FontColor->RGBColor[0, 0, 1],
  Background->RGBColor[1, 1, 0.85]],
 StyleBox["small",
  FontSize->22,
  FontSlant->"Italic",
  FontColor->RGBColor[0, 0, 1],
  Background->RGBColor[1, 1, 0.85]],
 StyleBox[" parameter).\n\nSimilarly to the previous notebook, we divide as \
follows this one:\n\n- Part I: Evaluations with an undeformed (original) \
crystal;\n- Part II: Case of an approximated deformation;\n- Part III: Case \
of a deformation;\n- Part IV: Comparisons.",
  FontSize->22,
  FontColor->RGBColor[0, 0, 1],
  Background->RGBColor[1, 1, 0.85]]
}], "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10001.},
 CellChangeTimes->{{3.43609917853125*^9, 3.436099224875*^9}, {
   3.451201105219131*^9, 3.4512011607417097`*^9}, {3.451202261049141*^9, 
   3.4512022642358913`*^9}, {3.451380513178369*^9, 3.45138054907161*^9}, {
   3.451380621354679*^9, 3.4513806318446302`*^9}, {3.451380663944434*^9, 
   3.451380665324871*^9}, 3.451380835741723*^9, {3.451380883232542*^9, 
   3.451380932025751*^9}, {3.45138098428447*^9, 3.451381101560313*^9}, {
   3.451381137605834*^9, 3.4513812892934093`*^9}, {3.451381335947049*^9, 
   3.4513813424192867`*^9}, {3.451381406000942*^9, 3.4513815693796167`*^9}, {
   3.451381599587194*^9, 3.4513816160378428`*^9}, {3.451381648755763*^9, 
   3.451381662300729*^9}, {3.451381704127902*^9, 3.45138171648451*^9}, {
   3.451382259750657*^9, 3.451382312554418*^9}, {3.4513832778456984`*^9, 
   3.4513833884064627`*^9}, {3.4513834207689877`*^9, 
   3.4513834284008837`*^9}, {3.45138347707425*^9, 3.451383535066996*^9}, {
   3.451383600079137*^9, 3.451383608542776*^9}, {3.451383641804398*^9, 
   3.4513836594058237`*^9}, {3.4513837085029287`*^9, 
   3.4513837950532207`*^9}, {3.451383842090927*^9, 3.451383869607256*^9}, {
   3.451383972789274*^9, 3.451384074278797*^9}, {3.451384120558514*^9, 
   3.4513841250309677`*^9}, {3.451623575273048*^9, 3.451623576629842*^9}, {
   3.451623723281217*^9, 3.4516237502320232`*^9}, {3.4516252629844713`*^9, 
   3.451625277865951*^9}, 3.4516301683616*^9, {3.451630274543489*^9, 
   3.451630319368353*^9}, {3.45163038029524*^9, 3.4516304496679487`*^9}, {
   3.45163048058594*^9, 3.451630508022175*^9}, {3.451630543243938*^9, 
   3.451630554396184*^9}, {3.4516305844061337`*^9, 3.4516305965389*^9}, {
   3.451630671518499*^9, 3.45163074097786*^9}, {3.451630789384632*^9, 
   3.451630834297195*^9}, {3.451630882513088*^9, 3.451630887383438*^9}, {
   3.451630958466445*^9, 3.4516310233802843`*^9}, {3.451631107681582*^9, 
   3.45163115383357*^9}, {3.4516357609731703`*^9, 3.451635762360878*^9}, {
   3.451635972151944*^9, 3.451636005181984*^9}, {3.4516402816594057`*^9, 
   3.4516402868771152`*^9}, {3.451718418411845*^9, 3.451718532230791*^9}, {
   3.451718572022703*^9, 3.451718636750465*^9}, {3.45171873269027*^9, 
   3.45171874852979*^9}, 3.451718817600716*^9, 3.451719631281345*^9, {
   3.4517197104528837`*^9, 3.4517200758146763`*^9}, {3.451720168016982*^9, 
   3.451720322906805*^9}, 3.451720357930373*^9, {3.451720392408083*^9, 
   3.4517204987574453`*^9}, {3.451720545320046*^9, 3.45172055124533*^9}, {
   3.451721255481255*^9, 3.451721275242407*^9}, {3.4517271352554398`*^9, 
   3.451727156645337*^9}, {3.4517274572440367`*^9, 3.451727461141712*^9}, {
   3.451727558386169*^9, 3.4517275648990917`*^9}, {3.451727605239909*^9, 
   3.451727641435083*^9}, 3.451729695420402*^9, {3.451729750634655*^9, 
   3.451729873244254*^9}, {3.451730002795368*^9, 3.4517300120559387`*^9}, {
   3.45911542234375*^9, 3.45911547275*^9}, {3.459115723375*^9, 
   3.459115747234375*^9}, {3.459115777421875*^9, 3.45911580071875*^9}, {
   3.459115838765625*^9, 3.4591158911875*^9}, {3.459116171578125*^9, 
   3.459116177234375*^9}, {3.4591162725625*^9, 3.459116291234375*^9}, {
   3.459116326796875*^9, 3.459116403703125*^9}, {3.45911644571875*^9, 
   3.459116532390625*^9}, {3.45911656446875*^9, 3.4591166079375*^9}, {
   3.459116653375*^9, 3.459116755828125*^9}, {3.45911682465625*^9, 
   3.459116869296875*^9}, {3.459116900890625*^9, 3.459116947375*^9}, {
   3.459117026890625*^9, 3.459117030734375*^9}, {3.459117113984375*^9, 
   3.45911717959375*^9}, {3.45911742165625*^9, 3.45911745671875*^9}, {
   3.459117496234375*^9, 3.459117656375*^9}, {3.459117804515625*^9, 
   3.4591178465*^9}, {3.459117889671875*^9, 3.459117943828125*^9}, {
   3.459117976109375*^9, 3.45911821184375*^9}, {3.459118252421875*^9, 
   3.4591183270625*^9}, {3.45911839728125*^9, 3.45911849109375*^9}, {
   3.459118552953125*^9, 3.45911865771875*^9}, {3.459118706015625*^9, 
   3.459118713484375*^9}, {3.459118798359375*^9, 3.4591188668125*^9}, {
   3.459118963578125*^9, 3.459119082375*^9}, {3.459119116703125*^9, 
   3.459119161234375*^9}, {3.459119315609375*^9, 3.459119323359375*^9}, {
   3.459119359296875*^9, 3.4591193660625*^9}, {3.4591587146875*^9, 
   3.4591587818125*^9}, {3.4591588135625*^9, 3.459158919328125*^9}, {
   3.459158956921875*^9, 3.45915908328125*^9}, {3.459159129515625*^9, 
   3.459159129859375*^9}, {3.459159340984375*^9, 3.459159340984375*^9}, {
   3.459159386828125*^9, 3.459159388625*^9}, {3.459160295890625*^9, 
   3.459160319921875*^9}, {3.4591603538125*^9, 3.459160395921875*^9}, {
   3.459160459703125*^9, 3.459160459703125*^9}, {3.4591608998125*^9, 
   3.45916096196875*^9}, 3.45916106203125*^9, {3.459170302734375*^9, 
   3.459170322953125*^9}, 3.459249345296875*^9, {3.45924950621875*^9, 
   3.45924950621875*^9}, {3.4592498403125*^9, 3.459249843671875*^9}, {
   3.459254848203125*^9, 3.459254891078125*^9}, {3.459254986625*^9, 
   3.459255049515625*^9}, {3.45925510746875*^9, 3.459255113109375*^9}, {
   3.459255262125*^9, 3.459255444890625*^9}, {3.459255499140625*^9, 
   3.459255547328125*^9}, {3.459255585734375*^9, 3.459255594625*^9}, {
   3.45925566684375*^9, 3.459255706796875*^9}, {3.459255748671875*^9, 
   3.459255857375*^9}, {3.45925590096875*^9, 3.459256001640625*^9}, {
   3.459256031765625*^9, 3.4592560700625*^9}, {3.45925611590625*^9, 
   3.459256125453125*^9}, {3.4592561625625*^9, 3.459256196609375*^9}, {
   3.459256254609375*^9, 3.45925627271875*^9}, {3.459256408953125*^9, 
   3.459256410890625*^9}, {3.45925649534375*^9, 3.45925657821875*^9}, {
   3.459256608375*^9, 3.459256644859375*^9}, {3.459256714265625*^9, 
   3.45925677784375*^9}, {3.45925715353125*^9, 3.4592571915*^9}, {
   3.459258026328125*^9, 3.459258298890625*^9}, {3.4592583303125*^9, 
   3.4592583719375*^9}, {3.45925870771875*^9, 3.459258763328125*^9}, {
   3.459546364875*^9, 3.459546366828125*^9}, {3.459546419046875*^9, 
   3.459546421671875*^9}, {3.459546692421875*^9, 3.45954669521875*^9}, 
   3.4595549515*^9, {3.4595550623125*^9, 3.459555100484375*^9}, {
   3.45955513528125*^9, 3.45955513528125*^9}, {3.459625041953125*^9, 
   3.45962505759375*^9}, {3.506949913347508*^9, 3.506949913683647*^9}, {
   3.506949987806744*^9, 3.506950028996641*^9}, {3.506950152571803*^9, 
   3.506950196199215*^9}, {3.5752855822629433`*^9, 3.575285696284465*^9}, {
   3.5752857425451107`*^9, 3.575285743958192*^9}, {3.575285800886448*^9, 
   3.575285809300929*^9}, {3.57528584830916*^9, 3.575285889444513*^9}, {
   3.5752859308768826`*^9, 3.5752859942525077`*^9}},
 FontFamily->"Times New Roman",
 FontSize->22,
 FontColor->GrayLevel[0],
 Background->RGBColor[1, 1, 0.85]],

Cell[TextData[{
 StyleBox["Note that in the 2D case the Fourier expansion (1) has the form\n\n\
",
  FontSize->22],
 "\[Chi][x,y]=",
 Cell[BoxData[
  FormBox[
   UnderscriptBox["\[Sum]", 
    RowBox[{" ", 
     RowBox[{
      StyleBox["h",
       FontFamily->"Courier New",
       FontSize->12,
       FontSlant->"Italic"], 
      StyleBox[",",
       FontFamily->"Courier New",
       FontSize->12,
       FontSlant->"Italic"], 
      RowBox[{
       StyleBox["k",
        FontFamily->"Courier New",
        FontSize->12,
        FontSlant->"Italic"], "\[Element]", "\[DoubleStruckCapitalZ]"}]}]}]], 
   TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   RowBox[{
    StyleBox[" ",
     FontFamily->"Courier New",
     FontSlant->"Plain"], 
    SubscriptBox[
     StyleBox["\[Chi]",
      FontFamily->"Courier New",
      FontSlant->"Plain"], 
     StyleBox["hk",
      FontFamily->"Courier New",
      FontSize->12,
      FontSlant->"Italic"]], " "}], TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   StyleBox[
    RowBox[{"Exp", "[", 
     RowBox[{
      StyleBox["2",
       FontSlant->"Plain"], 
      RowBox[{"\[Pi]\[ImaginaryI]", "(", 
       RowBox[{
        RowBox[{"h", 
         FractionBox["x", 
          StyleBox["a",
           FontSize->15,
           FontSlant->"Plain"]]}], "+", 
        RowBox[{"k", " ", 
         FractionBox["y", 
          StyleBox["b",
           FontSize->15,
           FontSlant->"Plain"]]}]}], ")"}]}], "]"}],
    FontFamily->"Courier New"], TraditionalForm]]],
 "\n\nwith Fourier coefficients\n\n",
 Cell[BoxData[
  FormBox[
   StyleBox[
    RowBox[{
     SubscriptBox[
      StyleBox["\[Chi]",
       FontFamily->"Courier New",
       FontSlant->"Plain"], 
      StyleBox["hk",
       FontFamily->"Courier New",
       FontSize->12,
       FontSlant->"Italic"]], " "}],
    FontFamily->"Courier New"], TraditionalForm]]],
 " = ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    FractionBox[
     StyleBox["1",
      FontSize->15,
      FontSlant->"Plain"], 
     StyleBox["ab",
      FontSize->15,
      FontSlant->"Plain"]], " "}], TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubsuperscriptBox["\[Integral]", "0", 
     StyleBox["a",
      FontFamily->"Courier New",
      FontSize->15,
      FontSlant->"Plain"]], 
    RowBox[{
     SubsuperscriptBox["\[Integral]", "0", 
      StyleBox["b",
       FontFamily->"Courier New",
       FontSize->15,
       FontSlant->"Plain"]], 
     RowBox[{
      StyleBox[
       RowBox[{"\[Chi]", "[", 
        RowBox[{"x", ",", "y"}], "]"}],
       FontFamily->"Courier New"], 
      StyleBox[
       RowBox[{"Exp", "[", 
        RowBox[{
         RowBox[{"-", 
          StyleBox["2",
           FontSlant->"Plain"]}], 
         RowBox[{"\[Pi]\[ImaginaryI]", "(", 
          RowBox[{
           RowBox[{"h", 
            FractionBox["x", 
             StyleBox["a",
              FontSize->15,
              FontSlant->"Plain"]]}], "+", 
           RowBox[{"k", " ", 
            FractionBox["y", 
             StyleBox["b",
              FontSize->15,
              FontSlant->"Plain"]]}]}], ")"}]}], "]"}],
       FontFamily->"Courier New"], 
      RowBox[{"\[DifferentialD]", 
       StyleBox["x",
        FontFamily->"Courier New"]}]}]}]}], TraditionalForm]]],
 " \[DifferentialD]",
 StyleBox["y",
  FontSlant->"Italic"],
 "\n\n(see Subsection 2.1.5)."
}], "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10001.},
 CellChangeTimes->{{3.43609917853125*^9, 3.436099224875*^9}, {
   3.451201105219131*^9, 3.4512011607417097`*^9}, {3.451202261049141*^9, 
   3.4512022642358913`*^9}, {3.451380513178369*^9, 3.45138054907161*^9}, {
   3.451380621354679*^9, 3.4513806318446302`*^9}, {3.451380663944434*^9, 
   3.451380665324871*^9}, 3.451380835741723*^9, {3.451380883232542*^9, 
   3.451380932025751*^9}, {3.45138098428447*^9, 3.451381101560313*^9}, {
   3.451381137605834*^9, 3.4513812892934093`*^9}, {3.451381335947049*^9, 
   3.4513813424192867`*^9}, {3.451381406000942*^9, 3.4513815693796167`*^9}, {
   3.451381599587194*^9, 3.4513816160378428`*^9}, {3.451381648755763*^9, 
   3.451381662300729*^9}, {3.451381704127902*^9, 3.45138171648451*^9}, {
   3.451382259750657*^9, 3.451382312554418*^9}, {3.4513832778456984`*^9, 
   3.4513833884064627`*^9}, {3.4513834207689877`*^9, 
   3.4513834284008837`*^9}, {3.45138347707425*^9, 3.451383535066996*^9}, {
   3.451383600079137*^9, 3.451383608542776*^9}, {3.451383641804398*^9, 
   3.4513836594058237`*^9}, {3.4513837085029287`*^9, 
   3.4513837950532207`*^9}, {3.451383842090927*^9, 3.451383869607256*^9}, {
   3.451383972789274*^9, 3.451384074278797*^9}, {3.451384120558514*^9, 
   3.4513841250309677`*^9}, {3.451623575273048*^9, 3.451623576629842*^9}, {
   3.451623723281217*^9, 3.4516237502320232`*^9}, {3.4516252629844713`*^9, 
   3.451625277865951*^9}, 3.4516301683616*^9, {3.451630274543489*^9, 
   3.451630319368353*^9}, {3.45163038029524*^9, 3.4516304496679487`*^9}, {
   3.45163048058594*^9, 3.451630508022175*^9}, {3.451630543243938*^9, 
   3.451630554396184*^9}, {3.4516305844061337`*^9, 3.4516305965389*^9}, {
   3.451630671518499*^9, 3.45163074097786*^9}, {3.451630789384632*^9, 
   3.451630834297195*^9}, {3.451630882513088*^9, 3.451630887383438*^9}, {
   3.451630958466445*^9, 3.4516310233802843`*^9}, {3.451631107681582*^9, 
   3.45163115383357*^9}, {3.4516357609731703`*^9, 3.451635762360878*^9}, {
   3.451635972151944*^9, 3.451636005181984*^9}, {3.4516402816594057`*^9, 
   3.4516402868771152`*^9}, {3.451718418411845*^9, 3.451718532230791*^9}, {
   3.451718572022703*^9, 3.451718636750465*^9}, {3.45171873269027*^9, 
   3.45171874852979*^9}, 3.451718817600716*^9, 3.451719631281345*^9, {
   3.4517197104528837`*^9, 3.4517200758146763`*^9}, {3.451720168016982*^9, 
   3.451720322906805*^9}, 3.451720357930373*^9, {3.451720392408083*^9, 
   3.4517204987574453`*^9}, {3.451720545320046*^9, 3.45172055124533*^9}, {
   3.451721255481255*^9, 3.451721275242407*^9}, {3.4517271352554398`*^9, 
   3.451727156645337*^9}, {3.4517274572440367`*^9, 3.451727461141712*^9}, {
   3.451727558386169*^9, 3.4517275648990917`*^9}, {3.451727605239909*^9, 
   3.451727641435083*^9}, 3.451729695420402*^9, {3.451729750634655*^9, 
   3.451729873244254*^9}, {3.451730002795368*^9, 3.4517300120559387`*^9}, {
   3.45911542234375*^9, 3.45911547275*^9}, {3.459115723375*^9, 
   3.459115747234375*^9}, {3.459115777421875*^9, 3.45911580071875*^9}, {
   3.459115838765625*^9, 3.4591158911875*^9}, {3.459116171578125*^9, 
   3.459116177234375*^9}, {3.4591162725625*^9, 3.459116291234375*^9}, {
   3.459116326796875*^9, 3.459116403703125*^9}, {3.45911644571875*^9, 
   3.459116532390625*^9}, {3.45911656446875*^9, 3.4591166079375*^9}, {
   3.459116653375*^9, 3.459116755828125*^9}, {3.45911682465625*^9, 
   3.459116869296875*^9}, {3.459116900890625*^9, 3.459116947375*^9}, {
   3.459117026890625*^9, 3.459117030734375*^9}, {3.459117113984375*^9, 
   3.45911717959375*^9}, {3.45911742165625*^9, 3.45911745671875*^9}, {
   3.459117496234375*^9, 3.459117656375*^9}, {3.459117804515625*^9, 
   3.4591178465*^9}, {3.459117889671875*^9, 3.459117943828125*^9}, {
   3.459117976109375*^9, 3.45911821184375*^9}, {3.459118252421875*^9, 
   3.4591183270625*^9}, {3.45911839728125*^9, 3.45911849109375*^9}, {
   3.459118552953125*^9, 3.45911865771875*^9}, {3.459118706015625*^9, 
   3.459118713484375*^9}, {3.459118798359375*^9, 3.4591188668125*^9}, {
   3.459118963578125*^9, 3.459119082375*^9}, {3.459119116703125*^9, 
   3.459119161234375*^9}, {3.459119315609375*^9, 3.459119323359375*^9}, {
   3.459119359296875*^9, 3.4591193660625*^9}, {3.4591587146875*^9, 
   3.4591587818125*^9}, {3.4591588135625*^9, 3.459158919328125*^9}, {
   3.459158956921875*^9, 3.45915908328125*^9}, {3.459159124390625*^9, 
   3.45915912540625*^9}, {3.459159513953125*^9, 3.4591595305625*^9}, {
   3.4591595785625*^9, 3.459159586203125*^9}, {3.45915961928125*^9, 
   3.45915977559375*^9}, {3.459159896625*^9, 3.459159970953125*^9}, {
   3.459160013484375*^9, 3.45916006021875*^9}, {3.45916009496875*^9, 
   3.459160140640625*^9}, {3.459160177390625*^9, 3.459160238515625*^9}, {
   3.459160746703125*^9, 3.459160773671875*^9}, 3.45916106203125*^9, {
   3.459162807875*^9, 3.45916287228125*^9}, {3.45916662953125*^9, 
   3.459166635515625*^9}, {3.459170302734375*^9, 3.459170322953125*^9}, {
   3.459256788703125*^9, 3.459256930734375*^9}, {3.459256975046875*^9, 
   3.459256983671875*^9}, {3.459257393546875*^9, 3.45925739578125*^9}, {
   3.45925748825*^9, 3.459257492609375*^9}, {3.45925753084375*^9, 
   3.459257588625*^9}, {3.45925765596875*^9, 3.459257697421875*^9}, {
   3.45925781*^9, 3.459257812046875*^9}, {3.459257846640625*^9, 
   3.459257951828125*^9}, {3.45925839284375*^9, 3.45925842496875*^9}, {
   3.459258501234375*^9, 3.4592585533125*^9}, {3.459258611859375*^9, 
   3.459258645703125*^9}, {3.459555263109375*^9, 3.459555263109375*^9}, {
   3.459555300484375*^9, 3.459555300484375*^9}, {3.45955545609375*^9, 
   3.459555456203125*^9}, {3.506950068502192*^9, 3.5069500721198807`*^9}, {
   3.575285753655746*^9, 3.5752857647403803`*^9}},
 FontFamily->"Times New Roman",
 FontSize->22,
 FontColor->RGBColor[0, 0, 1],
 Background->RGBColor[1, 1, 0.85]],

Cell[BoxData[
 RowBox[{"Date", "[", "]"}]], "Input",
 CellChangeTimes->{{3.507188286738323*^9, 3.5071882883072853`*^9}},
 FontSize->18],

Cell[BoxData[
 RowBox[{
  RowBox[{"Remove", "[", "\"\<Global`*\>\"", "]"}], ";", 
  RowBox[{"$Line", "=", "0"}], ";"}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.431586215703125*^9, 3.4315862223125*^9}, 
   3.436098419328125*^9, 3.459112164203125*^9, 3.45916170553125*^9, 
   3.459161890421875*^9, {3.459170302734375*^9, 3.45917031409375*^9}, {
   3.45954637884375*^9, 3.4595463803125*^9}},
 FontSize->18],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"<<", 
     RowBox[{"/", "home"}]}], "/", "MyDir"}], "/", "Book"}], "-", 
  RowBox[{"Mathematica", "/", 
   RowBox[{"TellName2", ".", "m"}]}]}]], "Input",
 CellChangeTimes->{{3.5516932889290123`*^9, 3.55169338504627*^9}, {
  3.5785495385512333`*^9, 3.5785495430394897`*^9}},
 FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Off", "[", 
   RowBox[{"General", "::", "spell1"}], "]"}], ";"}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.431586215703125*^9, 3.4315862223125*^9}, 
   3.436098419328125*^9, 3.459112164203125*^9, 3.45916170553125*^9, 
   3.459161890421875*^9, {3.459170302734375*^9, 3.45917031409375*^9}},
 FontSize->18],

Cell[BoxData[
 RowBox[{
  RowBox[{"SetOptions", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"Plot", ",", "Plot3D"}], "}"}], ",", 
    RowBox[{"ImageSize", "\[Rule]", "600"}], ",", "\[IndentingNewLine]", 
    RowBox[{"LabelStyle", "\[Rule]", 
     RowBox[{"(", 
      RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}], ")"}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"AxesStyle", "\[Rule]", 
     RowBox[{"Directive", "[", 
      RowBox[{"20", ",", 
       RowBox[{"Thickness", "[", "0.005", "]"}], ",", "Black"}], "]"}]}]}], 
   "]"}], ";"}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.431404133265625*^9, 3.431404152625*^9}, {
   3.431404184828125*^9, 3.43140419784375*^9}, {3.431404229828125*^9, 
   3.431404286*^9}, {3.431404358734375*^9, 3.431404362015625*^9}, 
   3.43140449659375*^9, {3.431404585328125*^9, 3.431404586390625*^9}, {
   3.431404647765625*^9, 3.431404694953125*^9}, {3.43140617875*^9, 
   3.4314062495625*^9}, {3.431406282875*^9, 3.4314063513125*^9}, {
   3.43140679328125*^9, 3.43140680225*^9}, {3.4314068341875*^9, 
   3.431406876078125*^9}, 3.431586168296875*^9, {3.456133135516242*^9, 
   3.45613315371024*^9}, 3.456133192744998*^9, {3.456139127607568*^9, 
   3.456139168352964*^9}, 3.456139229399897*^9, {3.456139834402177*^9, 
   3.456139847710493*^9}, 3.459112164203125*^9, 3.45916170553125*^9, 
   3.459161890421875*^9, {3.459170302734375*^9, 3.45917031409375*^9}, 
   3.48076542625*^9},
 FontSize->18]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Susceptibility ",
 StyleBox["\[Chi]",
  FontFamily->"Courier",
  FontSize->22],
 " of the perfect crystal"
}], "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10001.},
 CellChangeTimes->{{3.4561278892666187`*^9, 3.4561279023146544`*^9}, 
   3.456128006313026*^9, {3.4561281092059317`*^9, 3.456128161981234*^9}, {
   3.456132554287485*^9, 3.456132559911008*^9}, 3.4571610771792803`*^9, {
   3.45890498628125*^9, 3.458905003921875*^9}, {3.458905040765625*^9, 
   3.458905065171875*^9}, {3.45890880125*^9, 3.458908829625*^9}, {
   3.459031391640625*^9, 3.45903141328125*^9}, {3.459031609796875*^9, 
   3.45903161853125*^9}, 3.459032413875*^9, {3.4590787515625*^9, 
   3.45907876484375*^9}, {3.459080959859375*^9, 3.4590809625*^9}, {
   3.45908105425*^9, 3.459081063546875*^9}, 3.45908270415625*^9, 
   3.459083736921875*^9, {3.459161519140625*^9, 3.45916154453125*^9}, 
   3.45916170553125*^9, 3.459161949078125*^9, 3.459162395734375*^9, 
   3.459170336796875*^9, 3.4591703981875*^9},
 FontSize->22,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Lambda]x", "=", "1"}], ";"}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10001.},
 CellChangeTimes->{{3.45954644040625*^9, 3.459546443375*^9}, 
   3.459625094265625*^9, {3.480766220890625*^9, 3.480766224265625*^9}, {
   3.480766668375*^9, 3.480766669390625*^9}},
 FontFamily->"Courier New",
 FontSize->18],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Lambda]y", "=", "1"}], ";"}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10001.},
 CellChangeTimes->{{3.459546448296875*^9, 3.4595464525625*^9}, 
   3.459625094265625*^9, {3.4807662318125*^9, 3.480766236203125*^9}, {
   3.4807666714375*^9, 3.480766672296875*^9}},
 FontFamily->"Courier New",
 FontSize->18],

Cell[BoxData[
 RowBox[{
  RowBox[{"Z", "=", "1"}], ";"}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10001.},
 CellChangeTimes->{{3.459548257921875*^9, 3.459548260125*^9}, 
   3.459625094265625*^9, 3.506776967556319*^9},
 FontFamily->"Courier New",
 FontSize->18],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    StyleBox["\[Chi]",
     FontFamily->"Courier New"], "[", 
    RowBox[{"x_", ",", "y_"}], "]"}], ":=", 
   RowBox[{"Z", "*", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"Sin", "[", 
         FractionBox[
          RowBox[{"2", " ", "\[Pi]", " ", "x"}], "\[Lambda]x"], "]"}], ")"}], 
       "^", "6"}], "*", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"Sin", "[", 
         FractionBox[
          RowBox[{"2", " ", "\[Pi]", " ", "y"}], "\[Lambda]y"], "]"}], ")"}], 
       "^", "6"}]}], ")"}]}]}], ";"}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10001.},
 CellChangeTimes->{{3.459546431796875*^9, 3.459546434265625*^9}, {
   3.45954668275*^9, 3.459546686046875*^9}, 3.459625094265625*^9, {
   3.480766212546875*^9, 3.4807662176875*^9}, 3.48076626665625*^9, 
   3.480766477671875*^9, {3.48076729215625*^9, 3.480767294625*^9}, {
   3.480767336890625*^9, 3.480767343859375*^9}},
 FontFamily->"Courier New",
 FontSize->18]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Plot3D", "[", 
  RowBox[{
   RowBox[{
    StyleBox["\[Chi]",
     FontFamily->"Courier New"], "[", 
    RowBox[{"x", ",", "y"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "\[Lambda]x"}], "/", "2"}], "-", 
      RowBox[{"\[Lambda]x", "/", "10"}]}], ",", 
     RowBox[{
      RowBox[{"\[Lambda]x", "/", "2"}], "+", 
      RowBox[{"\[Lambda]x", "/", "10"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"y", ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "\[Lambda]y"}], "/", "2"}], "-", 
      RowBox[{"\[Lambda]y", "/", "10"}]}], ",", 
     RowBox[{
      RowBox[{"\[Lambda]y", "/", "2"}], "+", 
      RowBox[{"\[Lambda]y", "/", "10"}]}]}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
   RowBox[{"AxesStyle", "\[Rule]", 
    RowBox[{"Directive", "[", 
     RowBox[{"Blue", ",", "20", ",", 
      RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}]}], ",", 
   
   RowBox[{"ImageSize", "\[Rule]", "500"}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<x\>\"", ",", "\"\<y\>\"", ",", "\"\<\!\(\*
StyleBox[\"\[Chi]\",
FontFamily->\"Courier New\"]\)(x,y)\>\""}], "}"}]}], ",", 
   RowBox[{"PlotLabel", "\[Rule]", 
    RowBox[{"{", "\"\<\!\(\*
StyleBox[\"\[Chi]\",
FontFamily->\"Courier New\"]\)[x,y]\>\"", "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.506777056893928*^9, 3.506777097077627*^9}, {
  3.506777143484271*^9, 3.506777147231254*^9}, {3.506777181020751*^9, 
  3.506777192844201*^9}, {3.506777240153821*^9, 3.5067772948052673`*^9}, {
  3.507188523899884*^9, 3.507188543340781*^9}}],

Cell[CellGroupData[{

Cell["Part I", "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10003.},
 CellChangeTimes->{{3.4561278892666187`*^9, 3.4561279023146544`*^9}, 
   3.456128006313026*^9, {3.4561281092059317`*^9, 3.456128161981234*^9}, {
   3.456132554287485*^9, 3.456132559911008*^9}, 3.4571610771792803`*^9, {
   3.45890498628125*^9, 3.458905003921875*^9}, {3.458905040765625*^9, 
   3.458905065171875*^9}, {3.45890880125*^9, 3.458908829625*^9}, {
   3.459031391640625*^9, 3.45903141328125*^9}, {3.459031609796875*^9, 
   3.45903161853125*^9}, 3.459032413875*^9, {3.4590787515625*^9, 
   3.45907876484375*^9}, {3.459080959859375*^9, 3.4590809625*^9}, {
   3.45908105425*^9, 3.459081063546875*^9}, 3.45908270415625*^9, 
   3.459083736921875*^9, {3.459161519140625*^9, 3.45916154453125*^9}, 
   3.45916170553125*^9, 3.459161949078125*^9, {3.459162408015625*^9, 
   3.459162479640625*^9}, {3.459162572953125*^9, 3.459162590859375*^9}, 
   3.459162654765625*^9, {3.459167345890625*^9, 3.4591674620625*^9}, {
   3.459167493109375*^9, 3.45916751634375*^9}, {3.459167569421875*^9, 
   3.45916763553125*^9}, {3.459167676828125*^9, 3.459167680640625*^9}, {
   3.4591677316875*^9, 3.459167762609375*^9}, {3.459549029125*^9, 
   3.45954902959375*^9}, {3.459602988515625*^9, 3.459603044984375*^9}, {
   3.45960472828125*^9, 3.459604730828125*^9}, {3.459604822515625*^9, 
   3.4596048321875*^9}, {3.4596048689375*^9, 3.459604951390625*^9}, 
   3.459625128171875*^9, 3.5070286029018383`*^9, {3.507028673596087*^9, 
   3.5070286792001467`*^9}, {3.507028789126419*^9, 3.507028791881126*^9}, {
   3.5752863891650953`*^9, 3.575286391332219*^9}},
 FontFamily->"Times New Roman",
 FontSize->36,
 FontColor->RGBColor[0, 0, 1],
 Background->RGBColor[1, 0.9, 0.8]],

Cell["\<\
Let us begin considering the case of an original (undeformed) crystal:\
\>", "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10003.},
 CellChangeTimes->{{3.4561278892666187`*^9, 3.4561279023146544`*^9}, 
   3.456128006313026*^9, {3.4561281092059317`*^9, 3.456128161981234*^9}, {
   3.456132554287485*^9, 3.456132559911008*^9}, 3.4571610771792803`*^9, {
   3.45890498628125*^9, 3.458905003921875*^9}, {3.458905040765625*^9, 
   3.458905065171875*^9}, {3.45890880125*^9, 3.458908829625*^9}, {
   3.459031391640625*^9, 3.45903141328125*^9}, {3.459031609796875*^9, 
   3.45903161853125*^9}, 3.459032413875*^9, {3.4590787515625*^9, 
   3.45907876484375*^9}, {3.459080959859375*^9, 3.4590809625*^9}, {
   3.45908105425*^9, 3.459081063546875*^9}, 3.45908270415625*^9, 
   3.459083736921875*^9, {3.459161519140625*^9, 3.45916154453125*^9}, 
   3.45916170553125*^9, 3.459161949078125*^9, {3.459162408015625*^9, 
   3.459162479640625*^9}, {3.459162572953125*^9, 3.459162590859375*^9}, 
   3.459162654765625*^9, {3.459167345890625*^9, 3.4591674620625*^9}, {
   3.459167493109375*^9, 3.45916751634375*^9}, {3.459167569421875*^9, 
   3.45916763553125*^9}, {3.459167676828125*^9, 3.459167680640625*^9}, {
   3.4591677316875*^9, 3.459167762609375*^9}, {3.459549029125*^9, 
   3.45954902959375*^9}, {3.459602988515625*^9, 3.459603044984375*^9}, {
   3.45960472828125*^9, 3.459604730828125*^9}, {3.459604822515625*^9, 
   3.4596048321875*^9}, {3.4596048689375*^9, 3.459604951390625*^9}, 
   3.459625128171875*^9, 3.5070286029018383`*^9, {3.507028673596087*^9, 
   3.5070286792001467`*^9}, {3.507028789126419*^9, 3.507028791881126*^9}, 
   3.5752863880450315`*^9, {3.575286439412969*^9, 3.5752864542928205`*^9}},
 FontSize->22,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   StyleBox["\[Chi]hk",
    FontFamily->"Courier New"], "[", 
   RowBox[{"m_", ",", "n_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{
    StyleBox["\[Chi]hk",
     FontFamily->"Courier New"], "[", 
    RowBox[{"m", ",", "n"}], "]"}], "=", 
   RowBox[{
    FractionBox["1", 
     RowBox[{"\[Lambda]x", " ", "\[Lambda]y"}]], 
    RowBox[{"Integrate", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        StyleBox["\[Chi]",
         FontFamily->"Courier New"], "[", 
        RowBox[{"x", ",", "y"}], "]"}], 
       StyleBox[
        RowBox[{"Exp", "[", 
         RowBox[{
          RowBox[{"-", 
           StyleBox["2",
            FontSlant->"Plain"]}], "\[Pi]", " ", "\[ImaginaryI]", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"m", 
             FractionBox["x", 
              StyleBox["\[Lambda]x",
               FontSize->15,
               FontSlant->"Plain"]]}], "+", 
            RowBox[{"n", 
             FractionBox["y", 
              StyleBox["\[Lambda]y",
               FontSize->15,
               FontSlant->"Plain"]]}]}], ")"}]}], "]"}],
        FontFamily->"Courier New"]}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", 
        RowBox[{
         RowBox[{"-", "\[Lambda]x"}], "/", "2"}], ",", 
        RowBox[{"\[Lambda]x", "/", "2"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"y", ",", 
        RowBox[{
         RowBox[{"-", "\[Lambda]y"}], "/", "2"}], ",", 
        RowBox[{"\[Lambda]y", "/", "2"}]}], "}"}]}], "]"}]}]}]}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10003.},
 CellChangeTimes->{{3.459549068078125*^9, 3.459549189921875*^9}, {
   3.459549224921875*^9, 3.459549229390625*^9}, 3.45954926703125*^9, {
   3.45954933675*^9, 3.459549341109375*^9}, 3.45954996003125*^9, {
   3.459558456671875*^9, 3.45955845771875*^9}, 3.459605875390625*^9, 
   3.459625128171875*^9, {3.480766318796875*^9, 3.4807663333125*^9}, {
   3.480766493265625*^9, 3.48076649740625*^9}, {3.480768045578125*^9, 
   3.480768075875*^9}, {3.5067775731452312`*^9, 3.506777573786462*^9}, {
   3.507026555317594*^9, 3.507026566177608*^9}, 3.5070267929472113`*^9, {
   3.5070305267030087`*^9, 3.5070305349625683`*^9}},
 FontFamily->"Courier New",
 FontSize->18],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"ncoex", "=", "6"}], ";"}], "     ", 
  RowBox[{"(*", " ", 
   RowBox[{"4", " ", "orig"}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ncoey", "=", "6"}], ";"}]}], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10003.},
 CellChangeTimes->{{3.459549512234375*^9, 3.4595495230625*^9}, {
   3.459549775609375*^9, 3.459549787421875*^9}, {3.459549831515625*^9, 
   3.4595498848125*^9}, {3.4595501808125*^9, 3.459550182171875*^9}, {
   3.459550460265625*^9, 3.459550465703125*^9}, 3.4595557775*^9, {
   3.459557439125*^9, 3.45955744784375*^9}, {3.459557925890625*^9, 
   3.459557931984375*^9}, {3.459558202890625*^9, 3.459558206375*^9}, {
   3.459558297296875*^9, 3.4595583638125*^9}, {3.45955848421875*^9, 
   3.459558486515625*^9}, {3.459605761828125*^9, 3.4596057625*^9}, {
   3.459605818453125*^9, 3.459605832578125*^9}, 3.459625128171875*^9, {
   3.4807663364375*^9, 3.48076634709375*^9}, {3.48082126765625*^9, 
   3.4808212823125*^9}, {3.507026594009664*^9, 3.507026631075254*^9}, {
   3.5070323919503613`*^9, 3.507032396316979*^9}, {3.507034134422544*^9, 
   3.507034137711341*^9}, {3.5070342611787357`*^9, 3.507034263427397*^9}},
 FontFamily->"Courier New",
 FontSize->18],

Cell[BoxData[
 RowBox[{"Date", "[", "]"}]], "Input",
 CellChangeTimes->{{3.552985920768112*^9, 3.552985921915653*^9}},
 FontSize->18],

Cell[BoxData[
 RowBox[{
  RowBox[{"Do", "[", 
   RowBox[{
    RowBox[{"Do", "[", 
     RowBox[{
      RowBox[{"Print", "[", 
       RowBox[{"{", 
        RowBox[{"m", ",", "n", ",", 
         RowBox[{"Timing", "[", 
          RowBox[{"N", "[", 
           RowBox[{
            StyleBox["\[Chi]hk",
             FontFamily->"Courier New"], "[", 
            RowBox[{"m", ",", "n"}], "]"}], "]"}], "]"}]}], "}"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"m", ",", 
        RowBox[{"-", "ncoex"}], ",", "ncoex"}], "}"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"n", ",", 
      RowBox[{"-", "ncoey"}], ",", "ncoey"}], "}"}]}], "]"}], ";"}]], "Input",\

 CellChangeTimes->{{3.50702654786672*^9, 3.507026588776029*^9}, {
   3.507026640569257*^9, 3.507026655952016*^9}, {3.507026767118902*^9, 
   3.507026783808118*^9}, 3.507026893506958*^9, {3.507026998984873*^9, 
   3.507027000112488*^9}, {3.5070279315418158`*^9, 3.507027935491643*^9}, {
   3.507030543879985*^9, 3.507030557828981*^9}, {3.507030847500433*^9, 
   3.507030868192945*^9}}],

Cell[BoxData[
 RowBox[{"Date", "[", "]"}]], "Input",
 CellChangeTimes->{{3.552985920768112*^9, 3.552985921915653*^9}},
 FontSize->18],

Cell[BoxData[
 RowBox[{
  RowBox[{"SN", "[", 
   RowBox[{"x_", ",", " ", "y_", ",", " ", "ntx_", ",", " ", "nty_"}], "]"}], 
  " ", ":=", " ", 
  RowBox[{
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"m", "=", 
      RowBox[{"-", "ntx"}]}], "ntx"], 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"n", "=", 
       StyleBox[
        RowBox[{"-", "nty"}],
        FontColor->RGBColor[1, 0, 0]]}], "nty"], 
     RowBox[{
      RowBox[{"N", "[", 
       RowBox[{
        StyleBox["\[Chi]hk",
         FontSize->22], 
        StyleBox["[",
         FontSize->18], 
        RowBox[{"m", ",", "n"}], "]"}], "]"}], "*", 
      SuperscriptBox["E", 
       RowBox[{"I", "*", 
        RowBox[{"(", 
         StyleBox[
          RowBox[{
           RowBox[{
            FractionBox[
             RowBox[{"2", " ", "\[Pi]", " ", "m"}], "\[Lambda]x"], " ", "x"}],
            "+", 
           RowBox[{
            FractionBox[
             RowBox[{"2", " ", "\[Pi]", " ", "n"}], "\[Lambda]y"], " ", 
            "y"}]}],
          FontSize->24], ")"}]}]]}]}]}], " ", "//", " ", "Chop"}]}]], "Input",\

 CellChangeTimes->{{3.506952778627833*^9, 3.5069527998160667`*^9}, {
   3.5069529225464582`*^9, 3.5069529513666563`*^9}, {3.506953985547584*^9, 
   3.5069539865284777`*^9}, {3.507026807329492*^9, 3.5070268227357388`*^9}, {
   3.507030650323797*^9, 3.507030654619659*^9}, 3.507188444262045*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"ntx6", "=", "6"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"nty6", "=", "6"}], ";"}]}], "Input",
 CellChangeTimes->{{3.506952840642242*^9, 3.5069528406434298`*^9}, {
   3.506952887860076*^9, 3.506952898535535*^9}, {3.506953369183668*^9, 
   3.506953374448359*^9}, {3.507034158395381*^9, 3.5070341600237093`*^9}, 
   3.507034384357234*^9, 3.507034432442441*^9}],

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"Sumntx6N", "=", 
   RowBox[{"SN", "[", 
    RowBox[{"x", ",", "y", ",", "ntx6", ",", "nty6"}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.506952840642242*^9, 3.5069528406434298`*^9}, {
   3.506952887860076*^9, 3.506952898535535*^9}, 3.506953369183668*^9, {
   3.506953990035199*^9, 3.506953990975658*^9}, {3.506954046441042*^9, 
   3.506954052784486*^9}, {3.506954195274091*^9, 3.506954195887315*^9}, {
   3.5070268400411253`*^9, 3.507026844148245*^9}, {3.507034387345031*^9, 
   3.5070343884569407`*^9}, 3.507034432987981*^9, {3.507188449459502*^9, 
   3.507188456313833*^9}}],

Cell[BoxData[
 RowBox[{"graphS4N", "=", 
  RowBox[{"Plot3D", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", "Sumntx6N", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", 
      RowBox[{"-", 
       FractionBox["\[Lambda]x", "2"]}], ",", 
      FractionBox["\[Lambda]x", "2"]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"y", ",", 
      RowBox[{"-", " ", 
       FractionBox["\[Lambda]y", "2"]}], ",", 
      FractionBox["\[Lambda]y", "2"]}], "}"}], ",", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<\!\(\*
StyleBox[\"x\",
FontFamily->\"Courier New\",
FontWeight->\"Plain\"]\)\>\"", ",", "\"\<\!\(\*
StyleBox[\"y\",
FontWeight->\"Plain\"]\)\>\""}], "}"}]}], ",", " ", "\[IndentingNewLine]", 
    "  ", 
    RowBox[{"PlotLabel", "\[Rule]", 
     RowBox[{"{", "\"\<Sumntx6N\>\"", "}"}]}]}], "]"}]}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10006.},
 CellChangeTimes->{{3.45955340946875*^9, 3.459553473609375*^9}, {
   3.459607408609375*^9, 3.459607408703125*^9}, {3.459607614859375*^9, 
   3.459607621296875*^9}, {3.459607677421875*^9, 3.4596076795*^9}, {
   3.459607826828125*^9, 3.45960786221875*^9}, 3.459622829375*^9, 
   3.45962517903125*^9, {3.480766389640625*^9, 3.480766390234375*^9}, {
   3.480766535953125*^9, 3.4807665365*^9}, {3.48076698346875*^9, 
   3.480766996015625*^9}, {3.506950794317781*^9, 3.506950801239217*^9}, {
   3.506953189366084*^9, 3.5069532177138968`*^9}, {3.506953348859878*^9, 
   3.506953349418674*^9}, {3.5069542066405582`*^9, 3.5069542126487722`*^9}, {
   3.507026849210277*^9, 3.5070268805123453`*^9}, 3.5070343919911118`*^9, {
   3.507188484834339*^9, 3.5071884884532957`*^9}, {3.507188710682522*^9, 
   3.50718871509518*^9}},
 FontFamily->"Courier New",
 FontSize->18],

Cell[BoxData[
 RowBox[{"graphS4ReN", "=", 
  RowBox[{"Plot3D", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{"Re", "[", "Sumntx6N", "]"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", 
      RowBox[{"-", 
       FractionBox["\[Lambda]x", "2"]}], ",", 
      FractionBox["\[Lambda]x", "2"]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"y", ",", 
      RowBox[{"-", " ", 
       FractionBox["\[Lambda]y", "2"]}], ",", 
      FractionBox["\[Lambda]y", "2"]}], "}"}], ",", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<\!\(\*
StyleBox[\"x\",
FontFamily->\"Courier New\",
FontWeight->\"Plain\"]\)\>\"", ",", "\"\<\!\(\*
StyleBox[\"y\",
FontWeight->\"Plain\"]\)\>\""}], "}"}]}], ",", "\[IndentingNewLine]", 
    "             ", 
    RowBox[{"PlotLabel", "\[Rule]", 
     RowBox[{"{", "\"\<Re[Sumntx6N\>\"", "}"}]}]}], "]"}]}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10006.},
 CellChangeTimes->{{3.45955340946875*^9, 3.459553473609375*^9}, {
   3.459607408609375*^9, 3.459607408703125*^9}, {3.459607614859375*^9, 
   3.459607621296875*^9}, {3.459607677421875*^9, 3.4596076795*^9}, {
   3.459607826828125*^9, 3.45960786221875*^9}, 3.459622829375*^9, 
   3.45962517903125*^9, {3.480766389640625*^9, 3.480766390234375*^9}, {
   3.480766535953125*^9, 3.4807665365*^9}, {3.48076698346875*^9, 
   3.480766996015625*^9}, {3.506950794317781*^9, 3.506950801239217*^9}, {
   3.506953189366084*^9, 3.5069532177138968`*^9}, {3.506953348859878*^9, 
   3.506953349418674*^9}, {3.5069542066405582`*^9, 3.5069542126487722`*^9}, {
   3.507026849210277*^9, 3.5070268805123453`*^9}, {3.5070282351587963`*^9, 
   3.507028245723881*^9}, {3.507028362817822*^9, 3.507028368545802*^9}, 
   3.5070343894930983`*^9, {3.5071884526455317`*^9, 3.507188461586698*^9}, {
   3.507188553767138*^9, 3.507188584603709*^9}, {3.507188629992313*^9, 
   3.507188638320681*^9}},
 FontFamily->"Courier New",
 FontSize->18],

Cell[BoxData[
 RowBox[{"graphS4ImN", "=", 
  RowBox[{"Plot3D", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{"Im", "[", "Sumntx6N", "]"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", 
      RowBox[{"-", 
       FractionBox["\[Lambda]x", "2"]}], ",", 
      FractionBox["\[Lambda]x", "2"]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"y", ",", 
      RowBox[{"-", " ", 
       FractionBox["\[Lambda]y", "2"]}], ",", 
      FractionBox["\[Lambda]y", "2"]}], "}"}], ",", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<\!\(\*
StyleBox[\"x\",
FontFamily->\"Courier New\",
FontWeight->\"Plain\"]\)\>\"", ",", "\"\<\!\(\*
StyleBox[\"y\",
FontWeight->\"Plain\"]\)\>\""}], "}"}]}], ",", " ", "\[IndentingNewLine]", 
    "  ", 
    RowBox[{"PlotLabel", "\[Rule]", 
     RowBox[{"{", "\"\<Im[Sumntx6N\>\"", "}"}]}]}], "]"}]}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10006.},
 CellChangeTimes->{{3.45955340946875*^9, 3.459553473609375*^9}, {
   3.459607408609375*^9, 3.459607408703125*^9}, {3.459607614859375*^9, 
   3.459607621296875*^9}, {3.459607677421875*^9, 3.4596076795*^9}, {
   3.459607826828125*^9, 3.45960786221875*^9}, 3.459622829375*^9, 
   3.45962517903125*^9, {3.480766389640625*^9, 3.480766390234375*^9}, {
   3.480766535953125*^9, 3.4807665365*^9}, {3.48076698346875*^9, 
   3.480766996015625*^9}, {3.506950794317781*^9, 3.506950801239217*^9}, {
   3.506953189366084*^9, 3.5069532177138968`*^9}, {3.506953348859878*^9, 
   3.506953349418674*^9}, {3.5069542066405582`*^9, 3.5069542126487722`*^9}, {
   3.507026849210277*^9, 3.5070268805123453`*^9}, {3.5070282351587963`*^9, 
   3.507028245723881*^9}, {3.507028371723998*^9, 3.5070283781045856`*^9}, 
   3.507034390332576*^9, {3.507188467452569*^9, 3.507188471265669*^9}, {
   3.507188666333716*^9, 3.507188679175137*^9}},
 FontFamily->"Courier New",
 FontSize->18],

Cell[BoxData[
 RowBox[{"graphS4AbsN", "=", 
  RowBox[{"Plot3D", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{"Abs", "[", "Sumntx6N", "]"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", 
      RowBox[{"-", 
       FractionBox["\[Lambda]x", "2"]}], ",", 
      FractionBox["\[Lambda]x", "2"]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"y", ",", 
      RowBox[{"-", " ", 
       FractionBox["\[Lambda]y", "2"]}], ",", 
      FractionBox["\[Lambda]y", "2"]}], "}"}], ",", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<\!\(\*
StyleBox[\"x\",
FontFamily->\"Courier New\",
FontWeight->\"Plain\"]\)\>\"", ",", "\"\<\!\(\*
StyleBox[\"y\",
FontWeight->\"Plain\"]\)\>\""}], "}"}]}], ",", " ", "\[IndentingNewLine]", 
    "  ", 
    RowBox[{"PlotLabel", "\[Rule]", 
     RowBox[{"{", "\"\<Abs[Sumntx6N\>\"", "}"}]}]}], "]"}]}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10006.},
 CellChangeTimes->{{3.45955340946875*^9, 3.459553473609375*^9}, {
   3.459607408609375*^9, 3.459607408703125*^9}, {3.459607614859375*^9, 
   3.459607621296875*^9}, {3.459607677421875*^9, 3.4596076795*^9}, {
   3.459607826828125*^9, 3.45960786221875*^9}, 3.459622829375*^9, 
   3.45962517903125*^9, {3.480766389640625*^9, 3.480766390234375*^9}, {
   3.480766535953125*^9, 3.4807665365*^9}, {3.48076698346875*^9, 
   3.480766996015625*^9}, {3.506950794317781*^9, 3.506950801239217*^9}, {
   3.506953189366084*^9, 3.5069532177138968`*^9}, {3.506953348859878*^9, 
   3.506953349418674*^9}, {3.5069542066405582`*^9, 3.5069542126487722`*^9}, {
   3.507026849210277*^9, 3.5070268805123453`*^9}, {3.5070282351587963`*^9, 
   3.507028245723881*^9}, 3.5070343911620493`*^9, {3.507188476108137*^9, 
   3.5071884799804487`*^9}, {3.507188690887177*^9, 3.5071886962959633`*^9}},
 FontFamily->"Courier New",
 FontSize->18]
}, Closed]],

Cell[CellGroupData[{

Cell["Part II", "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10004.},
 CellChangeTimes->{{3.4561278892666187`*^9, 3.4561279023146544`*^9}, 
   3.456128006313026*^9, {3.4561281092059317`*^9, 3.456128161981234*^9}, {
   3.456132554287485*^9, 3.456132559911008*^9}, {3.456133257033012*^9, 
   3.4561332624322557`*^9}, 3.456133293068067*^9, {3.45903155753125*^9, 
   3.459031586453125*^9}, 3.45903250021875*^9, {3.45908097503125*^9, 
   3.45908097815625*^9}, {3.4590811195*^9, 3.459081124453125*^9}, {
   3.4590811558125*^9, 3.459081158203125*^9}, 3.459082649796875*^9, 
   3.45908270415625*^9, 3.45908374184375*^9, 3.459165353421875*^9, 
   3.459165459546875*^9, 3.459170357921875*^9, {3.45955283115625*^9, 
   3.459552859390625*^9}, {3.459553087359375*^9, 3.45955308978125*^9}, {
   3.459625136984375*^9, 3.459625140140625*^9}, {3.507028772825343*^9, 
   3.507028816830978*^9}, 3.507187231218854*^9, {3.575286377172409*^9, 
   3.5752863803645916`*^9}},
 FontFamily->"Times New Roman",
 FontSize->36,
 FontColor->RGBColor[0, 0, 1],
 Background->RGBColor[1, 0.9, 0.8]],

Cell["\<\
And now let us consider the case of an approximated deformation as follows:\
\>", "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10004.},
 CellChangeTimes->{{3.4561278892666187`*^9, 3.4561279023146544`*^9}, 
   3.456128006313026*^9, {3.4561281092059317`*^9, 3.456128161981234*^9}, {
   3.456132554287485*^9, 3.456132559911008*^9}, {3.456133257033012*^9, 
   3.4561332624322557`*^9}, 3.456133293068067*^9, {3.45903155753125*^9, 
   3.459031586453125*^9}, 3.45903250021875*^9, {3.45908097503125*^9, 
   3.45908097815625*^9}, {3.4590811195*^9, 3.459081124453125*^9}, {
   3.4590811558125*^9, 3.459081158203125*^9}, 3.459082649796875*^9, 
   3.45908270415625*^9, 3.45908374184375*^9, 3.459165353421875*^9, 
   3.459165459546875*^9, 3.459170357921875*^9, {3.45955283115625*^9, 
   3.459552859390625*^9}, {3.459553087359375*^9, 3.45955308978125*^9}, {
   3.459625136984375*^9, 3.459625140140625*^9}, {3.507028772825343*^9, 
   3.507028816830978*^9}, 3.507187231218854*^9, 3.5752863761403503`*^9, {
   3.5752864747739916`*^9, 3.5752864932610493`*^9}},
 FontSize->22,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Epsilon]", "=", 
   RowBox[{"1", "/", "10"}]}], ";"}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10004.},
 CellChangeTimes->{{3.456134729044327*^9, 3.4561347462537203`*^9}, 
   3.456134780115127*^9, {3.456135037572178*^9, 3.45613504782544*^9}, {
   3.456135378330126*^9, 3.456135396994176*^9}, {3.456136328961178*^9, 
   3.45613633386475*^9}, {3.456136983875338*^9, 3.4561369842224617`*^9}, 
   3.456138485869337*^9, {3.456138550249872*^9, 3.456138579401086*^9}, {
   3.456139787791667*^9, 3.456139790019498*^9}, {3.457167339632635*^9, 
   3.457167339938517*^9}, 3.45903250021875*^9, 3.459082649796875*^9, 
   3.45908270415625*^9, 3.45908374184375*^9, 3.459160576359375*^9, 
   3.459165459546875*^9, 3.459170357921875*^9, {3.459625136984375*^9, 
   3.459625140140625*^9}, 3.507027887345132*^9},
 FontSize->18],

Cell[BoxData[
 RowBox[{
  RowBox[{"u1", "[", 
   RowBox[{"x_", ",", "y_"}], "]"}], ":=", 
  RowBox[{"\[Epsilon]", "*", "x"}]}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10004.},
 CellChangeTimes->{{3.459078226765625*^9, 3.4590782385*^9}, {
   3.45907826853125*^9, 3.459078275859375*^9}, {3.459078647484375*^9, 
   3.459078649546875*^9}, 3.45908374184375*^9, {3.459160580609375*^9, 
   3.459160581859375*^9}, 3.459165459546875*^9, 3.459170357921875*^9, {
   3.45955289375*^9, 3.459552919390625*^9}, {3.45955312690625*^9, 
   3.4595531438125*^9}, {3.459625136984375*^9, 3.459625140140625*^9}},
 FontSize->18],

Cell[BoxData[
 StyleBox[
  RowBox[{
   RowBox[{"u2", "[", 
    RowBox[{"x_", ",", "y_"}], "]"}], ":=", 
   RowBox[{"\[Epsilon]", "*", "y"}]}],
  FontSize->18]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10004.},
 CellChangeTimes->{{3.45955312515625*^9, 3.459553187921875*^9}, 
   3.459625140140625*^9}],

Cell["\<\
Let us evaluate the \[Chi]hkappr coeff...\
\>", "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10004.},
 CellChangeTimes->{{3.4561278892666187`*^9, 3.4561279023146544`*^9}, 
   3.456128006313026*^9, {3.4561281092059317`*^9, 3.456128161981234*^9}, {
   3.456132554287485*^9, 3.456132559911008*^9}, {3.456133257033012*^9, 
   3.4561332624322557`*^9}, 3.456133293068067*^9, {3.45903155753125*^9, 
   3.459031586453125*^9}, 3.45903250021875*^9, {3.45908097503125*^9, 
   3.45908097815625*^9}, {3.4590811195*^9, 3.459081124453125*^9}, {
   3.4590811558125*^9, 3.459081158203125*^9}, 3.459082649796875*^9, 
   3.45908270415625*^9, 3.45908374184375*^9, 3.459165353421875*^9, 
   3.459165459546875*^9, 3.459170357921875*^9, {3.45955283115625*^9, 
   3.459552859390625*^9}, {3.459553087359375*^9, 3.45955308978125*^9}, {
   3.459625136984375*^9, 3.459625140140625*^9}, {3.507028772825343*^9, 
   3.507028816830978*^9}, 3.507187231218854*^9, 3.5752863761403503`*^9, {
   3.5752864747739916`*^9, 3.5752865395966997`*^9}},
 FontSize->22,
 Background->GrayLevel[0.85]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   StyleBox["\[Chi]hkappr",
    FontFamily->"Courier New"], "[", 
   RowBox[{"m_", ",", "n_"}], "]"}], ":=", " ", 
  RowBox[{
   RowBox[{
    StyleBox["\[Chi]hkappr",
     FontFamily->"Courier New"], "[", 
    RowBox[{"m", ",", "n"}], "]"}], "=", 
   RowBox[{
    FractionBox["1", 
     RowBox[{"\[Lambda]x", " ", "\[Lambda]y"}]], 
    RowBox[{"Integrate", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        StyleBox["\[Chi]",
         FontFamily->"Courier New"], "[", 
        RowBox[{"x", ",", "y"}], "]"}], 
       StyleBox[
        RowBox[{"Exp", "[", 
         RowBox[{
          RowBox[{"-", 
           StyleBox["2",
            FontSlant->"Plain"]}], "\[Pi]", " ", "\[ImaginaryI]", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"m", 
             FractionBox[
              RowBox[{"(", 
               RowBox[{"x", "-", 
                RowBox[{"u1", "[", 
                 RowBox[{"x", ",", "y"}], "]"}]}], ")"}], 
              StyleBox["\[Lambda]x",
               FontSize->15,
               FontSlant->"Plain"]]}], "+", 
            RowBox[{"n", 
             FractionBox[
              RowBox[{"(", 
               RowBox[{"y", "-", 
                RowBox[{"u2", "[", 
                 RowBox[{"x", ",", "y"}], "]"}]}], ")"}], 
              StyleBox["\[Lambda]y",
               FontSize->15,
               FontSlant->"Plain"]]}]}], ")"}]}], "]"}],
        FontFamily->"Courier New"]}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", 
        RowBox[{
         RowBox[{"-", "\[Lambda]x"}], "/", "2"}], ",", 
        RowBox[{"\[Lambda]x", "/", "2"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"y", ",", 
        RowBox[{
         RowBox[{"-", "\[Lambda]y"}], "/", "2"}], ",", 
        RowBox[{"\[Lambda]y", "/", "2"}]}], "}"}]}], "]"}]}]}]}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10003.},
 CellChangeTimes->{{3.459549068078125*^9, 3.459549189921875*^9}, {
   3.459549224921875*^9, 3.459549229390625*^9}, 3.45954926703125*^9, {
   3.45954933675*^9, 3.459549341109375*^9}, 3.45954996003125*^9, {
   3.459558456671875*^9, 3.45955845771875*^9}, 3.459605875390625*^9, 
   3.459625128171875*^9, {3.480766318796875*^9, 3.4807663333125*^9}, {
   3.480766493265625*^9, 3.48076649740625*^9}, {3.480768045578125*^9, 
   3.480768075875*^9}, {3.5067775731452312`*^9, 3.506777573786462*^9}, {
   3.507026555317594*^9, 3.507026566177608*^9}, 3.5070267929472113`*^9, {
   3.5070271936497707`*^9, 3.507027224501801*^9}, {3.507030752285582*^9, 
   3.5070307597799263`*^9}},
 FontFamily->"Courier New",
 FontSize->18],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"ncoex", "=", "6"}], ";"}], "     ", 
  RowBox[{"(*", " ", 
   RowBox[{"4", " ", "orig"}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ncoey", "=", "6"}], ";"}]}], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10003.},
 CellChangeTimes->{{3.459549512234375*^9, 3.4595495230625*^9}, {
   3.459549775609375*^9, 3.459549787421875*^9}, {3.459549831515625*^9, 
   3.4595498848125*^9}, {3.4595501808125*^9, 3.459550182171875*^9}, {
   3.459550460265625*^9, 3.459550465703125*^9}, 3.4595557775*^9, {
   3.459557439125*^9, 3.45955744784375*^9}, {3.459557925890625*^9, 
   3.459557931984375*^9}, {3.459558202890625*^9, 3.459558206375*^9}, {
   3.459558297296875*^9, 3.4595583638125*^9}, {3.45955848421875*^9, 
   3.459558486515625*^9}, {3.459605761828125*^9, 3.4596057625*^9}, {
   3.459605818453125*^9, 3.459605832578125*^9}, 3.459625128171875*^9, {
   3.4807663364375*^9, 3.48076634709375*^9}, {3.48082126765625*^9, 
   3.4808212823125*^9}, {3.507026594009664*^9, 3.507026631075254*^9}, {
   3.50703097007473*^9, 3.5070309732447443`*^9}, {3.5070341703460913`*^9, 
   3.507034179179304*^9}, {3.507034291513771*^9, 3.5070342954729033`*^9}},
 FontFamily->"Courier New",
 FontSize->18]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"Do", "[", 
   RowBox[{
    RowBox[{"Do", "[", 
     RowBox[{
      RowBox[{"Print", "[", 
       RowBox[{"{", 
        RowBox[{"m", ",", "n", ",", 
         RowBox[{"Timing", "[", 
          RowBox[{"N", "[", 
           RowBox[{
            StyleBox["\[Chi]hkappr",
             FontFamily->"Courier New"], "[", 
            RowBox[{"m", ",", "n"}], "]"}], "]"}], "]"}]}], "}"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"m", ",", 
        RowBox[{"-", "ncoex"}], ",", "ncoex"}], "}"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"n", ",", 
      RowBox[{"-", "ncoey"}], ",", "ncoey"}], "}"}]}], "]"}], ";"}]], "Input",\

 CellChangeTimes->{{3.50702654786672*^9, 3.507026588776029*^9}, {
   3.507026640569257*^9, 3.507026655952016*^9}, {3.507026767118902*^9, 
   3.507026783808118*^9}, 3.507026893506958*^9, {3.507026998984873*^9, 
   3.507027000112488*^9}, {3.507027237703451*^9, 3.507027239047903*^9}, {
   3.507027411903364*^9, 3.507027420299304*^9}, {3.507030991867447*^9, 
   3.507030999442379*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"SapprN", "[", 
   RowBox[{"x_", ",", " ", "y_", ",", " ", "ntx_", ",", " ", "nty_"}], "]"}], 
  " ", ":=", " ", 
  RowBox[{
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"m", "=", 
      RowBox[{"-", "ntx"}]}], "ntx"], 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"n", "=", 
       StyleBox[
        RowBox[{"-", "nty"}],
        FontColor->RGBColor[1, 0, 0]]}], "nty"], 
     RowBox[{
      RowBox[{"N", "[", 
       RowBox[{
        StyleBox["\[Chi]hkappr",
         FontSize->22], 
        StyleBox["[",
         FontSize->18], 
        RowBox[{"m", ",", "n"}], "]"}], "]"}], "*", 
      SuperscriptBox["E", 
       RowBox[{"I", "*", 
        RowBox[{"(", 
         StyleBox[
          RowBox[{
           RowBox[{
            FractionBox[
             RowBox[{"2", " ", "\[Pi]", " ", "m"}], "\[Lambda]x"], " ", 
            RowBox[{"(", 
             RowBox[{"x", "-", 
              RowBox[{"u1", "[", 
               RowBox[{"x", ",", "y"}], "]"}]}], ")"}]}], "+", 
           RowBox[{
            FractionBox[
             RowBox[{"2", " ", "\[Pi]", " ", "n"}], "\[Lambda]y"], " ", 
            RowBox[{"(", 
             RowBox[{"y", "-", 
              RowBox[{"u2", "[", 
               RowBox[{"x", ",", "y"}], "]"}]}], ")"}]}]}],
          FontSize->24], ")"}]}]]}]}]}], " ", "//", " ", "Chop"}]}]], "Input",\

 CellChangeTimes->{{3.506952778627833*^9, 3.5069527998160667`*^9}, {
  3.5069529225464582`*^9, 3.5069529513666563`*^9}, {3.506953985547584*^9, 
  3.5069539865284777`*^9}, {3.507027276385606*^9, 3.507027281103979*^9}, {
  3.507027974731813*^9, 3.507027987621009*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"ntx6", "=", "6"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"nty6", "=", "6"}], ";"}]}], "Input",
 CellChangeTimes->{{3.506952840642242*^9, 3.5069528406434298`*^9}, {
   3.506952887860076*^9, 3.506952898535535*^9}, {3.506953369183668*^9, 
   3.506953374448359*^9}, {3.5070341944881573`*^9, 3.507034195217915*^9}, 
   3.5070343928560677`*^9, 3.507034433528912*^9}],

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"Sumntx6apprN", "=", 
   RowBox[{"SapprN", "[", 
    RowBox[{"x", ",", "y", ",", "ntx6", ",", "nty6"}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.506952840642242*^9, 3.5069528406434298`*^9}, {
   3.506952887860076*^9, 3.506952898535535*^9}, 3.506953369183668*^9, {
   3.506953990035199*^9, 3.506953990975658*^9}, {3.506954046441042*^9, 
   3.506954052784486*^9}, {3.506954195274091*^9, 3.506954195887315*^9}, {
   3.507027285212043*^9, 3.507027286730093*^9}, {3.507027996959251*^9, 
   3.507028000213896*^9}, {3.5070343936982594`*^9, 3.5070343949291143`*^9}, 
   3.5070344341156673`*^9}],

Cell[BoxData[
 RowBox[{"graphSappr4Re", "=", 
  RowBox[{"Plot3D", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{"Re", "[", "Sumntx6apprN", "]"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", 
      RowBox[{"-", 
       FractionBox["\[Lambda]x", "2"]}], ",", 
      FractionBox["\[Lambda]x", "2"]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"y", ",", 
      RowBox[{"-", " ", 
       FractionBox["\[Lambda]y", "2"]}], ",", 
      FractionBox["\[Lambda]y", "2"]}], "}"}], ",", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<\!\(\*
StyleBox[\"x\",
FontFamily->\"Courier New\",
FontWeight->\"Plain\"]\)\>\"", ",", "\"\<\!\(\*
StyleBox[\"y\",
FontWeight->\"Plain\"]\)\>\""}], "}"}]}], ",", "\[IndentingNewLine]", 
    RowBox[{"PlotLabel", "\[Rule]", 
     RowBox[{"{", "\"\<Re[Sumntx6apprN\>\"", "}"}]}]}], "]"}]}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10006.},
 CellChangeTimes->{{3.45955340946875*^9, 3.459553473609375*^9}, {
   3.459607408609375*^9, 3.459607408703125*^9}, {3.459607614859375*^9, 
   3.459607621296875*^9}, {3.459607677421875*^9, 3.4596076795*^9}, {
   3.459607826828125*^9, 3.45960786221875*^9}, 3.459622829375*^9, 
   3.45962517903125*^9, {3.480766389640625*^9, 3.480766390234375*^9}, {
   3.480766535953125*^9, 3.4807665365*^9}, {3.48076698346875*^9, 
   3.480766996015625*^9}, {3.506950794317781*^9, 3.506950801239217*^9}, {
   3.506953189366084*^9, 3.5069532177138968`*^9}, {3.506953348859878*^9, 
   3.506953349418674*^9}, {3.5069542066405582`*^9, 3.5069542126487722`*^9}, {
   3.507026849210277*^9, 3.5070268805123453`*^9}, {3.5070273171012163`*^9, 
   3.507027326124021*^9}, {3.507028151459702*^9, 3.507028156686006*^9}, {
   3.507028451184371*^9, 3.5070284516509123`*^9}, 3.507031208157872*^9, 
   3.50703439717733*^9, 3.507188782374276*^9, {3.507188813641881*^9, 
   3.507188826127426*^9}, {3.507189041722571*^9, 3.5071890433878613`*^9}},
 FontFamily->"Courier New",
 FontSize->18],

Cell[BoxData[
 RowBox[{"graphSappr4Im", "=", 
  RowBox[{"Plot3D", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{"Im", "[", "Sumntx6apprN", "]"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", 
      RowBox[{"-", 
       FractionBox["\[Lambda]x", "2"]}], ",", 
      FractionBox["\[Lambda]x", "2"]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"y", ",", 
      RowBox[{"-", " ", 
       FractionBox["\[Lambda]y", "2"]}], ",", 
      FractionBox["\[Lambda]y", "2"]}], "}"}], ",", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<\!\(\*
StyleBox[\"x\",
FontFamily->\"Courier New\",
FontWeight->\"Plain\"]\)\>\"", ",", "\"\<\!\(\*
StyleBox[\"y\",
FontWeight->\"Plain\"]\)\>\""}], "}"}]}], ",", "\[IndentingNewLine]", 
    RowBox[{"PlotLabel", "\[Rule]", 
     RowBox[{"{", "\"\<Im[Sumntx6apprN\>\"", "}"}]}]}], "]"}]}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10006.},
 CellChangeTimes->{{3.45955340946875*^9, 3.459553473609375*^9}, {
   3.459607408609375*^9, 3.459607408703125*^9}, {3.459607614859375*^9, 
   3.459607621296875*^9}, {3.459607677421875*^9, 3.4596076795*^9}, {
   3.459607826828125*^9, 3.45960786221875*^9}, 3.459622829375*^9, 
   3.45962517903125*^9, {3.480766389640625*^9, 3.480766390234375*^9}, {
   3.480766535953125*^9, 3.4807665365*^9}, {3.48076698346875*^9, 
   3.480766996015625*^9}, {3.506950794317781*^9, 3.506950801239217*^9}, {
   3.506953189366084*^9, 3.5069532177138968`*^9}, {3.506953348859878*^9, 
   3.506953349418674*^9}, {3.5069542066405582`*^9, 3.5069542126487722`*^9}, {
   3.507026849210277*^9, 3.5070268805123453`*^9}, {3.5070273171012163`*^9, 
   3.507027326124021*^9}, {3.507028151459702*^9, 3.507028182715558*^9}, {
   3.5070284593115807`*^9, 3.507028460661345*^9}, {3.507028522586485*^9, 
   3.507028528912414*^9}, 3.507031200719837*^9, 3.507034396423862*^9, {
   3.507188845288618*^9, 3.507188850135194*^9}, {3.507189035913948*^9, 
   3.507189039081664*^9}},
 FontFamily->"Courier New",
 FontSize->18],

Cell[BoxData[
 RowBox[{"graphSappr4Abs", "=", 
  RowBox[{"Plot3D", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{"Abs", "[", "Sumntx6apprN", "]"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", 
      RowBox[{"-", 
       FractionBox["\[Lambda]x", "2"]}], ",", 
      FractionBox["\[Lambda]x", "2"]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"y", ",", 
      RowBox[{"-", " ", 
       FractionBox["\[Lambda]y", "2"]}], ",", 
      FractionBox["\[Lambda]y", "2"]}], "}"}], ",", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<\!\(\*
StyleBox[\"x\",
FontFamily->\"Courier New\",
FontWeight->\"Plain\"]\)\>\"", ",", "\"\<\!\(\*
StyleBox[\"y\",
FontWeight->\"Plain\"]\)\>\""}], "}"}]}], ",", "\[IndentingNewLine]", 
    RowBox[{"PlotLabel", "\[Rule]", 
     RowBox[{"{", "\"\<Abs[Sumntx6apprN\>\"", "}"}]}]}], "]"}]}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10006.},
 CellChangeTimes->{{3.45955340946875*^9, 3.459553473609375*^9}, {
   3.459607408609375*^9, 3.459607408703125*^9}, {3.459607614859375*^9, 
   3.459607621296875*^9}, {3.459607677421875*^9, 3.4596076795*^9}, {
   3.459607826828125*^9, 3.45960786221875*^9}, 3.459622829375*^9, 
   3.45962517903125*^9, {3.480766389640625*^9, 3.480766390234375*^9}, {
   3.480766535953125*^9, 3.4807665365*^9}, {3.48076698346875*^9, 
   3.480766996015625*^9}, {3.506950794317781*^9, 3.506950801239217*^9}, {
   3.506953189366084*^9, 3.5069532177138968`*^9}, {3.506953348859878*^9, 
   3.506953349418674*^9}, {3.5069542066405582`*^9, 3.5069542126487722`*^9}, {
   3.507026849210277*^9, 3.5070268805123453`*^9}, {3.5070273171012163`*^9, 
   3.507027326124021*^9}, {3.507028151459702*^9, 3.507028182715558*^9}, {
   3.5070284593115807`*^9, 3.507028460661345*^9}, 3.507031193743723*^9, 
   3.5070343956644278`*^9, {3.507188855952105*^9, 3.5071888623036537`*^9}, {
   3.507189028997772*^9, 3.5071890518653297`*^9}},
 FontFamily->"Courier New",
 FontSize->18]
}, Open  ]],

Cell[CellGroupData[{

Cell["Part III", "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10003.},
 CellChangeTimes->{{3.4561278892666187`*^9, 3.4561279023146544`*^9}, 
   3.456128006313026*^9, {3.4561281092059317`*^9, 3.456128161981234*^9}, {
   3.456132554287485*^9, 3.456132559911008*^9}, 3.4571610771792803`*^9, {
   3.45890498628125*^9, 3.458905003921875*^9}, {3.458905040765625*^9, 
   3.458905065171875*^9}, {3.45890880125*^9, 3.458908829625*^9}, {
   3.459031391640625*^9, 3.45903141328125*^9}, {3.459031609796875*^9, 
   3.45903161853125*^9}, 3.459032413875*^9, {3.4590787515625*^9, 
   3.45907876484375*^9}, {3.459080959859375*^9, 3.4590809625*^9}, {
   3.45908105425*^9, 3.459081063546875*^9}, 3.45908270415625*^9, 
   3.459083736921875*^9, {3.459161519140625*^9, 3.45916154453125*^9}, 
   3.45916170553125*^9, 3.459161949078125*^9, {3.459162408015625*^9, 
   3.459162479640625*^9}, {3.459162572953125*^9, 3.459162590859375*^9}, 
   3.459162654765625*^9, {3.459167345890625*^9, 3.4591674620625*^9}, {
   3.459167493109375*^9, 3.45916751634375*^9}, {3.459167569421875*^9, 
   3.45916763553125*^9}, {3.459167676828125*^9, 3.459167680640625*^9}, {
   3.4591677316875*^9, 3.459167762609375*^9}, {3.459549029125*^9, 
   3.45954902959375*^9}, {3.459602988515625*^9, 3.459603044984375*^9}, {
   3.45960472828125*^9, 3.459604730828125*^9}, {3.459604822515625*^9, 
   3.4596048321875*^9}, {3.4596048689375*^9, 3.459604951390625*^9}, 
   3.459625128171875*^9, 3.5070286029018383`*^9, {3.507028673596087*^9, 
   3.5070286792001467`*^9}, {3.507028789126419*^9, 3.507028791881126*^9}, {
   3.507028855662973*^9, 3.5070288642423553`*^9}, {3.5752863538640757`*^9, 
   3.5752863563002157`*^9}},
 FontFamily->"Times New Roman",
 FontSize->36,
 FontColor->RGBColor[0, 0, 1],
 Background->RGBColor[1, 0.9, 0.8]],

Cell["In the end, here you are the case of a deformed lattice...", "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10003.},
 CellChangeTimes->{{3.4561278892666187`*^9, 3.4561279023146544`*^9}, 
   3.456128006313026*^9, {3.4561281092059317`*^9, 3.456128161981234*^9}, {
   3.456132554287485*^9, 3.456132559911008*^9}, 3.4571610771792803`*^9, {
   3.45890498628125*^9, 3.458905003921875*^9}, {3.458905040765625*^9, 
   3.458905065171875*^9}, {3.45890880125*^9, 3.458908829625*^9}, {
   3.459031391640625*^9, 3.45903141328125*^9}, {3.459031609796875*^9, 
   3.45903161853125*^9}, 3.459032413875*^9, {3.4590787515625*^9, 
   3.45907876484375*^9}, {3.459080959859375*^9, 3.4590809625*^9}, {
   3.45908105425*^9, 3.459081063546875*^9}, 3.45908270415625*^9, 
   3.459083736921875*^9, {3.459161519140625*^9, 3.45916154453125*^9}, 
   3.45916170553125*^9, 3.459161949078125*^9, {3.459162408015625*^9, 
   3.459162479640625*^9}, {3.459162572953125*^9, 3.459162590859375*^9}, 
   3.459162654765625*^9, {3.459167345890625*^9, 3.4591674620625*^9}, {
   3.459167493109375*^9, 3.45916751634375*^9}, {3.459167569421875*^9, 
   3.45916763553125*^9}, {3.459167676828125*^9, 3.459167680640625*^9}, {
   3.4591677316875*^9, 3.459167762609375*^9}, {3.459549029125*^9, 
   3.45954902959375*^9}, {3.459602988515625*^9, 3.459603044984375*^9}, {
   3.45960472828125*^9, 3.459604730828125*^9}, {3.459604822515625*^9, 
   3.4596048321875*^9}, {3.4596048689375*^9, 3.459604951390625*^9}, 
   3.459625128171875*^9, 3.5070286029018383`*^9, {3.507028673596087*^9, 
   3.5070286792001467`*^9}, {3.507028789126419*^9, 3.507028791881126*^9}, {
   3.507028855662973*^9, 3.5070288642423553`*^9}, 3.5752863527730136`*^9, {
   3.575286553157475*^9, 3.575286567332286*^9}},
 FontSize->22,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   StyleBox["\[Chi]hkdef",
    FontFamily->"Courier New"], "[", 
   RowBox[{"m_", ",", "n_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{
    StyleBox["\[Chi]hkdef",
     FontFamily->"Courier New"], "[", 
    RowBox[{"m", ",", "n"}], "]"}], "=", 
   RowBox[{
    FractionBox["1", 
     RowBox[{"\[Lambda]x", " ", "\[Lambda]y"}]], 
    RowBox[{"Integrate", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        StyleBox["\[Chi]",
         FontFamily->"Courier New"], "[", 
        RowBox[{
         FractionBox["x", 
          RowBox[{"1", "+", "\[Epsilon]"}]], ",", 
         FractionBox["y", 
          RowBox[{"1", "+", "\[Epsilon]"}]]}], "]"}], 
       StyleBox[
        RowBox[{"Exp", "[", 
         RowBox[{
          RowBox[{"-", 
           StyleBox["2",
            FontSlant->"Plain"]}], "\[Pi]", " ", "\[ImaginaryI]", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"m", 
             FractionBox["x", 
              StyleBox["\[Lambda]x",
               FontSize->15,
               FontSlant->"Plain"]]}], "+", 
            RowBox[{"n", 
             FractionBox["y", 
              StyleBox["\[Lambda]y",
               FontSize->15,
               FontSlant->"Plain"]]}]}], ")"}]}], "]"}],
        FontFamily->"Courier New"]}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", 
        RowBox[{
         RowBox[{"-", "\[Lambda]x"}], "/", "2"}], ",", 
        RowBox[{"\[Lambda]x", "/", "2"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"y", ",", 
        RowBox[{
         RowBox[{"-", "\[Lambda]y"}], "/", "2"}], ",", 
        RowBox[{"\[Lambda]y", "/", "2"}]}], "}"}]}], "]"}]}]}]}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10003.},
 CellChangeTimes->{{3.459549068078125*^9, 3.459549189921875*^9}, {
   3.459549224921875*^9, 3.459549229390625*^9}, 3.45954926703125*^9, {
   3.45954933675*^9, 3.459549341109375*^9}, 3.45954996003125*^9, {
   3.459558456671875*^9, 3.45955845771875*^9}, 3.459605875390625*^9, 
   3.459625128171875*^9, {3.480766318796875*^9, 3.4807663333125*^9}, {
   3.480766493265625*^9, 3.48076649740625*^9}, {3.480768045578125*^9, 
   3.480768075875*^9}, {3.5067775731452312`*^9, 3.506777573786462*^9}, {
   3.507026555317594*^9, 3.507026566177608*^9}, 3.5070267929472113`*^9, {
   3.507028874228071*^9, 3.50702895173011*^9}, {3.507031231318034*^9, 
   3.5070312372778463`*^9}},
 FontFamily->"Courier New",
 FontSize->18],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"ncoex", "=", "6"}], ";"}], "     ", 
  RowBox[{"(*", " ", 
   RowBox[{"4", " ", "orig"}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ncoey", "=", "6"}], ";"}]}], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10003.},
 CellChangeTimes->{{3.459549512234375*^9, 3.4595495230625*^9}, {
   3.459549775609375*^9, 3.459549787421875*^9}, {3.459549831515625*^9, 
   3.4595498848125*^9}, {3.4595501808125*^9, 3.459550182171875*^9}, {
   3.459550460265625*^9, 3.459550465703125*^9}, 3.4595557775*^9, {
   3.459557439125*^9, 3.45955744784375*^9}, {3.459557925890625*^9, 
   3.459557931984375*^9}, {3.459558202890625*^9, 3.459558206375*^9}, {
   3.459558297296875*^9, 3.4595583638125*^9}, {3.45955848421875*^9, 
   3.459558486515625*^9}, {3.459605761828125*^9, 3.4596057625*^9}, {
   3.459605818453125*^9, 3.459605832578125*^9}, 3.459625128171875*^9, {
   3.4807663364375*^9, 3.48076634709375*^9}, {3.48082126765625*^9, 
   3.4808212823125*^9}, {3.507026594009664*^9, 3.507026631075254*^9}, {
   3.507031258707569*^9, 3.507031261375765*^9}, 3.507034196505427*^9, {
   3.507034327975514*^9, 3.507034328665667*^9}},
 FontFamily->"Courier New",
 FontSize->18],

Cell[BoxData[
 RowBox[{"Date", "[", "]"}]], "Input",
 CellChangeTimes->{{3.552985973204381*^9, 3.552985974368511*^9}},
 FontSize->18],

Cell[BoxData[
 RowBox[{
  RowBox[{"Do", "[", 
   RowBox[{
    RowBox[{"Do", "[", 
     RowBox[{
      RowBox[{"Print", "[", 
       RowBox[{"{", 
        RowBox[{"m", ",", "n", ",", 
         RowBox[{"Timing", "[", 
          RowBox[{"N", "[", 
           RowBox[{
            StyleBox["\[Chi]hkdef",
             FontFamily->"Courier New"], "[", 
            RowBox[{"m", ",", "n"}], "]"}], "]"}], "]"}]}], "}"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"m", ",", 
        RowBox[{"-", "ncoex"}], ",", "ncoex"}], "}"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"n", ",", 
      RowBox[{"-", "ncoey"}], ",", "ncoey"}], "}"}]}], "]"}], ";"}]], "Input",\

 CellChangeTimes->{{3.50702654786672*^9, 3.507026588776029*^9}, {
   3.507026640569257*^9, 3.507026655952016*^9}, {3.507026767118902*^9, 
   3.507026783808118*^9}, 3.507026893506958*^9, {3.507026998984873*^9, 
   3.507027000112488*^9}, {3.5070279315418158`*^9, 3.507027935491643*^9}, {
   3.507028877394104*^9, 3.5070288778250637`*^9}, {3.507031249184882*^9, 
   3.507031255589633*^9}}],

Cell[BoxData[
 RowBox[{"Date", "[", "]"}]], "Input",
 CellChangeTimes->{{3.552985973204381*^9, 3.552985974368511*^9}},
 FontSize->18],

Cell[BoxData[
 RowBox[{
  RowBox[{"SdefN", "[", 
   RowBox[{"x_", ",", " ", "y_", ",", " ", "ntx_", ",", " ", "nty_"}], "]"}], 
  " ", ":=", " ", 
  RowBox[{
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"m", "=", 
      RowBox[{"-", "ntx"}]}], "ntx"], 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"n", "=", 
       StyleBox[
        RowBox[{"-", "nty"}],
        FontColor->RGBColor[1, 0, 0]]}], "nty"], 
     RowBox[{
      RowBox[{"N", "[", 
       RowBox[{
        StyleBox["\[Chi]hkdef",
         FontSize->22], 
        StyleBox["[",
         FontSize->18], 
        RowBox[{"m", ",", "n"}], "]"}], "]"}], "*", 
      SuperscriptBox["E", 
       RowBox[{"I", "*", 
        RowBox[{"(", 
         StyleBox[
          RowBox[{
           RowBox[{
            FractionBox[
             RowBox[{"2", " ", "\[Pi]", " ", "m"}], "\[Lambda]x"], " ", "x"}],
            "+", 
           RowBox[{
            FractionBox[
             RowBox[{"2", " ", "\[Pi]", " ", "n"}], "\[Lambda]y"], " ", 
            "y"}]}],
          FontSize->24], ")"}]}]]}]}]}], " ", "//", " ", "Chop"}]}]], "Input",\

 CellChangeTimes->{{3.506952778627833*^9, 3.5069527998160667`*^9}, {
   3.5069529225464582`*^9, 3.5069529513666563`*^9}, {3.506953985547584*^9, 
   3.5069539865284777`*^9}, {3.507026807329492*^9, 3.5070268227357388`*^9}, {
   3.507028882682917*^9, 3.507028891207622*^9}, 3.507029012748601*^9, {
   3.507029855571274*^9, 3.507029861414747*^9}, 3.507188189492255*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"ntx6", "=", "6"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"nty6", "=", "6"}], ";"}]}], "Input",
 CellChangeTimes->{{3.506952840642242*^9, 3.5069528406434298`*^9}, {
   3.506952887860076*^9, 3.506952898535535*^9}, {3.506953369183668*^9, 
   3.506953374448359*^9}, {3.507029906797041*^9, 3.507029910306436*^9}, {
   3.5070322377205477`*^9, 3.507032240548328*^9}, {3.507034198064939*^9, 
   3.507034198621951*^9}, 3.507034398086206*^9, 3.5070344347042027`*^9}],

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"Sumdefntx6N", "=", 
   RowBox[{"SdefN", "[", 
    RowBox[{"x", ",", "y", ",", "ntx6", ",", "nty6"}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.506952840642242*^9, 3.5069528406434298`*^9}, {
   3.506952887860076*^9, 3.506952898535535*^9}, 3.506953369183668*^9, {
   3.506953990035199*^9, 3.506953990975658*^9}, {3.506954046441042*^9, 
   3.506954052784486*^9}, {3.506954195274091*^9, 3.506954195887315*^9}, {
   3.5070268400411253`*^9, 3.507026844148245*^9}, {3.507028966619025*^9, 
   3.507028970851668*^9}, {3.507034399339239*^9, 3.5070344000511208`*^9}, 
   3.5070344351864147`*^9, {3.50718819672917*^9, 3.507188199991453*^9}}],

Cell[BoxData[
 RowBox[{"graphSdef4", "=", 
  RowBox[{"Plot3D", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", "Sumdefntx6N", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", 
      RowBox[{"-", 
       FractionBox["\[Lambda]x", "2"]}], ",", 
      FractionBox["\[Lambda]x", "2"]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"y", ",", 
      RowBox[{"-", " ", 
       FractionBox["\[Lambda]y", "2"]}], ",", 
      FractionBox["\[Lambda]y", "2"]}], "}"}], ",", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<\!\(\*
StyleBox[\"x\",
FontFamily->\"Courier New\",
FontWeight->\"Plain\"]\)\>\"", ",", "\"\<\!\(\*
StyleBox[\"y\",
FontWeight->\"Plain\"]\)\>\""}], "}"}]}], ",", "\[IndentingNewLine]", 
    RowBox[{"PlotLabel", "\[Rule]", 
     RowBox[{"{", "\"\<Sumdefntx6N\>\"", "}"}]}]}], "]"}]}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10006.},
 CellChangeTimes->{{3.45955340946875*^9, 3.459553473609375*^9}, {
   3.459607408609375*^9, 3.459607408703125*^9}, {3.459607614859375*^9, 
   3.459607621296875*^9}, {3.459607677421875*^9, 3.4596076795*^9}, {
   3.459607826828125*^9, 3.45960786221875*^9}, 3.459622829375*^9, 
   3.45962517903125*^9, {3.480766389640625*^9, 3.480766390234375*^9}, {
   3.480766535953125*^9, 3.4807665365*^9}, {3.48076698346875*^9, 
   3.480766996015625*^9}, {3.506950794317781*^9, 3.506950801239217*^9}, {
   3.506953189366084*^9, 3.5069532177138968`*^9}, {3.506953348859878*^9, 
   3.506953349418674*^9}, {3.5069542066405582`*^9, 3.5069542126487722`*^9}, {
   3.507026849210277*^9, 3.5070268805123453`*^9}, {3.5070282351587963`*^9, 
   3.507028245723881*^9}, {3.507030253558754*^9, 3.507030254098078*^9}, {
   3.5070322803402777`*^9, 3.5070322883823347`*^9}, 3.5070326131579638`*^9, 
   3.507034400843898*^9, 3.5071882037932787`*^9, 3.507188884577218*^9, 
   3.507188935108864*^9},
 FontFamily->"Courier New",
 FontSize->18],

Cell[BoxData[
 RowBox[{"graphSdef4Re", "=", 
  RowBox[{"Plot3D", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{"Re", "[", "Sumdefntx6N", "]"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", 
      RowBox[{"-", 
       FractionBox["\[Lambda]x", "2"]}], ",", 
      FractionBox["\[Lambda]x", "2"]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"y", ",", 
      RowBox[{"-", " ", 
       FractionBox["\[Lambda]y", "2"]}], ",", 
      FractionBox["\[Lambda]y", "2"]}], "}"}], ",", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<\!\(\*
StyleBox[\"x\",
FontFamily->\"Courier New\",
FontWeight->\"Plain\"]\)\>\"", ",", "\"\<\!\(\*
StyleBox[\"y\",
FontWeight->\"Plain\"]\)\>\""}], "}"}]}], ",", "\[IndentingNewLine]", 
    RowBox[{"PlotLabel", "\[Rule]", 
     RowBox[{"{", "\"\<Re[Sumdefntx6N\>\"", "}"}]}]}], "]"}]}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10006.},
 CellChangeTimes->{{3.45955340946875*^9, 3.459553473609375*^9}, {
   3.459607408609375*^9, 3.459607408703125*^9}, {3.459607614859375*^9, 
   3.459607621296875*^9}, {3.459607677421875*^9, 3.4596076795*^9}, {
   3.459607826828125*^9, 3.45960786221875*^9}, 3.459622829375*^9, 
   3.45962517903125*^9, {3.480766389640625*^9, 3.480766390234375*^9}, {
   3.480766535953125*^9, 3.4807665365*^9}, {3.48076698346875*^9, 
   3.480766996015625*^9}, {3.506950794317781*^9, 3.506950801239217*^9}, {
   3.506953189366084*^9, 3.5069532177138968`*^9}, {3.506953348859878*^9, 
   3.506953349418674*^9}, {3.5069542066405582`*^9, 3.5069542126487722`*^9}, {
   3.507026849210277*^9, 3.5070268805123453`*^9}, {3.5070282351587963`*^9, 
   3.507028245723881*^9}, {3.507028362817822*^9, 3.507028368545802*^9}, {
   3.50702897391982*^9, 3.507028978249017*^9}, 3.507034401814166*^9, 
   3.507188217710854*^9, {3.507188965874134*^9, 3.507188990923476*^9}},
 FontFamily->"Courier New",
 FontSize->18],

Cell[BoxData[
 RowBox[{"graphSdef4Im", "=", 
  RowBox[{"Plot3D", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{"Im", "[", "Sumdefntx6N", "]"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", 
      RowBox[{"-", 
       FractionBox["\[Lambda]x", "2"]}], ",", 
      FractionBox["\[Lambda]x", "2"]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"y", ",", 
      RowBox[{"-", " ", 
       FractionBox["\[Lambda]y", "2"]}], ",", 
      FractionBox["\[Lambda]y", "2"]}], "}"}], ",", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<\!\(\*
StyleBox[\"x\",
FontFamily->\"Courier New\",
FontWeight->\"Plain\"]\)\>\"", ",", "\"\<\!\(\*
StyleBox[\"y\",
FontWeight->\"Plain\"]\)\>\""}], "}"}]}], ",", "\[IndentingNewLine]", 
    RowBox[{"PlotLabel", "\[Rule]", 
     RowBox[{"{", "\"\<Im[Sumdefntx6N\>\"", "}"}]}]}], "]"}]}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10006.},
 CellChangeTimes->{{3.45955340946875*^9, 3.459553473609375*^9}, {
   3.459607408609375*^9, 3.459607408703125*^9}, {3.459607614859375*^9, 
   3.459607621296875*^9}, {3.459607677421875*^9, 3.4596076795*^9}, {
   3.459607826828125*^9, 3.45960786221875*^9}, 3.459622829375*^9, 
   3.45962517903125*^9, {3.480766389640625*^9, 3.480766390234375*^9}, {
   3.480766535953125*^9, 3.4807665365*^9}, {3.48076698346875*^9, 
   3.480766996015625*^9}, {3.506950794317781*^9, 3.506950801239217*^9}, {
   3.506953189366084*^9, 3.5069532177138968`*^9}, {3.506953348859878*^9, 
   3.506953349418674*^9}, {3.5069542066405582`*^9, 3.5069542126487722`*^9}, {
   3.507026849210277*^9, 3.5070268805123453`*^9}, {3.5070282351587963`*^9, 
   3.507028245723881*^9}, {3.507028362817822*^9, 3.507028368545802*^9}, {
   3.50702897391982*^9, 3.507028978249017*^9}, {3.507030230899912*^9, 
   3.50703024274193*^9}, 3.5070344025532637`*^9, 3.50718822275183*^9, {
   3.507189000572473*^9, 3.507189004441416*^9}},
 FontFamily->"Courier New",
 FontSize->18],

Cell[BoxData[
 RowBox[{"graphSdef4Abs", "=", 
  RowBox[{"Plot3D", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{"Abs", "[", "Sumntx6N", "]"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", 
      RowBox[{"-", 
       FractionBox["\[Lambda]x", "2"]}], ",", 
      FractionBox["\[Lambda]x", "2"]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"y", ",", 
      RowBox[{"-", " ", 
       FractionBox["\[Lambda]y", "2"]}], ",", 
      FractionBox["\[Lambda]y", "2"]}], "}"}], ",", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<\!\(\*
StyleBox[\"x\",
FontFamily->\"Courier New\",
FontWeight->\"Plain\"]\)\>\"", ",", "\"\<\!\(\*
StyleBox[\"y\",
FontWeight->\"Plain\"]\)\>\""}], "}"}]}], ",", "\[IndentingNewLine]", 
    RowBox[{"PlotLabel", "\[Rule]", 
     RowBox[{"{", "\"\<Abs[Sumdefntx6N\>\"", "}"}]}]}], "]"}]}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10006.},
 CellChangeTimes->{{3.45955340946875*^9, 3.459553473609375*^9}, {
   3.459607408609375*^9, 3.459607408703125*^9}, {3.459607614859375*^9, 
   3.459607621296875*^9}, {3.459607677421875*^9, 3.4596076795*^9}, {
   3.459607826828125*^9, 3.45960786221875*^9}, 3.459622829375*^9, 
   3.45962517903125*^9, {3.480766389640625*^9, 3.480766390234375*^9}, {
   3.480766535953125*^9, 3.4807665365*^9}, {3.48076698346875*^9, 
   3.480766996015625*^9}, {3.506950794317781*^9, 3.506950801239217*^9}, {
   3.506953189366084*^9, 3.5069532177138968`*^9}, {3.506953348859878*^9, 
   3.506953349418674*^9}, {3.5069542066405582`*^9, 3.5069542126487722`*^9}, {
   3.507026849210277*^9, 3.5070268805123453`*^9}, {3.5070282351587963`*^9, 
   3.507028245723881*^9}, {3.507030253558754*^9, 3.507030254098078*^9}, 
   3.507034403212228*^9, 3.5071882271030893`*^9, {3.507189010377462*^9, 
   3.50718901470251*^9}},
 FontFamily->"Courier New",
 FontSize->18]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Date", "[", "]"}]], "Input",
 CellChangeTimes->{{3.507188294878476*^9, 3.507188297308958*^9}}],

Cell[CellGroupData[{

Cell["Part IV ", "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10006.},
 CellChangeTimes->{{3.4561278892666187`*^9, 3.4561279023146544`*^9}, 
   3.456128006313026*^9, {3.4561281092059317`*^9, 3.456128161981234*^9}, {
   3.456132554287485*^9, 3.456132559911008*^9}, {3.456133257033012*^9, 
   3.4561332624322557`*^9}, 3.456133293068067*^9, {3.45903155753125*^9, 
   3.459031586453125*^9}, 3.45903250021875*^9, {3.45908097503125*^9, 
   3.45908097815625*^9}, {3.4590811195*^9, 3.459081124453125*^9}, {
   3.4590811558125*^9, 3.459081158203125*^9}, 3.459082649796875*^9, 
   3.45908270415625*^9, 3.45908374184375*^9, 3.459165459546875*^9, {
   3.459165498265625*^9, 3.45916551509375*^9}, {3.459165565828125*^9, 
   3.459165593328125*^9}, {3.4591656280625*^9, 3.459165711515625*^9}, {
   3.45916576253125*^9, 3.459165825796875*^9}, {3.459165864734375*^9, 
   3.459165889015625*^9}, {3.45916601834375*^9, 3.459166035265625*^9}, {
   3.459166079890625*^9, 3.459166106171875*^9}, {3.459166234265625*^9, 
   3.459166427796875*^9}, {3.45916664746875*^9, 3.459166649484375*^9}, {
   3.45916789009375*^9, 3.45916790028125*^9}, {3.459167967484375*^9, 
   3.459168031296875*^9}, {3.459168132546875*^9, 3.459168136328125*^9}, 
   3.459170375046875*^9, {3.45955331296875*^9, 3.459553359046875*^9}, {
   3.459607314296875*^9, 3.459607318859375*^9}, {3.459607362484375*^9, 
   3.459607372328125*^9}, {3.459625154796875*^9, 3.45962517903125*^9}, {
   3.507033341910882*^9, 3.507033360929264*^9}, {3.507187371977028*^9, 
   3.507187374856063*^9}, {3.575286174157798*^9, 3.5752861752208586`*^9}},
 FontFamily->"Times New Roman",
 FontSize->36,
 FontColor->RGBColor[0, 0, 1],
 Background->RGBColor[1, 0.9, 0.8]],

Cell["\<\
Comparison among   \[Chi]hk ,  \[Chi]hkdef  and  \[Chi]hkappr ...\
\>", "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10006.},
 CellChangeTimes->{{3.4561278892666187`*^9, 3.4561279023146544`*^9}, 
   3.456128006313026*^9, {3.4561281092059317`*^9, 3.456128161981234*^9}, {
   3.456132554287485*^9, 3.456132559911008*^9}, {3.456133257033012*^9, 
   3.4561332624322557`*^9}, 3.456133293068067*^9, {3.45903155753125*^9, 
   3.459031586453125*^9}, 3.45903250021875*^9, {3.45908097503125*^9, 
   3.45908097815625*^9}, {3.4590811195*^9, 3.459081124453125*^9}, {
   3.4590811558125*^9, 3.459081158203125*^9}, 3.459082649796875*^9, 
   3.45908270415625*^9, 3.45908374184375*^9, 3.459165459546875*^9, {
   3.459165498265625*^9, 3.45916551509375*^9}, {3.459165565828125*^9, 
   3.459165593328125*^9}, {3.4591656280625*^9, 3.459165711515625*^9}, {
   3.45916576253125*^9, 3.459165825796875*^9}, {3.459165864734375*^9, 
   3.459165889015625*^9}, {3.45916601834375*^9, 3.459166035265625*^9}, {
   3.459166079890625*^9, 3.459166106171875*^9}, {3.459166234265625*^9, 
   3.459166427796875*^9}, {3.45916664746875*^9, 3.459166649484375*^9}, {
   3.45916789009375*^9, 3.45916790028125*^9}, {3.459167967484375*^9, 
   3.459168031296875*^9}, {3.459168132546875*^9, 3.459168136328125*^9}, 
   3.459170375046875*^9, {3.45955331296875*^9, 3.459553359046875*^9}, {
   3.459607314296875*^9, 3.459607318859375*^9}, {3.459607362484375*^9, 
   3.459607372328125*^9}, {3.459625154796875*^9, 3.45962517903125*^9}, {
   3.507033341910882*^9, 3.507033360929264*^9}, {3.507187371977028*^9, 
   3.507187374856063*^9}, {3.575286582551156*^9, 3.5752865908046284`*^9}},
 FontSize->22,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{"Date", "[", "]"}]], "Input",
 CellChangeTimes->{{3.552986019545414*^9, 3.552986020665045*^9}},
 FontSize->18],

Cell[BoxData[
 RowBox[{
  RowBox[{"Do", "[", 
   RowBox[{
    RowBox[{"Do", "[", 
     RowBox[{
      RowBox[{"Print", "[", 
       RowBox[{"{", 
        RowBox[{"m", ",", "n", ",", 
         RowBox[{"Abs", "[", 
          RowBox[{"N", "[", 
           RowBox[{
            StyleBox["\[Chi]hk",
             FontFamily->"Courier New"], "[", 
            RowBox[{"m", ",", "n"}], "]"}], "]"}], "]"}], ",", 
         "\[IndentingNewLine]", "                             ", 
         RowBox[{"Abs", "[", 
          RowBox[{"N", "[", 
           RowBox[{
            StyleBox["\[Chi]hkdef",
             FontFamily->"Courier New"], "[", 
            RowBox[{"m", ",", "n"}], "]"}], "]"}], "]"}], ",", 
         "\[IndentingNewLine]", "                             ", 
         RowBox[{"Abs", "[", 
          RowBox[{"N", "[", 
           RowBox[{
            StyleBox["\[Chi]hkappr",
             FontFamily->"Courier New"], "[", 
            RowBox[{"m", ",", "n"}], "]"}], "]"}], "]"}]}], 
        "\[IndentingNewLine]", "              ", "}"}], "]"}], ",", 
      "\[IndentingNewLine]", " ", 
      RowBox[{"{", 
       RowBox[{"m", ",", 
        RowBox[{"-", "ntx6"}], ",", "ntx6"}], "}"}]}], "]"}], ",", 
    "\[IndentingNewLine]", "   ", 
    RowBox[{"{", 
     RowBox[{"n", ",", 
      RowBox[{"-", "nty6"}], ",", "nty6"}], "}"}]}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.50702654786672*^9, 3.507026588776029*^9}, {
   3.507026640569257*^9, 3.507026655952016*^9}, {3.507026767118902*^9, 
   3.507026783808118*^9}, 3.507026893506958*^9, {3.507026998984873*^9, 
   3.507027000112488*^9}, {3.507027237703451*^9, 3.507027239047903*^9}, {
   3.507027411903364*^9, 3.507027420299304*^9}, {3.507030991867447*^9, 
   3.507030999442379*^9}, {3.507032957861898*^9, 3.507033154128427*^9}, {
   3.507034404084638*^9, 3.507034404739799*^9}, {3.5070344356528807`*^9, 
   3.5070344362595043`*^9}}],

Cell[BoxData[
 RowBox[{"Date", "[", "]"}]], "Input",
 CellChangeTimes->{{3.552986019545414*^9, 3.552986020665045*^9}},
 FontSize->18],

Cell[CellGroupData[{

Cell[TextData[{
 "Various comparison between \[OpenCurlyDoubleQuote]",
 Cell[BoxData[
  RowBox[{
   StyleBox["\[Chi]",
    FontFamily->"Courier New"], 
   StyleBox["[",
    FontFamily->"Courier New"], 
   RowBox[{
    FractionBox["x", 
     RowBox[{"\[Epsilon]", "+", "1"}]], ",", 
    FractionBox["y", 
     RowBox[{"\[Epsilon]", "+", "1"}]]}], 
   StyleBox["]",
    FontFamily->"Courier New"]}]], "None",
  FontFamily->"Courier New"],
 " and  Sumntx6\[CloseCurlyDoubleQuote] ,   \[OpenCurlyDoubleQuote]",
 Cell[BoxData[
  RowBox[{
   StyleBox["\[Chi]",
    FontFamily->"Courier New"], 
   StyleBox["[",
    FontFamily->"Courier New"], 
   RowBox[{
    FractionBox["x", 
     RowBox[{"\[Epsilon]", "+", "1"}]], ",", 
    FractionBox["y", 
     RowBox[{"\[Epsilon]", "+", "1"}]]}], 
   StyleBox["]",
    FontFamily->"Courier New"]}]], "None",
  FontFamily->"Courier New"],
 " and  Re[Sumdefntx6]\[CloseCurlyDoubleQuote] and \[OpenCurlyDoubleQuote]",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    StyleBox["\[Chi]",
     FontFamily->"Courier New"], "[", 
    RowBox[{"x", ",", "y"}], "]"}], "-", 
   RowBox[{
    StyleBox["\[Chi]",
     FontFamily->"Courier New"], 
    StyleBox["[",
     FontFamily->"Courier New"], 
    RowBox[{
     FractionBox["x", 
      RowBox[{"\[Epsilon]", "+", "1"}]], ",", 
     FractionBox["y", 
      RowBox[{"\[Epsilon]", "+", "1"}]]}], 
    StyleBox["]",
     FontFamily->"Courier New"]}]}]], "Input",
  CellChangeTimes->{{3.506777056893928*^9, 3.506777097077627*^9}, {
   3.506777143484271*^9, 3.506777147231254*^9}, {3.506777181020751*^9, 
   3.506777192844201*^9}, {3.506777240153821*^9, 3.5067772948052673`*^9}, {
   3.507032791007544*^9, 3.5070328040772467`*^9}, {3.5070328416534348`*^9, 
   3.507032877255612*^9}}],
 "\[CloseCurlyDoubleQuote]"
}], "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10006.},
 CellChangeTimes->{{3.4561278892666187`*^9, 3.4561279023146544`*^9}, 
   3.456128006313026*^9, {3.4561281092059317`*^9, 3.456128161981234*^9}, {
   3.456132554287485*^9, 3.456132559911008*^9}, {3.456133257033012*^9, 
   3.4561332624322557`*^9}, 3.456133293068067*^9, {3.45903155753125*^9, 
   3.459031586453125*^9}, 3.45903250021875*^9, {3.45908097503125*^9, 
   3.45908097815625*^9}, {3.4590811195*^9, 3.459081124453125*^9}, {
   3.4590811558125*^9, 3.459081158203125*^9}, 3.459082649796875*^9, 
   3.45908270415625*^9, 3.45908374184375*^9, 3.459165459546875*^9, {
   3.459165498265625*^9, 3.45916551509375*^9}, {3.459165565828125*^9, 
   3.459165593328125*^9}, {3.4591656280625*^9, 3.459165711515625*^9}, {
   3.45916576253125*^9, 3.459165825796875*^9}, {3.459165864734375*^9, 
   3.459165889015625*^9}, {3.45916601834375*^9, 3.459166035265625*^9}, {
   3.459166079890625*^9, 3.459166106171875*^9}, {3.459166234265625*^9, 
   3.459166427796875*^9}, {3.45916664746875*^9, 3.459166649484375*^9}, {
   3.45916789009375*^9, 3.45916790028125*^9}, {3.459167967484375*^9, 
   3.459168031296875*^9}, {3.459168132546875*^9, 3.459168136328125*^9}, 
   3.459170375046875*^9, {3.45955331296875*^9, 3.459553359046875*^9}, {
   3.459607314296875*^9, 3.459607318859375*^9}, {3.459607362484375*^9, 
   3.459607372328125*^9}, {3.459625154796875*^9, 3.45962517903125*^9}, {
   3.507033396055225*^9, 3.507033464505752*^9}, {3.507033512110908*^9, 
   3.507033513654832*^9}, {3.50703440565561*^9, 3.5070344064142113`*^9}, {
   3.575286597349003*^9, 3.5752866246535645`*^9}},
 FontSize->22,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Compare$defvs", 
    StyleBox["Sumntx6",
     FontFamily->"Courier New"]}]], "=", 
  RowBox[{"Plot3D", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{
      RowBox[{
       StyleBox["\[Chi]",
        FontFamily->"Courier New"], 
       StyleBox["[",
        FontFamily->"Courier New"], 
       RowBox[{
        FractionBox["x", 
         RowBox[{"\[Epsilon]", "+", "1"}]], ",", 
        FractionBox["y", 
         RowBox[{"\[Epsilon]", "+", "1"}]]}], 
       StyleBox["]",
        FontFamily->"Courier New"]}], 
      StyleBox["-",
       FontFamily->"Courier New"], 
      StyleBox["Sumntx6",
       FontFamily->"Courier New"]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", 
      RowBox[{"-", 
       FractionBox["\[Lambda]x", "2"]}], ",", 
      FractionBox["\[Lambda]x", "2"]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"y", ",", 
      RowBox[{"-", " ", 
       FractionBox["\[Lambda]y", "2"]}], ",", 
      FractionBox["\[Lambda]y", "2"]}], "}"}], ",", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<\!\(\*
StyleBox[\"x\",
FontFamily->\"Courier New\",
FontWeight->\"Plain\"]\)\>\"", ",", "\"\<\!\(\*
StyleBox[\"y\",
FontWeight->\"Plain\"]\)\>\""}], "}"}]}], ",", "\[IndentingNewLine]", 
    RowBox[{"PlotLabel", "\[Rule]", 
     RowBox[{"{", "\"\<\!\(\*
StyleBox[\"\[Chi]\",
FontFamily->\"Courier New\"]\)\!\(\*
StyleBox[\"[\",
FontFamily->\"Courier New\"]\)\!\(\*FractionBox[\(x\), \(\[Epsilon] + 1\)]\),\
\!\(\*FractionBox[\(y\), \(\[Epsilon] + 1\)]\)\!\(\*
StyleBox[\"]\",
FontFamily->\"Courier New\"]\) - \!\(\*
StyleBox[\(Su\*
StyleBox[\"mntx6\",
FontFamily->\"Courier New\"]\)]\)\!\(\*
StyleBox[\"]\",
FontFamily->\"Courier New\"]\)\>\"", "}"}]}]}], "]"}]}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10006.},
 CellChangeTimes->{{3.45955340946875*^9, 3.459553473609375*^9}, {
   3.459607408609375*^9, 3.459607408703125*^9}, {3.459607614859375*^9, 
   3.459607621296875*^9}, {3.459607677421875*^9, 3.4596076795*^9}, {
   3.459607826828125*^9, 3.45960786221875*^9}, 3.459622829375*^9, 
   3.45962517903125*^9, {3.480766389640625*^9, 3.480766390234375*^9}, {
   3.480766535953125*^9, 3.4807665365*^9}, {3.48076698346875*^9, 
   3.480766996015625*^9}, {3.506950813442915*^9, 3.506950818215713*^9}, {
   3.50695329943742*^9, 3.506953325158485*^9}, {3.506953653848241*^9, 
   3.506953688436371*^9}, {3.506954237812236*^9, 3.50695424919657*^9}, {
   3.507030418464283*^9, 3.507030421012076*^9}, 3.507034407215865*^9, {
   3.507187449242169*^9, 3.5071874857434893`*^9}, {3.5071877287922087`*^9, 
   3.507187730527876*^9}, {3.507187767147732*^9, 3.507187786496808*^9}},
 FontFamily->"Courier New",
 FontSize->18],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Compare$", 
    StyleBox["\[Chi]",
     FontFamily->"Courier New"], "vsdef"}]], 
  StyleBox[" ",
   FontFamily->"Courier New"], 
  StyleBox["=",
   FontFamily->"Courier New"], 
  StyleBox[" ",
   FontFamily->"Courier New"], 
  RowBox[{"Plot3D", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      StyleBox["\[Chi]",
       FontFamily->"Courier New"], 
      StyleBox["[",
       FontFamily->"Courier New"], 
      RowBox[{
       FractionBox["x", 
        RowBox[{"\[Epsilon]", "+", "1"}]], ",", 
       FractionBox["y", 
        RowBox[{"\[Epsilon]", "+", "1"}]]}], 
      StyleBox["]",
       FontFamily->"Courier New"]}], 
     StyleBox[" ",
      FontFamily->"Courier New"], 
     StyleBox["-",
      FontFamily->"Courier New"], 
     RowBox[{
      StyleBox["\[Chi]",
       FontFamily->"Courier New"], "[", 
      RowBox[{"x", ",", "y"}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "\[Lambda]x"}], "/", "2"}], "-", 
       RowBox[{"\[Lambda]x", "/", "10"}]}], ",", 
      RowBox[{
       RowBox[{"\[Lambda]x", "/", "2"}], "+", 
       RowBox[{"\[Lambda]x", "/", "10"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"y", ",", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "\[Lambda]y"}], "/", "2"}], "-", 
       RowBox[{"\[Lambda]y", "/", "10"}]}], ",", 
      RowBox[{
       RowBox[{"\[Lambda]y", "/", "2"}], "+", 
       RowBox[{"\[Lambda]y", "/", "10"}]}]}], "}"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
    RowBox[{"AxesStyle", "\[Rule]", 
     RowBox[{"Directive", "[", 
      RowBox[{"Blue", ",", "20", ",", 
       RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}]}], ",", 
    RowBox[{"ImageSize", "\[Rule]", "500"}], ",", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"PlotLabel", "\[Rule]", 
     RowBox[{"{", "\"\<\!\(\*
StyleBox[\"\[Chi]\",
FontFamily->\"Courier New\"]\)\!\(\*
StyleBox[\"[\",
FontFamily->\"Courier New\"]\)\!\(\*FractionBox[\(x\), \(\[Epsilon] + 1\)]\),\
\!\(\*FractionBox[\(y\), \(\[Epsilon] + 1\)]\)\!\(\*
StyleBox[\"]\",
FontFamily->\"Courier New\"]\)\!\(\*
StyleBox[\" \",
FontFamily->\"Courier New\"]\)\!\(\*
StyleBox[\"-\",
FontFamily->\"Courier New\"]\)\!\(\*
StyleBox[\" \",
FontFamily->\"Courier New\"]\)\!\(\*
StyleBox[\"\[Chi]\",
FontFamily->\"Courier New\"]\)(x,y)\>\"", "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.506777056893928*^9, 3.506777097077627*^9}, {
  3.506777143484271*^9, 3.506777147231254*^9}, {3.506777181020751*^9, 
  3.506777192844201*^9}, {3.506777240153821*^9, 3.5067772948052673`*^9}, {
  3.507032791007544*^9, 3.5070328040772467`*^9}, {3.5070328416534348`*^9, 
  3.507032877255612*^9}, {3.507187582627921*^9, 3.507187648400782*^9}, {
  3.50718785196588*^9, 3.507187876146421*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Compare$", 
    StyleBox["\[Chi]",
     FontFamily->"Courier New"], "vs", 
    StyleBox["Sumntx6apprN",
     FontFamily->"Courier New"]}]], "=", 
  RowBox[{"Plot3D", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{
      RowBox[{
       StyleBox["\[Chi]",
        FontFamily->"Courier New"], "[", 
       RowBox[{"x", ",", "y"}], "]"}], 
      StyleBox["-",
       FontFamily->"Courier New"], 
      StyleBox[
       RowBox[{"Re", "[", "Sumntx6apprN", "]"}],
       FontFamily->"Courier New"]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", 
      RowBox[{"-", 
       FractionBox["\[Lambda]x", "2"]}], ",", 
      FractionBox["\[Lambda]x", "2"]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"y", ",", 
      RowBox[{"-", " ", 
       FractionBox["\[Lambda]y", "2"]}], ",", 
      FractionBox["\[Lambda]y", "2"]}], "}"}], ",", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<\!\(\*
StyleBox[\"x\",
FontFamily->\"Courier New\",
FontWeight->\"Plain\"]\)\>\"", ",", "\"\<\!\(\*
StyleBox[\"y\",
FontWeight->\"Plain\"]\)\>\""}], "}"}]}], ",", "\[IndentingNewLine]", 
    RowBox[{"PlotLabel", "\[Rule]", 
     RowBox[{"{", "\"\<\!\(\*
StyleBox[\"\[Chi]\",
FontFamily->\"Courier New\"]\)[x,y] - \!\(\*
StyleBox[\"Re\",
FontFamily->\"Courier New\"]\)\!\(\*
StyleBox[\"[\",
FontFamily->\"Courier New\"]\)\!\(\*
StyleBox[\"Sumntx6apprN\",
FontFamily->\"Courier New\"]\)\!\(\*
StyleBox[\"]\",
FontFamily->\"Courier New\"]\)\>\"", "}"}]}]}], "]"}]}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10006.},
 CellChangeTimes->{{3.45955340946875*^9, 3.459553473609375*^9}, {
   3.459607408609375*^9, 3.459607408703125*^9}, {3.459607614859375*^9, 
   3.459607621296875*^9}, {3.459607677421875*^9, 3.4596076795*^9}, {
   3.459607826828125*^9, 3.45960786221875*^9}, 3.459622829375*^9, 
   3.45962517903125*^9, {3.480766389640625*^9, 3.480766390234375*^9}, {
   3.480766535953125*^9, 3.4807665365*^9}, {3.48076698346875*^9, 
   3.480766996015625*^9}, {3.506950813442915*^9, 3.506950818215713*^9}, {
   3.50695329943742*^9, 3.506953325158485*^9}, {3.506953653848241*^9, 
   3.506953688436371*^9}, {3.506954237812236*^9, 3.50695424919657*^9}, {
   3.506954358504129*^9, 3.506954362973515*^9}, 3.5070325249436207`*^9, 
   3.507032670855994*^9, 3.507034407924264*^9, {3.507187496145584*^9, 
   3.507187543215472*^9}, {3.507187689391159*^9, 3.507187716029408*^9}, {
   3.507187966858687*^9, 3.5071879758078833`*^9}, 3.507188037866734*^9, {
   3.507188070974635*^9, 3.507188109373749*^9}},
 FontFamily->"Courier New",
 FontSize->18],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Compare$defvs", 
    StyleBox["ReSumdefntx6N",
     FontFamily->"Courier New"]}]], "=", 
  RowBox[{"Plot3D", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{
      RowBox[{
       StyleBox["\[Chi]",
        FontFamily->"Courier New"], 
       StyleBox["[",
        FontFamily->"Courier New"], 
       RowBox[{
        FractionBox["x", 
         RowBox[{"\[Epsilon]", "+", "1"}]], ",", 
        FractionBox["y", 
         RowBox[{"\[Epsilon]", "+", "1"}]]}], 
       StyleBox["]",
        FontFamily->"Courier New"]}], 
      StyleBox["-",
       FontFamily->"Courier New"], 
      StyleBox[
       RowBox[{"Re", "[", "Sumdefntx6N", "]"}],
       FontFamily->"Courier New"]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", 
      RowBox[{"-", 
       FractionBox["\[Lambda]x", "2"]}], ",", 
      FractionBox["\[Lambda]x", "2"]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"y", ",", 
      RowBox[{"-", " ", 
       FractionBox["\[Lambda]y", "2"]}], ",", 
      FractionBox["\[Lambda]y", "2"]}], "}"}], ",", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<\!\(\*
StyleBox[\"x\",
FontFamily->\"Courier New\",
FontWeight->\"Plain\"]\)\>\"", ",", "\"\<\!\(\*
StyleBox[\"y\",
FontWeight->\"Plain\"]\)\>\""}], "}"}]}], ",", "\[IndentingNewLine]", 
    RowBox[{"PlotLabel", "\[Rule]", 
     RowBox[{"{", "\"\<\!\(\*
StyleBox[\"\[Chi]\",
FontFamily->\"Courier New\"]\)\!\(\*
StyleBox[\"[\",
FontFamily->\"Courier New\"]\)\!\(\*FractionBox[\(x\), \(\[Epsilon] + 1\)]\),\
\!\(\*FractionBox[\(y\), \(\[Epsilon] + 1\)]\)\!\(\*
StyleBox[\"]\",
FontFamily->\"Courier New\"]\) - \!\(\*
StyleBox[\"Re\",
FontFamily->\"Courier New\"]\)\!\(\*
StyleBox[\"[\",
FontFamily->\"Courier New\"]\)\!\(\*
StyleBox[\"Sumdefntx6N\",
FontFamily->\"Courier New\"]\)\!\(\*
StyleBox[\"]\",
FontFamily->\"Courier New\"]\)\>\"", "}"}]}]}], "]"}]}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10006.},
 CellChangeTimes->{{3.45955340946875*^9, 3.459553473609375*^9}, {
   3.459607408609375*^9, 3.459607408703125*^9}, {3.459607614859375*^9, 
   3.459607621296875*^9}, {3.459607677421875*^9, 3.4596076795*^9}, {
   3.459607826828125*^9, 3.45960786221875*^9}, 3.459622829375*^9, 
   3.45962517903125*^9, {3.480766389640625*^9, 3.480766390234375*^9}, {
   3.480766535953125*^9, 3.4807665365*^9}, {3.48076698346875*^9, 
   3.480766996015625*^9}, {3.506950813442915*^9, 3.506950818215713*^9}, {
   3.50695329943742*^9, 3.506953325158485*^9}, {3.506953653848241*^9, 
   3.506953688436371*^9}, {3.506954237812236*^9, 3.50695424919657*^9}, {
   3.506954358504129*^9, 3.506954362973515*^9}, 3.5070325249436207`*^9, 
   3.507032670855994*^9, 3.507034407924264*^9, {3.507187496145584*^9, 
   3.507187543215472*^9}, {3.507187689391159*^9, 3.507187716029408*^9}, {
   3.507188251261097*^9, 3.507188260316536*^9}},
 FontFamily->"Courier New",
 FontSize->18]
}, Open  ]]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Date", "[", "]"}]], "Input",
 CellChangeTimes->{{3.507188294878476*^9, 3.507188297308958*^9}}],

Cell[TextData[{
 "Remark:\n\nComputation of the partial sums  \n\n\n",
 StyleBox["S[x,y,ntx,nty]:=",
  FontFamily->"Courier New"],
 Cell[BoxData[
  FormBox[
   UnderoverscriptBox["\[Sum]", 
    RowBox[{" ", 
     StyleBox[
      RowBox[{"h", 
       StyleBox["=",
        FontSize->15], 
       StyleBox[
        RowBox[{"-", "ntx"}],
        FontSize->15]}],
      FontFamily->"Courier New"]}], 
    RowBox[{" ", "ntx"}]], TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   UnderoverscriptBox["\[Sum]", 
    RowBox[{" ", 
     StyleBox[
      RowBox[{"k", 
       StyleBox["=",
        FontSize->15], 
       StyleBox[
        RowBox[{"-", "nty"}],
        FontSize->15]}],
      FontFamily->"Courier New"]}], 
    RowBox[{" ", "nty"}]], TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   RowBox[{
    StyleBox[" ",
     FontFamily->"Courier New",
     FontSlant->"Plain"], 
    SubscriptBox[
     StyleBox["\[Chi]",
      FontFamily->"Courier New",
      FontSlant->"Plain"], 
     StyleBox["hk",
      FontFamily->"Courier New",
      FontSize->15]], " "}], TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   StyleBox[
    RowBox[{"Exp", "[", 
     RowBox[{
      StyleBox["2",
       FontSlant->"Plain"], "\[Pi]", " ", "\[ImaginaryI]", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"h", 
         FractionBox[
          RowBox[{"x", "-", 
           RowBox[{"u1", "[", 
            RowBox[{"x", ",", "y"}], "]"}]}], 
          StyleBox["a",
           FontSize->15,
           FontSlant->"Plain"]]}], "+", 
        RowBox[{"k", " ", 
         FractionBox[
          RowBox[{"y", "-", 
           RowBox[{"u2", "[", 
            RowBox[{"x", ",", "y"}], "]"}]}], 
          StyleBox["\[Lambda]y",
           FontSize->15,
           FontSlant->"Plain"]]}]}], ")"}]}], "]"}],
    FontFamily->"Courier New"], TraditionalForm]]],
 "\n                               =",
 Cell[BoxData[
  FormBox[
   UnderoverscriptBox["\[Sum]", 
    RowBox[{" ", 
     StyleBox[
      RowBox[{"h", 
       StyleBox["=",
        FontSize->15], 
       StyleBox[
        RowBox[{"-", "ntx"}],
        FontSize->15]}],
      FontFamily->"Courier New"]}], 
    RowBox[{" ", "ntx"}]], TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   UnderoverscriptBox["\[Sum]", 
    RowBox[{" ", 
     StyleBox[
      RowBox[{"k", 
       StyleBox["=",
        FontSize->15], 
       StyleBox[
        RowBox[{"-", "nty"}],
        FontSize->15]}],
      FontFamily->"Courier New"]}], 
    RowBox[{" ", "nty"}]], TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   RowBox[{
    StyleBox[" ",
     FontFamily->"Courier New",
     FontSlant->"Plain"], 
    SubscriptBox[
     StyleBox["\[Chi]",
      FontFamily->"Courier New",
      FontSlant->"Plain"], 
     StyleBox["hk",
      FontFamily->"Courier New",
      FontSize->15]], " "}], TraditionalForm]]],
 " ",
 Cell[BoxData[
  FormBox[
   StyleBox[
    RowBox[{"Exp", "[", 
     RowBox[{
      StyleBox["2",
       FontSlant->"Plain"], "\[Pi]", " ", "\[ImaginaryI]", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"h", 
         FractionBox[
          StyleBox[
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "-", "\[Epsilon]"}], ")"}], "x"}],
           FontFamily->"Courier New"], 
          StyleBox["a",
           FontSize->15,
           FontSlant->"Plain"]]}], "+", 
        RowBox[{"k", " ", 
         FractionBox[
          StyleBox[
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "-", "\[Epsilon]"}], ")"}], "y"}],
           FontFamily->"Courier New"], 
          StyleBox["\[Lambda]y",
           FontSize->15,
           FontSlant->"Plain"]]}]}], ")"}]}], "]"}],
    FontFamily->"Courier New"], TraditionalForm]]],
 "\n\napproximating the exact susceptibility after the deformation, which is\n\
\n",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{
     StyleBox["\[Chi]",
      FontFamily->"Courier",
      FontSize->22], 
     StyleBox["'",
      FontFamily->"Courier New"]}], 
    StyleBox["[",
     FontFamily->"Courier New"], 
    StyleBox[
     RowBox[{"x", ",", "y"}],
     FontFamily->"Courier New"], 
    StyleBox["]",
     FontFamily->"Courier New"]}], 
   StyleBox["=",
    FontFamily->"Courier New"], 
   RowBox[{
    RowBox[{
     StyleBox["\[Chi]",
      FontFamily->"Courier New"], 
     StyleBox["[",
      FontFamily->"Courier New"], 
     RowBox[{
      SuperscriptBox["g", 
       RowBox[{"-", "1"}]], 
      StyleBox["[",
       FontFamily->"Courier New"], 
      StyleBox[
       RowBox[{"x", ",", "y"}],
       FontFamily->"Courier New"], 
      StyleBox["]",
       FontFamily->"Courier New"]}], 
     StyleBox["]",
      FontFamily->"Courier New"]}], 
    StyleBox["=",
     FontFamily->"Courier New"], 
    RowBox[{
     StyleBox["\[Chi]",
      FontFamily->"Courier New"], 
     StyleBox["[",
      FontFamily->"Courier New"], 
     RowBox[{
      FractionBox["x", 
       RowBox[{"\[Epsilon]", "+", "1"}]], ",", 
      FractionBox["y", 
       RowBox[{"\[Epsilon]", "+", "1"}]]}], 
     StyleBox["]",
      FontFamily->"Courier New"]}]}]}]], "None",
  FontFamily->"Courier New"],
 "\n\n(recall that ",
 StyleBox["g[x,y]=(x,y)+ u[x,y]=(",
  FontFamily->"Courier"],
 StyleBox["(1+\[Epsilon])x,(1+\[Epsilon])y)",
  FontFamily->"Courier New"],
 ", so that ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"-", "1"}]], 
    StyleBox["[",
     FontFamily->"Courier New"], 
    StyleBox[
     RowBox[{"x", ",", "y"}],
     FontFamily->"Courier New"], 
    StyleBox["]",
     FontFamily->"Courier New"]}], 
   StyleBox["=",
    FontFamily->"Courier New"], 
   RowBox[{
    StyleBox["(",
     FontFamily->"Courier New"], 
    RowBox[{
     FractionBox["x", 
      RowBox[{"\[Epsilon]", "+", "1"}]], ",", 
     FractionBox["y", 
      RowBox[{"\[Epsilon]", "+", "1"}]]}], ")"}]}]],
  FontFamily->"Courier New"],
 ")"
}], "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10005.},
 CellChangeTimes->{{3.4561278892666187`*^9, 3.4561279023146544`*^9}, 
   3.456128006313026*^9, {3.4561281092059317`*^9, 3.456128161981234*^9}, {
   3.456132554287485*^9, 3.456132559911008*^9}, {3.456133257033012*^9, 
   3.4561332624322557`*^9}, 3.456133293068067*^9, {3.45903155753125*^9, 
   3.459031586453125*^9}, 3.45903250021875*^9, {3.45908097503125*^9, 
   3.45908097815625*^9}, {3.4590811195*^9, 3.459081124453125*^9}, {
   3.4590811558125*^9, 3.459081158203125*^9}, 3.459082649796875*^9, 
   3.45908270415625*^9, 3.45908374184375*^9, 3.459165459546875*^9, {
   3.459165498265625*^9, 3.45916551509375*^9}, {3.459165565828125*^9, 
   3.459165593328125*^9}, {3.4591656280625*^9, 3.459165711515625*^9}, {
   3.45916576253125*^9, 3.459165825796875*^9}, {3.459165864734375*^9, 
   3.459165889015625*^9}, {3.45916601834375*^9, 3.459166035265625*^9}, {
   3.459166079890625*^9, 3.459166106171875*^9}, {3.459166234265625*^9, 
   3.459166427796875*^9}, {3.45916664746875*^9, 3.459166649484375*^9}, {
   3.45916792165625*^9, 3.459167955953125*^9}, 3.45916814171875*^9, 
   3.459170363234375*^9, {3.459552129453125*^9, 3.459552201578125*^9}, {
   3.459552298390625*^9, 3.459552438515625*^9}, {3.459552475125*^9, 
   3.45955253528125*^9}, {3.4595525683125*^9, 3.45955266953125*^9}, {
   3.4595527765*^9, 3.45955279096875*^9}, {3.45955295903125*^9, 
   3.45955300946875*^9}, {3.4595533023125*^9, 3.459553305015625*^9}, {
   3.45955334753125*^9, 3.45955334903125*^9}, {3.45955353671875*^9, 
   3.45955353775*^9}, {3.459605919328125*^9, 3.459605935140625*^9}, {
   3.459605977484375*^9, 3.45960598903125*^9}, {3.45960606578125*^9, 
   3.459606088453125*^9}, {3.459606121109375*^9, 3.4596061489375*^9}, 
   3.459625164640625*^9, {3.48076657809375*^9, 3.480766584359375*^9}, {
   3.506951405725848*^9, 3.506951406684589*^9}, {3.506953725478381*^9, 
   3.50695380825464*^9}, 3.575285174766636*^9, {3.5752863111756344`*^9, 
   3.5752863235243406`*^9}, {3.5762446445889497`*^9, 3.576244646991354*^9}},
 FontSize->22,
 Background->GrayLevel[0.85]]
},
WindowToolbars->"EditBar",
CellGrouping->Manual,
WindowSize->{1438, 813},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
FrontEndVersion->"8.0 for Microsoft Windows (64-bit) (February 23, 2011)",
StyleDefinitions->FrontEnd`FileName[{
   ParentDirectory[], "Cavaliere"}, "Zosi.nb", CharacterEncoding -> 
  "WindowsANSI"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[545, 20, 500, 8, 87, "Text"],
Cell[1048, 30, 11161, 262, 1020, "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10001.}],
Cell[12212, 294, 13369, 303, 823, "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10001.}],
Cell[25584, 599, 9163, 212, 293, "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10001.}],
Cell[34750, 813, 135, 3, 36, "Input"],
Cell[34888, 818, 448, 9, 36, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[35339, 829, 348, 10, 33, "Input"],
Cell[CellGroupData[{
Cell[35712, 843, 382, 8, 36, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[36097, 853, 1489, 30, 91, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}]
}, Open  ]],
Cell[CellGroupData[{
Cell[37623, 888, 1048, 21, 56, "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10001.}],
Cell[38674, 911, 353, 8, 36, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10001.}],
Cell[39030, 921, 354, 8, 36, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10001.}],
Cell[39387, 931, 274, 7, 36, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10001.}],
Cell[39664, 940, 1030, 29, 63, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10001.}]
}, Open  ]],
Cell[40709, 972, 1645, 44, 52, "Input"],
Cell[CellGroupData[{
Cell[42379, 1020, 1726, 27, 71, "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10003.}],
Cell[44108, 1049, 1753, 27, 41, "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10003.}],
Cell[45864, 1078, 2240, 61, 47, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10003.}],
Cell[48107, 1141, 1243, 23, 48, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10003.}],
Cell[49353, 1166, 133, 3, 27, "Input"],
Cell[49489, 1171, 1048, 27, 23, "Input"],
Cell[50540, 1200, 133, 3, 27, "Input"],
Cell[50676, 1205, 1411, 42, 56, "Input"],
Cell[52090, 1249, 390, 8, 39, "Input"],
Cell[52483, 1259, 635, 12, 23, "Input"],
Cell[53121, 1273, 1754, 40, 75, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10006.}],
Cell[54878, 1315, 1946, 43, 75, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10006.}],
Cell[56827, 1360, 1888, 42, 75, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10006.}],
Cell[58718, 1404, 1845, 41, 75, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10006.}]
}, Closed]],
Cell[CellGroupData[{
Cell[60600, 1450, 1071, 18, 68, "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10004.}],
Cell[61674, 1470, 1104, 18, 55, "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10004.}],
Cell[62781, 1490, 858, 15, 36, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10004.}],
Cell[63642, 1507, 619, 12, 36, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10004.}],
Cell[64264, 1521, 313, 9, 36, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10004.}],
Cell[64580, 1532, 1070, 18, 55, "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10004.}],
Cell[CellGroupData[{
Cell[65675, 1554, 2607, 70, 93, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10003.}],
Cell[68285, 1626, 1244, 23, 64, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10003.}]
}, Open  ]],
Cell[69544, 1652, 1050, 27, 24, "Input"],
Cell[70597, 1681, 1655, 48, 56, "Input"],
Cell[72255, 1731, 392, 8, 39, "Input"],
Cell[72650, 1741, 645, 12, 23, "Input"],
Cell[73298, 1755, 1978, 42, 75, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10006.}],
Cell[75279, 1799, 2005, 43, 75, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10006.}],
Cell[77287, 1844, 1964, 42, 75, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10006.}]
}, Open  ]],
Cell[CellGroupData[{
Cell[79288, 1891, 1782, 28, 53, "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10003.}],
Cell[81073, 1921, 1783, 26, 41, "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10003.}],
Cell[82859, 1949, 2429, 66, 47, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10003.}],
Cell[85291, 2017, 1215, 23, 48, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10003.}],
Cell[86509, 2042, 133, 3, 27, "Input"],
Cell[86645, 2047, 1053, 27, 23, "Input"],
Cell[87701, 2076, 133, 3, 27, "Input"],
Cell[87837, 2081, 1489, 43, 56, "Input"],
Cell[89329, 2126, 488, 9, 39, "Input"],
Cell[89820, 2137, 688, 12, 23, "Input"],
Cell[90511, 2151, 1895, 41, 75, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10006.}],
Cell[92409, 2194, 1899, 41, 75, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10006.}],
Cell[94311, 2237, 1949, 42, 75, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10006.}],
Cell[96263, 2281, 1855, 41, 75, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10006.}]
}, Open  ]],
Cell[98133, 2325, 118, 2, 23, "Input"],
Cell[CellGroupData[{
Cell[98276, 2331, 1696, 26, 53, "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10006.}],
Cell[99975, 2359, 1692, 26, 41, "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10006.}],
Cell[101670, 2387, 133, 3, 27, "Input"],
Cell[101806, 2392, 1892, 45, 99, "Input"],
Cell[103701, 2439, 133, 3, 27, "Input"],
Cell[CellGroupData[{
Cell[103859, 2446, 3441, 81, 46, "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10006.}],
Cell[107303, 2529, 2731, 72, 81, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10006.}],
Cell[110037, 2603, 2926, 85, 58, "Input"],
Cell[112966, 2690, 2614, 67, 75, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10006.}],
Cell[115583, 2759, 2915, 77, 81, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10006.}]
}, Open  ]]
}, Open  ]],
Cell[118525, 2840, 118, 2, 23, "Input"],
Cell[118646, 2844, 7945, 254, 315, "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10005.}]
}
]
*)

(* End of internal cache information *)
