(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     32860,        884]
NotebookOptionsPosition[     30724,        818]
NotebookOutlinePosition[     31202,        838]
CellTagsIndexPosition[     31159,        835]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["\<\
Evaluation time
\[CapitalDelta]t <  10 s\
\>", "Text",
 CellChangeTimes->{{3.551627898219295*^9, 3.551627958733335*^9}, {
   3.5516924573766603`*^9, 3.5516924665834084`*^9}, 3.551696315790497*^9, {
   3.5525677432265663`*^9, 3.5525677706085873`*^9}, {3.5752872862144036`*^9, 
   3.5752872879645033`*^9}},
 FontSize->24,
 FontColor->RGBColor[0, 0, 1],
 Background->RGBColor[1, 0.9, 0.8]],

Cell[TextData[{
 "The aim of this notebook is to solve under the ",
 StyleBox["one-wave approximation",
  FontSlant->"Italic"],
 " \nthe Takagi-Taupin equation (see Eq. 2.356.). For further details,\nsee \
Subsection 2.3.3.1.\n\nThis means that the differential equation we have to \
solve is the Eq. 2.3.64:\n\n \n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"cos", "(", "\[Theta]bMo", ")"}], " ", 
      RowBox[{
       SuperscriptBox["u", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "(", 
       RowBox[{"x", ",", "z"}], ")"}]}], "-", 
     RowBox[{
      RowBox[{"sin", "(", "\[Theta]bMo", ")"}], " ", 
      RowBox[{
       SuperscriptBox["u", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "(", 
       RowBox[{"x", ",", "z"}], ")"}]}]}], "\[LongEqual]", 
    RowBox[{
     FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", "ka", " ", "\[Chi]oMo",
      " ", 
     RowBox[{"u", "(", 
      RowBox[{"x", ",", "z"}], ")"}]}]}], TraditionalForm]],
  CellChangeTimes->{3.5752878305305367`*^9}],
 "\n\nUsing the DSolve program we try to get and plot  those approximate \
solutions, \nconsidering different initial conditions.\n\n- Part I: the \
initial condition chosen is u[x,0] = C1[x];\n- Part II: the initial condition \
chosen is u[x,0] = 1;\n- Part III: the initial condition chosen is u[x,0] = \
Sin[x];\n\nThe values of \[Chi] are from the site written by Sergey Stepanov \
(from Argonne National Laboratory): ",
 StyleBox["http://sergey.gmca.aps.anl.gov/cgi/WWW_form.exe?template=x0h_form.\
htm",
  FontSlant->"Italic"],
 "."
}], "Text",
 CellChangeTimes->{{3.551627898219295*^9, 3.551627958733335*^9}, {
   3.5516924573766603`*^9, 3.5516924665834084`*^9}, 3.551696315790497*^9, {
   3.5525677432265663`*^9, 3.5525677706085873`*^9}, {3.5752872955169353`*^9, 
   3.5752873000121927`*^9}, {3.5752873403845015`*^9, 3.575287369623174*^9}, {
   3.5752875147964773`*^9, 3.5752876124450626`*^9}, {3.5752876452199373`*^9, 
   3.5752876466610203`*^9}, {3.5752877581483965`*^9, 3.5752877899442153`*^9}, 
   3.5752878375909405`*^9, {3.575287884142603*^9, 3.5752878845066237`*^9}, {
   3.575287937948681*^9, 3.575288087727247*^9}, {3.5752881994136353`*^9, 
   3.5752882265971904`*^9}, {3.575288342732833*^9, 3.575288358604741*^9}, {
   3.575353108298691*^9, 3.575353112709464*^9}, {3.575353261498905*^9, 
   3.575353291195553*^9}},
 FontSize->24,
 FontColor->RGBColor[0, 0, 1],
 Background->RGBColor[1, 1, 0.85]],

Cell[BoxData[
 RowBox[{"Date", "[", "]"}]], "Input",
 CellChangeTimes->{{3.55162785537078*^9, 3.5516278611405487`*^9}}],

Cell[BoxData[
 RowBox[{"Remove", "[", "\"\<Global`*\>\"", "]"}]], "Input",
 CellChangeTimes->{{3.51176009984375*^9, 3.51176010875*^9}}],

Cell[CellGroupData[{

Cell["Part I", "Text",
 CellChangeTimes->{{3.511245384625*^9, 3.5112454665*^9}, 3.511245529*^9, {
   3.511490782453125*^9, 3.511490860828125*^9}, {3.511777189644801*^9, 
   3.5117772279947357`*^9}, 3.511777292002207*^9, {3.5752883749326744`*^9, 
   3.575288405212406*^9}},
 FontSize->36,
 FontWeight->"Plain",
 FontColor->RGBColor[0, 0, 1],
 Background->RGBColor[1, 0.9, 0.8]],

Cell[TextData[StyleBox["Let us begin considering a general initial condition, \
i.e.  u[x, 0] = C1[x].\n\nWe solve the approximated Takagi-Taupin equeation, \
applying this IC...",
 FontFamily->"Times New Roman",
 FontSize->24,
 FontColor->GrayLevel[0]]], "Text",
 CellChangeTimes->{{3.511245384625*^9, 3.5112454665*^9}, 3.511245529*^9, {
   3.511490782453125*^9, 3.511490860828125*^9}, {3.511777189644801*^9, 
   3.5117772279947357`*^9}, 3.511777292002207*^9, 3.5752883722525215`*^9, {
   3.575288460558572*^9, 3.5752884989727693`*^9}, 3.5752886038207664`*^9},
 FontSize->18,
 FontWeight->"Plain",
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{"solnz", " ", "=", 
  RowBox[{"DSolve", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          RowBox[{"Sin", "[", "\[Theta]bMo", "]"}]}], " ", 
         RowBox[{"D", "[", 
          RowBox[{
           RowBox[{"u", "[", 
            RowBox[{"x", ",", " ", "z"}], "]"}], ",", "x"}], " ", "]"}]}], 
        " ", "+", 
        RowBox[{
         RowBox[{"Cos", "[", "\[Theta]bMo", "]"}], 
         RowBox[{"D", "[", 
          RowBox[{
           RowBox[{"u", "[", 
            RowBox[{"x", ",", " ", "z"}], "]"}], ",", " ", "z"}], "]"}]}]}], 
       " ", "==", " ", "\[IndentingNewLine]", "                          ", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"I", "*", "ka", "*", 
          RowBox[{"\[Chi]oMo", "/", "2"}]}], ")"}], " ", 
        RowBox[{"u", "[", 
         RowBox[{"x", ",", " ", "z"}], "]"}]}]}], ",", " ", 
      RowBox[{
       RowBox[{"u", "[", 
        RowBox[{"x", ",", " ", "0"}], "]"}], " ", "==", " ", 
       RowBox[{"C1", "[", "x", "]"}]}]}], "}"}], ",", " ", "u", ",", " ", 
    RowBox[{"{", 
     RowBox[{"x", ",", " ", "z"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.35194625578983*^9, 3.351946274146*^9}, {
   3.35211412804254*^9, 3.3521141293394*^9}, {3.511180624149849*^9, 
   3.5111806954725723`*^9}, {3.511181274124192*^9, 3.5111812973695517`*^9}, {
   3.511181339759506*^9, 3.5111813744521437`*^9}, {3.5111815458927402`*^9, 
   3.5111816420165663`*^9}, {3.511181751980998*^9, 3.511181752647786*^9}, {
   3.511183119082559*^9, 3.5111831217967777`*^9}, {3.511184769395935*^9, 
   3.511184771134444*^9}, 3.511184839114249*^9, {3.5112333796875*^9, 
   3.5112334460625*^9}, 3.51123347659375*^9, {3.5115953513427963`*^9, 
   3.511595360054541*^9}, {3.5115954570419273`*^9, 3.5115954607513027`*^9}, {
   3.5115964333702173`*^9, 3.511596443881453*^9}, {3.511596478721034*^9, 
   3.511596496807939*^9}, {3.511758956421875*^9, 3.511759033359375*^9}, {
   3.511759117828125*^9, 3.511759125625*^9}, {3.511760708109375*^9, 
   3.511760715140625*^9}, {3.511775789171145*^9, 3.511775791078499*^9}, {
   3.5117762522524233`*^9, 3.5117762524786463`*^9}, 3.511776675450441*^9},
 FontSize->16],

Cell[BoxData[
 RowBox[{
  RowBox[{"funI1", "[", 
   RowBox[{"x_", ",", "z_"}], "]"}], ":=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"u", "[", 
     RowBox[{"x", ",", "z"}], "]"}], "/.", 
    RowBox[{"solnz", "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], " ", "//", "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.511232015703125*^9, 3.5112320281875*^9}, {
  3.511233545421875*^9, 3.511233564203125*^9}, {3.51175913034375*^9, 
  3.511759131890625*^9}, {3.51176007771875*^9, 3.511760090625*^9}, {
  3.511760720484375*^9, 3.511760724390625*^9}, {3.511776259582368*^9, 
  3.511776268305174*^9}},
 FontSize->18],

Cell[TextData[StyleBox["Simple check...",
 FontFamily->"Times New Roman",
 FontSize->24,
 FontColor->GrayLevel[0]]], "Text",
 CellChangeTimes->{{3.511245384625*^9, 3.5112454665*^9}, 3.511245529*^9, {
   3.511490782453125*^9, 3.511490860828125*^9}, {3.511777189644801*^9, 
   3.5117772279947357`*^9}, 3.511777292002207*^9, 3.5752883722525215`*^9, {
   3.575288460558572*^9, 3.5752884989727693`*^9}, 3.5752886038207664`*^9, {
   3.57535341376789*^9, 3.5753534206315928`*^9}},
 FontSize->18,
 FontWeight->"Plain",
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     RowBox[{"Sin", "[", "\[Theta]bMo", "]"}]}], 
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{"funI1", "[", 
       RowBox[{"x", ",", "z"}], "]"}], ",", "x"}], "]"}]}], "+", 
   RowBox[{
    RowBox[{"Cos", "[", "\[Theta]bMo", "]"}], " ", 
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{"funI1", "[", 
       RowBox[{"x", ",", "z"}], "]"}], ",", "z"}], "]"}]}], "-", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"I", "*", "ka", "*", 
      RowBox[{"\[Chi]oMo", "/", "2"}]}], ")"}], 
    RowBox[{"funI1", "[", 
     RowBox[{"x", ",", "z"}], "]"}]}]}], "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.51107296878125*^9, 3.511072969453125*^9}, {
  3.5110979552288923`*^9, 3.511097959592779*^9}, {3.51176047565625*^9, 
  3.5117605678125*^9}, {3.51176060803125*^9, 3.511760608390625*^9}, {
  3.511760727765625*^9, 3.511760735*^9}, {3.511776271244025*^9, 
  3.511776284203598*^9}},
 FontSize->18],

Cell[BoxData[
 RowBox[{
  RowBox[{"ini1", "[", "x_", "]"}], " ", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"funI1", "[", 
     RowBox[{"x", ",", "z"}], "]"}], "  ", "/.", " ", 
    RowBox[{"z", "->", "0"}]}], " ", "//", "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.511098054223167*^9, 3.511098059018763*^9}, {
  3.511098102817257*^9, 3.511098134725198*^9}, {3.511098181789311*^9, 
  3.511098248525207*^9}, {3.511760640390625*^9, 3.511760661375*^9}, {
  3.511760737953125*^9, 3.511760738015625*^9}, {3.51177628847123*^9, 
  3.511776292185995*^9}},
 FontSize->18],

Cell[BoxData[
 RowBox[{
  RowBox[{"funI1simp", "[", 
   RowBox[{"x_", ",", "z_"}], "]"}], "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"u", "[", 
     RowBox[{"x", ",", "z"}], "]"}], "/.", 
    RowBox[{"solnz", "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], " ", "//", "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.511232015703125*^9, 3.5112320281875*^9}, {
  3.511233545421875*^9, 3.511233564203125*^9}, {3.51175913034375*^9, 
  3.511759131890625*^9}, {3.51176007771875*^9, 3.511760090625*^9}, {
  3.511760720484375*^9, 3.511760724390625*^9}, {3.5117607828125*^9, 
  3.511760788390625*^9}, {3.511776295650976*^9, 3.511776326068947*^9}},
 FontSize->18],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     RowBox[{"Sin", "[", "\[Theta]bMo", "]"}]}], 
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{"funI1simp", "[", 
       RowBox[{"x", ",", "z"}], "]"}], ",", "x"}], "]"}]}], "+", 
   RowBox[{
    RowBox[{"Cos", "[", "\[Theta]bMo", "]"}], " ", 
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{"funI1simp", "[", 
       RowBox[{"x", ",", "z"}], "]"}], ",", "z"}], "]"}]}], "-", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"I", "*", "ka", "*", 
      RowBox[{"\[Chi]oMo", "/", "2"}]}], ")"}], 
    RowBox[{"funI1simp", "[", 
     RowBox[{"x", ",", "z"}], "]"}]}]}], "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.51107296878125*^9, 3.511072969453125*^9}, {
   3.5110979552288923`*^9, 3.511097959592779*^9}, {3.51176047565625*^9, 
   3.5117605678125*^9}, {3.51176060803125*^9, 3.511760608390625*^9}, {
   3.511760727765625*^9, 3.511760735*^9}, {3.511761155109375*^9, 
   3.511761162671875*^9}, {3.511776360096259*^9, 3.5117763822972403`*^9}, 
   3.511776665243864*^9},
 FontSize->18],

Cell[TextData[StyleBox["We verified that the solved in a proper way the \
system but we cannot plot the results, \nbecause C1 is an unknown function. \
In Part II and Part III this will be possible...",
 FontFamily->"Times New Roman",
 FontSize->24,
 FontColor->GrayLevel[0]]], "Text",
 CellChangeTimes->{{3.511245384625*^9, 3.5112454665*^9}, 3.511245529*^9, {
   3.511490782453125*^9, 3.511490860828125*^9}, {3.511777189644801*^9, 
   3.5117772279947357`*^9}, 3.511777292002207*^9, 3.5752883722525215`*^9, {
   3.575288460558572*^9, 3.5752884989727693`*^9}, 3.5752886038207664`*^9, {
   3.5752887925095587`*^9, 3.575288852733003*^9}},
 FontSize->18,
 FontWeight->"Plain",
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"inirid", "[", "x_", "]"}], " ", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"funI1simp", "[", 
     RowBox[{"x", ",", "z"}], "]"}], "  ", "/.", " ", 
    RowBox[{"z", "->", "0"}]}], " ", "//", "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.511098054223167*^9, 3.511098059018763*^9}, {
  3.511098102817257*^9, 3.511098134725198*^9}, {3.511098181789311*^9, 
  3.511098248525207*^9}, {3.511760640390625*^9, 3.511760661375*^9}, {
  3.511760737953125*^9, 3.511760738015625*^9}, {3.511761237875*^9, 
  3.51176124840625*^9}, {3.511776386711605*^9, 3.5117763903791933`*^9}},
 FontSize->18]
}, Open  ]],

Cell[CellGroupData[{

Cell["Part II", "Text",
 CellChangeTimes->{{3.511245384625*^9, 3.5112454665*^9}, 3.511245529*^9, {
   3.511490782453125*^9, 3.511490860828125*^9}, {3.511777189644801*^9, 
   3.5117772279947357`*^9}, {3.5117772765120087`*^9, 3.51177729600976*^9}, {
   3.5752883838531847`*^9, 3.5752884027322645`*^9}},
 FontSize->36,
 FontWeight->"Plain",
 FontColor->RGBColor[0, 0, 1],
 Background->RGBColor[1, 0.9, 0.8]],

Cell["\<\
Let\[CloseCurlyQuote]s suppose now: u[x, 0] = 1...\
\>", "Text",
 CellChangeTimes->{{3.511245384625*^9, 3.5112454665*^9}, 3.511245529*^9, {
   3.511490782453125*^9, 3.511490860828125*^9}, {3.511777189644801*^9, 
   3.5117772279947357`*^9}, {3.5117772765120087`*^9, 3.51177729600976*^9}, 
   3.575288382789124*^9, {3.575288573933057*^9, 3.575288608749048*^9}},
 FontSize->24,
 FontWeight->"Plain",
 FontColor->GrayLevel[0],
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{"\[Theta]bMo", "=", " ", 
  RowBox[{"185", "/", "1000"}]}]], "Input",
 CellChangeTimes->{{3.511232484375*^9, 3.511232491234375*^9}, {
  3.51123256671875*^9, 3.511232573734375*^9}},
 FontSize->18],

Cell[BoxData[
 RowBox[{"Sin", "[", "\[Theta]bMo", "]"}]], "Input",
 CellChangeTimes->{{3.51123250565625*^9, 3.511232516515625*^9}},
 FontSize->18],

Cell[BoxData[
 RowBox[{"Cos", "[", "\[Theta]bMo", "]"}]], "Input",
 CellChangeTimes->{{3.51123250565625*^9, 3.511232533609375*^9}},
 FontSize->18],

Cell[BoxData[
 RowBox[{"Tan", "[", "\[Theta]bMo", "]"}]], "Input",
 CellChangeTimes->{{3.51123250565625*^9, 3.511232547109375*^9}},
 FontSize->18],

Cell[BoxData[
 RowBox[{"\[Lambda]", "=", " ", 
  RowBox[{
   RowBox[{"7", "/", "10"}], "*", 
   SuperscriptBox["10", 
    RowBox[{"-", "10"}]]}]}]], "Input",
 CellChangeTimes->{{3.511181419675506*^9, 3.511181460836718*^9}, {
  3.511181511300641*^9, 3.5111815207761993`*^9}},
 FontSize->18],

Cell[BoxData[
 RowBox[{"ka", " ", "=", " ", 
  RowBox[{"2", " ", 
   RowBox[{"\[Pi]", " ", "/", "\[Lambda]"}]}]}]], "Input",
 CellChangeTimes->{{3.511181401632319*^9, 3.511181413505374*^9}},
 FontSize->18],

Cell[BoxData[
 RowBox[{"\[Chi]oMoI", "=", 
  RowBox[{
   RowBox[{"-", 
    RowBox[{"(", 
     RowBox[{"3", "/", 
      RowBox[{"10", "^", "6"}]}], ")"}]}], "+", 
   RowBox[{"I", " ", 
    RowBox[{"16", "/", 
     RowBox[{"10", "^", "9"}]}]}]}]}]], "Input",
 CellChangeTimes->{{3.5111830479051533`*^9, 3.5111830963252077`*^9}, 
   3.511183130882056*^9, 3.511184589593164*^9},
 FontSize->16],

Cell[BoxData[
 RowBox[{"solnz2", " ", "=", 
  RowBox[{"DSolve", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          RowBox[{"Sin", "[", "\[Theta]bMo", "]"}]}], " ", 
         RowBox[{"D", "[", 
          RowBox[{
           RowBox[{"u", "[", 
            RowBox[{"x", ",", " ", "z"}], "]"}], ",", "x"}], " ", "]"}]}], 
        " ", "+", 
        RowBox[{
         RowBox[{"Cos", "[", "\[Theta]bMo", "]"}], 
         RowBox[{"D", "[", 
          RowBox[{
           RowBox[{"u", "[", 
            RowBox[{"x", ",", " ", "z"}], "]"}], ",", " ", "z"}], "]"}]}]}], 
       " ", "==", " ", "\[IndentingNewLine]", "                          ", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"I", "*", "ka", "*", 
          RowBox[{"\[Chi]oMoI", "/", "2"}]}], ")"}], " ", 
        RowBox[{"u", "[", 
         RowBox[{"x", ",", " ", "z"}], "]"}]}]}], ",", " ", 
      RowBox[{
       RowBox[{"u", "[", 
        RowBox[{"x", ",", " ", "0"}], "]"}], " ", "==", " ", "1"}]}], "}"}], 
    ",", " ", "u", ",", " ", 
    RowBox[{"{", 
     RowBox[{"x", ",", " ", "z"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.35194625578983*^9, 3.351946274146*^9}, {
   3.35211412804254*^9, 3.3521141293394*^9}, {3.511180624149849*^9, 
   3.5111806954725723`*^9}, {3.511181274124192*^9, 3.5111812973695517`*^9}, {
   3.511181339759506*^9, 3.5111813744521437`*^9}, {3.5111815458927402`*^9, 
   3.5111816420165663`*^9}, {3.511181751980998*^9, 3.511181752647786*^9}, {
   3.511183119082559*^9, 3.5111831217967777`*^9}, {3.511184769395935*^9, 
   3.511184771134444*^9}, 3.511184839114249*^9, {3.5112333796875*^9, 
   3.5112334460625*^9}, 3.51123347659375*^9, {3.5115953513427963`*^9, 
   3.511595360054541*^9}, {3.5115954570419273`*^9, 3.5115954607513027`*^9}, {
   3.5115964333702173`*^9, 3.511596443881453*^9}, {3.511596478721034*^9, 
   3.511596496807939*^9}, {3.511758956421875*^9, 3.511759033359375*^9}, {
   3.511776492528871*^9, 3.5117764934095173`*^9}},
 FontSize->16],

Cell[BoxData[
 RowBox[{
  RowBox[{"funI2", "[", 
   RowBox[{"x_", ",", "z_"}], "]"}], " ", "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"u", "[", 
     RowBox[{"x", ",", "z"}], "]"}], "/.", 
    RowBox[{"solnz2", "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], " ", "//", "Simplify", " ", 
   RowBox[{"(*", " ", 
    RowBox[{"senxa", " ", ":="}], " ", "*)"}]}]}]], "Input",
 CellChangeTimes->{{3.511232015703125*^9, 3.5112320281875*^9}, {
   3.511233545421875*^9, 3.511233564203125*^9}, {3.51176014028125*^9, 
   3.51176014734375*^9}, {3.5117602049375*^9, 3.51176023065625*^9}, 
   3.51176032871875*^9, 3.511760408953125*^9, {3.511776498149384*^9, 
   3.511776511822567*^9}},
 FontSize->18],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     RowBox[{"Sin", "[", "\[Theta]bMo", "]"}]}], 
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{"funI2", "[", 
       RowBox[{"x", ",", "z"}], "]"}], ",", "x"}], "]"}]}], "+", 
   RowBox[{
    RowBox[{"Cos", "[", "\[Theta]bMo", "]"}], " ", 
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{"funI2", "[", 
       RowBox[{"x", ",", "z"}], "]"}], ",", "z"}], "]"}]}], "-", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"I", "*", "ka", "*", 
      RowBox[{"\[Chi]oMoI", "/", "2"}]}], ")"}], 
    RowBox[{"funI2", "[", 
     RowBox[{"x", ",", "z"}], "]"}]}]}], "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.51107296878125*^9, 3.511072969453125*^9}, {
  3.5110979552288923`*^9, 3.511097959592779*^9}, {3.51176047565625*^9, 
  3.5117605678125*^9}, {3.51176060803125*^9, 3.511760608390625*^9}, {
  3.511760727765625*^9, 3.511760735*^9}, {3.511761155109375*^9, 
  3.511761162671875*^9}, {3.511776360096259*^9, 3.5117763822972403`*^9}, {
  3.511776631336935*^9, 3.51177663954241*^9}},
 FontSize->18],

Cell[BoxData[
 RowBox[{
  RowBox[{"ini2", "[", 
   RowBox[{"x_", ",", "z_"}], "]"}], " ", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"funI2", "[", 
     RowBox[{"x", ",", "z"}], "]"}], "  ", "/.", " ", 
    RowBox[{"z", "->", "0"}]}], " ", "//", "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.511098054223167*^9, 3.511098059018763*^9}, {
  3.511098102817257*^9, 3.511098134725198*^9}, {3.511098181789311*^9, 
  3.511098248525207*^9}, {3.511760640390625*^9, 3.511760661375*^9}, {
  3.511760737953125*^9, 3.511760738015625*^9}, {3.51177628847123*^9, 
  3.511776292185995*^9}, {3.511776515014126*^9, 3.5117765186498137`*^9}, {
  3.5117767493189087`*^9, 3.5117767506805553`*^9}},
 FontSize->18],

Cell["\<\
In this case it is possible to plot the results dealing with the displacement. 

We would underline two aspects:

- the Takagi-Taupin equation are a powerful instrument to see how the \
radiation interacts with matter and
offers to us the chance to plot these results, as we arer seeing;
- the solutions are complex, so we use Plot3D for three quantities of them: \
real part (Re), imaginary part (Im) and module (Abs).\
\>", "Text",
 CellChangeTimes->{{3.511245384625*^9, 3.5112454665*^9}, 3.511245529*^9, {
   3.511490782453125*^9, 3.511490860828125*^9}, {3.511777189644801*^9, 
   3.5117772279947357`*^9}, {3.5117772765120087`*^9, 3.51177729600976*^9}, 
   3.575288382789124*^9, {3.575288573933057*^9, 3.575288608749048*^9}, {
   3.5752888782294617`*^9, 3.5752890481251793`*^9}},
 FontSize->24,
 FontWeight->"Plain",
 FontColor->GrayLevel[0],
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{"Plot3D", "[", 
  RowBox[{
   RowBox[{"Re", "[", 
    RowBox[{"funI2", "[", 
     RowBox[{"x", ",", "z"}], "]"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"z", ",", "0", ",", 
     RowBox[{"1", "/", "10000"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.511233570015625*^9, 3.51123361728125*^9}, {
  3.51123367275*^9, 3.51123368309375*^9}, {3.5117767895640707`*^9, 
  3.5117768371964903`*^9}},
 FontSize->18],

Cell[BoxData[
 RowBox[{"Plot3D", "[", 
  RowBox[{
   RowBox[{"Im", "[", 
    RowBox[{"funI2", "[", 
     RowBox[{"x", ",", "z"}], "]"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"z", ",", "0", ",", 
     RowBox[{"1", "/", "10000"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.511233570015625*^9, 3.51123361728125*^9}, {
  3.51123367275*^9, 3.51123368309375*^9}, {3.5117767895640707`*^9, 
  3.511776838566877*^9}},
 FontSize->18],

Cell[BoxData[
 RowBox[{"Plot3D", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"Abs", "[", 
     RowBox[{"funI2", "[", 
      RowBox[{"x", ",", "z"}], "]"}], "]"}], "^", "2"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"z", ",", "0", ",", 
     RowBox[{"1", "/", "1000"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.511233570015625*^9, 3.51123361728125*^9}, {
  3.51123367275*^9, 3.51123368309375*^9}, {3.5117767895640707`*^9, 
  3.5117767954999447`*^9}},
 FontSize->18]
}, Open  ]],

Cell[CellGroupData[{

Cell["Part III", "Text",
 CellChangeTimes->{{3.511245384625*^9, 3.5112454665*^9}, 3.511245529*^9, {
   3.511490782453125*^9, 3.511490860828125*^9}, {3.511777189644801*^9, 
   3.5117772279947357`*^9}, {3.5117772765120087`*^9, 3.51177729600976*^9}, 
   3.5117773327373247`*^9, 3.511781551484809*^9, {3.5752883935327387`*^9, 
   3.5752883997970967`*^9}},
 FontSize->36,
 FontWeight->"Plain",
 FontColor->RGBColor[0, 0, 1],
 Background->RGBColor[1, 0.9, 0.8]],

Cell["Here the initial condition is u[x, 0] = Sin[x]...", "Text",
 CellChangeTimes->{{3.511245384625*^9, 3.5112454665*^9}, 3.511245529*^9, {
   3.511490782453125*^9, 3.511490860828125*^9}, {3.511777189644801*^9, 
   3.5117772279947357`*^9}, {3.5117772765120087`*^9, 3.51177729600976*^9}, 
   3.5117773327373247`*^9, 3.511781551484809*^9, 3.5752883925006795`*^9, {
   3.5752886775339823`*^9, 3.575288682260253*^9}},
 FontSize->24,
 FontWeight->"Plain",
 FontColor->GrayLevel[0],
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{"solnz3", " ", "=", 
  RowBox[{"DSolve", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          RowBox[{"Sin", "[", "\[Theta]bMo", "]"}]}], " ", 
         RowBox[{"D", "[", 
          RowBox[{
           RowBox[{"u", "[", 
            RowBox[{"x", ",", " ", "z"}], "]"}], ",", "x"}], " ", "]"}]}], 
        " ", "+", 
        RowBox[{
         RowBox[{"Cos", "[", "\[Theta]bMo", "]"}], 
         RowBox[{"D", "[", 
          RowBox[{
           RowBox[{"u", "[", 
            RowBox[{"x", ",", " ", "z"}], "]"}], ",", " ", "z"}], "]"}]}]}], 
       " ", "==", " ", "\[IndentingNewLine]", "                          ", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"I", "*", "ka", "*", 
          RowBox[{"\[Chi]oMoI", "/", "2"}]}], ")"}], " ", 
        RowBox[{"u", "[", 
         RowBox[{"x", ",", " ", "z"}], "]"}]}]}], ",", " ", 
      RowBox[{
       RowBox[{"u", "[", 
        RowBox[{"x", ",", " ", "0"}], "]"}], " ", "==", " ", 
       RowBox[{"Sin", "[", "x", "]"}]}]}], "}"}], ",", " ", "u", ",", " ", 
    RowBox[{"{", 
     RowBox[{"x", ",", " ", "z"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.35194625578983*^9, 3.351946274146*^9}, {
   3.35211412804254*^9, 3.3521141293394*^9}, {3.511180624149849*^9, 
   3.5111806954725723`*^9}, {3.511181274124192*^9, 3.5111812973695517`*^9}, {
   3.511181339759506*^9, 3.5111813744521437`*^9}, {3.5111815458927402`*^9, 
   3.5111816420165663`*^9}, {3.511181751980998*^9, 3.511181752647786*^9}, {
   3.511183119082559*^9, 3.5111831217967777`*^9}, {3.511184769395935*^9, 
   3.511184771134444*^9}, 3.511184839114249*^9, {3.5112333796875*^9, 
   3.5112334460625*^9}, 3.51123347659375*^9, {3.5115953513427963`*^9, 
   3.511595360054541*^9}, {3.5115954570419273`*^9, 3.5115954607513027`*^9}, {
   3.5115964333702173`*^9, 3.511596443881453*^9}, {3.511596478721034*^9, 
   3.511596496807939*^9}, {3.511758956421875*^9, 3.511759033359375*^9}, {
   3.511776492528871*^9, 3.5117764934095173`*^9}, {3.5117769108355513`*^9, 
   3.511776930008609*^9}},
 FontSize->16],

Cell[BoxData[
 RowBox[{
  RowBox[{"funI3", "[", 
   RowBox[{"x_", ",", "z_"}], "]"}], " ", "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"u", "[", 
     RowBox[{"x", ",", "z"}], "]"}], "/.", 
    RowBox[{"solnz3", "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], " ", "//", "Simplify", " ", 
   RowBox[{"(*", " ", 
    RowBox[{"senxa", " ", ":="}], " ", "*)"}]}]}]], "Input",
 CellChangeTimes->{{3.511232015703125*^9, 3.5112320281875*^9}, {
   3.511233545421875*^9, 3.511233564203125*^9}, {3.51176014028125*^9, 
   3.51176014734375*^9}, {3.5117602049375*^9, 3.51176023065625*^9}, 
   3.51176032871875*^9, 3.511760408953125*^9, {3.511776498149384*^9, 
   3.511776511822567*^9}, {3.5117769350451727`*^9, 3.511776938725668*^9}},
 FontSize->18],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     RowBox[{"Sin", "[", "\[Theta]bMo", "]"}]}], 
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{"funI3", "[", 
       RowBox[{"x", ",", "z"}], "]"}], ",", "x"}], "]"}]}], "+", 
   RowBox[{
    RowBox[{"Cos", "[", "\[Theta]bMo", "]"}], " ", 
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{"funI3", "[", 
       RowBox[{"x", ",", "z"}], "]"}], ",", "z"}], "]"}]}], "-", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"I", "*", "ka", "*", 
      RowBox[{"\[Chi]oMoI", "/", "2"}]}], ")"}], 
    RowBox[{"funI3", "[", 
     RowBox[{"x", ",", "z"}], "]"}]}]}], "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.51107296878125*^9, 3.511072969453125*^9}, {
  3.5110979552288923`*^9, 3.511097959592779*^9}, {3.51176047565625*^9, 
  3.5117605678125*^9}, {3.51176060803125*^9, 3.511760608390625*^9}, {
  3.511760727765625*^9, 3.511760735*^9}, {3.511761155109375*^9, 
  3.511761162671875*^9}, {3.511776360096259*^9, 3.5117763822972403`*^9}, {
  3.511776631336935*^9, 3.51177663954241*^9}, {3.5117769418395977`*^9, 
  3.5117769730563498`*^9}},
 FontSize->18],

Cell[BoxData[
 RowBox[{
  RowBox[{"ini3", "[", 
   RowBox[{"x_", ",", "z_"}], "]"}], " ", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"funI3", "[", 
     RowBox[{"x", ",", "z"}], "]"}], "  ", "/.", " ", 
    RowBox[{"z", "->", "0"}]}], " ", "//", "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.511098054223167*^9, 3.511098059018763*^9}, {
  3.511098102817257*^9, 3.511098134725198*^9}, {3.511098181789311*^9, 
  3.511098248525207*^9}, {3.511760640390625*^9, 3.511760661375*^9}, {
  3.511760737953125*^9, 3.511760738015625*^9}, {3.51177628847123*^9, 
  3.511776292185995*^9}, {3.511776515014126*^9, 3.5117765186498137`*^9}, {
  3.5117767493189087`*^9, 3.5117767506805553`*^9}, {3.511776976270306*^9, 
  3.51177698292866*^9}},
 FontSize->18],

Cell["\<\
As done in Part II, after verifying the solutions, we can plot the \
displacement with the same protocol...\
\>", "Text",
 CellChangeTimes->{{3.511245384625*^9, 3.5112454665*^9}, 3.511245529*^9, {
   3.511490782453125*^9, 3.511490860828125*^9}, {3.511777189644801*^9, 
   3.5117772279947357`*^9}, {3.5117772765120087`*^9, 3.51177729600976*^9}, 
   3.575288382789124*^9, {3.575288573933057*^9, 3.575288608749048*^9}, {
   3.5752888782294617`*^9, 3.575289081605094*^9}},
 FontSize->24,
 FontWeight->"Plain",
 FontColor->GrayLevel[0],
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{"Plot3D", "[", 
  RowBox[{
   RowBox[{"Re", "[", 
    RowBox[{"funI3", "[", 
     RowBox[{"x", ",", "z"}], "]"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"z", ",", "0", ",", 
     RowBox[{"1", "/", "10000"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.511233570015625*^9, 3.51123361728125*^9}, {
  3.51123367275*^9, 3.51123368309375*^9}, {3.5117767895640707`*^9, 
  3.5117768371964903`*^9}, {3.5117769865989933`*^9, 3.511776986924349*^9}},
 FontSize->18],

Cell[BoxData[
 RowBox[{"Plot3D", "[", 
  RowBox[{
   RowBox[{"Im", "[", 
    RowBox[{"funI3", "[", 
     RowBox[{"x", ",", "z"}], "]"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"z", ",", "0", ",", 
     RowBox[{"1", "/", "10000"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.511233570015625*^9, 3.51123361728125*^9}, {
  3.51123367275*^9, 3.51123368309375*^9}, {3.5117767895640707`*^9, 
  3.5117768371964903`*^9}, {3.5117769865989933`*^9, 3.511776986924349*^9}, {
  3.511777030913455*^9, 3.511777032040238*^9}},
 FontSize->18],

Cell[BoxData[
 RowBox[{"Plot3D", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"Abs", "[", 
     RowBox[{"funI3", "[", 
      RowBox[{"x", ",", "z"}], "]"}], "]"}], "^", "2"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"z", ",", "0", ",", 
     RowBox[{"1", "/", "1000"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.511233570015625*^9, 3.51123361728125*^9}, {
  3.51123367275*^9, 3.51123368309375*^9}, {3.5117767895640707`*^9, 
  3.5117768371964903`*^9}, {3.5117769865989933`*^9, 3.511776986924349*^9}, {
  3.5117770353237467`*^9, 3.511777066669796*^9}},
 FontSize->18]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Date", "[", "]"}]], "Input",
 CellChangeTimes->{{3.551627873550037*^9, 3.551627880785304*^9}},
 FontSize->16]
},
WindowToolbars->"RulerBar",
CellGrouping->Manual,
WindowSize->{1904, 946},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
ShowSelection->True,
FrontEndVersion->"8.0 for Microsoft Windows (64-bit) (February 23, 2011)",
StyleDefinitions->"StyleZo2.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[545, 20, 396, 10, 87, "Text"],
Cell[944, 32, 2632, 61, 539, "Text"],
Cell[3579, 95, 119, 2, 31, "Input"],
Cell[3701, 99, 135, 2, 31, "Input"],
Cell[CellGroupData[{
Cell[3861, 105, 376, 8, 71, "Text"],
Cell[4240, 115, 628, 12, 117, "Text"],
Cell[4871, 129, 2234, 49, 57, "Input"],
Cell[7108, 180, 606, 15, 36, "Input"],
Cell[7717, 197, 540, 11, 57, "Text"],
Cell[8260, 210, 995, 28, 64, "Input"],
Cell[9258, 240, 563, 13, 36, "Input"],
Cell[9824, 255, 653, 15, 36, "Input"],
Cell[10480, 272, 1085, 29, 64, "Input"],
Cell[11568, 303, 702, 13, 87, "Text"],
Cell[12273, 318, 614, 13, 36, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12924, 336, 404, 8, 71, "Text"],
Cell[13331, 346, 462, 10, 57, "Text"],
Cell[13796, 358, 218, 5, 36, "Input"],
Cell[14017, 365, 146, 3, 36, "Input"],
Cell[14166, 370, 146, 3, 36, "Input"],
Cell[14315, 375, 146, 3, 36, "Input"],
Cell[14464, 380, 289, 8, 36, "Input"],
Cell[14756, 390, 205, 5, 36, "Input"],
Cell[14964, 397, 389, 12, 33, "Input"],
Cell[15356, 411, 2040, 47, 57, "Input"],
Cell[17399, 460, 688, 17, 36, "Input"],
Cell[18090, 479, 1092, 29, 64, "Input"],
Cell[19185, 510, 689, 15, 36, "Input"],
Cell[19877, 527, 885, 19, 237, "Text"],
Cell[20765, 548, 528, 15, 36, "Input"],
Cell[21296, 565, 526, 15, 36, "Input"],
Cell[21825, 582, 555, 16, 36, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[22417, 603, 455, 9, 71, "Text"],
Cell[22875, 614, 507, 9, 57, "Text"],
Cell[23385, 625, 2122, 48, 57, "Input"],
Cell[25510, 675, 736, 17, 36, "Input"],
Cell[26249, 694, 1145, 30, 64, "Input"],
Cell[27397, 726, 737, 16, 36, "Input"],
Cell[28137, 744, 571, 12, 57, "Text"],
Cell[28711, 758, 576, 15, 36, "Input"],
Cell[29290, 775, 625, 16, 36, "Input"],
Cell[29918, 793, 654, 17, 36, "Input"]
}, Open  ]],
Cell[30587, 813, 133, 3, 33, "Input"]
}
]
*)

(* End of internal cache information *)
