(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     34272,        978]
NotebookOptionsPosition[     31639,        899]
NotebookOutlinePosition[     32421,        928]
CellTagsIndexPosition[     32378,        925]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["\<\
Evaluation time
\[CapitalDelta]t < 7 s\
\>", "Text",
 CellChangeTimes->{{3.49174229625*^9, 3.491742331265625*^9}, {
  3.491880970015625*^9, 3.49188099371875*^9}, {3.573982380931521*^9, 
  3.5739824010669394`*^9}, {3.573982594386303*^9, 3.5739826541570997`*^9}, {
  3.573982782129212*^9, 3.573982782759836*^9}, {3.574481659813899*^9, 
  3.574481663807506*^9}},
 FontSize->24,
 FontColor->RGBColor[0, 0, 1],
 Background->RGBColor[1, 0.9, 0.8]],

Cell["", "Text",
 CellChangeTimes->{{3.5744980696923437`*^9, 3.574498079588997*^9}, 
   3.5745075568467617`*^9}],

Cell[TextData[{
 "This notebook  calculates the amount of fluid (i.e., the thermal energy) \
crossing \na surface \[CapitalSigma] according to the  equation (4.1.7). \n\
For our convenience, we repeat the definition of a surface integral of \na  \
vector function.\n\nLet ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    StyleBox["G",
     FontWeight->"Bold",
     FontSlant->"Plain"], ":", 
    RowBox[{
     StyleBox["U",
      FontSlant->"Plain"], "\[Subset]", 
     RowBox[{
      SuperscriptBox["\[DoubleStruckCapitalR]", "3"], "\[LongRightArrow]", 
      SuperscriptBox["\[DoubleStruckCapitalR]", "3"], " "}]}]}], 
   TraditionalForm]]],
 "be a continuous vector field, and let \[CapitalSigma] be a smooth \
(oriented) surface lying in U that is parametrized by ",
 StyleBox["f",
  FontWeight->"Bold"],
 "(s,t), where ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"s", ",", "t"}], ")"}], "\[Epsilon]", " ", "R"}], "\[Subset]", 
    SuperscriptBox["\[DoubleStruckCapitalR]", "2"]}], TraditionalForm]]],
 ".  The ",
 StyleBox["surface integral",
  FontWeight->"Bold"],
 " (or ",
 StyleBox["flux integral",
  FontWeight->"Bold"],
 ")",
 StyleBox[" of G over ",
  FontWeight->"Bold"],
 "\[CapitalSigma] is:\n",
 StyleBox["\n",
  FontFamily->"Times New Roman"],
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"\[Integral]", 
     RowBox[{
      SubscriptBox["\[Integral]", "\[CapitalSigma]"], 
      RowBox[{
       StyleBox[
        RowBox[{"G", " ", "\[CenterDot]", "n"}],
        FontWeight->"Bold"], 
       RowBox[{"\[DifferentialD]", "\[Sigma]"}]}]}]}], "=", 
    RowBox[{"\[Integral]", 
     RowBox[{
      SubscriptBox["\[Integral]", "R"], 
      RowBox[{
       StyleBox["G",
        FontWeight->"Bold"], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          StyleBox["f",
           FontWeight->"Bold"], 
          RowBox[{"(", 
           RowBox[{"s", ",", "t"}], ")"}]}], ")"}], "\[CenterDot]", 
        RowBox[{"(", 
         FormBox[
          RowBox[{
           FractionBox[
            RowBox[{"\[PartialD]", "f"}], 
            RowBox[{"\[PartialD]", "s"}]], "\[Times]", 
           FractionBox[
            RowBox[{"\[PartialD]", "f"}], 
            RowBox[{"\[PartialD]", "t"}]]}],
          TraditionalForm], ")"}]}], "ds", " ", "dt"}]}]}]}], 
   "\n"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
   "As", " ", "a", " ", "result", "  ", "of", " ", "the", " ", "dot", " ", 
    "product", " ", "of", " ", "our", " ", "vector", " ", "field", " ", 
    "with", " ", "the", " ", "normal", " ", "vector"}], ",", " ", 
   RowBox[{
   "the", " ", "final", " ", "integrand", " ", "will", " ", "actually", " ", 
    "still", " ", "be", " ", "a", " ", "scalar", " ", 
    RowBox[{"function", "."}]}]}]}], "DisplayFormula",
  CellChangeTimes->{{3.491654272359375*^9, 3.49165427525*^9}, 
    3.49173933728125*^9},
  FontFamily->"Times New Roman"],
 StyleBox["\n",
  FontFamily->"Times New Roman"],
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     StyleBox["If",
      FontWeight->"Plain"], 
     StyleBox[" ",
      FontWeight->"Plain"], 
     StyleBox["we",
      FontWeight->"Plain"], 
     StyleBox[" ",
      FontWeight->"Plain"], 
     StyleBox["observe",
      FontWeight->"Plain"], 
     StyleBox[" ",
      FontWeight->"Plain"], 
     StyleBox["that",
      FontWeight->"Plain"], 
     StyleBox[
      RowBox[{
       StyleBox["  ",
        FontWeight->"Plain"], 
       StyleBox[" ",
        FontWeight->"Bold"]}]], 
     StyleBox[
      RowBox[{
       StyleBox["G",
        FontSlant->"Plain"], "\[CenterDot]", 
       StyleBox["n",
        FontSlant->"Plain"]}],
      FontWeight->"Bold"]}], " ", "=", " ", 
    RowBox[{"||", 
     StyleBox["G",
      FontWeight->"Bold",
      FontSlant->"Plain"], 
     StyleBox[" ",
      FontWeight->"Bold",
      FontSlant->"Plain"], "||", " ", "||", 
     StyleBox["n",
      FontWeight->"Bold",
      FontSlant->"Plain"], "||", " ", 
     RowBox[{"cos", " ", "\[Theta]"}]}]}], TraditionalForm]],
  FontFamily->"Times New Roman"],
 StyleBox[", the cosine takes care of the ",
  FontFamily->"Times New Roman"],
 StyleBox["tilt ",
  FontFamily->"Times New Roman",
  FontSlant->"Italic"],
 StyleBox[": if the vector field is moving tangent to the surface, ",
  FontFamily->"Times New Roman"],
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"cos", " ", "\[Theta]"}], " ", "=", " ", 
    RowBox[{
     RowBox[{"cos", " ", 
      RowBox[{"(", 
       RowBox[{"\[Pi]", "/", "2"}], ")"}]}], " ", "=", " ", "0"}]}], 
   TraditionalForm]],
  FontFamily->"Times New Roman"],
 StyleBox[" and the flux is zero; on the contrary, we hav",
  FontFamily->"Times New Roman"],
 "e  a maximum when cos 0 = 1.\n\nIt's important to get the right orientation \
of the surface: the integral represents the flux from the \"inside\" of the \
surface to the \"outside\". The direction in which the normal vector points \
is considered \"outward\". \n\n",
 StyleBox["We consider two cases:\n\nCase I: the field ",
  FontSize->24],
 StyleBox["G",
  FontSize->24,
  FontWeight->"Bold"],
 StyleBox[" is constant and the surface ",
  FontSize->24],
 Cell[BoxData[
  FormBox[
   StyleBox["\[CapitalSigma]",
    FontSize->24], TraditionalForm]]],
 " ",
 StyleBox["is flat, considered in Part I\nCase II: the field ",
  FontSize->24],
 StyleBox["G",
  FontSize->24,
  FontWeight->"Bold"],
 StyleBox[" is not constant and the surface ",
  FontSize->24],
 Cell[BoxData[
  FormBox[
   StyleBox["\[CapitalSigma]",
    FontSize->24], TraditionalForm]]],
 StyleBox[" is curved, considered in Part II",
  FontSize->24]
}], "Text",
 CellChangeTimes->{{3.4916488885*^9, 3.4916489540625*^9}, {
   3.491649038890625*^9, 3.491649040640625*^9}, {3.4916491686875*^9, 
   3.49164917021875*^9}, {3.4916507385*^9, 3.491650741234375*^9}, 
   3.491652965125*^9, {3.491738708671875*^9, 3.491738729828125*^9}, {
   3.4917387999375*^9, 3.491738802390625*^9}, {3.4917388381875*^9, 
   3.491738955265625*^9}, {3.491739059078125*^9, 3.491739198890625*^9}, {
   3.49173927225*^9, 3.491739287234375*^9}, {3.49173932959375*^9, 
   3.4917393638125*^9}, {3.491739417734375*^9, 3.491739425625*^9}, {
   3.4917409141875*^9, 3.491740937015625*^9}, {3.4938751373125*^9, 
   3.4938751373125*^9}, 3.493875177640625*^9, {3.493875210140625*^9, 
   3.493875233625*^9}, {3.574481690514753*^9, 3.574481691747155*^9}, {
   3.5744817602468753`*^9, 3.574481872895873*^9}},
 FontSize->24,
 FontColor->RGBColor[0, 0, 1],
 Background->RGBColor[1, 1, 0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"Remove", "[", "\"\<Global`*\>\"", "]"}], ";", 
  RowBox[{"$Line", "=", "0"}], ";"}]], "Input",
 CellChangeTimes->{3.491654737671875*^9},
 FontSize->24],

Cell[BoxData[
 RowBox[{"$Version", " "}]], "Input",
 CellChangeTimes->{{3.50744749321875*^9, 3.507447496109375*^9}},
 FontSize->24],

Cell[BoxData[
 RowBox[{
  RowBox[{"SetOptions", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"Plot", ",", "ParametricPlot3D", ",", "VectorPlot3D"}], "}"}], 
    ",", 
    RowBox[{"ImageSize", "\[Rule]", "500"}], ",", 
    RowBox[{"LabelStyle", "\[Rule]", 
     RowBox[{"(", 
      RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}], ")"}]}], ",", 
    RowBox[{"AxesStyle", "\[Rule]", 
     RowBox[{"Directive", "[", 
      RowBox[{"20", ",", 
       RowBox[{"Thickness", "[", "0.005", "]"}], ",", "Blue"}], "]"}]}]}], 
   "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.431404133265625*^9, 3.431404152625*^9}, {
   3.431404184828125*^9, 3.43140419784375*^9}, {3.431404229828125*^9, 
   3.431404286*^9}, {3.431404358734375*^9, 3.431404362015625*^9}, 
   3.43140449659375*^9, {3.431404585328125*^9, 3.431404586390625*^9}, {
   3.431404647765625*^9, 3.431404694953125*^9}, {3.43140617875*^9, 
   3.4314062495625*^9}, {3.431406282875*^9, 3.4314063513125*^9}, {
   3.43140679328125*^9, 3.43140680225*^9}, {3.4314068341875*^9, 
   3.431406876078125*^9}, {3.491650035328125*^9, 3.491650036578125*^9}, {
   3.491709218609375*^9, 3.49170923096875*^9}},
 FontSize->18,
 Background->GrayLevel[0.85]],

Cell[CellGroupData[{

Cell["Part I", "Text",
 CellChangeTimes->{{3.491655157234375*^9, 3.491655227296875*^9}, 
   3.491655416015625*^9, {3.49165773978125*^9, 3.491657761828125*^9}, {
   3.4917147475*^9, 3.491714785890625*^9}, {3.4917148241875*^9, 
   3.4917148331875*^9}, 3.491739511546875*^9, {3.5744818944551115`*^9, 
   3.574481896576715*^9}},
 FontSize->36,
 FontColor->RGBColor[0, 0, 1],
 Background->RGBColor[1, 0.9, 0.8]],

Cell[TextData[{
 "First, the surface \[CapitalSigma], represented by  the plane ",
 Cell[BoxData[
  FormBox[
   RowBox[{"z", "=", 
    RowBox[{"5", "-", 
     RowBox[{"3", "x"}]}]}], TraditionalForm]]],
 ", \nover  the rectangle 0\[LessEqual]x\[LessEqual]1., -1.5\[LessEqual]y\
\[LessEqual]1.5,\nis parametrized by "
}], "Text",
 CellChangeTimes->{{3.491655157234375*^9, 3.491655227296875*^9}, 
   3.491655416015625*^9, {3.49165773978125*^9, 3.491657761828125*^9}, {
   3.4917147475*^9, 3.491714785890625*^9}, {3.4917148241875*^9, 
   3.4917148331875*^9}, {3.491739511546875*^9, 3.491739589578125*^9}, {
   3.491739884875*^9, 3.49173989409375*^9}},
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"f1", "[", 
    RowBox[{"x_", ",", "y_"}], "]"}], ":=", 
   RowBox[{"{", 
    RowBox[{"x", ",", "y", ",", 
     RowBox[{"5", "-", 
      RowBox[{"3", "x"}]}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.491654791671875*^9, 3.4916547988125*^9}, {
   3.49165485278125*^9, 3.491654853609375*^9}, 3.491716653203125*^9},
 FontSize->18],

Cell["\<\
Then we calculate the value of the plane in a couple of points (shown in the \
global graphics, just for completeness):\
\>", "Text",
 CellChangeTimes->{{3.491655448265625*^9, 3.49165549709375*^9}, {
  3.49173960059375*^9, 3.491739607078125*^9}, {3.49173990534375*^9, 
  3.491739908875*^9}, {3.57448199041088*^9, 3.5744819983512936`*^9}, {
  3.5744820289273477`*^9, 3.5744820672280436`*^9}},
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{"p1", "=", 
  RowBox[{"f1", "[", 
   RowBox[{"1", ",", "0"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.491655503890625*^9, 3.491655512734375*^9}, {
   3.491655619*^9, 3.49165562265625*^9}, {3.491707976328125*^9, 
   3.49170799690625*^9}, {3.4917080854375*^9, 3.49170808765625*^9}, 
   3.491716654828125*^9},
 FontSize->18],

Cell[BoxData[
 RowBox[{"p2", "=", 
  RowBox[{"f1", "[", 
   RowBox[{"0", ",", 
    RowBox[{"-", "1.5"}]}], "]"}]}]], "Input",
 CellChangeTimes->{
  3.49165551784375*^9, 3.491716656765625*^9, {3.49188022440625*^9, 
   3.49188022559375*^9}},
 FontSize->18],

Cell["\<\
Here you are... a picture of \[CapitalSigma]...\
\>", "Text",
 CellChangeTimes->{{3.49165778434375*^9, 3.491657789078125*^9}, {
  3.491739481078125*^9, 3.491739488890625*^9}, {3.57448201335852*^9, 
  3.574482025058541*^9}},
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 StyleBox[
  RowBox[{"twopoints", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{"p1", ",", "p2"}], "}"}]}],
  FontFamily->"Courier"]], "Input",
 CellChangeTimes->{{3.49188020865625*^9, 3.491880283421875*^9}, {
  3.491881046328125*^9, 3.49188105278125*^9}}],

Cell[BoxData[
 RowBox[{"gg", "=", 
  RowBox[{"ListPointPlot3D", "[", 
   RowBox[{"twopoints", " ", ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"Directive", "[", 
      RowBox[{"Orange", ",", 
       RowBox[{"PointSize", "[", "0.025", "]"}]}], "]"}]}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{
  3.491880027828125*^9, {3.491880310515625*^9, 3.491880324875*^9}, {
   3.491880627359375*^9, 3.491880655078125*^9}, {3.491880712515625*^9, 
   3.491880715359375*^9}, {3.49188075778125*^9, 3.4918808774375*^9}, 
   3.4918810614375*^9, {3.574482666366312*^9, 3.574482667918401*^9}}],

Cell[BoxData[
 RowBox[{"surf1", "=", 
  RowBox[{"ParametricPlot3D", "[", 
   RowBox[{
    RowBox[{"f1", "[", 
     RowBox[{"x", ",", "y"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", "1"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"y", ",", 
      RowBox[{"-", "1.5"}], ",", "1.5"}], "}"}], ",", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<x\>\"", ",", "\"\<y\>\"", ",", "\"\<z\>\""}], "}"}]}], ",",
     "\[IndentingNewLine]", "                                   ", 
    RowBox[{"ImageSize", "\[Rule]", "400"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.491650007859375*^9, 3.491650014234375*^9}, {
   3.49165486825*^9, 3.491654898578125*^9}, {3.4916556065*^9, 
   3.491655636796875*^9}, {3.491655719359375*^9, 3.491655735578125*^9}, 
   3.491655948390625*^9, {3.4916565808125*^9, 3.491656608703125*^9}, 
   3.49165769528125*^9, {3.491707926140625*^9, 3.491707940875*^9}, {
   3.491708035828125*^9, 3.491708062046875*^9}, {3.49170839240625*^9, 
   3.491708397984375*^9}, {3.49170847125*^9, 3.491708472609375*^9}, {
   3.49170851825*^9, 3.49170854084375*^9}, 3.491708576625*^9, {
   3.491716441203125*^9, 3.491716443984375*^9}, 3.49171665825*^9},
 FontSize->18],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"surf1", ",", "gg"}], "]"}]], "Input",
 CellChangeTimes->{{3.49188089053125*^9, 3.4918809063125*^9}}],

Cell[TextData[{
 "Second, as in our case the surface \[CapitalSigma] is the plane\n       3 x \
+ 0  + z =5,  \nthe components  {3,0,1}  of the  normal   ",
 StyleBox["n ",
  FontWeight->"Bold",
  FontSlant->"Italic"],
 " are easily found. \nOtherwise, we could  use           "
}], "Text",
 CellChangeTimes->{{3.491657827890625*^9, 3.491658142921875*^9}, {
  3.491714843234375*^9, 3.491714951484375*^9}, {3.491715075484375*^9, 
  3.491715082203125*^9}, {3.491715932921875*^9, 3.491715933796875*^9}, {
  3.491739618328125*^9, 3.49173963221875*^9}, {3.49173993575*^9, 
  3.491739936953125*^9}},
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  StyleBox["normal1",
   FontColor->RGBColor[1, 0, 0]], "=", 
  RowBox[{"Cross", "[", 
   RowBox[{
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{"f1", "[", 
       RowBox[{"x", ",", "y"}], "]"}], ",", "x"}], "]"}], ",", 
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{"f1", "[", 
       RowBox[{"x", ",", "y"}], "]"}], ",", "y"}], "]"}]}], "]"}]}]], "Input",\

 CellChangeTimes->{
  3.491658148640625*^9, {3.49171661315625*^9, 3.491716614265625*^9}, {
   3.491716664109375*^9, 3.491716665828125*^9}},
 FontSize->24],

Cell[BoxData[
 RowBox[{"unitvect1", " ", "=", 
  RowBox[{"normal1", "/", 
   SqrtBox[
    RowBox[{"normal1", ".", "normal1", " "}]]}]}]], "Input",
 CellChangeTimes->{{3.491658149953125*^9, 3.491658168390625*^9}, {
  3.491716617578125*^9, 3.491716623578125*^9}},
 FontSize->24],

Cell[BoxData[
 RowBox[{"modulus1", " ", "=", " ", 
  FractionBox[
   RowBox[{"unitvect1", " ", ".", "unitvect1", " "}], 
   RowBox[{
    SqrtBox[
     RowBox[{
      RowBox[{"unitvect1", " ", ".", "unitvect1"}], "  ", "*", " ", 
      RowBox[{"unitvect1", " ", ".", "unitvect1", " "}]}]], " "}]]}]], "Input",\

 CellChangeTimes->{{3.491658183484375*^9, 3.49165821865625*^9}, {
  3.49171662534375*^9, 3.4917166383125*^9}},
 FontSize->24],

Cell["\<\
Next step regards G(f(x, y)); if we suppose G to be a constant vector, e.g., \
\
\>", "Text",
 CellChangeTimes->{{3.49165823709375*^9, 3.491658354625*^9}, {
  3.491715097890625*^9, 3.491715122140625*^9}, {3.4917152775625*^9, 
  3.491715399796875*^9}, {3.491715445296875*^9, 3.49171546175*^9}},
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"G1", "[", 
    RowBox[{"x_", ",", "y_", ",", "z_"}], "]"}], " ", ":=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "15"}], ",", "0", ",", 
     RowBox[{"-", "5"}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.49170867084375*^9, 3.49170867309375*^9}, {
  3.4917093675*^9, 3.49170938834375*^9}, {3.491715198453125*^9, 
  3.491715199078125*^9}},
 FontSize->24],

Cell["\<\
then G1(f (x, y)) = {-15, 0, -5} for all the points (clearly it is constant).\
\
\>", "Text",
 CellChangeTimes->{{3.49165823709375*^9, 3.491658354625*^9}, {
  3.491715097890625*^9, 3.491715122140625*^9}, {3.4917152775625*^9, 
  3.491715399796875*^9}, {3.491715445296875*^9, 3.491715476203125*^9}, {
  3.574482095635668*^9, 3.5744821211641283`*^9}},
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell["Otherwise, we could use the command Apply ", "Text",
 CellChangeTimes->{{3.49165823709375*^9, 3.491658354625*^9}, {
   3.491715097890625*^9, 3.491715122140625*^9}, {3.4917152775625*^9, 
   3.491715399796875*^9}, {3.491715445296875*^9, 3.49171546175*^9}, {
   3.4917155725*^9, 3.4917156075625*^9}, 3.491739971296875*^9},
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{"vec1", "=", 
  RowBox[{"Apply", "[", 
   RowBox[{"G1", ",", 
    RowBox[{"f1", "[", 
     RowBox[{"x", ",", "y"}], "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.491715406875*^9, 3.491715407828125*^9}, {
   3.49171608890625*^9, 3.491716095171875*^9}, {3.491716478015625*^9, 
   3.491716479890625*^9}, 3.491716670625*^9},
 FontSize->24],

Cell[BoxData[
 RowBox[{"vec1field", " ", "=", " ", 
  RowBox[{"VectorPlot3D", "[", 
   RowBox[{"vec1", ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0.5", ",", "1"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"y", ",", 
      RowBox[{"-", "1."}], ",", "1."}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"z", ",", "2", ",", "5.0"}], "}"}], ",", 
    RowBox[{"VectorPoints", "\[Rule]", "5"}], ",", "\[IndentingNewLine]", 
    RowBox[{"VectorScale", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Large", ",", 
       RowBox[{"Scaled", "[", "0.07", "]"}]}], "}"}]}], ",", 
    RowBox[{"VectorColorFunction", "\[Rule]", "Hue"}]}], "]"}]}]], "Input",
 CellChangeTimes->{
  3.491650070453125*^9, {3.491658607265625*^9, 3.491658623671875*^9}, {
   3.49165865815625*^9, 3.4916587085*^9}, {3.49165888115625*^9, 
   3.491658882015625*^9}, {3.491658938828125*^9, 3.491658952921875*^9}, {
   3.491659119703125*^9, 3.49165913884375*^9}, {3.49165920421875*^9, 
   3.491659235859375*^9}, {3.49165929290625*^9, 3.4916593084375*^9}, {
   3.49170870246875*^9, 3.491708734265625*^9}, {3.491709293234375*^9, 
   3.49170930140625*^9}, {3.49170937584375*^9, 3.491709392734375*^9}, {
   3.49171595803125*^9, 3.491715998828125*^9}, {3.491716083421875*^9, 
   3.491716126921875*^9}, {3.491716174265625*^9, 3.491716191125*^9}, {
   3.4917162540625*^9, 3.491716262828125*^9}, {3.49171645590625*^9, 
   3.4917164905*^9}},
 FontSize->24],

Cell["\<\
Here we have the representation of the flow crossing  \[CapitalSigma]\
\>", "Text",
 CellChangeTimes->{{3.491739701453125*^9, 3.49173977525*^9}, {
  3.574482129147585*^9, 3.5744821583232536`*^9}},
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"surf1", ",", "vec1field", ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{
  3.49165008003125*^9, {3.4916591048125*^9, 3.49165910821875*^9}, {
   3.491716500625*^9, 3.491716516203125*^9}},
 FontSize->24],

Cell["\<\
Finally, we evaluate the flux (the flux is negative, as it enters \
\[CapitalSigma] ).\
\>", "Text",
 CellChangeTimes->{{3.491739701453125*^9, 3.49173977525*^9}, {3.4917398065*^9,
    3.491739859953125*^9}, {3.49174062221875*^9, 3.491740623125*^9}, 
   3.574482164347598*^9},
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{"integrand1", "=", 
  RowBox[{
   RowBox[{"Apply", "[", 
    RowBox[{"G1", ",", 
     RowBox[{"f1", "[", 
      RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ".", 
   StyleBox["normal1",
    FontColor->RGBColor[1, 0, 0]], 
   StyleBox[
    RowBox[{
     StyleBox[" ",
      FontColor->RGBColor[1, 0, 0]], "  "}]], 
   RowBox[{"(*", 
    StyleBox[
     RowBox[{" ", 
      StyleBox[" ",
       FontColor->RGBColor[1, 0, 0]]}]], "*)"}]}]}]], "Input",
 CellChangeTimes->{{3.49171660321875*^9, 3.491716603609375*^9}, {
  3.49171667803125*^9, 3.491716682125*^9}, {3.49171672940625*^9, 
  3.491716729765625*^9}},
 FontSize->24],

Cell[BoxData[
 RowBox[{
  SubscriptBox["\[CapitalPhi]", "A"], " ", "=", " ", 
  RowBox[{"Integrate", "[", 
   RowBox[{"integrand1", ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", "1"}], "}"}], ",", "      ", 
    "\[IndentingNewLine]", "                            ", 
    RowBox[{"{", 
     RowBox[{"y", ",", 
      RowBox[{"-", "1.5"}], ",", "1.5"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.49171668425*^9, 3.4917166908125*^9}, {
  3.49173987384375*^9, 3.491739877546875*^9}},
 FontSize->24]
}, Open  ]],

Cell[CellGroupData[{

Cell["Case II", "Text",
 CellChangeTimes->{{3.491655157234375*^9, 3.491655227296875*^9}, 
   3.491655416015625*^9, {3.49165773978125*^9, 3.491657761828125*^9}, {
   3.4917147475*^9, 3.491714785890625*^9}, {3.4917148241875*^9, 
   3.4917148331875*^9}, 3.4917167855625*^9, {3.491716823125*^9, 
   3.49171685203125*^9}, {3.491716885609375*^9, 3.491716987765625*^9}, 
   3.491740022796875*^9},
 FontSize->36,
 FontColor->RGBColor[0, 0, 1],
 Background->RGBColor[1, 0.9, 0.8]],

Cell["\<\
The surface \[CapitalSigma] is represented by  the parametric surface f2[x, \
y]
over the rectangle 0\[LessEqual]x\[LessEqual]\[Pi], \
0\[LessEqual]y\[LessEqual]\[Pi]. \
\>", "Text",
 CellChangeTimes->{{3.491655157234375*^9, 3.491655227296875*^9}, 
   3.491655416015625*^9, {3.49165773978125*^9, 3.491657761828125*^9}, {
   3.4917147475*^9, 3.491714785890625*^9}, {3.4917148241875*^9, 
   3.4917148331875*^9}, 3.4917167855625*^9, {3.491716823125*^9, 
   3.49171685203125*^9}, {3.491716885609375*^9, 3.491716987765625*^9}, 
   3.491740022796875*^9},
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"f2", "[", 
   RowBox[{"x_", ",", "y_"}], "]"}], ":=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Cos", "[", "x", "]"}], ",", 
    RowBox[{
     RowBox[{"Sin", "[", "x", "]"}], "+", 
     RowBox[{"Cos", "[", "y", "]"}]}], ",", 
    RowBox[{"Sin", "[", "y", "]"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.4917097320625*^9, 3.49170975740625*^9}, {
   3.491711342625*^9, 3.491711401390625*^9}, 3.49171188065625*^9, {
   3.491712606875*^9, 3.49171260865625*^9}},
 FontSize->24],

Cell[BoxData[
 RowBox[{"surf2", "=", 
  RowBox[{"ParametricPlot3D", "[", 
   RowBox[{
    RowBox[{"f2", "[", 
     RowBox[{"x", ",", "y"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"y", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<x\>\"", ",", "\"\<y\>\"", ",", "\"\<z\>\""}], "}"}]}], ",",
     "\[IndentingNewLine]", "                                   ", 
    RowBox[{"ImageSize", "\[Rule]", "600"}], ",", 
    RowBox[{"ViewPoint", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"2", ",", 
       RowBox[{"-", "2"}], ",", "1"}], "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.491650007859375*^9, 3.491650014234375*^9}, {
   3.49165486825*^9, 3.491654898578125*^9}, {3.4916556065*^9, 
   3.491655636796875*^9}, {3.491655719359375*^9, 3.491655735578125*^9}, 
   3.491655948390625*^9, {3.4916565808125*^9, 3.491656608703125*^9}, 
   3.49165769528125*^9, {3.491707926140625*^9, 3.491707940875*^9}, {
   3.491708035828125*^9, 3.491708062046875*^9}, {3.49170839240625*^9, 
   3.491708397984375*^9}, {3.49170847125*^9, 3.491708472609375*^9}, {
   3.49170851825*^9, 3.49170854084375*^9}, 3.491708576625*^9, {
   3.491711758171875*^9, 3.49171179878125*^9}, {3.491711844109375*^9, 
   3.491711845265625*^9}, 3.491711891421875*^9, {3.491713023828125*^9, 
   3.491713024328125*^9}, {3.491717095890625*^9, 3.491717098828125*^9}},
 FontSize->24],

Cell["Now we suppose G to be given by ", "Text",
 CellChangeTimes->{{3.49165823709375*^9, 3.491658354625*^9}, {
  3.491715097890625*^9, 3.491715122140625*^9}, {3.4917152775625*^9, 
  3.491715399796875*^9}, {3.491715445296875*^9, 3.49171546175*^9}, {
  3.4917401319375*^9, 3.491740151796875*^9}},
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"G2", "[", 
   RowBox[{"x_", ",", "y_", ",", "z_"}], "]"}], ":=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"1", "-", "x"}], ",", "y", ",", 
    RowBox[{"10", " ", "z"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.491710878328125*^9, 3.491710878875*^9}, {
  3.491717115765625*^9, 3.491717116484375*^9}},
 FontSize->24],

Cell["\<\
The vector field given by G over  \[CapitalSigma] is \
\>", "Text",
 CellChangeTimes->{{3.49165823709375*^9, 3.491658354625*^9}, {
  3.491715097890625*^9, 3.491715122140625*^9}, {3.4917152775625*^9, 
  3.491715399796875*^9}, {3.491715445296875*^9, 3.49171546175*^9}, {
  3.4917401319375*^9, 3.491740151796875*^9}, {3.491740185578125*^9, 
  3.4917402354375*^9}, {3.491740267546875*^9, 3.491740268078125*^9}},
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{"vec2", "=", 
  RowBox[{"Apply", "[", 
   RowBox[{"G2", ",", 
    RowBox[{"f2", "[", 
     RowBox[{"x", ",", "y"}], "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.49171189653125*^9, 3.491711899375*^9}, {
  3.491717294390625*^9, 3.491717294984375*^9}, {3.49171778884375*^9, 
  3.4917177903125*^9}},
 FontSize->24],

Cell[BoxData[
 RowBox[{"vec2field", " ", "=", " ", 
  RowBox[{"VectorPlot3D", "[", 
   RowBox[{"vec2", ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", 
      RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"y", ",", 
      RowBox[{"-", "1"}], ",", "2"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"z", ",", "0", ",", "1"}], "}"}], ",", 
    RowBox[{"VectorPoints", "\[Rule]", "5"}], ",", "\[IndentingNewLine]", 
    RowBox[{"ViewPoint", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"2", ",", 
       RowBox[{"-", "2"}], ",", "1"}], "}"}]}], ",", "\[IndentingNewLine]", 
    RowBox[{"VectorScale", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Automatic", ",", 
       RowBox[{"Scaled", "[", "0.15", "]"}]}], "}"}]}], ",", 
    RowBox[{"VectorColorFunction", "\[Rule]", "Hue"}]}], "]"}]}]], "Input",
 CellChangeTimes->{
  3.491650070453125*^9, {3.491658607265625*^9, 3.491658623671875*^9}, {
   3.49165865815625*^9, 3.4916587085*^9}, {3.49165888115625*^9, 
   3.491658882015625*^9}, {3.491658938828125*^9, 3.491658952921875*^9}, {
   3.491659119703125*^9, 3.49165913884375*^9}, {3.49165920421875*^9, 
   3.491659235859375*^9}, {3.49165929290625*^9, 3.4916593084375*^9}, {
   3.49170870246875*^9, 3.491708734265625*^9}, {3.491709293234375*^9, 
   3.49170930140625*^9}, {3.49170937584375*^9, 3.491709392734375*^9}, {
   3.491710807828125*^9, 3.491710895171875*^9}, {3.4917112155*^9, 
   3.491711219328125*^9}, {3.49171128875*^9, 3.49171130821875*^9}, {
   3.49171142121875*^9, 3.49171142159375*^9}, {3.49171374865625*^9, 
   3.491713757234375*^9}, {3.491717120296875*^9, 3.491717120921875*^9}, {
   3.491717159796875*^9, 3.49171716434375*^9}, {3.491720061171875*^9, 
   3.49172006828125*^9}, {3.491740355078125*^9, 3.491740366859375*^9}},
 FontSize->24],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"surf2", ",", "vec2field", ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
   RowBox[{"ViewPoint", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"2", ",", 
      RowBox[{"-", "2"}], ",", "1"}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{
  3.49165008003125*^9, {3.4916591048125*^9, 3.49165910821875*^9}, {
   3.4917109440625*^9, 3.491710957765625*^9}, {3.4917171430625*^9, 
   3.49171714565625*^9}, 3.491717179421875*^9, {3.49171817159375*^9, 
   3.491718184390625*^9}, {3.4917183175625*^9, 3.4917183373125*^9}, {
   3.491720184015625*^9, 3.491720186484375*^9}},
 FontSize->18],

Cell[TextData[{
 "The components of the  normal   ",
 StyleBox["n",
  FontWeight->"Bold",
  FontSlant->"Italic"],
 "  are given by "
}], "Text",
 CellChangeTimes->{{3.491740465296875*^9, 3.491740503015625*^9}},
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  StyleBox["normal2",
   FontColor->RGBColor[1, 0, 0]], "=", 
  RowBox[{"Cross", "[", 
   RowBox[{
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{"f2", "[", 
       RowBox[{"x", ",", "y"}], "]"}], ",", "x"}], "]"}], ",", 
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{"f2", "[", 
       RowBox[{"x", ",", "y"}], "]"}], ",", "y"}], "]"}]}], "]"}]}]], "Input",\

 CellChangeTimes->{{3.491711911015625*^9, 3.491711912703125*^9}, {
  3.49171721465625*^9, 3.491717215015625*^9}},
 FontSize->24],

Cell[BoxData[
 RowBox[{"integrand2", "=", 
  RowBox[{
   RowBox[{"Apply", "[", 
    RowBox[{"G2", ",", 
     RowBox[{"f2", "[", 
      RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ".", 
   StyleBox["normal2",
    FontColor->RGBColor[1, 0, 0]], "  ", 
   RowBox[{"(*", 
    StyleBox[
     RowBox[{" ", 
      StyleBox[" ",
       FontColor->RGBColor[1, 0, 0]]}]], "*)"}]}]}]], "Input",
 CellChangeTimes->{{3.491711915921875*^9, 3.491711921546875*^9}, 
   3.491712667046875*^9, {3.4917172190625*^9, 3.4917172244375*^9}, 
   3.491718089125*^9},
 FontSize->24],

Cell["\<\
 The flux is positive in the region  0\[LessEqual]x\[LessEqual]\[Pi], 0\
\[LessEqual]y\[LessEqual]\[Pi] as it leaves \[CapitalSigma].\
\>", "Text",
 CellChangeTimes->{{3.491740648703125*^9, 3.491740732953125*^9}, {
  3.574482209700192*^9, 3.5744822098522005`*^9}},
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  SubscriptBox["\[CapitalPhi]", "A"], " ", "=", " ", 
  RowBox[{"Integrate", "[", 
   RowBox[{"integrand2", ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"y", ",", "0.", ",", "\[Pi]"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{
  3.49171267340625*^9, {3.491717368828125*^9, 3.4917173726875*^9}, 
   3.491718091046875*^9},
 FontSize->24],

Cell["\<\
 The field  is practically tangent in the region  -0.1\[LessEqual]x\
\[LessEqual]0.1, -0.7\[LessEqual]y\[LessEqual]-0.6. \
\>", "Text",
 CellChangeTimes->{{3.491740648703125*^9, 3.491740822203125*^9}, {
  3.5074475365*^9, 3.507447538203125*^9}},
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  SubscriptBox["\[CapitalPhi]", "B"], " ", "=", " ", 
  RowBox[{
   RowBox[{"Integrate", "[", 
    RowBox[{"integrand2", ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "0.1"}], ",", "0.1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "0.7"}], ",", 
       RowBox[{"-", "0.6"}]}], "}"}]}], "]"}], "//", "N"}]}]], "Input",
 CellChangeTimes->{
  3.491712675515625*^9, {3.4917127805*^9, 3.49171278125*^9}, {
   3.491717675265625*^9, 3.49171773846875*^9}, {3.49171805521875*^9, 
   3.491718113875*^9}, {3.4917202234375*^9, 3.491720374515625*^9}, {
   3.491720410140625*^9, 3.49172043121875*^9}},
 FontSize->24]
}, Open  ]]
},
ScreenStyleEnvironment->"Working",
PrintingStyleEnvironment->"Printout",
CellGrouping->Manual,
WindowSize->{1438, 813},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrintingPageRange->{Automatic, Automatic},
PrintingOptions->{"Magnification"->1,
"PaperOrientation"->"Portrait",
"PaperSize"->{612, 792},
"PostScriptOutputFile":>"",
"PrintCellBrackets"->False,
"PrintMultipleHorizontalPages"->False,
"PrintRegistrationMarks"->True,
"PrintingMargins"->{{54, 54}, {72, 72}}},
CellLabelAutoDelete->True,
Magnification->1,
FrontEndVersion->"9.0 for Linux x86 (64-bit) (January 25, 2013)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[545, 20, 451, 11, 89, "Text"],
Cell[999, 33, 112, 2, 31, "Text"],
Cell[1114, 37, 6504, 197, 667, "Text"],
Cell[7621, 236, 186, 5, 44, "Input"],
Cell[7810, 243, 131, 3, 44, "Input"],
Cell[7944, 248, 1194, 26, 82, "Input"],
Cell[CellGroupData[{
Cell[9163, 278, 406, 8, 71, "Text"],
Cell[9572, 288, 693, 16, 120, "Text"],
Cell[10268, 306, 382, 11, 37, "Input"],
Cell[10653, 319, 446, 9, 58, "Text"],
Cell[11102, 330, 345, 8, 37, "Input"],
Cell[11450, 340, 254, 8, 37, "Input"],
Cell[11707, 350, 278, 7, 58, "Text"],
Cell[11988, 359, 269, 7, 32, "Input"],
Cell[12260, 368, 589, 13, 32, "Input"],
Cell[12852, 383, 1218, 25, 66, "Input"],
Cell[14073, 410, 148, 3, 32, "Input"],
Cell[14224, 415, 638, 14, 151, "Text"],
Cell[14865, 431, 548, 18, 44, "Input"],
Cell[15416, 451, 276, 7, 63, "Input"],
Cell[15695, 460, 436, 12, 93, "Input"],
Cell[16134, 474, 348, 8, 58, "Text"],
Cell[16485, 484, 419, 12, 44, "Input"],
Cell[16907, 498, 403, 9, 58, "Text"],
Cell[17313, 509, 370, 6, 58, "Text"],
Cell[17686, 517, 362, 9, 44, "Input"],
Cell[18051, 528, 1412, 29, 82, "Input"],
Cell[19466, 559, 251, 6, 58, "Text"],
Cell[19720, 567, 291, 7, 44, "Input"],
Cell[20014, 576, 330, 8, 58, "Text"],
Cell[20347, 586, 639, 21, 44, "Input"],
Cell[20989, 609, 513, 13, 82, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[21539, 627, 471, 9, 71, "Text"],
Cell[22013, 638, 603, 13, 89, "Text"],
Cell[22619, 653, 509, 14, 44, "Input"],
Cell[23131, 669, 1484, 30, 82, "Input"],
Cell[24618, 701, 340, 6, 58, "Text"],
Cell[24961, 709, 351, 10, 44, "Input"],
Cell[25315, 721, 462, 9, 58, "Text"],
Cell[25780, 732, 338, 9, 44, "Input"],
Cell[26121, 743, 1779, 36, 119, "Input"],
Cell[27903, 781, 633, 14, 37, "Input"],
Cell[28539, 797, 255, 9, 58, "Text"],
Cell[28797, 808, 522, 17, 44, "Input"],
Cell[29322, 827, 552, 17, 44, "Input"],
Cell[29877, 846, 319, 7, 58, "Text"],
Cell[30199, 855, 432, 12, 44, "Input"],
Cell[30634, 869, 300, 7, 58, "Text"],
Cell[30937, 878, 686, 18, 44, "Input"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
