(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     32551,        865]
NotebookOptionsPosition[     29858,        777]
NotebookOutlinePosition[     30803,        815]
CellTagsIndexPosition[     30684,        808]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["\<\
Evaluation time:
\[CapitalDelta]t < 5 s\
\>", "Text",
 CellChangeTimes->{{3.5726815466762786`*^9, 3.572681568044501*^9}},
 FontSize->24,
 FontColor->RGBColor[0, 0, 1],
 Background->RGBColor[1, 0.9, 0.8]],

Cell[TextData[{
 StyleBox["NATURAL CUBIC SPLINES (DIRECT METHOD) - ", "Title",
  FontFamily->"Times New Roman",
  FontSize->16,
  FontWeight->"Plain"],
 StyleBox["INTRODUCTION", "Section",
  FontFamily->"Times New Roman",
  FontSize->16,
  FontWeight->"Plain"],
 StyleBox["\n", "Title"],
 "\nIn this .nb  we describe how to calculate, step  by step, the (twenty) \
coefficients  of the five \nthird-degree  polynomials constituing the cubic \
spline interpolating  the  simple  set of points \n\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"{", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["x", "i"], ",", 
       SubscriptBox["f", "i"]}], ")"}], "}"}], "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "0"}], "}"}], ",", "  ", 
      RowBox[{"{", 
       RowBox[{"2", ",", "2"}], "}"}], ",", "  ", 
      RowBox[{"{", 
       RowBox[{"5", ",", "3"}], "}"}], ",", "  ", 
      RowBox[{"{", 
       RowBox[{"9", ",", "5"}], "}"}], ",", "  ", 
      RowBox[{"{", 
       RowBox[{"11", ",", "2"}], "}"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"14", ",", "1"}], "}"}]}], "}"}]}], TraditionalForm]]],
 "\n\nIn part  ",
 ButtonBox["I",
  BaseStyle->"Hyperlink",
  ButtonData->"Part A"],
 ", instead of using the method described in Section \\ref{211}, which \
requires some manipulations to obtain the coefficients\n\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["s", 
     RowBox[{"k", ",", "0"}]], " ", ",", "  ", 
    SubscriptBox["s", 
     RowBox[{"k", ",", "1"}]], " ", ",", " ", 
    SubscriptBox["s", 
     RowBox[{"k", ",", "2"}]], ",", " ", 
    SubscriptBox["s", 
     RowBox[{"k", ",", "3"}]]}], TraditionalForm]]],
 "\n\nin terms of\n\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["S", "k"], "(", 
     SubscriptBox["x", "k"], ")"}], ",", 
    RowBox[{
     SubscriptBox["S", "k"], "(", 
     SubscriptBox["x", 
      RowBox[{"k", "+", "1"}]], ")"}], ",", " ", 
    RowBox[{
     SubsuperscriptBox["S", "k", "''"], "(", 
     SubscriptBox["x", "k"], ")"}], ",", " ", 
    RowBox[{
     SubsuperscriptBox["S", "k", "''"], "(", 
     SubscriptBox["x", 
      RowBox[{"k", "+", "1"}]], ")"}]}], TraditionalForm]]],
 "\n\nand ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["h", "k"], TraditionalForm]]],
 ", we impose from the beginning the conditions (I) to (IV) required in \
Section \\ref{sub211}.\n\nThe second derivative at the end points is set \
equal to zero, condition (VI) of Section \\ref{sub211}, and all the \
conditions are thus assembled to form the final system.\n\nIn part ",
 ButtonBox["II",
  BaseStyle->"Hyperlink",
  ButtonData->"Part B"],
 ", the coordinates of points are introduced and the solutions \nof the \
system give the twenty coefficients of the piecewise  polynomials.\n\nIn part \
",
 ButtonBox["III",
  BaseStyle->"Hyperlink",
  ButtonData->"Part C"],
 ", the explicit  representation of the polynomial on each  subdomain\nis \
given.\n\nNote: An alternative method to obtain the coefficients can be found \
in\n\n",
 ButtonBox["http://math.fullerton.edu/mathews/n2003/CubicSplinesMod.html",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://math.fullerton.edu/mathews/n2003/CubicSplinesMod.html"], None},
  ButtonNote->"http://math.fullerton.edu/mathews/n2003/CubicSplinesMod.html"],
 "\n               "
}], "Text",
 CellChangeTimes->{{3.560421038626769*^9, 3.560421039056433*^9}, {
  3.560421081586558*^9, 3.560421082082908*^9}, {3.560421207926751*^9, 
  3.560421248249384*^9}, {3.560421289124728*^9, 3.560421453919998*^9}, {
  3.560421497058775*^9, 3.560421824390606*^9}, {3.5604398390729*^9, 
  3.560439841552505*^9}, {3.56043995967916*^9, 3.560439990829438*^9}, {
  3.560453568663887*^9, 3.560453638264796*^9}, {3.560582320757521*^9, 
  3.560582324705972*^9}, {3.560584317822356*^9, 3.560584320520732*^9}, {
  3.572681465023608*^9, 3.572681524765025*^9}, {3.572681592543902*^9, 
  3.5726816102869167`*^9}, {3.5774553842444706`*^9, 3.5774553989864964`*^9}},
 FontColor->RGBColor[0, 0, 1],
 Background->RGBColor[1, 1, 0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"Remove", "[", "\"\<Global`*\>\"", "]"}], ";", 
  RowBox[{"$Line", "=", "0"}], ";"}]], "Input",
 CellChangeTimes->{{3.481022187171875*^9, 3.481022222703125*^9}, 
   3.48102225303125*^9, {3.48125798384375*^9, 3.481257989375*^9}, {
   3.481258048796875*^9, 3.481258049421875*^9}, 3.481258330015625*^9, {
   3.481258527140625*^9, 3.481258577125*^9}, 3.486126360451357*^9, {
   3.507637155479566*^9, 3.507637157897114*^9}}],

Cell[BoxData["$Version"], "Input",
 CellChangeTimes->{{3.507637164278963*^9, 3.507637166287161*^9}}],

Cell[BoxData[
 RowBox[{"Date", "[", "]"}]], "Input",
 CellChangeTimes->{{3.507637351112958*^9, 3.507637352507922*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"points", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"5", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"9", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"11", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"14", ",", "1"}], "}"}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.481022187171875*^9, 3.481022222703125*^9}, 
   3.48102225303125*^9, {3.48125798384375*^9, 3.481257989375*^9}, {
   3.481258048796875*^9, 3.481258049421875*^9}, 3.481258330015625*^9, {
   3.481258527140625*^9, 3.4812585526875*^9}, {3.481259178296875*^9, 
   3.4812591903125*^9}, 3.485579354890625*^9, {3.485599206703125*^9, 
   3.4855992109375*^9}, {3.485599283671875*^9, 3.485599286609375*^9}, 
   3.485609879578125*^9, {3.4861263948289337`*^9, 3.486126410650749*^9}, {
   3.560440083991767*^9, 3.560440087546916*^9}}],

Cell[BoxData[
 RowBox[{"numpoints", "=", 
  RowBox[{"Length", "[", "points", "]"}]}]], "Input",
 CellChangeTimes->{{3.481022187171875*^9, 3.481022222703125*^9}, 
   3.48102225303125*^9, {3.48125798384375*^9, 3.481257989375*^9}, {
   3.481258048796875*^9, 3.481258049421875*^9}, 3.481258330015625*^9, {
   3.481258527140625*^9, 3.481258581203125*^9}, 3.485579355390625*^9, 
   3.485583282640625*^9, 3.485599650328125*^9, 3.486126556101701*^9}],

Cell[BoxData[
 RowBox[{"grapoints", "=", 
  RowBox[{"ListPlot", "[", 
   RowBox[{"points", ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"PointSize", "[", "Medium", "]"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{
  3.478176561*^9, {3.47886444053125*^9, 3.478864453640625*^9}, {
   3.481370595125*^9, 3.481370597578125*^9}, {3.4813708623125*^9, 
   3.481370865234375*^9}, {3.485579366921875*^9, 3.48557936759375*^9}, 
   3.4866469631954308`*^9, {3.560440105879177*^9, 3.560440139271071*^9}}],

Cell["We extract the coordinates from the list of points.", "Text",
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"xpoints", "=", 
   RowBox[{"points", "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "1"}], "]"}], "]"}]}], ";", 
  RowBox[{"ypoints", "=", 
   RowBox[{"points", "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2"}], "]"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.481168711203125*^9, 3.48116873875*^9}, {
   3.481168784109375*^9, 3.48116878440625*^9}, {3.481257990609375*^9, 
   3.481257994953125*^9}, 3.481258050171875*^9, 3.481258115453125*^9, {
   3.48125833725*^9, 3.481258343921875*^9}, {3.4855793566875*^9, 
   3.48557935909375*^9}, 3.485599654328125*^9, {3.560440272860049*^9, 
   3.560440297408477*^9}}],

Cell["\<\
We define the i-th third-degree polynomial with its first and second \
derivatives\
\>", "Text",
 CellChangeTimes->{{3.481258169046875*^9, 3.481258191015625*^9}, {
   3.4812589095625*^9, 3.48125891409375*^9}, {3.485583333921875*^9, 
   3.4855834316875*^9}, {3.48619287126575*^9, 3.486192877139627*^9}, 
   3.560440558979886*^9, 3.560442903483376*^9},
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"Splinek", "[", 
   RowBox[{"k_Integer", ",", "x_"}], "]"}], ":=", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"s0", "[", "k", "]"}], " ", "+", " ", 
   RowBox[{
    RowBox[{"s1", "[", "k", "]"}], " ", 
    RowBox[{"(", 
     RowBox[{"x", "-", 
      RowBox[{"xpoints", "[", 
       RowBox[{"[", "k", "]"}], "]"}]}], ")"}]}], " ", "+", 
   RowBox[{
    RowBox[{"s2", "[", "k", "]"}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"x", "-", 
       RowBox[{"xpoints", "[", 
        RowBox[{"[", "k", "]"}], "]"}]}], ")"}], "2"]}], "+", 
   RowBox[{
    RowBox[{"s3", "[", "k", "]"}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"x", "-", 
       RowBox[{"xpoints", "[", 
        RowBox[{"[", "k", "]"}], "]"}]}], ")"}], "3"]}]}]}]], "Input",
 CellChangeTimes->{{3.4810257514375*^9, 3.481025780328125*^9}, 
   3.48102585075*^9, 3.481028596953125*^9, 3.481258263109375*^9, {
   3.485581277453125*^9, 3.48558130740625*^9}, {3.486192831087728*^9, 
   3.4861928332235394`*^9}, {3.4867365116133423`*^9, 
   3.4867365694025383`*^9}, {3.486736599654405*^9, 3.486736621229403*^9}, {
   3.486736860025666*^9, 3.48673693376058*^9}, {3.486736983053804*^9, 
   3.486736990316464*^9}, {3.560442913972138*^9, 3.560442916474089*^9}, {
   3.560452677998627*^9, 3.560452717502199*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"SplinekD1", "[", 
   RowBox[{"k_Integer", ",", "x_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"s1", "[", "k", "]"}], " ", "+", " ", 
   RowBox[{"2", 
    RowBox[{"s2", "[", "k", "]"}], " ", 
    RowBox[{"(", 
     RowBox[{"x", "-", 
      RowBox[{"xpoints", "[", 
       RowBox[{"[", "k", "]"}], "]"}]}], ")"}]}], "+", " ", 
   RowBox[{"3", 
    RowBox[{"s3", "[", "k", "]"}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"x", "-", 
       RowBox[{"xpoints", "[", 
        RowBox[{"[", "k", "]"}], "]"}]}], ")"}], "2"]}]}]}]], "Input",
 CellChangeTimes->{
  3.4810257514375*^9, {3.481258305578125*^9, 3.481258306015625*^9}, {
   3.485581285953125*^9, 3.485581299390625*^9}, {3.486192844303831*^9, 
   3.486192845727736*^9}, {3.486736546657803*^9, 3.486736583214348*^9}, {
   3.486736626867426*^9, 3.486736681239847*^9}, {3.486736946950328*^9, 
   3.486736955115497*^9}, {3.4867369948881063`*^9, 3.4867370000440903`*^9}, {
   3.560442924142695*^9, 3.5604429343918*^9}, {3.56045259467756*^9, 
   3.560452616498255*^9}, {3.560452709691867*^9, 3.560452712883379*^9}, 
   3.56045277729163*^9, {3.560452824864834*^9, 3.560452831124082*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"SplinekD2", "[", 
   RowBox[{"k_Integer", ",", "x_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"2", " ", 
    RowBox[{"s2", "[", "k", "]"}]}], " ", "+", " ", 
   RowBox[{"6", " ", 
    RowBox[{"s3", "[", "k", "]"}], 
    RowBox[{"(", 
     RowBox[{"x", "-", 
      RowBox[{"xpoints", "[", 
       RowBox[{"[", "k", "]"}], "]"}]}], ")"}]}]}]}]], "Input",
 CellChangeTimes->{{3.560452833421798*^9, 3.56045283667159*^9}}],

Cell[CellGroupData[{

Cell["Part I", "Section",
 CellChangeTimes->{{3.481257998609375*^9, 3.481257999875*^9}, {
  3.48125838840625*^9, 3.48125841678125*^9}, {3.48133765459375*^9, 
  3.481337701859375*^9}, {3.4855832109375*^9, 3.48558321753125*^9}, {
  3.5726816507562313`*^9, 3.5726816509732437`*^9}},
 FontSize->36,
 FontColor->RGBColor[0, 0, 1],
 Background->RGBColor[1, 0.9, 0.8],
 CellTags->"Part A"],

Cell[TextData[{
 "We impose the conditions\n\n",
 Cell[BoxData[
  FormBox[
   SubscriptBox["S", "k"], TraditionalForm]]],
 "(",
 Cell[BoxData[
  FormBox[
   SubscriptBox["x", "k"], TraditionalForm]]],
 ") = ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["y", "k"], TraditionalForm]]],
 "    with k = 1,2,3,4,5 \n\nand\n\n",
 Cell[BoxData[
  FormBox[
   SubscriptBox["S", "k"], TraditionalForm]]],
 "(",
 Cell[BoxData[
  FormBox[
   SubscriptBox["x", 
    RowBox[{"k", "+", "1"}]], TraditionalForm]]],
 ") = ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["y", 
    RowBox[{"k", "+", "1", "   "}]], TraditionalForm]]],
 "with k = 1,2,3,4,5"
}], "Text",
 CellChangeTimes->{{3.481257998609375*^9, 3.481257999875*^9}, {
   3.48125838840625*^9, 3.48125841678125*^9}, 3.485579361109375*^9, {
   3.485583558609375*^9, 3.485583561671875*^9}, {3.485583665390625*^9, 
   3.48558382215625*^9}, {3.48559560103125*^9, 3.485595619140625*^9}, {
   3.4867018311803102`*^9, 3.4867018641753407`*^9}, {3.48670189515548*^9, 
   3.486701895330472*^9}, {3.560440901823851*^9, 3.560440913538362*^9}},
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"tab1", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Splinek", "[", 
       RowBox[{"i", ",", 
        RowBox[{"x", "[", "i", "]"}]}], "]"}], "\[Equal]", 
      RowBox[{"y", "[", "i", "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", 
       RowBox[{"numpoints", "-", "1"}]}], "}"}]}], "]"}]}], ";", 
  RowBox[{"tab1", "//", "Column"}]}]], "Input",
 CellChangeTimes->{{3.48102580940625*^9, 3.4810258294375*^9}, 
   3.481258266078125*^9, {3.485581328765625*^9, 3.485581331640625*^9}, {
   3.4856099461875*^9, 3.485609946625*^9}, 3.486217333671915*^9, {
   3.486217685794669*^9, 3.486217691740452*^9}, {3.560441677612932*^9, 
   3.560441709397636*^9}, {3.560452725503032*^9, 3.560452727818899*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"tab2", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Splinek", "[", 
       RowBox[{"i", ",", 
        RowBox[{"x", "[", 
         RowBox[{"i", "+", "1"}], "]"}]}], "]"}], "\[Equal]", 
      RowBox[{"y", "[", 
       RowBox[{"i", "+", "1"}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", 
       RowBox[{"numpoints", "-", "1"}]}], "}"}]}], "]"}]}], ";", " ", 
  RowBox[{"tab2", "//", "Column"}]}]], "Input",
 CellChangeTimes->{{3.481028654125*^9, 3.481028657921875*^9}, 
   3.481258266609375*^9, {3.48558133534375*^9, 3.485581339140625*^9}, {
   3.485609949359375*^9, 3.48560994978125*^9}, 3.486217375733328*^9, {
   3.486217697711337*^9, 3.48621769957086*^9}, {3.560441712583369*^9, 
   3.560441717153493*^9}, {3.560452732367831*^9, 3.560452733519765*^9}}],

Cell["We put together the previous equations", "Text",
 CellChangeTimes->{{3.481168880640625*^9, 3.4811688860625*^9}, 
   3.481258479625*^9, {3.48558390334375*^9, 3.485583920515625*^9}, {
   3.486128414643187*^9, 3.486128417771188*^9}},
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"equaz", "=", 
   RowBox[{"Join", "[", 
    RowBox[{"tab1", ",", "tab2"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.486217719512596*^9, 3.486217783090219*^9}, {
  3.560440977335521*^9, 3.560441027604613*^9}}],

Cell["\<\
We impose the continuity conditions for the first and second derivative at \
the internal points\
\>", "Text",
 CellChangeTimes->{{3.481258428046875*^9, 3.481258430125*^9}, {
   3.481258611578125*^9, 3.481258646203125*^9}, {3.48125898009375*^9, 
   3.481258986796875*^9}, {3.48558393840625*^9, 3.485583991015625*^9}, 
   3.4861285859639673`*^9, {3.560441030362773*^9, 3.560441030802447*^9}},
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"tab3", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"SplinekD1", "[", 
       RowBox[{"i", ",", 
        RowBox[{"x", "[", "i", "]"}]}], "]"}], "\[Equal]", 
      RowBox[{"SplinekD1", "[", 
       RowBox[{
        RowBox[{"i", "-", "1"}], ",", 
        RowBox[{"x", "[", "i", "]"}]}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "2", ",", 
       RowBox[{"numpoints", "-", "1"}]}], "}"}]}], "]"}]}], ";", 
  RowBox[{"tab3", "//", "Column"}]}]], "Input",
 CellChangeTimes->{{3.48102580940625*^9, 3.4810258294375*^9}, 
   3.481258266078125*^9, {3.485581328765625*^9, 3.485581331640625*^9}, {
   3.4856099461875*^9, 3.485609946625*^9}, 3.486217333671915*^9, {
   3.486217685794669*^9, 3.486217691740452*^9}, {3.4863646530022173`*^9, 
   3.4863646916061697`*^9}, {3.56044177967339*^9, 3.560441783359059*^9}, {
   3.560452740673521*^9, 3.560452745944285*^9}, {3.560582782462014*^9, 
   3.560582785126947*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"tab4", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"SplinekD2", "[", 
       RowBox[{"i", ",", 
        RowBox[{"x", "[", "i", "]"}]}], "]"}], "\[Equal]", 
      RowBox[{"SplinekD2", "[", 
       RowBox[{
        RowBox[{"i", "-", "1"}], ",", 
        RowBox[{"x", "[", "i", "]"}]}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "2", ",", 
       RowBox[{"numpoints", "-", "1"}]}], "}"}]}], "]"}]}], ";", 
  RowBox[{"tab4", "//", "Column"}]}]], "Input",
 CellChangeTimes->{{3.48102580940625*^9, 3.4810258294375*^9}, 
   3.481258266078125*^9, {3.485581328765625*^9, 3.485581331640625*^9}, {
   3.4856099461875*^9, 3.485609946625*^9}, 3.486217333671915*^9, {
   3.486217685794669*^9, 3.486217691740452*^9}, {3.4863646530022173`*^9, 
   3.4863646916061697`*^9}, {3.486364753311594*^9, 3.486364760682445*^9}, {
   3.56044178713431*^9, 3.560441791079743*^9}, {3.560452850550837*^9, 
   3.560452856128634*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"equaz", "=", 
   RowBox[{"Join", "[", 
    RowBox[{"equaz", ",", "tab3", ",", "tab4"}], "]"}]}], ";", 
  RowBox[{"Length", "[", "equaz", "]"}]}]], "Input",
 CellChangeTimes->{{3.486217719512596*^9, 3.486217783090219*^9}, {
   3.486365123188199*^9, 3.486365136305236*^9}, 3.4864739699444857`*^9, {
   3.486474033447693*^9, 3.4864741117598877`*^9}, {3.4864745588401337`*^9, 
   3.486474563521443*^9}, {3.486474614500966*^9, 3.486474622242896*^9}, {
   3.4864747023164062`*^9, 3.486474706059621*^9}, {3.560441801794491*^9, 
   3.560441821700316*^9}, {3.560441886652292*^9, 3.560441887964549*^9}, {
   3.560452862740119*^9, 3.560452865679714*^9}}],

Cell["\<\
We add the conditions to obtain the natural spline (that is, the second \
derivatives are set to zero at the end points)\
\>", "Text",
 CellChangeTimes->{{3.481258428046875*^9, 3.481258430125*^9}, {
  3.481258611578125*^9, 3.48125869225*^9}, {3.4855839986875*^9, 
  3.485584087015625*^9}, {3.48558491565625*^9, 3.48558492275*^9}, {
  3.560441827116551*^9, 3.560441827714529*^9}},
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"equaz", "=", 
   RowBox[{"Join", "[", 
    RowBox[{"equaz", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"SplinekD2", "[", 
         RowBox[{"1", ",", 
          RowBox[{"x", "[", "1", "]"}]}], "]"}], " ", "\[Equal]", " ", "0"}], 
       ",", 
       RowBox[{
        RowBox[{"SplinekD2", "[", 
         RowBox[{
          RowBox[{"numpoints", "-", "1"}], ",", 
          RowBox[{"x", "[", "numpoints", "]"}]}], "]"}], " ", "\[Equal]", " ",
         "0"}]}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{
  3.481025800453125*^9, 3.48102862415625*^9, {3.48125805175*^9, 
   3.481258052265625*^9}, {3.48125830865625*^9, 3.481258309171875*^9}, 
   3.4812584808125*^9, {3.485581381390625*^9, 3.48558139834375*^9}, {
   3.485599657015625*^9, 3.485599657578125*^9}, {3.560441912955468*^9, 
   3.560441948085501*^9}, {3.560452911733042*^9, 3.560452918326156*^9}}],

Cell["We have assembled all the conditions", "Text",
 CellChangeTimes->{{3.481258428046875*^9, 3.481258430125*^9}, {
   3.481258611578125*^9, 3.48125869225*^9}, {3.4855839986875*^9, 
   3.485584087015625*^9}, {3.48558412878125*^9, 3.485584136015625*^9}, 
   3.486220289556675*^9, {3.48636342111878*^9, 3.486363432393417*^9}, {
   3.4869026539047823`*^9, 3.486902655419804*^9}},
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{"equaz", "//", "Column"}]], "Input",
 CellChangeTimes->{
  3.481025800453125*^9, 3.48102862415625*^9, {3.481253057953125*^9, 
   3.481253067421875*^9}, {3.48125848153125*^9, 3.481258482109375*^9}, {
   3.560441973627579*^9, 3.560441975347063*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Part II", "Section",
 CellChangeTimes->{{3.481257998609375*^9, 3.481257999875*^9}, {
   3.48125838840625*^9, 3.48125841678125*^9}, {3.48133765459375*^9, 
   3.481337701859375*^9}, {3.4855832109375*^9, 3.48558321753125*^9}, {
   3.485584935421875*^9, 3.48558493609375*^9}, 3.4866520700107718`*^9, 
   3.486652121680141*^9, {3.5726816864042706`*^9, 3.572681686708288*^9}},
 FontSize->36,
 FontColor->RGBColor[0, 0, 1],
 Background->RGBColor[1, 0.9, 0.8],
 CellTags->"Part B"],

Cell["\<\
We solve the system using the numerical values fot the points\
\>", "Text",
 CellChangeTimes->{{3.481258428046875*^9, 3.481258430125*^9}, {
   3.481258611578125*^9, 3.48125869225*^9}, {3.4855839986875*^9, 
   3.485584087015625*^9}, {3.48558412878125*^9, 3.485584136015625*^9}, 
   3.486220289556675*^9, {3.48636342111878*^9, 3.486363432393417*^9}, {
   3.4869026539047823`*^9, 3.486902655419804*^9}, {3.560442024823437*^9, 
   3.560442045649098*^9}, {3.560442292215493*^9, 3.560442294476576*^9}},
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"pointrule", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"x", "[", "i", "]"}], "\[Rule]", 
         RowBox[{"xpoints", "[", 
          RowBox[{"[", "i", "]"}], "]"}]}], ",", 
        RowBox[{
         RowBox[{"y", "[", "i", "]"}], "\[Rule]", 
         RowBox[{"ypoints", "[", 
          RowBox[{"[", "i", "]"}], "]"}]}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "numpoints"}], "}"}]}], "]"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{
  3.481025800453125*^9, 3.48102862415625*^9, {3.481253057953125*^9, 
   3.481253067421875*^9}, {3.48125848153125*^9, 3.481258482109375*^9}, {
   3.486475254829937*^9, 3.486475367140348*^9}, {3.486475602303331*^9, 
   3.486475606790205*^9}, {3.486475731145455*^9, 3.486475764426319*^9}, {
   3.4864758123348618`*^9, 3.486475816267816*^9}, {3.486476352228588*^9, 
   3.486476369016283*^9}, {3.486476415942169*^9, 3.4864764199709377`*^9}, {
   3.486476584765547*^9, 3.4864766053888493`*^9}, {3.486476652953957*^9, 
   3.4864766639058943`*^9}, {3.486476700748397*^9, 3.4864767185256233`*^9}, 
   3.486476908096891*^9, {3.560442332362879*^9, 3.56044234040553*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"solution", "=", 
   RowBox[{"Solve", "[", 
    RowBox[{"equaz", "/.", "pointrule"}], "]"}]}], ";", 
  RowBox[{
   RowBox[{"solution", "[", 
    RowBox[{"[", "1", "]"}], "]"}], "//", "Column"}]}]], "Input",
 CellChangeTimes->{{3.48137244821875*^9, 3.481372501875*^9}, 
   3.485610128140625*^9, {3.4856101671875*^9, 3.48561020996875*^9}, {
   3.48613080131485*^9, 3.486130849820629*^9}, {3.4864758547805147`*^9, 
   3.4864758690279303`*^9}, {3.486476948475902*^9, 3.48647695904475*^9}, {
   3.486476999921118*^9, 3.486477014309394*^9}, {3.4867379814588823`*^9, 
   3.486737986668706*^9}, {3.560442343781273*^9, 3.56044234796222*^9}, {
   3.560442405716942*^9, 3.560442438534679*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Part III", "Section",
 CellChangeTimes->{{3.481257998609375*^9, 3.481257999875*^9}, {
  3.48125838840625*^9, 3.48125841678125*^9}, {3.48133765459375*^9, 
  3.481337701859375*^9}, {3.4855832109375*^9, 3.48558321753125*^9}, {
  3.485584935421875*^9, 3.48558493609375*^9}, {3.48558568240625*^9, 
  3.485585683046875*^9}, {3.572681687564337*^9, 3.572681688596396*^9}},
 FontSize->36,
 FontColor->RGBColor[0, 0, 1],
 Background->RGBColor[1, 0.9, 0.8],
 CellTags->"Part C"],

Cell["We construct the polynomial representation on each domain", "Text",
 CellChangeTimes->{{3.56045298682974*^9, 3.560452998170805*^9}},
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"Spline", "[", 
   RowBox[{"i_", ",", "x_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"Splinek", "[", 
    RowBox[{"i", ",", "x"}], "]"}], "/.", 
   RowBox[{"Flatten", "[", "solution", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.478864388375*^9, 3.4788644106875*^9}, {
   3.48136997090625*^9, 3.481370036875*^9}, {3.481370352015625*^9, 
   3.48137039659375*^9}, {3.481370456953125*^9, 3.48137048196875*^9}, {
   3.481370537609375*^9, 3.481370538359375*^9}, {3.485581646671875*^9, 
   3.485581659984375*^9}, 3.48558238965625*^9, 3.485599660765625*^9, {
   3.4866502735700808`*^9, 3.486650281382329*^9}, {3.48665034982545*^9, 
   3.486650383486067*^9}, {3.4866504400677223`*^9, 3.486650476918561*^9}, 
   3.486650525287737*^9, 3.486650586764394*^9, {3.560453060160716*^9, 
   3.560453064682354*^9}, {3.560453114045724*^9, 3.560453141884013*^9}, {
   3.560453335521559*^9, 3.560453338881849*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"Spline", "[", 
     RowBox[{"i", ",", "x"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", 
      RowBox[{"numpoints", "-", "2"}]}], "}"}]}], "]"}], "//", 
  "Column"}]], "Input",
 CellChangeTimes->{{3.486648764645464*^9, 3.486648800347858*^9}, {
  3.486650607179964*^9, 3.486650612811702*^9}, {3.486651254235032*^9, 
  3.486651257778431*^9}, {3.560453118730633*^9, 3.560453122298453*^9}, {
  3.560453161486095*^9, 3.560453210341862*^9}}],

Cell["We check the interpolation conditions", "Text",
 CellChangeTimes->{{3.560453260280023*^9, 3.560453270012649*^9}, 
   3.560453678545815*^9},
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"Spline", "[", 
     RowBox[{"i", ",", 
      RowBox[{"xpoints", "[", 
       RowBox[{"[", "i", "]"}], "]"}]}], "]"}], "\[Equal]", 
    RowBox[{"ypoints", "[", 
     RowBox[{"[", "i", "]"}], "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"i", ",", 
     RowBox[{"numpoints", "-", "1"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.486648764645464*^9, 3.486648800347858*^9}, {
  3.486650607179964*^9, 3.486650612811702*^9}, {3.48665065459324*^9, 
  3.4866507073940077`*^9}, {3.560453239308821*^9, 3.560453255780783*^9}}],

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"Spline", "[", 
     RowBox[{"i", ",", 
      RowBox[{"xpoints", "[", 
       RowBox[{"[", 
        RowBox[{"i", "+", "1"}], "]"}], "]"}]}], "]"}], "\[Equal]", 
    RowBox[{"ypoints", "[", 
     RowBox[{"[", 
      RowBox[{"i", "+", "1"}], "]"}], "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"i", ",", 
     RowBox[{"numpoints", "-", "1"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.486648764645464*^9, 3.486648800347858*^9}, {
  3.486650607179964*^9, 3.486650612811702*^9}, {3.48665065459324*^9, 
  3.4866507073940077`*^9}, {3.486650746338719*^9, 3.48665074699219*^9}, {
  3.560453282016647*^9, 3.560453294966141*^9}}],

Cell["We reconstruct the interpolating spline", "Text",
 CellChangeTimes->{{3.481258169046875*^9, 3.481258191015625*^9}, {
  3.4812589095625*^9, 3.48125891409375*^9}, {3.485583333921875*^9, 
  3.4855834316875*^9}, {3.48619287126575*^9, 3.486192877139627*^9}, {
  3.4867394848399982`*^9, 3.486739500179656*^9}, {3.560453299399889*^9, 
  3.560453332550001*^9}},
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"S", "[", "x_", "]"}], "=", 
   RowBox[{"Sum", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Spline", "[", 
       RowBox[{"i", ",", "x"}], "]"}], "*", 
      RowBox[{"(", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"xpoints", "[", 
           RowBox[{"[", "i", "]"}], "]"}], "\[LessEqual]", " ", "x", " ", 
          "\[LessEqual]", " ", 
          RowBox[{"xpoints", "[", 
           RowBox[{"[", 
            RowBox[{"i", "+", "1"}], "]"}], "]"}]}], ",", "1", ",", "0"}], 
        "]"}], ")"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", 
       RowBox[{"numpoints", "-", "1"}]}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.478864388375*^9, 3.4788644106875*^9}, {
   3.48137068846875*^9, 3.481370755921875*^9}, {3.48557936578125*^9, 
   3.48557936625*^9}, {3.48558166575*^9, 3.485581668421875*^9}, 
   3.485599661890625*^9, {3.486739292292282*^9, 3.486739295276779*^9}, {
   3.4867395395208597`*^9, 3.48673954364093*^9}, {3.486739770190029*^9, 
   3.486739772614367*^9}, {3.560453348357019*^9, 3.560453353061451*^9}}],

Cell["And plot the result", "Text",
 CellChangeTimes->{{3.481258169046875*^9, 3.481258191015625*^9}, {
  3.4812589095625*^9, 3.48125891409375*^9}, {3.485583333921875*^9, 
  3.4855834316875*^9}, {3.48619287126575*^9, 3.486192877139627*^9}, {
  3.4867394848399982`*^9, 3.486739500179656*^9}, {3.560453299399889*^9, 
  3.560453332550001*^9}, {3.56045337054767*^9, 3.560453374716021*^9}},
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"graspline", "=", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"S", "[", "x", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"xpoints", "[", 
        RowBox[{"[", "1", "]"}], "]"}], ",", 
       RowBox[{"xpoints", "[", 
        RowBox[{"[", "numpoints", "]"}], "]"}]}], "}"}]}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{
  3.478176561*^9, {3.47886444053125*^9, 3.4788644661875*^9}, {
   3.48137080265625*^9, 3.48137082796875*^9}, {3.4813708694375*^9, 
   3.481370875625*^9}, {3.48557936825*^9, 3.48557936871875*^9}, {
   3.485586639046875*^9, 3.485586652265625*^9}, 3.48559966340625*^9, {
   3.560453382768798*^9, 3.560453517499179*^9}}],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"graspline", ",", "grapoints"}], "]"}]], "Input",
 CellChangeTimes->{{3.560453469645726*^9, 3.56045351043243*^9}}]
}, Open  ]]
},
AutoGeneratedPackage->None,
WindowSize->{1904, 946},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
PrintingOptions->{"PrintCellBrackets"->True,
"PrintMultipleHorizontalPages"->False,
"PrintRegistrationMarks"->True,
"PrintingMargins"->{{54, 54}, {54, 54}}},
ShowSelection->True,
Magnification->1.5,
FrontEndVersion->"8.0 for Microsoft Windows (64-bit) (February 23, 2011)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "Part A"->{
  Cell[11646, 313, 382, 8, 139, "Section",
   CellTags->"Part A"]},
 "Part B"->{
  Cell[20414, 543, 479, 9, 139, "Section",
   CellTags->"Part B"]},
 "Part C"->{
  Cell[23446, 614, 473, 9, 139, "Section",
   CellTags->"Part C"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"Part A", 30431, 796},
 {"Part B", 30512, 799},
 {"Part C", 30593, 802}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[557, 20, 213, 7, 132, "Text"],
Cell[773, 29, 4073, 107, 753, "Text"],
Cell[4849, 138, 453, 8, 43, "Input"],
Cell[5305, 148, 100, 1, 43, "Input"],
Cell[5408, 151, 118, 2, 43, "Input"],
Cell[5529, 155, 1022, 24, 43, "Input"],
Cell[6554, 181, 442, 7, 43, "Input"],
Cell[6999, 190, 502, 10, 43, "Input"],
Cell[7504, 202, 97, 1, 65, "Text"],
Cell[7604, 205, 656, 15, 43, "Input"],
Cell[8263, 222, 390, 8, 65, "Text"],
Cell[8656, 232, 1330, 33, 72, "Input"],
Cell[9989, 267, 1180, 27, 45, "Input"],
Cell[11172, 296, 449, 13, 43, "Input"],
Cell[CellGroupData[{
Cell[11646, 313, 382, 8, 139, "Section",
 CellTags->"Part A"],
Cell[12031, 323, 1102, 35, 214, "Text"],
Cell[13136, 360, 767, 18, 43, "Input"],
Cell[13906, 380, 832, 20, 43, "Input"],
Cell[14741, 402, 266, 4, 65, "Text"],
Cell[15010, 408, 249, 6, 43, "Input"],
Cell[15262, 416, 431, 8, 65, "Text"],
Cell[15696, 426, 981, 23, 43, "Input"],
Cell[16680, 451, 981, 23, 43, "Input"],
Cell[17664, 476, 678, 12, 43, "Input"],
Cell[18345, 490, 419, 8, 65, "Text"],
Cell[18767, 500, 927, 23, 43, "Input"],
Cell[19697, 525, 407, 6, 65, "Text"],
Cell[20107, 533, 270, 5, 43, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[20414, 543, 479, 9, 139, "Section",
 CellTags->"Part B"],
Cell[20896, 554, 536, 9, 65, "Text"],
Cell[21435, 565, 1255, 28, 43, "Input"],
Cell[22693, 595, 716, 14, 43, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[23446, 614, 473, 9, 139, "Section",
 CellTags->"Part C"],
Cell[23922, 625, 168, 2, 65, "Text"],
Cell[24093, 629, 922, 17, 43, "Input"],
Cell[25018, 648, 520, 13, 43, "Input"],
Cell[25541, 663, 175, 3, 65, "Text"],
Cell[25719, 668, 595, 15, 43, "Input"],
Cell[26317, 685, 699, 18, 43, "Input"],
Cell[27019, 705, 389, 6, 65, "Text"],
Cell[27411, 713, 1137, 28, 43, "Input"],
Cell[28551, 743, 414, 6, 65, "Text"],
Cell[28968, 751, 710, 18, 43, "Input"],
Cell[29681, 771, 161, 3, 43, "Input"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
