(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[    464546,       9022]
NotebookOptionsPosition[    456219,       8749]
NotebookOutlinePosition[    456636,       8767]
CellTagsIndexPosition[    456593,       8764]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["\<\
Evaluation time:
\[CapitalDelta]t < 5 s\
\>", "Text",
 CellChangeTimes->{
  3.484992245703125*^9, {3.484992316015625*^9, 3.4849923314375*^9}, {
   3.48499253890625*^9, 3.484992628625*^9}, {3.484994235171875*^9, 
   3.484994236890625*^9}, {3.48499689084375*^9, 3.48499689559375*^9}, {
   3.48767985275*^9, 3.4876798598125*^9}, {3.560539989233566*^9, 
   3.5605399935075*^9}, {3.572683149268942*^9, 3.572683161356633*^9}},
 FontSize->18,
 FontColor->RGBColor[0, 0, 1],
 Background->RGBColor[1, 0.9, 0.8]],

Cell[TextData[{
 StyleBox["Interpolation using B-splines of order 3 (i.e. degree 2)\n\n",
  FontSize->24,
  FontWeight->"Bold"],
 StyleBox["Warning! \nIn Section 6.4, it is clearly stated that   ",
  FontWeight->"Bold",
  FontColor->RGBColor[0.5, 0, 0.5]],
 StyleBox["order ",
  FontWeight->"Bold",
  FontSlant->"Italic",
  FontColor->RGBColor[0.5, 0, 0.5]],
 StyleBox["=",
  FontWeight->"Bold",
  FontColor->RGBColor[0.5, 0, 0.5]],
 StyleBox[" degree",
  FontWeight->"Bold",
  FontSlant->"Italic",
  FontColor->RGBColor[0.5, 0, 0.5]],
 StyleBox[" + 1. \nIn ",
  FontWeight->"Bold",
  FontColor->RGBColor[0.5, 0, 0.5]],
 StyleBox["Mathematica,",
  FontWeight->"Bold",
  FontSlant->"Italic",
  FontColor->RGBColor[0.5, 0, 0.5]],
 StyleBox[" the command ",
  FontWeight->"Bold",
  FontColor->RGBColor[0.5, 0, 0.5]],
 StyleBox["InterpolationOrder",
  FontWeight->"Bold",
  FontSlant->"Italic",
  FontColor->RGBColor[0.5, 0, 0.5]],
 StyleBox[" refers to the degree of the interpolating polynomial,\ntherefore, \
 ",
  FontWeight->"Bold",
  FontColor->RGBColor[0.5, 0, 0.5]],
 StyleBox["InterpolationOrder \[Rule] 2",
  FontFamily->"Courier"],
 StyleBox["  considers",
  FontWeight->"Bold",
  FontColor->RGBColor[0.5, 0, 0.5]],
 StyleBox[" parabolae, etc.",
  FontWeight->"Bold",
  FontSlant->"Italic",
  FontColor->RGBColor[0.5, 0, 0.5]],
 StyleBox["\n",
  FontWeight->"Bold",
  FontColor->RGBColor[0.5, 0, 0.5]],
 "\n",
 StyleBox["Introduction",
  FontSize->16,
  FontSlant->"Italic"],
 "\n\nThe main purpose of this nb is to examine the properties of the \
functions  ",
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["B", "i", "3"], TraditionalForm]]],
 "(x) (B-spline of third order, second degree).\n\nTo this end,   by means of \
the expression\n\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"S", "(", "x", ")"}], " ", "=", " ", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"i", "=", "1"}], "M"], 
     RowBox[{
      SubscriptBox["\[Alpha]", "i"], " ", 
      RowBox[{
       SubsuperscriptBox["B", "i", "3"], "(", "x", ")"}]}]}]}], 
   TraditionalForm]]],
 ",  \n\nwe interpolate the same set of points {",
 Cell[BoxData[
  FormBox[
   SubscriptBox["x", 
    RowBox[{"i", ","}]], TraditionalForm]]],
 " ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["f", "i"], TraditionalForm]]],
 "} given in the text (Chapter \\ref{chap:splines}, Section \
\\ref{subsec:uniform-cubic}).\n\n In the first section we use the command \n \
\n ",
 StyleBox["parabolicSpline =  Interpolation[points, InterpolationOrder \
\[Rule] 2, Method \[Rule] \"Spline\"]",
  FontFamily->"Courier"],
 "\n\nIn the second section we access  the information contained in  \
parabolicSpline, that is, the coefficients ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Alpha]", "i"], TraditionalForm]]],
 " of the splines and the set of knots.\n              \nIn the third  \
section we extract the polynomial representation of each Bspline and \
reconstruct the complete spline.\n\nIn the fourth  section we check the ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["C", "1"], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["C", "2"], TraditionalForm]]],
 "  and the boundary conditions of S(x).\n         \nIn the fifth  section we \
check that our reconstruction coincides with the one given by Mathematica.\n"
}], "Text",
 CellChangeTimes->{{3.4822342910645547`*^9, 3.4822343209855466`*^9}, {
   3.4827529496875*^9, 3.482752986359375*^9}, {3.482753058375*^9, 
   3.48275329565625*^9}, {3.482754376203125*^9, 3.4827544480625*^9}, {
   3.48275486803125*^9, 3.482754928265625*^9}, {3.482755560515625*^9, 
   3.48275556246875*^9}, {3.4827556411875*^9, 3.48275569015625*^9}, {
   3.48351817559375*^9, 3.483518182875*^9}, {3.483518280890625*^9, 
   3.4835183170625*^9}, {3.484914080453125*^9, 3.48491409403125*^9}, {
   3.484982273*^9, 3.484982330890625*^9}, {3.48499031065625*^9, 
   3.48499031225*^9}, {3.484991693046875*^9, 3.4849918995*^9}, {
   3.484991929671875*^9, 3.484992071828125*^9}, {3.484992112015625*^9, 
   3.48499219953125*^9}, {3.484992274671875*^9, 3.484992288953125*^9}, {
   3.48499252521875*^9, 3.48499252659375*^9}, {3.484992681984375*^9, 
   3.484992822796875*^9}, {3.4849957348125*^9, 3.4849958199375*^9}, {
   3.484996916859375*^9, 3.484997034578125*^9}, {3.484998766484375*^9, 
   3.484998831421875*^9}, {3.484999638984375*^9, 3.48499968971875*^9}, {
   3.484999752609375*^9, 3.4849998213125*^9}, {3.485845938390625*^9, 
   3.485845955046875*^9}, 3.486032339453125*^9, {3.486037365875*^9, 
   3.48603750078125*^9}, {3.486037535953125*^9, 3.486037636859375*^9}, {
   3.48603782975*^9, 3.48603789246875*^9}, 3.486037925296875*^9, 
   3.48603796115625*^9, {3.486038164078125*^9, 3.486038197546875*^9}, {
   3.486038247203125*^9, 3.486038345859375*^9}, {3.486038501484375*^9, 
   3.486038610640625*^9}, {3.48603864065625*^9, 3.486038657*^9}, {
   3.486038689890625*^9, 3.48603873975*^9}, {3.486038935171875*^9, 
   3.486039040234375*^9}, 3.48767391171875*^9, {3.487674100546875*^9, 
   3.48767410190625*^9}, 3.48767422915625*^9, {3.487674321171875*^9, 
   3.487674338859375*^9}, {3.487679923796875*^9, 3.487680016453125*^9}, {
   3.560539123899595*^9, 3.560539175993996*^9}, {3.560539245033219*^9, 
   3.560539266249639*^9}, {3.560539807589909*^9, 3.560539897319377*^9}, {
   3.560539928614897*^9, 3.560539936182129*^9}, {3.572682995818165*^9, 
   3.57268300098246*^9}, {3.5726832293225203`*^9, 3.572683230621595*^9}, {
   3.5759820885876875`*^9, 3.5759821324191947`*^9}, {3.5759821938517084`*^9, 
   3.575982416195426*^9}, {3.5771145566773157`*^9, 3.577114605384102*^9}, {
   3.577455456006997*^9, 3.577455579496814*^9}, 3.5777004872100897`*^9, {
   3.5777005308190737`*^9, 3.577700572484064*^9}, {3.577700737642572*^9, 
   3.577700759298161*^9}, {3.577700803323374*^9, 3.577700815984679*^9}, 
   3.577700851907233*^9, {3.57770104517517*^9, 3.5777011228729143`*^9}, {
   3.577701198090828*^9, 3.5777012040804253`*^9}, {3.5777012388769083`*^9, 
   3.577701392484387*^9}, {3.577701616682128*^9, 3.577701618868987*^9}},
 FontFamily->"Times New Roman",
 FontColor->RGBColor[0, 0, 1],
 Background->RGBColor[1, 1, 0.85]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Remove", "[", "\"\<Global`*\>\"", "]"}], ";", 
  RowBox[{"$Line", "=", "0"}], ";"}]], "Input",
 CellChangeTimes->{{3.48351269165625*^9, 3.48351271565625*^9}, {
  3.507637742033667*^9, 3.507637746368614*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Remove", "::", "rmnsm"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"There are no symbols matching \
\\\"\[NoBreak]\\!\\(\\\"Global`*\\\"\\)\[NoBreak]\\\". \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/Remove/rmnsm\\\", \
ButtonNote -> \\\"Remove::rmnsm\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.577701408913793*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Date", "[", "]"}]], "Input",
 CellChangeTimes->{{3.5076377665006247`*^9, 3.50763776796949*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "2013", ",", "5", ",", "16", ",", "15", ",", "56", ",", 
   "49.02735`8.443013395423455"}], "}"}]], "Output",
 CellChangeTimes->{3.577701409050252*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["$Version"], "Input",
 CellChangeTimes->{{3.5076377504385023`*^9, 3.507637752584931*^9}}],

Cell[BoxData["\<\"9.0 for Linux x86 (64-bit) (January 24, 2013)\"\>"], \
"Output",
 CellChangeTimes->{3.577701409097273*^9}]
}, Open  ]],

Cell["Part I", "Text",
 CellChangeTimes->{
  3.484992245703125*^9, {3.484992316015625*^9, 3.4849923314375*^9}, {
   3.48499253890625*^9, 3.484992628625*^9}, {3.484994235171875*^9, 
   3.484994236890625*^9}, {3.48499689084375*^9, 3.48499689559375*^9}, {
   3.48767985275*^9, 3.4876798598125*^9}, {3.560539989233566*^9, 
   3.5605399935075*^9}, {3.572683032405257*^9, 3.5726830337403336`*^9}},
 FontFamily->"Times New Roman",
 FontSize->36,
 FontColor->RGBColor[0, 0, 1],
 Background->RGBColor[1, 0.9, 0.8]],

Cell[CellGroupData[{

Cell[TextData[{
 "Construction of the interpolating function S(x) over the points  {",
 Cell[BoxData[
  FormBox[
   SubscriptBox["x", 
    RowBox[{"i", ","}]], TraditionalForm]]],
 " ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["f", "i"], TraditionalForm]]],
 "} by means of  B-splines of order 3."
}], "Text",
 CellChangeTimes->{
  3.484992245703125*^9, {3.484992316015625*^9, 3.4849923314375*^9}, {
   3.48499253890625*^9, 3.484992628625*^9}, {3.484994235171875*^9, 
   3.484994236890625*^9}, {3.48499689084375*^9, 3.48499689559375*^9}, {
   3.48767985275*^9, 3.4876798598125*^9}, {3.560539989233566*^9, 
   3.5605399935075*^9}},
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"points", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}], ",", "  ", 
     RowBox[{"{", 
      RowBox[{"2", ",", "2"}], "}"}], ",", "  ", 
     RowBox[{"{", 
      RowBox[{"5", ",", "3"}], "}"}], ",", "  ", 
     RowBox[{"{", 
      RowBox[{"9", ",", "5"}], "}"}], ",", "  ", 
     RowBox[{"{", 
      RowBox[{"11", ",", "2"}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"14", ",", "1"}], "}"}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.482465335703125*^9, 3.48246537171875*^9}, {
   3.482562224859375*^9, 3.482562705859375*^9}, {3.482563028953125*^9, 
   3.4825630511875*^9}, 3.48256308603125*^9, {3.48266181428125*^9, 
   3.482661845375*^9}, {3.482661878609375*^9, 3.48266189509375*^9}, {
   3.484992237328125*^9, 3.484992239*^9}, {3.560540011679805*^9, 
   3.560540015432552*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"numpoints", "=", 
  RowBox[{"Length", "[", "points", "]"}]}]], "Input",
 CellChangeTimes->{{3.487596017078125*^9, 3.487596021859375*^9}, 
   3.487673975046875*^9, {3.560540003858188*^9, 3.560540007826174*^9}}],

Cell[BoxData["6"], "Output",
 CellChangeTimes->{3.57770140914736*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"parabolicSpline", "=", 
   RowBox[{"Interpolation", "[", 
    RowBox[{"points", ",", 
     RowBox[{"InterpolationOrder", "\[Rule]", "2"}], ",", 
     RowBox[{"Method", "\[Rule]", "\"\<Spline\>\""}]}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{
  3.482232981299215*^9, 3.482563196046875*^9, {3.482662067734375*^9, 
   3.482662069859375*^9}, {3.482662414515625*^9, 3.48266242134375*^9}, 
   3.484991111609375*^9, 3.560540019292644*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"parabolicSpline", "[", "x", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "14"}], "}"}], ",", 
   RowBox[{"AxesOrigin", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "1"}], ",", "0"}], "}"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "1"}], ",", "15"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "6"}], "}"}]}], "}"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"Epilog", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Red", ",", 
      RowBox[{"PointSize", "[", "Medium", "]"}], ",", 
      RowBox[{"Point", "[", "points", "]"}]}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{
  3.482232990035215*^9, {3.482662078546875*^9, 3.482662109859375*^9}, {
   3.482662150546875*^9, 3.4826622134375*^9}, {3.484979612859375*^9, 
   3.484979664171875*^9}, {3.4849796941875*^9, 3.4849797615625*^9}, 
   3.484991112828125*^9, {3.560540092011394*^9, 3.560540096045826*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVl3k8VO8XxzFj38eMZB1jm6WQipQ8R5aErKlki+z7miVkTZRIolSyhUqK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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{-1, 0},
  Epilog->{
    RGBColor[1, 0, 0], 
    PointSize[Medium], 
    PointBox[{{0, 0}, {2, 2}, {5, 3}, {9, 5}, {11, 2}, {14, 1}}]},
  Method->{},
  PlotRange->{{-1, 15}, {0, 6}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.57770140924804*^9},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]]
}, Open  ]],

Cell["Part II", "Text",
 CellChangeTimes->{
  3.484992245703125*^9, {3.484992316015625*^9, 3.4849923314375*^9}, {
   3.48499253890625*^9, 3.484992628625*^9}, {3.484994235171875*^9, 
   3.484994236890625*^9}, {3.48499689084375*^9, 3.48499689559375*^9}, {
   3.48767985275*^9, 3.4876798598125*^9}, {3.560539989233566*^9, 
   3.5605399935075*^9}, {3.572683032405257*^9, 3.572683048796195*^9}},
 FontFamily->"Times New Roman",
 FontSize->36,
 FontColor->RGBColor[0, 0, 1],
 Background->RGBColor[1, 0.9, 0.8]],

Cell[CellGroupData[{

Cell[TextData[{
 "Access to various information contained in the ",
 StyleBox["InterpolatingFunction.", "Input"]
}], "Text",
 CellChangeTimes->{{3.482233312453421*^9, 3.482233325558337*^9}, {
   3.482233750040195*^9, 3.482233753784411*^9}, {3.484993382796875*^9, 
   3.484993390234375*^9}, {3.484993463875*^9, 3.4849934725*^9}, {
   3.484993612375*^9, 3.48499369059375*^9}, {3.484993903390625*^9, 
   3.4849939055625*^9}, {3.48499398996875*^9, 3.484994000125*^9}, {
   3.484994033875*^9, 3.48499412828125*^9}, {3.484994219125*^9, 
   3.484994243046875*^9}, {3.48499690290625*^9, 3.484996904171875*^9}, 
   3.560540140130722*^9},
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[TextData[{
 "The ",
 StyleBox["BSplineFunction ", "Input"],
 " is stored  in 4th place."
}], "Text",
 CellChangeTimes->{{3.482233312453421*^9, 3.482233325558337*^9}, {
   3.482233750040195*^9, 3.482233753784411*^9}, {3.484993382796875*^9, 
   3.484993390234375*^9}, {3.484993463875*^9, 3.4849934725*^9}, {
   3.484993612375*^9, 3.48499369059375*^9}, {3.484993903390625*^9, 
   3.4849939055625*^9}, {3.48499398996875*^9, 3.484994000125*^9}, {
   3.484994033875*^9, 3.48499412828125*^9}, 3.484994219125*^9, {
   3.4860324106875*^9, 3.486032443421875*^9}, {3.560540151381531*^9, 
   3.560540152231888*^9}},
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"bspfun", "=", 
  RowBox[{"parabolicSpline", "[", 
   RowBox[{"[", 
    RowBox[{"4", ",", "1"}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4822332962139254`*^9, 3.482233307867051*^9}, 
   3.484994515921875*^9}],

Cell[BoxData[
 TagBox[
  RowBox[{"BSplineFunction", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"{", 
      RowBox[{"0.`", ",", "14.`"}], "}"}], "}"}], ",", "\<\"<>\"\>"}], "]"}],
  False,
  Editable->False]], "Output",
 CellChangeTimes->{3.577701409425675*^9}]
}, Open  ]],

Cell[TextData[{
 "The coefficients ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Alpha]", "i"], TraditionalForm]]],
 " for the basis B-splinesbasis are named  \[OpenCurlyDoubleQuote]Control \
points\[CloseCurlyDoubleQuote]"
}], "Text",
 CellChangeTimes->{{3.559482737098605*^9, 3.55948274359533*^9}},
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"coeff", "=", 
  RowBox[{"bspfun", "[", "\"\<ControlPoints\>\"", "]"}]}]], "Input",
 CellChangeTimes->{{3.4822343225455565`*^9, 3.4822343308448095`*^9}, 
   3.4849929160625*^9, {3.507638118600814*^9, 3.507638119331163*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.`", ",", "2.3954012623985577`", ",", "2.6683949504057716`", ",", 
   "6.471946698727582`", ",", 
   RowBox[{"-", "0.23174030658250672`"}], ",", "1.`"}], "}"}]], "Output",
 CellChangeTimes->{3.577701409453103*^9}]
}, Open  ]],

Cell["The set of knots being used", "Text",
 CellChangeTimes->{{3.4822343342300315`*^9, 3.4822343385356593`*^9}, {
  3.484993012875*^9, 3.48499302471875*^9}, {3.559482762046647*^9, 
  3.559482776161458*^9}},
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"knotsx", "=", 
  RowBox[{"Flatten", "[", 
   RowBox[{"bspfun", "[", "\"\<Knots\>\"", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4822333526865635`*^9, 3.4822333562589407`*^9}, {
   3.4822337669515705`*^9, 3.482233768386853*^9}, {3.4822338392615557`*^9, 
   3.482233842178793*^9}, {3.482662276328125*^9, 3.482662277625*^9}, 
   3.487674823375*^9, 3.487675352796875*^9, {3.56054076508379*^9, 
   3.56054077150636*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.`", ",", "0.`", ",", "0.`", ",", "3.5`", ",", "7.`", ",", "10.`", ",", 
   "14.`", ",", "14.`", ",", "14.`"}], "}"}]], "Output",
 CellChangeTimes->{3.5777014094791193`*^9}]
}, Open  ]],

Cell["The degree, for later use", "Text",
 CellChangeTimes->{{3.4822343410950756`*^9, 3.482234344433497*^9}, {
  3.4849930594375*^9, 3.4849930729375*^9}, {3.559482957028283*^9, 
  3.55948296530249*^9}},
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"degx", " ", "=", " ", "2"}], ";"}]], "Input",
 CellChangeTimes->{{3.482233357163735*^9, 3.4822333657904797`*^9}, {
   3.482233770648984*^9, 3.4822337722246747`*^9}, {3.4822338341446466`*^9, 
   3.482233836235117*^9}, {3.482662458*^9, 3.482662458859375*^9}, 
   3.487674759234375*^9, {3.5076378135469837`*^9, 3.507637841595442*^9}, 
   3.560541094075318*^9}],

Cell[CellGroupData[{

Cell["\<\
We are using non-uniform (thus non-uniform knots) degree 3 B-spline basis.
We plot the (6) Bases along the  x-direction. The internal knotes are marked \
with \"\[FivePointedStar]\".\
\>", "Text",
 CellChangeTimes->{{3.482234042054359*^9, 3.482234050026061*^9}, {
   3.4849943335*^9, 3.484994358125*^9}, {3.48499459071875*^9, 
   3.484994612359375*^9}, 3.484994668703125*^9, {3.486032497859375*^9, 
   3.486032526109375*^9}, {3.487679281953125*^9, 3.487679285453125*^9}},
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"symB1", "=", " ", 
   SubsuperscriptBox["B", "1", "3"]}], ";", " ", 
  RowBox[{"symB2", "=", " ", 
   SubsuperscriptBox["B", "2", "3"]}], ";", 
  RowBox[{"symB3", "=", " ", 
   SubsuperscriptBox["B", "3", "3"]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"symB4", "=", " ", 
   SubsuperscriptBox["B", "4", "3"]}], ";", " ", 
  RowBox[{"symB5", "=", " ", 
   SubsuperscriptBox["B", "5", "3"]}], ";", 
  RowBox[{"symB6", "=", 
   SubsuperscriptBox["B", "6", "3"]}], ";"}]}], "Input",
 CellChangeTimes->{{3.483703373765625*^9, 3.483703378671875*^9}, {
  3.48370352328125*^9, 3.483703539609375*^9}, {3.4837036211875*^9, 
  3.4837036309375*^9}, {3.48370469346875*^9, 3.483704720125*^9}, {
  3.48663741703125*^9, 3.48663746434375*^9}, {3.560541100551261*^9, 
  3.560541109236298*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"symKnots", " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"Text", "[", 
      RowBox[{
       RowBox[{"Style", "[", 
        RowBox[{"\"\<\[FivePointedStar]\>\"", ",", "Medium"}], "]"}], ",", 
       "#"}], "]"}], "&"}], "/@", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"3.5", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"7.", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"10.", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"14", ",", "0"}], "}"}]}], "}"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.559486202627114*^9, 3.559486214635637*^9}, {
  3.559486301576712*^9, 3.559486302571568*^9}, {3.559486366049752*^9, 
  3.559486368770009*^9}, {3.560543713016664*^9, 3.560543726445463*^9}, {
  3.560543826129165*^9, 3.56054384044953*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"Evaluate", "[", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"BSplineBasis", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"degx", ",", "knotsx"}], "}"}], ",", "k", ",", "x"}], "]"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{"k", ",", "0", ",", "5"}], "}"}]}], "]"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "14"}], "}"}], ",", "\[IndentingNewLine]", 
   "    ", 
   RowBox[{"Epilog", "->", 
    RowBox[{"{", 
     RowBox[{"{", "\[IndentingNewLine]", 
      RowBox[{"symKnots", ",", "\[IndentingNewLine]", " ", 
       RowBox[{"Text", "[", 
        RowBox[{
         RowBox[{"Style", "[", "\"\<3.5\>\"", "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"3.5", ",", 
           RowBox[{"-", "0.09"}]}], "}"}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Text", "[", 
        RowBox[{
         RowBox[{"Style", "[", "\"\<7\>\"", "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"7", ",", 
           RowBox[{"-", "0.09"}]}], "}"}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Text", "[", 
        RowBox[{
         RowBox[{"Style", "[", "\"\<10\>\"", "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"10", ",", 
           RowBox[{"-", "0.09"}]}], "}"}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Text", "[", 
        RowBox[{
         RowBox[{"Style", "[", "symB1", "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"0.6", ",", "0.9"}], "}"}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Text", "[", 
        RowBox[{
         RowBox[{"Style", "[", "symB2", "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"2.5", ",", "0.75"}], "}"}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Text", "[", 
        RowBox[{
         RowBox[{"Style", "[", "symB3", "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"5", ",", "0.8"}], "}"}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Text", "[", 
        RowBox[{
         RowBox[{"Style", "[", "symB4", "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"8.5", ",", "0.85"}], "}"}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Text", "[", 
        RowBox[{
         RowBox[{"Style", "[", "symB5", "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"11.5", ",", "0.7"}], "}"}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Text", "[", 
        RowBox[{
         RowBox[{"Style", "[", "symB6", "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"13.4", ",", "0.9"}], "}"}]}], "]"}]}], "}"}], "}"}]}], ",",
    "\[IndentingNewLine]", 
   RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.4822338086527767`*^9, 3.4822338219915457`*^9}, {
   3.482233861491841*^9, 3.4822339121320906`*^9}, {3.48256328578125*^9, 
   3.48256328990625*^9}, {3.48256332328125*^9, 3.482563376203125*^9}, {
   3.48266249828125*^9, 3.4826625106875*^9}, {3.484916641671875*^9, 
   3.484916680765625*^9}, {3.484916723734375*^9, 3.4849167388125*^9}, {
   3.484916772609375*^9, 3.48491687671875*^9}, {3.484980861421875*^9, 
   3.48498086334375*^9}, {3.484994385328125*^9, 3.484994389234375*^9}, {
   3.48499455128125*^9, 3.4849945548125*^9}, {3.48500009903125*^9, 
   3.485000242453125*^9}, 3.4860324928125*^9, {3.48603720228125*^9, 
   3.4860372225*^9}, 3.487674760140625*^9, 3.487674824921875*^9, 
   3.487675354203125*^9, {3.48767608575*^9, 3.48767611534375*^9}, {
   3.48767643309375*^9, 3.48767662653125*^9}, {3.560541115495524*^9, 
   3.560541139399583*^9}, {3.560543730691453*^9, 3.56054379465246*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxN0Ak01GsfwPFZjFn+yo3SpM1eY2vTm4jfkwpt2giF5IYhYmqEiiuZLMne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     "]]}, 
   {Hue[0.9060679774997897, 0.6, 0.6], LineBox[CompressedData["
1:eJxN1nc8Vf//APA7zCSRcd1LskIaMrJyX28jGWWrNDRkhmyKlkiozGSlZCuy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     "]]}, 
   {Hue[0.1421359549995791, 0.6, 0.6], LineBox[CompressedData["
1:eJxN13k0VP//OHBE9n0GSZYZWUulRaU8n1JCshOiEpHIHpLsRcjSYquEEFIJ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     "]]}, 
   {Hue[0.37820393249936934`, 0.6, 0.6], LineBox[CompressedData["
1:eJxN13k0VeHXB3CUCtcsGgznXpTrlCQUyt4lQhKRUomQQqYiZWggQxIZElGm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     "]]}, 
   {Hue[0.6142719099991583, 0.6, 0.6], LineBox[CompressedData["
1:eJxF13k0VW3UAHBJlJJkSLqu6d5zLxeJlKHsnQrJEEkKb9KkzPJKEhKSBpSM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     "]]}, 
   {Hue[0.8503398874989481, 0.6, 0.6], LineBox[CompressedData["
1:eJxF1Akw1esbB3Ak3VAK6SRk+Z3T4ReFq2yd58naekSnRaWk7CRlaZEst6i0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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  Epilog->{{{
      InsetBox[
       FormBox[
        StyleBox["\"\[FivePointedStar]\"", Medium, StripOnInput -> False], 
        TraditionalForm], {0, 0}], 
      InsetBox[
       FormBox[
        StyleBox["\"\[FivePointedStar]\"", Medium, StripOnInput -> False], 
        TraditionalForm], {3.5, 0}], 
      InsetBox[
       FormBox[
        StyleBox["\"\[FivePointedStar]\"", Medium, StripOnInput -> False], 
        TraditionalForm], {7., 0}], 
      InsetBox[
       FormBox[
        StyleBox["\"\[FivePointedStar]\"", Medium, StripOnInput -> False], 
        TraditionalForm], {10., 0}], 
      InsetBox[
       FormBox[
        StyleBox["\"\[FivePointedStar]\"", Medium, StripOnInput -> False], 
        TraditionalForm], {14, 0}]}, 
     InsetBox[
      FormBox[
       StyleBox["\"3.5\"", StripOnInput -> False], TraditionalForm], {
      3.5, -0.09}], 
     InsetBox[
      FormBox[
       StyleBox["\"7\"", StripOnInput -> False], TraditionalForm], {
      7, -0.09}], 
     InsetBox[
      FormBox[
       StyleBox["\"10\"", StripOnInput -> False], TraditionalForm], {
      10, -0.09}], 
     InsetBox[
      FormBox[
       StyleBox[
        SubsuperscriptBox["B", "1", "3"], StripOnInput -> False], 
       TraditionalForm], {0.6, 0.9}], 
     InsetBox[
      FormBox[
       StyleBox[
        SubsuperscriptBox["B", "2", "3"], StripOnInput -> False], 
       TraditionalForm], {2.5, 0.75}], 
     InsetBox[
      FormBox[
       StyleBox[
        SubsuperscriptBox["B", "3", "3"], StripOnInput -> False], 
       TraditionalForm], {5, 0.8}], 
     InsetBox[
      FormBox[
       StyleBox[
        SubsuperscriptBox["B", "4", "3"], StripOnInput -> False], 
       TraditionalForm], {8.5, 0.85}], 
     InsetBox[
      FormBox[
       StyleBox[
        SubsuperscriptBox["B", "5", "3"], StripOnInput -> False], 
       TraditionalForm], {11.5, 0.7}], 
     InsetBox[
      FormBox[
       StyleBox[
        SubsuperscriptBox["B", "6", "3"], StripOnInput -> False], 
       TraditionalForm], {13.4, 0.9}]}},
  Method->{},
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.577701409588544*^9},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]]
}, Open  ]],

Cell["It is instructive to Piesewise expand  the basis functions.", "Text",
 CellChangeTimes->{{3.482234065314257*^9, 3.4822340765776014`*^9}, {
   3.48499443396875*^9, 3.484994447921875*^9}, 3.4849946855625*^9, {
   3.560541197550055*^9, 3.560541201201146*^9}},
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"bsplines", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"PiecewiseExpand", "[", 
      RowBox[{
       RowBox[{"BSplineBasis", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"degx", ",", "knotsx"}], "}"}], ",", "k", ",", "x"}], "]"}],
        ",", "\[IndentingNewLine]", 
       RowBox[{"Method", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<OrderlessConditions\>\"", "\[Rule]", "False"}], 
         "}"}]}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"k", ",", "0", ",", "5"}], "}"}]}], "]"}]}], ";", 
  RowBox[{"bsplines", "//", "Column"}]}]], "Input",
 CellChangeTimes->{{3.482234083410489*^9, 3.482234133487131*^9}, {
   3.482662576265625*^9, 3.482662577359375*^9}, {3.4826639286875*^9, 
   3.482663929375*^9}, {3.487595990984375*^9, 3.487595993171875*^9}, 
   3.487674760953125*^9, 3.4876748258125*^9, 3.48767535721875*^9, {
   3.560541203841139*^9, 3.560541205708734*^9}, {3.560541353112389*^9, 
   3.560541368365471*^9}}],

Cell[BoxData[
 TagBox[GridBox[{
    {
     TagBox[GridBox[{
        {"\[Piecewise]", GridBox[{
           {
            RowBox[{"0.9999999999999999`", "\[VeryThinSpace]", "-", 
             RowBox[{"0.5714285714285714`", " ", "x"}], "+", 
             RowBox[{"0.08163265306122448`", " ", 
              SuperscriptBox["x", "2"]}]}], 
            RowBox[{"0.`", "\[LessEqual]", "x", "\[LessEqual]", "3.5`"}]},
           {"0", 
            TagBox["True",
             "PiecewiseDefault",
             AutoDelete->True]}
          },
          AllowedDimensions->{2, Automatic},
          Editable->True,
          
          GridBoxAlignment->{
           "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{1.}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.84]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}},
          Selectable->True]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
          "RowsIndexed" -> {}},
       GridBoxItemSize->{
        "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
         "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.35]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      "Piecewise",
      DeleteWithContents->True,
      Editable->False,
      SelectWithContents->True,
      Selectable->False]},
    {
     TagBox[GridBox[{
        {"\[Piecewise]", GridBox[{
           {
            RowBox[{"0.`", "\[VeryThinSpace]", "+", 
             RowBox[{"0.5714285714285714`", " ", "x"}], "-", 
             RowBox[{"0.12244897959183673`", " ", 
              SuperscriptBox["x", "2"]}]}], 
            RowBox[{"0.`", "\[LessEqual]", "x", "<", "3.5`"}]},
           {
            RowBox[{"1.9999999999999998`", "\[VeryThinSpace]", "-", 
             RowBox[{"0.5714285714285714`", " ", "x"}], "+", 
             RowBox[{"0.04081632653061224`", " ", 
              SuperscriptBox["x", "2"]}]}], 
            RowBox[{"3.5`", "\[LessEqual]", "x", "\[LessEqual]", "7.`"}]},
           {"0", 
            TagBox["True",
             "PiecewiseDefault",
             AutoDelete->True]}
          },
          AllowedDimensions->{2, Automatic},
          Editable->True,
          
          GridBoxAlignment->{
           "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{1.}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.84]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}},
          Selectable->True]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
          "RowsIndexed" -> {}},
       GridBoxItemSize->{
        "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
         "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.35]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      "Piecewise",
      DeleteWithContents->True,
      Editable->False,
      SelectWithContents->True,
      Selectable->False]},
    {
     TagBox[GridBox[{
        {"\[Piecewise]", GridBox[{
           {
            RowBox[{"0.`", "\[VeryThinSpace]", "+", 
             RowBox[{"0.04081632653061224`", " ", 
              SuperscriptBox["x", "2"]}]}], 
            RowBox[{"0.`", "\[LessEqual]", "x", "<", "3.5`"}]},
           {
            RowBox[{
             RowBox[{"-", "1.5384615384615385`"}], "+", 
             RowBox[{"0.8791208791208792`", " ", "x"}], "-", 
             RowBox[{"0.0847723704866562`", " ", 
              SuperscriptBox["x", "2"]}]}], 
            RowBox[{"3.5`", "\[LessEqual]", "x", "<", "7.`"}]},
           {
            RowBox[{"5.128205128205128`", "\[VeryThinSpace]", "-", 
             RowBox[{"1.0256410256410255`", " ", "x"}], "+", 
             RowBox[{"0.05128205128205128`", " ", 
              SuperscriptBox["x", "2"]}]}], 
            RowBox[{"7.`", "\[LessEqual]", "x", "\[LessEqual]", "10.`"}]},
           {"0", 
            TagBox["True",
             "PiecewiseDefault",
             AutoDelete->True]}
          },
          AllowedDimensions->{2, Automatic},
          Editable->True,
          
          GridBoxAlignment->{
           "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{1.}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.84]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}},
          Selectable->True]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
          "RowsIndexed" -> {}},
       GridBoxItemSize->{
        "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
         "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.35]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      "Piecewise",
      DeleteWithContents->True,
      Editable->False,
      SelectWithContents->True,
      Selectable->False]},
    {
     TagBox[GridBox[{
        {"\[Piecewise]", GridBox[{
           {
            RowBox[{"0.5384615384615385`", "\[VeryThinSpace]", "-", 
             RowBox[{"0.3076923076923077`", " ", "x"}], "+", 
             RowBox[{"0.04395604395604396`", " ", 
              SuperscriptBox["x", "2"]}]}], 
            RowBox[{"3.5`", "\[LessEqual]", "x", "<", "7.`"}]},
           {
            RowBox[{
             RowBox[{"-", "6.461538461538461`"}], "+", 
             RowBox[{"1.6923076923076923`", " ", "x"}], "-", 
             RowBox[{"0.0989010989010989`", " ", 
              SuperscriptBox["x", "2"]}]}], 
            RowBox[{"7.`", "\[LessEqual]", "x", "<", "10.`"}]},
           {
            RowBox[{"7.`", "\[VeryThinSpace]", "-", 
             RowBox[{"1.`", " ", "x"}], "+", 
             RowBox[{"0.03571428571428571`", " ", 
              SuperscriptBox["x", "2"]}]}], 
            RowBox[{"10.`", "\[LessEqual]", "x", "\[LessEqual]", "14.`"}]},
           {"0", 
            TagBox["True",
             "PiecewiseDefault",
             AutoDelete->True]}
          },
          AllowedDimensions->{2, Automatic},
          Editable->True,
          
          GridBoxAlignment->{
           "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{1.}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.84]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}},
          Selectable->True]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
          "RowsIndexed" -> {}},
       GridBoxItemSize->{
        "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
         "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.35]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      "Piecewise",
      DeleteWithContents->True,
      Editable->False,
      SelectWithContents->True,
      Selectable->False]},
    {
     TagBox[GridBox[{
        {"\[Piecewise]", GridBox[{
           {
            RowBox[{"2.333333333333333`", "\[VeryThinSpace]", "-", 
             RowBox[{"0.6666666666666666`", " ", "x"}], "+", 
             RowBox[{"0.047619047619047616`", " ", 
              SuperscriptBox["x", "2"]}]}], 
            RowBox[{"7.`", "\[LessEqual]", "x", "<", "10.`"}]},
           {
            RowBox[{
             RowBox[{"-", "12.25`"}], "+", 
             RowBox[{"2.25`", " ", "x"}], "-", 
             RowBox[{"0.09821428571428571`", " ", 
              SuperscriptBox["x", "2"]}]}], 
            RowBox[{"10.`", "\[LessEqual]", "x", "\[LessEqual]", "14.`"}]},
           {"0", 
            TagBox["True",
             "PiecewiseDefault",
             AutoDelete->True]}
          },
          AllowedDimensions->{2, Automatic},
          Editable->True,
          
          GridBoxAlignment->{
           "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{1.}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.84]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}},
          Selectable->True]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
          "RowsIndexed" -> {}},
       GridBoxItemSize->{
        "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
         "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.35]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      "Piecewise",
      DeleteWithContents->True,
      Editable->False,
      SelectWithContents->True,
      Selectable->False]},
    {
     TagBox[GridBox[{
        {"\[Piecewise]", GridBox[{
           {
            RowBox[{"6.25`", "\[VeryThinSpace]", "-", 
             RowBox[{"1.25`", " ", "x"}], "+", 
             RowBox[{"0.0625`", " ", 
              SuperscriptBox["x", "2"]}]}], 
            RowBox[{"10.`", "\[LessEqual]", "x", "\[LessEqual]", "14.`"}]},
           {"0", 
            TagBox["True",
             "PiecewiseDefault",
             AutoDelete->True]}
          },
          AllowedDimensions->{2, Automatic},
          Editable->True,
          
          GridBoxAlignment->{
           "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{1.}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.84]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}},
          Selectable->True]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
          "RowsIndexed" -> {}},
       GridBoxItemSize->{
        "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
         "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.35]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      "Piecewise",
      DeleteWithContents->True,
      Editable->False,
      SelectWithContents->True,
      Selectable->False]}
   },
   DefaultBaseStyle->"Column",
   GridBoxAlignment->{"Columns" -> {{Left}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Column"]], "Output",
 CellChangeTimes->{3.577701409874504*^9}]
}, Open  ]],

Cell[TextData[{
 "We observe that, in the first interval ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{"0", ",", "3.5"}], ")"}], TraditionalForm]]],
 ", only three Bsplines ",
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["B", "1", "3"], TraditionalForm]],
  FontSize->10],
 StyleBox[", ",
  FontSize->10],
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["B", "2", "3"], TraditionalForm]],
  FontSize->10],
 StyleBox[", ",
  FontSize->10],
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["B", "3", "3"], TraditionalForm]],
  FontSize->10],
 StyleBox[" ",
  FontSize->10],
 "give a contibution. The same observation holds for every other interval."
}], "Text",
 CellChangeTimes->{{3.482664394578125*^9, 3.482664468984375*^9}, {
  3.482664514625*^9, 3.482664539265625*^9}, {3.48275498540625*^9, 
  3.48275501025*^9}, {3.482755052734375*^9, 3.482755109421875*^9}, {
  3.48497849896875*^9, 3.484978499578125*^9}, {3.484978533796875*^9, 
  3.484978604484375*^9}, {3.484978754390625*^9, 3.48497876734375*^9}, {
  3.484994730125*^9, 3.484994889828125*^9}, {3.48499492471875*^9, 
  3.484994988171875*^9}, {3.484995021609375*^9, 3.48499506625*^9}, {
  3.487659286171875*^9, 3.487659317546875*^9}, {3.4876805590625*^9, 
  3.487680561609375*^9}, {3.559483857982459*^9, 3.559483930729468*^9}, {
  3.5605406961833*^9, 3.560540696705807*^9}, {3.560541256759673*^9, 
  3.560541267581703*^9}},
 FontSize->14,
 Background->GrayLevel[0.85]]
}, Open  ]],

Cell["Part III", "Text",
 CellChangeTimes->{
  3.484992245703125*^9, {3.484992316015625*^9, 3.4849923314375*^9}, {
   3.48499253890625*^9, 3.484992628625*^9}, {3.484994235171875*^9, 
   3.484994236890625*^9}, {3.48499689084375*^9, 3.48499689559375*^9}, {
   3.48767985275*^9, 3.4876798598125*^9}, {3.560539989233566*^9, 
   3.5605399935075*^9}, {3.572683032405257*^9, 3.572683058756765*^9}},
 FontFamily->"Times New Roman",
 FontSize->36,
 FontColor->RGBColor[0, 0, 1],
 Background->RGBColor[1, 0.9, 0.8]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["It is convenient to extract the polynomial representation of the \
segments of",
  FontFamily->"Times New Roman"],
 " B-splines on each of the four subintervals formed by the knots.\nThe \
Interpolating spline S(x), together with the first and second derivatives, \
are plotted."
}], "Text",
 CellChangeTimes->{{3.482664394578125*^9, 3.482664468984375*^9}, {
   3.482664514625*^9, 3.482664539265625*^9}, {3.48275498540625*^9, 
   3.48275501025*^9}, {3.482755052734375*^9, 3.482755109421875*^9}, {
   3.48497849896875*^9, 3.484978499578125*^9}, {3.484978533796875*^9, 
   3.484978604484375*^9}, {3.484978754390625*^9, 3.48497884175*^9}, {
   3.484978883515625*^9, 3.484978886390625*^9}, {3.48499516884375*^9, 
   3.484995178203125*^9}, {3.48499522409375*^9, 3.4849953056875*^9}, {
   3.484995706578125*^9, 3.484995708015625*^9}, {3.4849960660625*^9, 
   3.484996119171875*^9}, 3.4849968864375*^9, {3.487679648203125*^9, 
   3.487679666359375*^9}, {3.487679864890625*^9, 3.487679878234375*^9}, {
   3.560541288395127*^9, 3.560541311944597*^9}},
 Background->RGBColor[0.9, 1, 1]],

Cell["\<\
We extract the segments of the B-spline which give a contribution  on the \
first interval\
\>", "Text",
 CellChangeTimes->{{3.482664394578125*^9, 3.482664468984375*^9}, {
   3.482664514625*^9, 3.482664539265625*^9}, {3.48275498540625*^9, 
   3.48275501025*^9}, {3.482755052734375*^9, 3.482755109421875*^9}, {
   3.48497849896875*^9, 3.484978499578125*^9}, {3.484978533796875*^9, 
   3.484978604484375*^9}, {3.484978754390625*^9, 3.48497884175*^9}, {
   3.484978883515625*^9, 3.484978931140625*^9}, {3.48499782309375*^9, 
   3.4849978416875*^9}, {3.487678947921875*^9, 3.487679004125*^9}, 
   3.487680630375*^9},
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"bsplines", "[", 
   RowBox[{"[", 
    RowBox[{"1", ",", "1", ",", "1", ",", "1"}], "]"}], "]"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     SuperscriptBox[
      SubscriptBox["B", "1"], "3"], "   ", "0."}], " ", "\[LessEqual]", " ", 
    "x", " ", "<", " ", "3.5"}], " ", "*)"}]}]], "Input",
 CellChangeTimes->{{3.482664695234375*^9, 3.482664696796875*^9}, {
   3.484912448203125*^9, 3.4849124485625*^9}, {3.48491807028125*^9, 
   3.484918106625*^9}, {3.484918140140625*^9, 3.484918141765625*^9}, {
   3.48491841321875*^9, 3.484918450671875*^9}, {3.4849185378125*^9, 
   3.484918538265625*^9}, 3.484918575984375*^9, {3.48491869765625*^9, 
   3.484918698015625*^9}, {3.484918768078125*^9, 3.4849187769375*^9}, {
   3.560541545920249*^9, 3.560541562785468*^9}}],

Cell[BoxData[
 RowBox[{"0.9999999999999999`", "\[VeryThinSpace]", "-", 
  RowBox[{"0.5714285714285714`", " ", "x"}], "+", 
  RowBox[{"0.08163265306122448`", " ", 
   SuperscriptBox["x", "2"]}]}]], "Output",
 CellChangeTimes->{3.5777014101869392`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"bsplines", "[", 
   RowBox[{"[", 
    RowBox[{"2", ",", "1", ",", "1", ",", "1"}], "]"}], "]"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     SuperscriptBox[
      SubscriptBox["B", "2"], "3"], "   ", "0"}], " ", "\[LessEqual]", "  ", 
    "x", " ", "<", " ", "3.5"}], " ", "*)"}], "  "}]], "Input",
 CellChangeTimes->{{3.4826639458125*^9, 3.48266394865625*^9}, {
   3.48266465525*^9, 3.4826646664375*^9}, {3.484918169609375*^9, 
   3.484918194828125*^9}, {3.484918550640625*^9, 3.484918569953125*^9}, {
   3.48491867809375*^9, 3.484918680265625*^9}, 3.484918746984375*^9, {
   3.484918778953125*^9, 3.48491878215625*^9}, {3.48759757971875*^9, 
   3.487597580453125*^9}, {3.487597615296875*^9, 3.487597616203125*^9}, {
   3.560541564932166*^9, 3.560541580110403*^9}}],

Cell[BoxData[
 RowBox[{"0.`", "\[VeryThinSpace]", "+", 
  RowBox[{"0.5714285714285714`", " ", "x"}], "-", 
  RowBox[{"0.12244897959183673`", " ", 
   SuperscriptBox["x", "2"]}]}]], "Output",
 CellChangeTimes->{3.577701410215332*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"bsplines", "[", 
   RowBox[{"[", 
    RowBox[{"3", ",", "1", ",", "1", ",", "1"}], "]"}], "]"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     SuperscriptBox[
      SubscriptBox["B", "3"], "3"], "   ", "0"}], " ", "\[LessEqual]", "  ", 
    "x", " ", "<", " ", "3.5"}], " ", "*)"}], "        "}]], "Input",
 CellChangeTimes->{{3.4826639458125*^9, 3.48266394865625*^9}, {
  3.48266465525*^9, 3.4826646664375*^9}, {3.482664763515625*^9, 
  3.48266478965625*^9}, {3.484914455515625*^9, 3.484914455765625*^9}, {
  3.484918226015625*^9, 3.484918240453125*^9}, {3.484918629546875*^9, 
  3.4849186456875*^9}, {3.484918747921875*^9, 3.484918748234375*^9}, {
  3.48491878525*^9, 3.484918786640625*^9}, {3.487597594640625*^9, 
  3.4875975955625*^9}, {3.560541593799525*^9, 3.560541609471902*^9}}],

Cell[BoxData[
 RowBox[{"0.`", "\[VeryThinSpace]", "+", 
  RowBox[{"0.04081632653061224`", " ", 
   SuperscriptBox["x", "2"]}]}]], "Output",
 CellChangeTimes->{3.577701410225977*^9}]
}, Open  ]],

Cell["...  on the second interval", "Text",
 CellChangeTimes->{{3.482664394578125*^9, 3.482664468984375*^9}, {
  3.482664514625*^9, 3.482664539265625*^9}, {3.48275498540625*^9, 
  3.48275501025*^9}, {3.482755052734375*^9, 3.482755109421875*^9}, {
  3.48497849896875*^9, 3.484978499578125*^9}, {3.484978533796875*^9, 
  3.484978604484375*^9}, {3.484978754390625*^9, 3.48497884175*^9}, {
  3.484978883515625*^9, 3.484978931140625*^9}, {3.48499782309375*^9, 
  3.4849978416875*^9}, {3.487678947921875*^9, 3.487679004125*^9}, {
  3.487679036984375*^9, 3.4876790456875*^9}},
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"bsplines", "[", 
   RowBox[{"[", 
    RowBox[{"2", ",", "1", ",", "2", ",", "1"}], "]"}], "]"}], 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     SuperscriptBox[
      SubscriptBox["B", "2"], "3"], "  ", "3.5"}], " ", "\[LessEqual]", " ", 
    "x", " ", "<", " ", "7.0"}], " ", "*)"}]}]], "Input",
 CellChangeTimes->{{3.482664695234375*^9, 3.482664696796875*^9}, {
   3.484912448203125*^9, 3.4849124485625*^9}, {3.484917832671875*^9, 
   3.48491783290625*^9}, {3.48491790596875*^9, 3.484917977078125*^9}, {
   3.484918312125*^9, 3.484918321234375*^9}, {3.484918499265625*^9, 
   3.48491853634375*^9}, {3.484918573890625*^9, 3.48491857434375*^9}, 
   3.48491885628125*^9, {3.4849189955*^9, 3.48491899634375*^9}, 
   3.484975175890625*^9, {3.560541612309511*^9, 3.560541640470606*^9}}],

Cell[BoxData[
 RowBox[{"1.9999999999999998`", "\[VeryThinSpace]", "-", 
  RowBox[{"0.5714285714285714`", " ", "x"}], "+", 
  RowBox[{"0.04081632653061224`", " ", 
   SuperscriptBox["x", "2"]}]}]], "Output",
 CellChangeTimes->{3.577701410257819*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"bsplines", "[", 
   RowBox[{"[", 
    RowBox[{"3", ",", "1", ",", "2", ",", "1"}], "]"}], "]"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     SuperscriptBox[
      SubscriptBox["B", "3"], "3"], "  ", "3.5"}], " ", "\[LessEqual]", " ", 
    "x", " ", "<", " ", "7.0"}], " ", "*)"}], " "}]], "Input",
 CellChangeTimes->{{3.4826639458125*^9, 3.48266394865625*^9}, {
  3.48266465525*^9, 3.4826646664375*^9}, {3.482664763515625*^9, 
  3.48266478965625*^9}, {3.484914455515625*^9, 3.484914455765625*^9}, {
  3.484918029859375*^9, 3.484918030171875*^9}, {3.484918369875*^9, 
  3.48491837971875*^9}, {3.484918590390625*^9, 3.48491859365625*^9}, {
  3.484918886796875*^9, 3.48491889828125*^9}, {3.484918983734375*^9, 
  3.484919007453125*^9}, {3.487597671125*^9, 3.4875976725*^9}, {
  3.560541643512006*^9, 3.560541667513589*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "1.5384615384615385`"}], "+", 
  RowBox[{"0.8791208791208792`", " ", "x"}], "-", 
  RowBox[{"0.0847723704866562`", " ", 
   SuperscriptBox["x", "2"]}]}]], "Output",
 CellChangeTimes->{3.5777014102828712`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"bsplines", "[", 
   RowBox[{"[", 
    RowBox[{"4", ",", "1", ",", "1", ",", "1"}], "]"}], "]"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     SuperscriptBox[
      SubscriptBox["B", "4"], "3"], "  ", "3.5"}], " ", "\[LessEqual]", " ", 
    "x", " ", "<", " ", "7.0"}], " ", "*)"}], " "}]], "Input",
 CellChangeTimes->{{3.4826639458125*^9, 3.48266394865625*^9}, {
  3.48266465525*^9, 3.4826646664375*^9}, {3.48266474965625*^9, 
  3.482664751828125*^9}, {3.48491439440625*^9, 3.484914451171875*^9}, {
  3.4849147040625*^9, 3.484914723890625*^9}, {3.48491894675*^9, 
  3.484918967484375*^9}, {3.484919010046875*^9, 3.484919011359375*^9}, {
  3.484919228046875*^9, 3.484919228421875*^9}, {3.48497494140625*^9, 
  3.484974942046875*^9}, {3.487597701671875*^9, 3.487597723265625*^9}, {
  3.560541669370417*^9, 3.560541691076755*^9}}],

Cell[BoxData[
 RowBox[{"0.5384615384615385`", "\[VeryThinSpace]", "-", 
  RowBox[{"0.3076923076923077`", " ", "x"}], "+", 
  RowBox[{"0.04395604395604396`", " ", 
   SuperscriptBox["x", "2"]}]}]], "Output",
 CellChangeTimes->{3.5777014103076277`*^9}]
}, Open  ]],

Cell["...  on the third interval", "Text",
 CellChangeTimes->{{3.482664394578125*^9, 3.482664468984375*^9}, {
  3.482664514625*^9, 3.482664539265625*^9}, {3.48275498540625*^9, 
  3.48275501025*^9}, {3.482755052734375*^9, 3.482755109421875*^9}, {
  3.48497849896875*^9, 3.484978499578125*^9}, {3.484978533796875*^9, 
  3.484978604484375*^9}, {3.484978754390625*^9, 3.48497884175*^9}, {
  3.484978883515625*^9, 3.484978931140625*^9}, {3.48499782309375*^9, 
  3.4849978416875*^9}, {3.487678947921875*^9, 3.487679004125*^9}, {
  3.487679057640625*^9, 3.487679064640625*^9}},
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"bsplines", "[", 
   RowBox[{"[", 
    RowBox[{"3", ",", "1", ",", "3", ",", "1"}], "]"}], "]"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     SuperscriptBox[
      SubscriptBox["B", "3"], "3"], "  ", "7"}], " ", "\[LessEqual]", " ", 
    "x", " ", "<", " ", "10.0"}], " ", "*)"}], "     "}]], "Input",
 CellChangeTimes->{{3.4826639458125*^9, 3.48266394865625*^9}, {
  3.48266465525*^9, 3.4826646664375*^9}, {3.482664763515625*^9, 
  3.48266478965625*^9}, {3.484914455515625*^9, 3.484914455765625*^9}, {
  3.484918029859375*^9, 3.484918030171875*^9}, {3.484918369875*^9, 
  3.48491837971875*^9}, {3.484918590390625*^9, 3.48491859365625*^9}, {
  3.484918886796875*^9, 3.48491889828125*^9}, {3.484918983734375*^9, 
  3.484919007453125*^9}, {3.484919077921875*^9, 3.48491910540625*^9}, {
  3.560541693782122*^9, 3.560541708389437*^9}}],

Cell[BoxData[
 RowBox[{"5.128205128205128`", "\[VeryThinSpace]", "-", 
  RowBox[{"1.0256410256410255`", " ", "x"}], "+", 
  RowBox[{"0.05128205128205128`", " ", 
   SuperscriptBox["x", "2"]}]}]], "Output",
 CellChangeTimes->{3.577701410337613*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"bsplines", "[", 
   RowBox[{"[", 
    RowBox[{"4", ",", "1", ",", "2", ",", "1"}], "]"}], "]"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     SuperscriptBox[
      SubscriptBox["B", "4"], "3"], "  ", "7"}], " ", "\[LessEqual]", " ", 
    "x", " ", "<", " ", "10.0"}], " ", "*)"}], " "}]], "Input",
 CellChangeTimes->{{3.4826639458125*^9, 3.48266394865625*^9}, {
  3.48266465525*^9, 3.4826646664375*^9}, {3.48266474965625*^9, 
  3.482664751828125*^9}, {3.48491439440625*^9, 3.484914451171875*^9}, {
  3.4849147040625*^9, 3.484914723890625*^9}, {3.484919149796875*^9, 
  3.484919185109375*^9}, {3.48491925015625*^9, 3.484919286953125*^9}, {
  3.48491937034375*^9, 3.484919370796875*^9}, {3.487597794484375*^9, 
  3.487597795359375*^9}, {3.560541711072585*^9, 3.560541735813311*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "6.461538461538461`"}], "+", 
  RowBox[{"1.6923076923076923`", " ", "x"}], "-", 
  RowBox[{"0.0989010989010989`", " ", 
   SuperscriptBox["x", "2"]}]}]], "Output",
 CellChangeTimes->{3.57770141034857*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"bsplines", "[", 
   RowBox[{"[", 
    RowBox[{"5", ",", "1", ",", "1", ",", "1"}], "]"}], "]"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     SuperscriptBox[
      SubscriptBox["B", "5"], "3"], "  ", "7"}], " ", "\[LessEqual]", " ", 
    "x", " ", "<", " ", "10.0"}], " ", "*)"}], " "}]], "Input",
 CellChangeTimes->{{3.4826639458125*^9, 3.48266394865625*^9}, {
  3.48266465525*^9, 3.4826646664375*^9}, {3.48266474965625*^9, 
  3.482664751828125*^9}, {3.48491439440625*^9, 3.484914451171875*^9}, {
  3.484919309734375*^9, 3.484919351984375*^9}, {3.487597797484375*^9, 
  3.487597798328125*^9}, {3.560541743270293*^9, 3.560541769807501*^9}, {
  3.560541860297443*^9, 3.560541862505116*^9}}],

Cell[BoxData[
 RowBox[{"2.333333333333333`", "\[VeryThinSpace]", "-", 
  RowBox[{"0.6666666666666666`", " ", "x"}], "+", 
  RowBox[{"0.047619047619047616`", " ", 
   SuperscriptBox["x", "2"]}]}]], "Output",
 CellChangeTimes->{3.577701410387238*^9}]
}, Open  ]],

Cell["and  on the fourth interval", "Text",
 CellChangeTimes->{{3.482664394578125*^9, 3.482664468984375*^9}, {
  3.482664514625*^9, 3.482664539265625*^9}, {3.48275498540625*^9, 
  3.48275501025*^9}, {3.482755052734375*^9, 3.482755109421875*^9}, {
  3.48497849896875*^9, 3.484978499578125*^9}, {3.484978533796875*^9, 
  3.484978604484375*^9}, {3.484978754390625*^9, 3.48497884175*^9}, {
  3.484978883515625*^9, 3.484978931140625*^9}, {3.48499782309375*^9, 
  3.4849978416875*^9}, {3.487678947921875*^9, 3.487679004125*^9}, {
  3.487679075640625*^9, 3.487679091765625*^9}},
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"bsplines", "[", 
   RowBox[{"[", 
    RowBox[{"4", ",", "1", ",", "3", ",", "1"}], "]"}], "]"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     SuperscriptBox[
      SubscriptBox["B", "4"], "3"], "  ", "10"}], " ", "\[LessEqual]", " ", 
    "x", " ", "<", " ", "14.0"}], " ", "*)"}], " "}]], "Input",
 CellChangeTimes->{{3.4826639458125*^9, 3.48266394865625*^9}, {
  3.48266465525*^9, 3.4826646664375*^9}, {3.48266474965625*^9, 
  3.482664751828125*^9}, {3.48491439440625*^9, 3.484914451171875*^9}, {
  3.484919309734375*^9, 3.484919313453125*^9}, {3.484919409390625*^9, 
  3.48491945521875*^9}, {3.484919517671875*^9, 3.4849195189375*^9}, {
  3.487597852109375*^9, 3.487597852953125*^9}, {3.560541792279954*^9, 
  3.56054181501201*^9}}],

Cell[BoxData[
 RowBox[{"7.`", "\[VeryThinSpace]", "-", 
  RowBox[{"1.`", " ", "x"}], "+", 
  RowBox[{"0.03571428571428571`", " ", 
   SuperscriptBox["x", "2"]}]}]], "Output",
 CellChangeTimes->{3.577701410412677*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"bsplines", "[", 
   RowBox[{"[", 
    RowBox[{"5", ",", "1", ",", "2", ",", "1"}], "]"}], "]"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     SuperscriptBox[
      SubscriptBox["B", "5"], "3"], "  ", "10"}], " ", "\[LessEqual]", " ", 
    "x", " ", "<", " ", "14.0"}], " ", "*)"}], " "}]], "Input",
 CellChangeTimes->{{3.4826639458125*^9, 3.48266394865625*^9}, {
  3.48266465525*^9, 3.4826646664375*^9}, {3.48266474965625*^9, 
  3.482664751828125*^9}, {3.48491439440625*^9, 3.484914451171875*^9}, {
  3.484919309734375*^9, 3.484919351984375*^9}, {3.48491950746875*^9, 
  3.484919512984375*^9}, {3.48491956040625*^9, 3.484919581984375*^9}, {
  3.484975095125*^9, 3.484975095609375*^9}, {3.48759785465625*^9, 
  3.4875978554375*^9}, {3.560541872342458*^9, 3.560541885594566*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "12.25`"}], "+", 
  RowBox[{"2.25`", " ", "x"}], "-", 
  RowBox[{"0.09821428571428571`", " ", 
   SuperscriptBox["x", "2"]}]}]], "Output",
 CellChangeTimes->{3.577701410437339*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"bsplines", "[", 
   RowBox[{"[", 
    RowBox[{"6", ",", "1", ",", "1", ",", "1"}], "]"}], "]"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     SuperscriptBox[
      SubscriptBox["B", "6"], "3"], "  ", "10"}], " ", "\[LessEqual]", " ", 
    "x", " ", "<", " ", "14.0"}], " ", "*)"}], " "}]], "Input",
 CellChangeTimes->{{3.4826639458125*^9, 3.48266394865625*^9}, {
  3.48266465525*^9, 3.4826646664375*^9}, {3.48266474965625*^9, 
  3.482664751828125*^9}, {3.48491439440625*^9, 3.48491448825*^9}, {
  3.484919547640625*^9, 3.484919584640625*^9}, {3.560541887586315*^9, 
  3.560541902073401*^9}}],

Cell[BoxData[
 RowBox[{"6.25`", "\[VeryThinSpace]", "-", 
  RowBox[{"1.25`", " ", "x"}], "+", 
  RowBox[{"0.0625`", " ", 
   SuperscriptBox["x", "2"]}]}]], "Output",
 CellChangeTimes->{3.577701410465489*^9}]
}, Open  ]],

Cell["We plot the BSplines separately", "Text",
 CellChangeTimes->{{3.482664394578125*^9, 3.482664468984375*^9}, {
   3.482664514625*^9, 3.482664539265625*^9}, {3.48275498540625*^9, 
   3.48275501025*^9}, {3.482755052734375*^9, 3.48275518615625*^9}, {
   3.4827552320625*^9, 3.48275526790625*^9}, {3.48499732775*^9, 
   3.48499733709375*^9}, {3.484997378734375*^9, 3.4849973836875*^9}, 
   3.48499786365625*^9},
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"p1", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{"BSplineBasis", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"degx", ",", "knotsx"}], "}"}], ",", "0", ",", "x"}], "]"}], 
     "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", "14"}], "}"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
    RowBox[{"Epilog", "->", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Text", "[", 
        RowBox[{
         RowBox[{"Style", "[", "symB1", "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"2", ",", "0.6"}], "}"}]}], "]"}], ",", " ", 
       RowBox[{"Text", "[", 
        RowBox[{
         RowBox[{"Style", "[", "\"\<\[FivePointedStar]\>\"", "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "0"}], "}"}]}], "]"}], ",", "symKnots"}], 
      "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.48759641690625*^9, 3.487596459359375*^9}, {
   3.48759658953125*^9, 3.487596589984375*^9}, 3.487674764046875*^9, 
   3.4876748324375*^9, 3.487675357234375*^9, {3.487676704890625*^9, 
   3.487676737234375*^9}, {3.4876767755*^9, 3.487676857984375*^9}, 
   3.487677198359375*^9, {3.48767722984375*^9, 3.48767726196875*^9}, {
   3.4876776701875*^9, 3.487677672546875*^9}, {3.4876777235*^9, 
   3.4876778080625*^9}, 3.487678289359375*^9, {3.560541929551568*^9, 
   3.560541964074728*^9}, {3.560542035760143*^9, 3.560542048837446*^9}, {
   3.560543861689001*^9, 3.560543878322206*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxN0Ak01GsfwPFZjFn+yo3SpM1eY2vTm4jfkwpt2giF5IYhYmqEiiuZLMne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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  Epilog->{
    InsetBox[
     FormBox[
      StyleBox[
       SubsuperscriptBox["B", "1", "3"], StripOnInput -> False], 
      TraditionalForm], {2, 0.6}], 
    InsetBox[
     FormBox[
      StyleBox["\"\[FivePointedStar]\"", StripOnInput -> False], 
      TraditionalForm], {0, 0}], {
     InsetBox[
      FormBox[
       StyleBox["\"\[FivePointedStar]\"", Medium, StripOnInput -> False], 
       TraditionalForm], {0, 0}], 
     InsetBox[
      FormBox[
       StyleBox["\"\[FivePointedStar]\"", Medium, StripOnInput -> False], 
       TraditionalForm], {3.5, 0}], 
     InsetBox[
      FormBox[
       StyleBox["\"\[FivePointedStar]\"", Medium, StripOnInput -> False], 
       TraditionalForm], {7., 0}], 
     InsetBox[
      FormBox[
       StyleBox["\"\[FivePointedStar]\"", Medium, StripOnInput -> False], 
       TraditionalForm], {10., 0}], 
     InsetBox[
      FormBox[
       StyleBox["\"\[FivePointedStar]\"", Medium, StripOnInput -> False], 
       TraditionalForm], {14, 0}]}},
  Method->{},
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.577701410505883*^9},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"p2", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{"BSplineBasis", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"degx", ",", "knotsx"}], "}"}], ",", "1", ",", "x"}], "]"}], 
     "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", "14"}], "}"}], ",", 
    RowBox[{"Epilog", "->", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Text", "[", 
        RowBox[{
         RowBox[{"Style", "[", "symB2", "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"5", ",", "0.4"}], "}"}]}], "]"}], ",", "symKnots"}], 
      "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.48759641690625*^9, 3.487596504953125*^9}, {
   3.4875965946875*^9, 3.487596595421875*^9}, 3.48767476465625*^9, 
   3.48767483321875*^9, 3.487675357234375*^9, {3.4876768743125*^9, 
   3.487676902609375*^9}, {3.48767718575*^9, 3.48767718778125*^9}, {
   3.48767797740625*^9, 3.48767801840625*^9}, 3.48767805196875*^9, 
   3.487678286359375*^9, {3.560542067621826*^9, 3.560542088134289*^9}, {
   3.560543896738544*^9, 3.560543900912682*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxN1nc8Vf//APA7zCSRcd1LskIaMrJyX28jGWWrNDRkhmyKlkiozGSlZCuy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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  Epilog->{
    InsetBox[
     FormBox[
      StyleBox[
       SubsuperscriptBox["B", "2", "3"], StripOnInput -> False], 
      TraditionalForm], {5, 0.4}], {
     InsetBox[
      FormBox[
       StyleBox["\"\[FivePointedStar]\"", Medium, StripOnInput -> False], 
       TraditionalForm], {0, 0}], 
     InsetBox[
      FormBox[
       StyleBox["\"\[FivePointedStar]\"", Medium, StripOnInput -> False], 
       TraditionalForm], {3.5, 0}], 
     InsetBox[
      FormBox[
       StyleBox["\"\[FivePointedStar]\"", Medium, StripOnInput -> False], 
       TraditionalForm], {7., 0}], 
     InsetBox[
      FormBox[
       StyleBox["\"\[FivePointedStar]\"", Medium, StripOnInput -> False], 
       TraditionalForm], {10., 0}], 
     InsetBox[
      FormBox[
       StyleBox["\"\[FivePointedStar]\"", Medium, StripOnInput -> False], 
       TraditionalForm], {14, 0}]}},
  Method->{},
  PlotRange->{{0, 14}, {0., 0.6666661564424514}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{
  3.5777014105466547`*^9},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"p3", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{"BSplineBasis", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"degx", ",", "knotsx"}], "}"}], ",", "2", ",", "x"}], "]"}], 
     "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", "14"}], "}"}], ",", 
    RowBox[{"Epilog", "->", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Text", "[", 
        RowBox[{
         RowBox[{"Style", "[", "symB3", "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"8", ",", "0.5"}], "}"}]}], "]"}], ",", "symKnots"}], 
      "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.48759641690625*^9, 3.487596459359375*^9}, {
   3.487596489421875*^9, 3.487596507265625*^9}, {3.48759660015625*^9, 
   3.487596600875*^9}, 3.4876747651875*^9, 3.48767483371875*^9, 
   3.48767535725*^9, {3.487676924765625*^9, 3.4876769491875*^9}, 
   3.4876771784375*^9, {3.487677844546875*^9, 3.487677925140625*^9}, {
   3.48767806865625*^9, 3.4876781044375*^9}, 3.48767828446875*^9, {
   3.560542100544751*^9, 3.56054214418454*^9}, {3.560543911261594*^9, 
   3.560543914388486*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxN13k0VP//OHBE9n0GSZYZWUulRaU8n1JCshOiEpHIHpLsRcjSYquEEFIJ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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  Epilog->{
    InsetBox[
     FormBox[
      StyleBox[
       SubsuperscriptBox["B", "3", "3"], StripOnInput -> False], 
      TraditionalForm], {8, 0.5}], {
     InsetBox[
      FormBox[
       StyleBox["\"\[FivePointedStar]\"", Medium, StripOnInput -> False], 
       TraditionalForm], {0, 0}], 
     InsetBox[
      FormBox[
       StyleBox["\"\[FivePointedStar]\"", Medium, StripOnInput -> False], 
       TraditionalForm], {3.5, 0}], 
     InsetBox[
      FormBox[
       StyleBox["\"\[FivePointedStar]\"", Medium, StripOnInput -> False], 
       TraditionalForm], {7., 0}], 
     InsetBox[
      FormBox[
       StyleBox["\"\[FivePointedStar]\"", Medium, StripOnInput -> False], 
       TraditionalForm], {10., 0}], 
     InsetBox[
      FormBox[
       StyleBox["\"\[FivePointedStar]\"", Medium, StripOnInput -> False], 
       TraditionalForm], {14, 0}]}},
  Method->{},
  PlotRange->{{0, 14}, {0., 0.740740450997566}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{
  3.577701410591158*^9},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"p4", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{"BSplineBasis", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"degx", ",", "knotsx"}], "}"}], ",", "3", ",", "x"}], "]"}], 
     "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", "14"}], "}"}], ",", 
    RowBox[{"Epilog", "->", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Text", "[", 
        RowBox[{
         RowBox[{"Style", "[", "symB4", "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"11.5", ",", "0.5"}], "}"}]}], "]"}], ",", "symKnots"}], 
      "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.48759641690625*^9, 3.487596459359375*^9}, {
   3.487596492140625*^9, 3.487596509359375*^9}, {3.487596604234375*^9, 
   3.48759660490625*^9}, 3.487674765703125*^9, 3.487674834234375*^9, 
   3.48767535725*^9, {3.487676959859375*^9, 3.487676988109375*^9}, 
   3.48767716859375*^9, {3.4876781398125*^9, 3.487678161*^9}, 
   3.487678282609375*^9, {3.560542150066072*^9, 3.560542184110415*^9}, 
   3.56054392508077*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxN13k0VeHXB3CUCtcsGgznXpTrlCQUyt4lQhKRUomQQqYiZWggQxIZElGm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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  Epilog->{
    InsetBox[
     FormBox[
      StyleBox[
       SubsuperscriptBox["B", "4", "3"], StripOnInput -> False], 
      TraditionalForm], {11.5, 0.5}], {
     InsetBox[
      FormBox[
       StyleBox["\"\[FivePointedStar]\"", Medium, StripOnInput -> False], 
       TraditionalForm], {0, 0}], 
     InsetBox[
      FormBox[
       StyleBox["\"\[FivePointedStar]\"", Medium, StripOnInput -> False], 
       TraditionalForm], {3.5, 0}], 
     InsetBox[
      FormBox[
       StyleBox["\"\[FivePointedStar]\"", Medium, StripOnInput -> False], 
       TraditionalForm], {7., 0}], 
     InsetBox[
      FormBox[
       StyleBox["\"\[FivePointedStar]\"", Medium, StripOnInput -> False], 
       TraditionalForm], {10., 0}], 
     InsetBox[
      FormBox[
       StyleBox["\"\[FivePointedStar]\"", Medium, StripOnInput -> False], 
       TraditionalForm], {14, 0}]}},
  Method->{},
  PlotRange->{{0, 14}, {0., 0.7777773828800543}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{
  3.577701410635844*^9},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"p5", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{"BSplineBasis", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"degx", ",", "knotsx"}], "}"}], ",", "4", ",", "x"}], "]"}], 
     "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", "14"}], "}"}], ",", 
    RowBox[{"Epilog", "->", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Text", "[", 
        RowBox[{
         RowBox[{"Style", "[", "symB5", "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"9", ",", "0.5"}], "}"}]}], "]"}], ",", "symKnots"}], 
      "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.48759641690625*^9, 3.487596459359375*^9}, {
   3.48759649453125*^9, 3.487596511875*^9}, {3.48759660684375*^9, 
   3.48759660915625*^9}, 3.487674766421875*^9, 3.487674835546875*^9, 
   3.48767535725*^9, {3.487677004125*^9, 3.487677027484375*^9}, 
   3.48767707025*^9, 3.48767715565625*^9, {3.487678197109375*^9, 
   3.48767822096875*^9}, 3.487678280421875*^9, {3.560542193383422*^9, 
   3.560542218669089*^9}, 3.560543932966192*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxF13k0VW3UAHBJlJJkSLqu6d5zLxeJlKHsnQrJEEkKb9KkzPJKEhKSBpSM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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  Epilog->{
    InsetBox[
     FormBox[
      StyleBox[
       SubsuperscriptBox["B", "5", "3"], StripOnInput -> False], 
      TraditionalForm], {9, 0.5}], {
     InsetBox[
      FormBox[
       StyleBox["\"\[FivePointedStar]\"", Medium, StripOnInput -> False], 
       TraditionalForm], {0, 0}], 
     InsetBox[
      FormBox[
       StyleBox["\"\[FivePointedStar]\"", Medium, StripOnInput -> False], 
       TraditionalForm], {3.5, 0}], 
     InsetBox[
      FormBox[
       StyleBox["\"\[FivePointedStar]\"", Medium, StripOnInput -> False], 
       TraditionalForm], {7., 0}], 
     InsetBox[
      FormBox[
       StyleBox["\"\[FivePointedStar]\"", Medium, StripOnInput -> False], 
       TraditionalForm], {10., 0}], 
     InsetBox[
      FormBox[
       StyleBox["\"\[FivePointedStar]\"", Medium, StripOnInput -> False], 
       TraditionalForm], {14, 0}]}},
  Method->{},
  PlotRange->{{0, 14}, {0., 0.6363636127363811}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{
  3.577701410678954*^9},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"p6", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{"BSplineBasis", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"degx", ",", "knotsx"}], "}"}], ",", "5", ",", "x"}], "]"}], 
     "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", "14"}], "}"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
    RowBox[{"Epilog", "->", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Text", "[", 
        RowBox[{
         RowBox[{"Style", "[", "symB6", "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"12.", ",", "0.6"}], "}"}]}], "]"}], ",", "symKnots"}], 
      "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.48759641690625*^9, 3.487596459359375*^9}, {
   3.487596497375*^9, 3.487596514078125*^9}, {3.487596612*^9, 
   3.487596612578125*^9}, 3.48767476703125*^9, 3.487674836171875*^9, 
   3.48767535725*^9, {3.48767700725*^9, 3.48767701378125*^9}, {
   3.48767708440625*^9, 3.48767714296875*^9}, {3.487678245703125*^9, 
   3.487678274984375*^9}, {3.560542228571639*^9, 3.560542243106405*^9}, 
   3.560543946197765*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxF1Akw1esbB3Ak3VAK6SRk+Z3T4ReFq2yd58naekSnRaWk7CRlaZEst6i0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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  Epilog->{
    InsetBox[
     FormBox[
      StyleBox[
       SubsuperscriptBox["B", "6", "3"], StripOnInput -> False], 
      TraditionalForm], {12., 0.6}], {
     InsetBox[
      FormBox[
       StyleBox["\"\[FivePointedStar]\"", Medium, StripOnInput -> False], 
       TraditionalForm], {0, 0}], 
     InsetBox[
      FormBox[
       StyleBox["\"\[FivePointedStar]\"", Medium, StripOnInput -> False], 
       TraditionalForm], {3.5, 0}], 
     InsetBox[
      FormBox[
       StyleBox["\"\[FivePointedStar]\"", Medium, StripOnInput -> False], 
       TraditionalForm], {7., 0}], 
     InsetBox[
      FormBox[
       StyleBox["\"\[FivePointedStar]\"", Medium, StripOnInput -> False], 
       TraditionalForm], {10., 0}], 
     InsetBox[
      FormBox[
       StyleBox["\"\[FivePointedStar]\"", Medium, StripOnInput -> False], 
       TraditionalForm], {14, 0}]}},
  Method->{},
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.577701410719755*^9},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]],

Cell[TextData[{
 "We remind that the support of ",
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["B", "1", "2"], TraditionalForm]]],
 "(x) is formed by  4 knots, of which the first three are coincident; in the \
support for  ",
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["B", "2", "2"], TraditionalForm]]],
 "(x),   the first two knots are coincident; all the knots for  ",
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["B", "3", "2"], TraditionalForm]]],
 "(x)   are distinct."
}], "Text",
 CellChangeTimes->{{3.482664394578125*^9, 3.482664468984375*^9}, {
   3.482664514625*^9, 3.482664539265625*^9}, {3.48275498540625*^9, 
   3.48275501025*^9}, {3.482755052734375*^9, 3.48275518615625*^9}, 
   3.484914425703125*^9, {3.484914587328125*^9, 3.484914590265625*^9}, {
   3.4849790056875*^9, 3.484979036765625*^9}, 3.48499291775*^9, {
   3.4849973990625*^9, 3.48499747065625*^9}, {3.484997518078125*^9, 
   3.484997519515625*^9}, {3.486033256890625*^9, 3.486033259125*^9}, {
   3.4860333613125*^9, 3.4860333878125*^9}, {3.486033419140625*^9, 
   3.486033420671875*^9}, {3.486033454171875*^9, 3.48603354928125*^9}, {
   3.486033587921875*^9, 3.486033646125*^9}, {3.4860336766875*^9, 
   3.48603369671875*^9}, {3.487677327484375*^9, 3.48767743590625*^9}, {
   3.487677468828125*^9, 3.48767752884375*^9}, {3.48767759678125*^9, 
   3.4876776201875*^9}, {3.487678337703125*^9, 3.487678360234375*^9}, {
   3.48767911278125*^9, 3.48767911421875*^9}, {3.560542304410742*^9, 
   3.560542311434954*^9}},
 FontFamily->"Times New Roman",
 FontSize->14,
 FontColor->GrayLevel[0],
 Background->GrayLevel[0.85]],

Cell["\<\
We reconstruct the spline and plot the resultant on each subdomain formed by \
the four knots\
\>", "Text",
 CellChangeTimes->{{3.482664394578125*^9, 3.482664468984375*^9}, {
   3.482664514625*^9, 3.482664539265625*^9}, {3.48275498540625*^9, 
   3.48275501025*^9}, {3.482755052734375*^9, 3.48275518615625*^9}, 
   3.484914425703125*^9, {3.484914587328125*^9, 3.484914590265625*^9}, {
   3.4849790056875*^9, 3.484979036765625*^9}, 3.48499291775*^9, {
   3.4849973990625*^9, 3.48499747065625*^9}, {3.484997518078125*^9, 
   3.484997519515625*^9}, {3.559508322045296*^9, 3.559508328452069*^9}},
 FontFamily->"Times New Roman",
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", "x_", "]"}], "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"coeff", ".", "bsplines"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.559507412758713*^9, 3.559507440327875*^9}, {
  3.559508155235904*^9, 3.559508183032079*^9}, {3.559542860157253*^9, 
  3.559542870016616*^9}}],

Cell[BoxData[
 TagBox[GridBox[{
    {"\[Piecewise]", GridBox[{
       {"0.`", 
        RowBox[{
         RowBox[{"x", ">", "14.`"}], "||", 
         RowBox[{"x", "<", "0"}]}]},
       {
        RowBox[{"54.39244564672879`", "\[VeryThinSpace]", "-", 
         RowBox[{"8.243362388538223`", " ", "x"}], "+", 
         RowBox[{"0.3164011622081956`", " ", 
          SuperscriptBox["x", "2"]}]}], 
        RowBox[{"10.`", "\[LessEqual]", "x", "\[LessEqual]", "14.`"}]},
       {
        RowBox[{
         RowBox[{"-", "28.675383228133448`"}], "+", 
         RowBox[{"8.370203386434223`", " ", "x"}], "-", 
         RowBox[{"0.5142771265404268`", " ", 
          SuperscriptBox["x", "2"]}]}], 
        RowBox[{"7.`", "\[LessEqual]", "x", "<", "10.`"}]},
       {
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1.3688007213706044`", "\[VeryThinSpace]", "-", 
           RowBox[{"0.18440036068530208`", " ", "x"}]}], ")"}], " ", "x"}], 
        RowBox[{"0.`", "\[LessEqual]", "x", "<", "3.5`"}]},
       {
        RowBox[{"4.17047390041078`", "\[VeryThinSpace]", "-", 
         RowBox[{"1.01432722172127`", " ", "x"}], "+", 
         RowBox[{"0.15604648832782286`", " ", 
          SuperscriptBox["x", "2"]}]}], 
        TagBox["True",
         "PiecewiseDefault",
         AutoDelete->True]}
      },
      AllowedDimensions->{2, Automatic},
      Editable->True,
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxItemSize->{
       "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.84]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}},
      Selectable->True]}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxItemSize->{
    "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[0.35]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  "Piecewise",
  DeleteWithContents->True,
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 CellChangeTimes->{3.577701410838628*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"f1", "[", "x_", "]"}], "=", 
  RowBox[{
   RowBox[{"f", "[", "x", "]"}], "[", 
   RowBox[{"[", 
    RowBox[{"1", ",", "3", ",", "1"}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.482664798328125*^9, 3.482664876421875*^9}, {
  3.482665070609375*^9, 3.482665072234375*^9}, {3.484914595796875*^9, 
  3.48491461284375*^9}, {3.484917527796875*^9, 3.48491757125*^9}, {
  3.484992918484375*^9, 3.484992919515625*^9}, {3.487597965578125*^9, 
  3.487597966796875*^9}, {3.560542421629487*^9, 3.56054243631225*^9}, {
  3.56054276181186*^9, 3.560542797077459*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "28.675383228133448`"}], "+", 
  RowBox[{"8.370203386434223`", " ", "x"}], "-", 
  RowBox[{"0.5142771265404268`", " ", 
   SuperscriptBox["x", "2"]}]}]], "Output",
 CellChangeTimes->{3.5777014108758*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"segment1", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{"f1", "[", "x", "]"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", "3.5"}], "}"}]}], "]"}], " "}]], "Input",
 CellChangeTimes->{{3.4826639558125*^9, 3.48266397771875*^9}, {
   3.482664893203125*^9, 3.48266489575*^9}, {3.4826649806875*^9, 
   3.482664982765625*^9}, {3.482665113578125*^9, 3.482665156546875*^9}, {
   3.482665204203125*^9, 3.482665208359375*^9}, 3.4849145061875*^9, {
   3.48499787665625*^9, 3.484997877140625*^9}, {3.48499791696875*^9, 
   3.48499791890625*^9}, 3.560542444274894*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwB4QQe+yFib1JlAgAAAE0AAAACAAAAoVirt4gscz7EQkXg5aw8wKT6FoKj
llE/qtI8FJmqPMBNiwUpfZZhPzawFlxMqDzAotN8/GmWcT8/VHEns6M8wMx3
OGZgloE/GUDCrIGaPMDhSRabW5aRP+qm0nEiiDzA7DKFNVmWoT8Esa3lcmM8
wHGnvAJYlrE/FLdMdE8aPMAuLq2ZslPCP4JCVezLfDvAK7/xcH46yz8dcw0i
Cus6wAGH0GtL+tE/xbkjw2BdOsCplFI3BbbWP0G+9e0XxTnAln1PouEg2z8f
qlhfRTg5wL/MdqVr6t8/3uFyLBOhOMBrvSn4zU7iP30GecURDjjAGIJVbfd/
5D/t6BdcOYY3wON5lq534OY/51jYslD0NsBQ35Q/iRjpPw8P0qNpbTbAM/Rt
9G1F6z/awviZZOo1wDU8XHWpoe0/6YMFvpxdNcDZ8QdGdtXvP9OomzuL2zTA
Tm1k8Uwc8T/sO5eL9k80wGo5slFISPI/hfXtL1zIM8BXvN5ZDGDzP9bERBsr
SzPA1NgVyHuP9D8IHXUFxsQywCKsK96zqvU/e5Ji76JIMsD/GExal932PwKe
QcaLwzHAl91ZaOQK+D95JpcVUUIxwABZRh76I/k/dGsN+grLMMD4bT06u1T6
P76UdVIgSzDAwTkT/kRx+z/pqX6WBaovwEVd1lM4iPw/0o0CpuXELsBZGqQP
17b9P+ZSH74Xzy3APo5Qcz7R/j/iEldSTewswNnNg56oAQBALnRfcFT5K8Bx
AFbM5pcAQBItLmCnDSvAco4XTgkkAUBO1rxjYzQqwDpp3oIBvAFAXG8wj49L
KcBrn5QL3kkCQOSrHh3WdCjAeYFBXe/UAkBEpkgay6QnwE+w82HWawNADFsg
8MrFJsCNOpW6ofgDQEQ3qNBO+CXAkxE8xkKRBEDLMx2wXBwlwAJE0iXIHwVA
n7AEjp9RJMBOIl9OgqsFQNanf6NVjSPAYk3xKRJDBkAD8cgdMbsiwN7TclmG
0AZAQxmUjqr5IcAip/k70GkHQPFRnh3JKiHAQyZ3504ACEB+m4uti2IgwM0A
5OaxjAhAlJauEKNUH8AfKFaZ6iQJQC3mRMm2yh3A2aq3nwezCUCnsI5vM2Ac
wHHZD29ZPgpAnfmLx7wBG8DQVG3xgNUKQAX6cQ4EixnAmCu6x4xiC0CeoOUM
hzIYwNjpdJQCZQtAkppXMJAsGMAYqC9heGcLQD/vY7eZJhjAmSSl+mNsC0Dd
qEvwrRoYwJodkC07dgtAB11XDdsCGMCbD2aT6YkLQCDJX/RH0xfAnvMRX0ax
C0BUsDR2bHQXwN6xzCu8swtAGgLyDIJuF8AecIf4MbYLQKKuSQeYaBfAn+z8
kR27C0DsF8gmxVwXwKDl58T0xAtAbCsBESRFF8Ch170qo9gLQDZWZJL0FRfA
4pV49xjbC0DpU8diEBAXwCJUM8SO3QtAXKzEliwKF8Ci0KhdeuILQHttjilm
/hbAosmTkFHsC0CtMF763eYWwOKHTl3H7gtAVwSU5/zgFsAiRgkqPfELQMAy
ZDgc2xbAo8J+wyj2C0DIn9MEXM8WwOSAOZCe+AtAa95ygHzJFsAkP/RcFPsL
QM93rF+dwxbAZP2uKYr9C0Dta4Civr0WwKS7afb//wtAz7ruSOC3FsAtKkZO

     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0, -29.},
  Method->{},
  PlotRange->{{0, 3.5}, {-28.67538263026178, -5.679566516467005}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{
  3.577701410901752*^9},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"f2", "[", "x_", "]"}], "=", 
  RowBox[{
   RowBox[{"f", "[", "x", "]"}], "[", 
   RowBox[{"[", 
    RowBox[{"1", ",", "4", ",", "1"}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.482664798328125*^9, 3.482664876421875*^9}, {
  3.482665070609375*^9, 3.482665072234375*^9}, {3.484914595796875*^9, 
  3.48491461284375*^9}, {3.48491465646875*^9, 3.48491468153125*^9}, {
  3.484914796234375*^9, 3.48491482015625*^9}, {3.484914870453125*^9, 
  3.48491489696875*^9}, {3.484917425203125*^9, 3.484917425734375*^9}, {
  3.48491749365625*^9, 3.484917494078125*^9}, {3.484975188671875*^9, 
  3.48497523265625*^9}, {3.48499291996875*^9, 3.48499292084375*^9}, {
  3.487597989765625*^9, 3.487597993375*^9}, {3.56054245098733*^9, 
  3.560542466863947*^9}, {3.560542814080294*^9, 3.560542814283745*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"1.3688007213706044`", "\[VeryThinSpace]", "-", 
    RowBox[{"0.18440036068530208`", " ", "x"}]}], ")"}], " ", "x"}]], "Output",
 CellChangeTimes->{3.57770141092019*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"segment2", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{"f2", "[", "x", "]"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "3.5", ",", "7.0"}], "}"}]}], "]"}], " "}]], "Input",
 CellChangeTimes->{{3.4826639558125*^9, 3.48266397771875*^9}, {
   3.482664893203125*^9, 3.48266489575*^9}, {3.4826649806875*^9, 
   3.482664982765625*^9}, {3.482665113578125*^9, 3.482665156546875*^9}, {
   3.482665204203125*^9, 3.482665208359375*^9}, 3.4849145061875*^9, {
   3.484975271390625*^9, 3.484975284296875*^9}, {3.484997882078125*^9, 
   3.484997911578125*^9}, 3.560542472978189*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV1nk8VdsXAPDLPcrT2edeQ6ZLMheSuYnOyhQ3cxK/VM+QJOQVKWUoaVDC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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{3.5, 0.6000000000000001},
  Method->{},
  PlotRange->{{3.5, 7.}, {0.5459874626433079, 2.5401460781044936`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{
  3.577701410955492*^9},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"f3", "[", "x_", "]"}], "=", 
  RowBox[{
   RowBox[{"f", "[", "x", "]"}], "[", 
   RowBox[{"[", 
    RowBox[{"1", ",", "2", ",", "1"}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.482664798328125*^9, 3.482664876421875*^9}, {
  3.482665070609375*^9, 3.482665072234375*^9}, {3.484914595796875*^9, 
  3.48491461284375*^9}, {3.48491465646875*^9, 3.48491468153125*^9}, {
  3.484914796234375*^9, 3.48491482015625*^9}, {3.484914870453125*^9, 
  3.48491489696875*^9}, {3.484917425203125*^9, 3.484917425734375*^9}, {
  3.48497532003125*^9, 3.484975320453125*^9}, {3.48497535390625*^9, 
  3.48497538434375*^9}, {3.484975434296875*^9, 3.48497543875*^9}, {
  3.484992921234375*^9, 3.48499292203125*^9}, {3.48759802596875*^9, 
  3.48759802946875*^9}, {3.560542484282909*^9, 3.560542509449363*^9}, {
  3.560542834682199*^9, 3.560542837640813*^9}}],

Cell[BoxData[
 RowBox[{"54.39244564672879`", "\[VeryThinSpace]", "-", 
  RowBox[{"8.243362388538223`", " ", "x"}], "+", 
  RowBox[{"0.3164011622081956`", " ", 
   SuperscriptBox["x", "2"]}]}]], "Output",
 CellChangeTimes->{3.577701410983487*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"segment3", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{"f3", "[", "x", "]"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "7", ",", "10"}], "}"}]}], "]"}], " "}]], "Input",
 CellChangeTimes->{{3.4826639558125*^9, 3.48266397771875*^9}, {
   3.482664893203125*^9, 3.48266489575*^9}, {3.4826649806875*^9, 
   3.482664982765625*^9}, {3.482665113578125*^9, 3.482665156546875*^9}, {
   3.482665204203125*^9, 3.482665208359375*^9}, 3.4849145061875*^9, {
   3.484975271390625*^9, 3.484975284296875*^9}, {3.484975398203125*^9, 
   3.484975417578125*^9}, {3.48499788959375*^9, 3.484997906578125*^9}, 
   3.560542519280049*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV0mlQkwcQBuBIYACTjyscBnJ/IQRBOZxaTLF9QS0I8SgDiuKBXIYq4BQF
jeNBHRW1ZECr4GAhCoooymVamyqgVoSIReU+VESLCAFCpGBFtF9/7Ow8P/ad
nZ0VxqSExZvQaLQVVP3f3VpdTGk0DlR52sncGClkAXsWjlMON/jbNkVLsfJ6
u6J/FgdJJr8vpm2WIi0z59GfdA5uRBQ0KaKkqPc3zz1mzsGhm9y7snAp4i4a
3VnWHJiljDH6l0mhTmtcJeFxcLvwufPX7lKw2en5cn8O3lvrXT0NbpjTwC2+
uo8DRO6Njt/lhmmGR5lGy4FjSGSRke6GZo/h+VmTHNTbaKo6TktQrpkUpX/J
xcd3Sz+X8CVIbVU4MndyIYoOdcmscsWSjZK91RoutLIoSdZiV5jePbNeOsmF
+rv95rQmMUr/SFoU7MuD31tut3+sGFH87GPKVB4GvbZvGTCSMDixu9ZW8KAb
vfz1whMk0vThRSZ6Hmy6erVlEhKWHr3Paz35sCiaGWrTinDwUyNbmshHjWhb
4pa1ItD96fUXrvCxJmifuEsvRHrEmH5oiI9PX8TvzjosxJtZ5y1TWAL4ercl
bZIIwbba0Ta+QICJiSnf2DoBbscZBSFhAugO7nfaEiPA1h3OFz1SBRB0j807
O83H7KH8gdRTAnw8xI2p9uODf/1xSU6lAHnpob0LDvMgc7t63u+pAA183zX8
+1w8GPJz0RgE8Es5Vetuz4WcIwjLsxLCPlRcOajgoMPk2h1TLyE8y394UVDp
gtYFIxXfrhBCPcu1ctjCBR3slk7bZMqjHfSicGe0JNnVLFEJ8Tj/5d+yS2wE
MM3I0DIhxOXG1mdmbGg2/1LX0yREhXNpqXL9HOTPDD4LGBbC8OTG1p5bTlBa
qm5aWYoQaV+dpBI7YbOu82GcuwjZ8nk+DzIc8Wtb+6bsIBEaWlZPfKV3AOuM
cu4yhQjq5ZMJpXIH9Kuf7Go+IsLO7ohYhtYepewf99cViyCdYvCPe9ojLaiz
VnZfhJ+Cn5ipTrOgqX158PgrEewbEkZmZrPwQZ+tjDUlkecoSk9It4Nf5lmf
IjEJb5f73U5vbTGYFKG4GUiiL8die2mCLQosfutYE0viZ/PCwHs9NqgfeViv
yyARt0RLT9tggzeQpV4sJKHQMnzq71nDavnKSMs66o8Y5naNNVYoyXe4Hfic
RHYmsXekmUA2wa5qpFxnTfd59JCA8gCnZPULEpEn6QHXHhCQx5I5m/pIPD7m
mpJcS8Aw1yde2U9id8AI/Z/rBPy0cqJqgKTuc8KapSKg6zy0UThGAofNyk/K
CVSHHA27TNl7z/pL+4IJnLt1PMjLQCJToZ1SLCWQrM7xWTxO7bMo/zL8Cdgp
Cs3WvaPmi/sCJzwIRE1pr2VPkag4p1y3nUFgaWLNBaf3VF7QgfEN5gTm99zJ
LaDcp1e9WkEnQKttyCj7l8qf29zmPc1E8ZH2iIZpar/kFuOHISay3neFrPpI
YvWEV9ToABNp3z/7pp1y9K5cbn8/E8ErX7u/nqHul3i0QtfNhE/dG962T1Re
r3VGbTsTzr7DLCNli9CiqzeeMkEvHrXY85mEjSbA+8pfTOgdjDOfKSuch63U
Oib+A2kOCb4=
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{7., 3.5},
  Method->{},
  PlotRange->{{7, 10}, {3.5989380994317806`, 12.19256564166815}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{
  3.577701411011368*^9},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"f4", "[", "x_", "]"}], "=", 
  RowBox[{
   RowBox[{"f", "[", "x", "]"}], "[", 
   RowBox[{"[", "2", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.482664798328125*^9, 3.482664876421875*^9}, {
   3.482665070609375*^9, 3.482665072234375*^9}, {3.484914595796875*^9, 
   3.48491461284375*^9}, {3.48491465646875*^9, 3.48491468153125*^9}, {
   3.484914796234375*^9, 3.48491482015625*^9}, {3.484914870453125*^9, 
   3.48491489696875*^9}, {3.484917425203125*^9, 3.484917425734375*^9}, {
   3.484992922453125*^9, 3.484992923234375*^9}, {3.487598037453125*^9, 
   3.48759804065625*^9}, {3.560542525017014*^9, 3.560542529823891*^9}, 
   3.560542859186751*^9}],

Cell[BoxData[
 RowBox[{"4.17047390041078`", "\[VeryThinSpace]", "-", 
  RowBox[{"1.01432722172127`", " ", "x"}], "+", 
  RowBox[{"0.15604648832782286`", " ", 
   SuperscriptBox["x", "2"]}]}]], "Output",
 CellChangeTimes->{3.577701411035303*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"segment4", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{"f4", "[", "x", "]"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "10", ",", "14"}], "}"}]}], "]"}], " "}]], "Input",
 CellChangeTimes->{{3.4826639558125*^9, 3.48266397771875*^9}, {
   3.482664893203125*^9, 3.48266489575*^9}, {3.4826649806875*^9, 
   3.482664982765625*^9}, {3.482665113578125*^9, 3.482665156546875*^9}, {
   3.482665204203125*^9, 3.482665208359375*^9}, 3.4849145061875*^9, {
   3.484914830375*^9, 3.48491483578125*^9}, {3.484914908546875*^9, 
   3.4849149094375*^9}, {3.484916414625*^9, 3.48491641496875*^9}, {
   3.48497546071875*^9, 3.484975465046875*^9}, {3.48499789678125*^9, 
   3.484997898375*^9}, 3.560542605198299*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVzn841AccB/DrjHSKQivmFu57P79+nfta+rl3JiSu1Xbp2YSEjkPPqVT6
KedHxNNspFFL149LXVJX7lo2YbQWFUcd1TQSlaKJUOz2x+d5P6/n/Tzv5+MU
uXlNNJ1GowUb7/+0964yBgF65ODr1K9YaN4/3nTC6JPOGVf0vixk/7mgeNkU
AvePPc7k+rEw9t01URqdgKFWH94YwIJhT3mUmSmBo01dd+zELBTVltZPZxB4
8kRRfHUdC7NXZWTb2RKQv2hmjCawMDNmlbWIR+CW+riwvIiFqPTfahq+IXC9
NH4na9i4PzWJuXM3AfHbnB65mEBmkv+8sFMESoJtdZOnjTtNozdP3SUg5CY6
WJuxcTx3wNL8PYGoWld9TQQbvKV1H+6w2DA81F0W1LGhatP98IeYjTP1ziue
cTiQNf97rz2ZjY579YM0BQc5vzMqVp9kw6py+KL1Cw5eW8UsenabjXcnJpbH
BHLhH9AVf+EtG7eFTKLpHBcT8iVftjI5MGcyk2OteRiZ6PjV3o+DspNuHxjb
eBDvCTHclHNQNWwptX7KQ3HX0LGSEg7qNmjClwXxIVC3Tf+pjoMLg9FbF1Tw
MUda4ND/hoNZ3wd6tM0TwC+jqC1yLhdjo/OeO2QJ0FKwQ7jQl4urhbLBhWMC
rM1NES3fzEWnt+aRVEbis97qv+OPcFHrYBdj0kZiKdXtMlzDxawwZpAm0AXK
rpVEyUtjHzc7+7LWBZMprTXbbHjwPaxzOMB2hdZkMb1iKQ+JeTcyTpe4QvOm
56X5Jh5YpT5Z7dPdMKMxMbkmn4fH/PV9BZluCM2fqyqv4oE9VfLKa4o7Xl83
U+ie8dDu5Sgp2+KOx/r7NPYsPvb/EzzWNeAOqzVPueoFfNxdURkXK/LA/Err
YekGPlSTktErCR6omuEUnXGIjyVm6xr3qT2Q3rBlb7WGj7G/1PKsPg+cT1J6
h3byUdafkkuSQtikzjlmO02AnO5Td8elQsi3q1U0oQBhI4+Sbc4I4RruKBGH
CuDmXBrR3SsEWfbgvFYhwMgvVFod1xOZPTKl4pIA9nY/zt8e7wkDw9lH0SFA
b4VhPOWSJxLzHXJOmJBYX1CzZvOAJyIshrZ+7k4iKzm/UvKFCAXPrabpQkhY
NgpnMneIUH0+2DdzHwlVkc2iT3UiBGyQOlaWkRAk1fIcaRRsUhrOmLSQcHng
79nvQyFwk1NRpdGh6WVH5/pSOPDtroMyvbE/9JLhu5zCgJt7fEsriXyluUWx
P4WmrkKh8iGJ0tGLqSuCKGQFx9zweULios+FAJWEwgdH0+bUPhJ5AbFLEqQU
RJbhtV4vjP8xjnQejaUQN67V9BnNJpS59XEUDK3xR1a/IsGNXGvqmEDhWrY+
1OkNiWhTvqxFTkE+pHxePURC37t35uJdFFRPPz7c+o7Ee1H+6tjdFDqbQm7z
hkloH6SVFO6hID5noT48QuITPv3rwX0UXMK2JEWMkeh4G+d6VkFh48rGjbbj
JFro8ip9OoWfvbmSW0ZHySQh9EwK02w65nt8JLHOT6daf5ACaF78bqO1Wu+I
nGwKO/rz7IsmSGjSCp10ORTK23stgiZJBJ5tftVziEJPg8/HSaNTWP03bfMo
/AfR9BVp
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{10., 9.5},
  Method->{},
  PlotRange->{{10, 14}, {9.63185068794792, 20.55500423469082}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{
  3.5777014110594254`*^9},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]],

Cell["We plot the complete spline", "Text",
 CellChangeTimes->{{3.482664394578125*^9, 3.482664468984375*^9}, {
   3.482664514625*^9, 3.482664539265625*^9}, {3.48275498540625*^9, 
   3.48275501025*^9}, {3.482755052734375*^9, 3.48275518615625*^9}, {
   3.48491260909375*^9, 3.484912650578125*^9}, 3.48491287253125*^9, {
   3.48497766284375*^9, 3.484977663578125*^9}, {3.484979246015625*^9, 
   3.4849792499375*^9}, {3.484979322359375*^9, 3.484979372375*^9}, {
   3.484979455421875*^9, 3.48497947915625*^9}, {3.48603562734375*^9, 
   3.486035649875*^9}, {3.5605429039791*^9, 3.560542908362828*^9}},
 FontFamily->"Times New Roman",
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"graphSx", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"f", "[", "x", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", 
      RowBox[{"-", "1"}], ",", "15"}], "}"}], ",", 
    RowBox[{"AxesOrigin", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "0"}], "}"}]}], ",", 
    RowBox[{"PlotPoints", "\[Rule]", "500"}], ",", 
    RowBox[{"Epilog", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Red", ",", 
       RowBox[{"PointSize", "[", "Medium", "]"}], ",", 
       RowBox[{"Point", "[", "points", "]"}]}], "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{
  3.482232990035215*^9, {3.482662078546875*^9, 3.482662109859375*^9}, {
   3.482662150546875*^9, 3.4826622134375*^9}, {3.48266495928125*^9, 
   3.4826649904375*^9}, {3.484975777125*^9, 3.48497580125*^9}, {
   3.48497956090625*^9, 3.484979579671875*^9}, {3.48498021971875*^9, 
   3.48498023115625*^9}, {3.484997551734375*^9, 3.48499757775*^9}, {
   3.4860350655625*^9, 3.486035078453125*^9}, {3.486035127015625*^9, 
   3.48603512909375*^9}, {3.560542925730338*^9, 3.560542955965399*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQB2IQfUL55Lv//9/vZ4CCvPUOybx/EHxh6x3XpX4g+HFB
yw+YfkDwvzS0Tsp+gOAr3nM0u34Awa+asat2XSOCr8u7hieWGcHfzz1XoOrj
Wzh/1W236r0f38D5D14cVWT9/hrOd+IOXsfz/BWc/+/fjIVWL1/C+c/Z31Zp
XHsB50v5iU2QOvEczl+e+oPb+MwzOD9h0otc7t1P4fziCRPNuPY8gfMvnua3
5j30GM6PlpmjemHTIzjf3u5h2c6tD+F8/1KTdUmLH8D5oZd3Oino3IfzD8TV
fDtuehfObxGJLnsvchvO/52z+nCyxE04//R78bvhH6/B+QZv9fJCrlyB8z17
t5+Ze/sSnL8rPOZ72o4LcP7ezqf3fhadhfMNI9P3mXWehPPDahXNir2OwvmP
n+3z8Aw5iAhvL83ntkK7EOlhY50095KNcH66qym3eN9iOD/jdjHTJoYShH+E
KudszXKA8wF59bSI
      "]], LineBox[CompressedData["
1:eJwVkGk81Ykeh885/+M4nGzZXUWMyTamZL3K70fSxhh7UzLWa8pFKKEkbpZI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      "]], LineBox[CompressedData["
1:eJwVlGk4lQkDhi3v2Tjb+579HF0ha9KxjYjqqc6UiElJmlSHLJlBRc03lrQg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      "]], LineBox[CompressedData["
1:eJwd13k8lN0XAHCE/GxhZqLMmIVqiEiIJKdQdkNoZCzZIpVBRYulRSGJUkmK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      "]], LineBox[CompressedData["
1:eJwd13dcje//B/BT2kl92kuFdloqmq5LGmgRDUpDKCQaolAHEUrfhgaJoqES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      "]], LineBox[CompressedData["
1:eJxNz11IU3EABfDrLEyUyt1RZrKYlzJiQiuHlUbZB0ViYIUPJiarKys3dQ/L
ZWaRKG0rsYSFy4egtUhhY9NYy7WWgrEaPkhrmcUIkyLXNpHwlnZvBdH5Hzgc
fo9Hpmo8xoooitr3p3/3k+5Nfykl30v9S6ou8LyOcN8F7+4BwoVX3d4E4ZBp
QFmYArM9NpeBsMVmeZgigrmxll46Fa6WvTMfJxy4uLOth7BxK6eil8E5Vr2c
Xg4Xa5ueidPgNrpuJiuD+FNboVhNw7vun+vw5cHSdGbKtx2ORRtfWvfD6vDJ
4dAJeFWzSe1g4bvmcqdWD0f9zoUrnfAK1j6psxB/PdFmsR2u2fx4bZoHPpK5
sWJyDJ5eqbguROAHTy+3h7/AlVGVxMjB7g0z9u70gv/mJhYn9OvgmM1FObfA
GUz/19vFsERS1FBTBr9iTs8bqmGNnRHrNPCO8KZv2a2wOy8YlNyA10wLe+J9
cP5I2LPeAZ8pj89yfthcdsc7OA6fUn++NhKFpdyLOUcC7jQtKZOEE7mKFkUS
DpRaRUOEVWYN7Z2D7dIs5eg8XHCwyhBZgC2RLl82B/NnR6kqwuNdcuN7wk1v
+d6PP+Ch+nvDs4twLh8R5EtwR3fmgQbClY/0oSRhjj/04fsvuPZmq6yIh4OM
izUQth7Oif8kLJo6uq1EgOu17ecvEX4teJ74CZfcivEC4d+WB+3+
      "]]}, {}}, {{}, {}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{-1, 0},
  Epilog->{
    RGBColor[1, 0, 0], 
    PointSize[Medium], 
    PointBox[{{0, 0}, {2, 2}, {5, 3}, {9, 5}, {11, 2}, {14, 1}}]},
  Method->{},
  PlotRange->{{-1, 15}, {0., 5.382278057302763}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{
  3.577701411115796*^9},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]]
}, Open  ]],

Cell["Part IV", "Text",
 CellChangeTimes->{
  3.484992245703125*^9, {3.484992316015625*^9, 3.4849923314375*^9}, {
   3.48499253890625*^9, 3.484992628625*^9}, {3.484994235171875*^9, 
   3.484994236890625*^9}, {3.48499689084375*^9, 3.48499689559375*^9}, {
   3.48767985275*^9, 3.4876798598125*^9}, {3.560539989233566*^9, 
   3.5605399935075*^9}, {3.572683032405257*^9, 3.5726830337403336`*^9}, 
   3.5726830760287523`*^9},
 FontFamily->"Times New Roman",
 FontSize->36,
 FontColor->RGBColor[0, 0, 1],
 Background->RGBColor[1, 0.9, 0.8]],

Cell[CellGroupData[{

Cell[TextData[{
 "We can check graphically and manually  the ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["C", "1"], TraditionalForm]]],
 " and boundary conditions.\nIt is verified that no boundary conditions are \
introduced."
}], "Text",
 CellChangeTimes->{{3.4849789611875*^9, 3.48497897071875*^9}, {
   3.484979148703125*^9, 3.484979160640625*^9}, {3.484979192*^9, 
   3.484979203421875*^9}, {3.4849961621875*^9, 3.4849962291875*^9}, {
   3.48499627365625*^9, 3.48499632746875*^9}, 3.484996906109375*^9, {
   3.486039064921875*^9, 3.486039067234375*^9}, {3.4860391213125*^9, 
   3.486039158296875*^9}, {3.487681740421875*^9, 3.48768174615625*^9}, {
   3.560542971804951*^9, 3.560542983357932*^9}},
 FontFamily->"Times New Roman",
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"dSpline1", "=", " ", 
  RowBox[{"D", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{"f", "[", "x", "]"}], "]"}], ",", "x"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.560543005172978*^9, 3.560543006914804*^9}, {
  3.560584632971844*^9, 3.560584633263458*^9}}],

Cell[BoxData[
 TagBox[GridBox[{
    {"\[Piecewise]", GridBox[{
       {"0", 
        RowBox[{"x", "<", "0"}]},
       {
        RowBox[{
         RowBox[{
          RowBox[{"-", "0.18440036068530208`"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "7.422982885085576`"}], "+", "x"}], ")"}]}], "-", 
         RowBox[{"0.18440036068530208`", " ", "x"}]}], 
        RowBox[{"0", "<", "x", "<", 
         FractionBox["7", "2"]}]},
       {
        RowBox[{
         RowBox[{"-", "1.01432722172127`"}], "+", 
         RowBox[{"0.3120929766556457`", " ", "x"}]}], 
        RowBox[{
         FractionBox["7", "2"], "<", "x", "<", "7"}]},
       {
        RowBox[{"8.370203386434223`", "\[VeryThinSpace]", "-", 
         RowBox[{"1.0285542530808536`", " ", "x"}]}], 
        RowBox[{"7", "<", "x", "<", "10"}]},
       {
        RowBox[{
         RowBox[{"-", "8.243362388538223`"}], "+", 
         RowBox[{"0.6328023244163912`", " ", "x"}]}], 
        RowBox[{"10", "<", "x", "<", "14"}]},
       {"0", 
        RowBox[{"x", ">", "14"}]},
       {"Indeterminate", 
        TagBox["True",
         "PiecewiseDefault",
         AutoDelete->True]}
      },
      AllowedDimensions->{2, Automatic},
      Editable->True,
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxItemSize->{
       "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.84]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}},
      Selectable->True]}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxItemSize->{
    "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[0.35]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  "Piecewise",
  DeleteWithContents->True,
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 CellChangeTimes->{3.5777014113408833`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"graD1", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{"dSpline1", ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", 
      RowBox[{"-", "1"}], ",", "15"}], "}"}], ",", 
    RowBox[{"AxesOrigin", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "0"}], "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{
  3.560543015946636*^9, {3.560584638796559*^9, 3.56058463911704*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQBGIQXfhzY8D//+/3M0BB1Wl5xzPXEfyWub2GM9cj+NMc
M4WM4xH8XZ0KV9L2vYPzWaT6w8/VvIXzZ1jlxM39+QrOP1CtlmP9+SmcH+i7
d4GczDU4X8Uj7PXuU1fh/G9O700jKxH8WRaKpydfuwLnP1Fu/cox8TKcX/7L
x+sz60U439p/5/P++8fh/Acur2tO2SD4LVayQqyzjsH551QbbapCjsL5iX88
JqacPATn8wdvLC1K2w3nR9iJLniusAvOX6RZeSrm9g4434zBUd49YBucH7P2
wglpq41wvrdh5jPFl+vh/HvshtY8cWsR4bn1wJMH7ivg/AVyB/JFzOfA+Yxn
hUxLrKbD+UnVqb8u206C89uDC+rTm7rgfK8NolzqnQ1wviWr/vIHT0vgfABp
jo9I
      "]], LineBox[CompressedData["
1:eJwVzn881HcAx/EL1537FrdplJBGHov5UV3h9Oj9qcddPB61za9Wi+XH5OHH
I3lQQg/ZSmhhND/KGKY5k2ge6Fwsp915RN3q1NjlR87R2Y5w962HJs3+eD9e
f76fmyNPBh43YjAYgpX9X2+mu+j55Cl479BenhqlMZJkuMGTpaMnhWfXOUyj
cTi4XxWSA7tp+mn4Uxr03cPV+Q2FSA25nc9U0Ch+j/nMVVQC5cNUYYOcxuPW
MP+E6irktvzbqr9Noy7j28oz93/BwtlVxdnlNFKcxiW9vo04ONtzwOV7GsI/
PIes5E2oC88yfnSZRlJhkmno+K8IFbKSN2TQ4Ko3CZZG2iE3WxvYGEZDtK8r
9Mf4blTUrOcqHWmodO9HbaekeGWh6k2xpWFWFhMvb5DCP/uHzI2WK3//WKTP
TvdgdbzdyygWjf3FcWV7YmRI5DkqXk8boJm0Uo5G9UHQ655n22xAkaCj1txd
iVndfnastwHRS7bTFReVkM502ydsM2B363k352Elimf53slbDZhyONghuDQA
nzm3uIwNBvCNxxRpE0+Qq7d8ULSoh0Zq8maibBAfvpn6TtKhxy74+4sZI/ic
lWO1hq/HTEXyOY/pCXRt7nVq5i/ALcah09hoFqWSoCrOsTnEyXKuVqUZwJtg
5S216HD+Kd+zZWgR4r8nre90aqH9JN3u6LNl+EuGv7zOmcSqxRvcjVuMyG65
9dsu9jh2vgtvD2oyIcm8iWqTUhX6s3gKuTOLxJnn9fmQAXiZ9xsV7WSRTt06
52j7AdRdi/AMISyypq/yUiFjAOebCqpfHmKRuqxmv8luJbyHtEnrv2ER9aJS
XrBXCZFLpVXcIIsEajbcG9/3GBeUzIi1WWySmvTZGfPLCsyFVpQMFrCJjWvE
rqgDChx7sb2v5hqbiF8k0WJKAf5S2I5dzWwyF1qaHJn3EPNbJMwwFZtE+Y6c
bMt/gLC0hIZbHqbEzyY+JqSwDz72g/qgEVNiI8/+QlQiR/q95cDjL0yJ11rV
vT1H5RBHO7WkzJuSI8Gubn/aycG7eTrxGpNDrqoHjJj1Mrjx182MunII9519
Y6Tkd9gHB0zFnuMQttedZduxHhx7nSo8m8shH2WaxbbV9qCyvPp63hUOEcgj
Bg7G9MB6/GVkcx2HpAaz68/OS2GRUDBmUHCIIfFQwF/GUqzO7R/K3ESRR0Fj
vlsDfoPARe9ZtJUiXPVFmyOqLlxQWJf9tIMiJPHj+eyvusD4IO6QzJci3Xlp
5ZrTnVisYSs5iRS5JbOYqSqXwEvosc0mnSLPgyRShYMEKdrDha5ZFLFXh5e+
bezAgpvoU/+rFKlfvomQu2Lo7gj7S7opUujpd8VS0w7nsBPOor4Vj2w2Wnii
HbFGJZfETyjCDi7xOfWqDfU/d2rvj6541D7c2sw2TPlpfJ9pKfJ1olrzmN0G
Rx0l0i2s+JZzOxhXWpER02ieT6/4uAs7VyW34j99sg3C
      "]], LineBox[CompressedData["
1:eJwBMQPO/CFib1JlAgAAADIAAAACAAAAg5dT8HIKDEDwhI0jC2C0P9/VgsQg
EQxAEHVBKL+itD8eeaojMhsMQJCW+01LB7U/XBzSgkMlDEAAuLVz12u1P9hi
IUFmOQxA8Popv+80tj/S77+9q2EMQNCAElYgx7c/aM8ehZVsDECAGWK8HTS4
P/6ufUx/dwxAILKxIhuhuD8pbjvbUo0MQHDjUO8Ve7k/gOy2+Pm4DEAARo+I
Cy+7Py7prTNIEA1AMAsMu/aWvj+K4pup5L4NQMDKApBms8I/Q9V3lR0cD0AY
Vfz0PIPJPwsdp+/k5BBASIA2opFx0z+JabVmoCQSQLxNYeklrtk/80Cr5Gh/
E0D8xvEc5zjgP3EyxLQWwxRA9CLs1Ath4z/crsSL0SEWQFQ4kpG6zOY/+GrU
myl6F0Bms5evdyjqPyhBB/5muxhAUmpWXYVK7T9EoiFnsRcaQFJt4IcOWPA/
MZgOJsYcGkCqtGRYZl7wPx6O++TaIRpAAvzoKL5k8D/3edViBCwaQLKK8clt
cfA/qlGJXldAGkAUqAIMzYrwPxAB8VX9aBpA1uIkkIu98D/cX8BESboaQFxY
aZgII/E/yVWtA16/GkC0n+1oYCnxP7ZLmsJyxBpADudxObgv8T+PN3RAnM4a
QL51etpnPPE/Qg8oPO/iGkAek4scx1XxP6i+jzOVCxtA4s2toIWI8T90HV8i
4VwbQGZD8qgC7vE/YFAwVtxhG0CKSTmWOvTxP0uDAYrXZhtArk+Ag3L68T8i
6aPxzXAbQPZbDl7iBvI/0LTowLqEG0CEdCoTwh/yPyxMcl+UrBtAoqVifYFR
8j8Yf0OTj7EbQMarqWq5V/I/A7IUx4q2G0DqsfBX8V3yP9oXty6BwBtAML5+
MmFq8j+I4/v9bdQbQMDWmudAg/I/dBbNMWnZG0Dk3OHUeInyP19JnmVk3htA
BuMowrCP8j82r0DNWugbQE7vtpwgnPI/IuIRAVbtG0By9f2JWKLyPw0V4zRR
8htAlvtEd5Co8j/4R7RoTPcbQLgBjGTIrvI/5HqFnEf8G0DeB9NRALXyP+R6
hZxH/BtA3gfTUQC18j/xbXjP
      "]], LineBox[CompressedData["
1:eJxlkGtMk3cUxiu6ia6rgJcBfbn132RMWCBbR3ElvCebjkplwgbzEpDRSBgp
WAYyUbpGVKBoHA2yRa0Cpkkp3nAg3QyZp27RVVGGE0iZGRbU2iKOWtfa+/bu
8z6cnJzk/J4nz5MklX9SHsZisYTM/LeHLW8uyX6VgvGSgnPubietW+kVrnuN
gnT9wHsNR5x0x0e3ZIIIClTOlUbvV05auVfTnbaagkdZ9bmNUiddeb7q3tpY
CqB1cjyQ56QhaoUoiU+Bh3vC/g/fSZ/qOz7lk1Bg3qXNYjc9p4vM59Zc1FDQ
uerHWf46B13Vd1y5+gwFgkgz2HkO+tC+ZqtCR8HY656uC2wHPUCVGiTfU5DM
qTFUGRdoTlnUZ/YbFGS+kPe2cxZok73hW76TAvFP8raJs8/oLP+GVRpxHGwt
kOeVPZyjSbwlUuWKA/XeXRMNhY/pJUphaU5mArAKFz1U2SfoSsHw1DJJIrBM
rOuHyg5g30Zpz1V3IljidQ/adJP44mlshPW7JDCKlPCk6zEOfpqzuHM9D0w8
m7l9pwO/Fjd3X7bywChsHTl90oVjO74oTrfzYCw8bJ7d70JevSTm/FMeWKYU
bMUvLjSdiTymdfAgXFGbt33ehVH+0y0dPh7kG0t+W5PtRt0FQ3UNh4BFLLjX
PuPG0SibKDWDAGv7zB9NyR5MfGvE05tJIDyl2O/I8mAdfXGIiAgkBia5nxd4
MLpqdxoXCIi7bhdn7/Og9DqLLM8loJ79Ydo34kH3npjlthIC0bJvZuvkXkz4
M9esbSYACtFcucGHqp9F/UUqAhGalxkdt33o6E1tWXqEgPnK4MGrsz401nIE
MjWBmpcpcW+s8KM0/Pf2dzQE9LVUvqnCj7p3t+Vcu8ToVwaH1sYEkBOTG183
yORpvRK2JS2Ae0Lvu/gGApd09ZsPbgig+CalVQ0TyH/0zHb/ywDad1hCm28Q
2F86zT16K4CphysM0/cJ2IqwaaExiJ3yrUfV0wy/u3GU2xHEYOHGnR/MMP/H
hFyxPoijCSlROivTx93+yz3jQcx4hbJvsTP8gmzRnbkgds2xjcvmGZ6T/LGX
FUL50F/V1c8Z/009TwreDqH55IP1CX8zvKxYoPwwhLB/jHvXzfBt0U1nt4VQ
X37NecDL8PrxO5PyEEZIBm4KAoz/r+rYxS0hbEjX9lhDTP/WTRVpp/5//wu1
7bUM
      "]], LineBox[CompressedData["
1:eJwB8QIO/SFib1JlAgAAAC4AAAACAAAASvuETkoEJEDIjv+Rgo/+v7LgdSX8
BiRAiEU8UN6B/r8axmb8rQkkQEj8eA46dP6/g6tX018MJEAAs7XMlWb+v1R2
OYHDESRAfCAvSU1L/r/1C/3cihwkQHD7IUK8FP6/ODeElBkyJEBYsQc0mqf9
v9RiGTadNCRA0D9u39+a/b9xjq7XIDckQETO1Ioljv2/quXYGig8JEAw66Hh
sHT9vxyULaE2RiRABCU8j8dB/b8A8datU1okQLCYcOr02/y/yaopx42CJEAA
gNmgTxD8v1oez/kB0yRAqE6rDQV5+r/zyo3icIElQFAe/TX3Bfe/lgRedFIk
JkAM3MSoZM3zvxHetaICxCZASEkVEvyk8L8DfYFUOXEnQLjRJ5Q1cOq//qhe
r+ISKEAQ7RCZaQvkv3Car40SwihAQNqsdlg72r+7K4gIEW4pQIAwtSoLQcm/
D0pyLIIOKkAAYPEfImBQP9ot0NN5vCpAAGPDPVGmyz+unj8k5F4rQIC5y/ED
rNo/8XrzB2FhK0Cg1q6/ZN7aPzRXp+vdYytAwPORjcUQ2z+5Dw+z12grQCAu
WCmHdds/xIDeQctyK0DAouRgCj/cP9lifV+yhitA4Iv9zxDS3T8EJ7uagK4r
QDCvF9cOfOA/RwNvfv2wK0DAPQk+P5XgP4rfImJ6sytAYMz6pG+u4D8PmIop
dLgrQIDp3XLQ4OA/GglauGfCK0DQI6QOkkXhPzDr+NVO1itAcJgwRhUP4j9z
x6y5y9grQBAnIq1FKOI/tqNgnUjbK0CgtRMUdkHiPztcyGRC4CtAwNL24dZz
4j9GzZfzNeorQBANvX2Y2OI/iKlL17LsK0Cgm67kyPHiP8uF/7ov7ytAQCqg
S/kK4z9QPmeCKfQrQGBHgxlaPeM/kxobZqb2K0Dw1XSAilbjP9b2zkkj+StA
kGRm57pv4z8Y04ItoPsrQCDzV07riOM/3/QKAAD+K0Dg5aRo9aDjP8PlZR4=

      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGAwBmIQLc/99f9/Rh0HBijgYdvF08yM4KdurOYyY0Pw98XY
crzkQPDFOP6zzuFG8PM3H2D250PwFbhc/m8RRvArtrL+TRdD8C8mHP8lJYng
N233+tYgh+A/SQl866OJ4NsICL/+r43gT9195cUmPQTfTSjiiYQJgr9if9zt
J3YIfo5UzsmaEAT/yFHd4/rhCL5s4fsjjyIR/HPHiw54xCP4BqWV20WyEPyv
59uWrqlH8OtaFzbeWYXgc5ezeyWuRfBnZOQKPVuP4G/0tlz8fguSfwUvHmHa
j+B7zmPg0LyM4Itsj+8r/Y3gr34hO5vPRxfOb5vbmnDPD8FPCnqrui4QwZfa
s2eDbziC39EffawnCcFPM5v5kasSwVdsEfFgX4bg/7Go4b2+AsG/8fbxpWWr
EfwJ4Ztj3TYi+P+0gopb9yD4dy72z2O+jODvaPuefPkqgj/FOl5z8Q0E33up
3hanewj+roqzJxtfIvjTdE37A98g+IWP5oQovkfwNXxy7h/4guCzMF5ZMuE7
gv9gq3VWwi8Ef0/WYn2Dvwj+dHAGQfAB3Xivpg==
      "]]}, {}}, {{}, {}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{-1, 0},
  Method->{},
  PlotRange->{{-1, 15}, {-1.9131311450168074`, 1.366919085037081}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{
  3.57770141151188*^9},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]],

Cell["Second derivative of S (x)", "Text",
 CellChangeTimes->{{3.486038846015625*^9, 3.4860388865*^9}},
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"dSpline2", "=", " ", 
  RowBox[{"D", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{"f", "[", "x", "]"}], "]"}], ",", "x", ",", "x"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.560543273364825*^9, 3.560543275170184*^9}, {
  3.560584642481761*^9, 3.560584642701956*^9}}],

Cell[BoxData[
 TagBox[GridBox[{
    {"\[Piecewise]", GridBox[{
       {"0", 
        RowBox[{"x", "<", "0"}]},
       {
        RowBox[{"-", "0.36880072137060416`"}], 
        RowBox[{"0", "<", "x", "<", 
         FractionBox["7", "2"]}]},
       {"0.3120929766556457`", 
        RowBox[{
         FractionBox["7", "2"], "<", "x", "<", "7"}]},
       {
        RowBox[{"-", "1.0285542530808536`"}], 
        RowBox[{"7", "<", "x", "<", "10"}]},
       {"0.6328023244163912`", 
        RowBox[{"10", "<", "x", "<", "14"}]},
       {"0", 
        RowBox[{"x", ">", "14"}]},
       {"Indeterminate", 
        TagBox["True",
         "PiecewiseDefault",
         AutoDelete->True]}
      },
      AllowedDimensions->{2, Automatic},
      Editable->True,
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxItemSize->{
       "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.84]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}},
      Selectable->True]}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxItemSize->{
    "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[0.35]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  "Piecewise",
  DeleteWithContents->True,
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 CellChangeTimes->{3.577701411620537*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"graD2", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{"dSpline2", ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", 
      RowBox[{"-", "1"}], ",", "15"}], "}"}], ",", 
    RowBox[{"AxesOrigin", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "0"}], "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.486038846015625*^9, 3.48603889146875*^9}, 
   3.560543034663514*^9, {3.560584645776663*^9, 3.560584645979656*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQBGIQXfhzY8D//+/3M0BB1Wl5xzPXEfyWub2GM9cj+NMc
M4WM4xH8XZ0KV9L2vYPzWaT6w8/VvIXzZ1jlxM39+QrOP1CtlmP9+SmcH+i7
d4GczDU4X8Uj7PXuU1fh/G9O700jKxH8WRaKpydfuwLnP1Fu/cox8TKcX/7L
x+sz60U439p/5/P++8fh/Acur2tO2SD4LVayQqyzjsH551QbbapCjsL5iX88
JqacPATn8wdvLC1K2w3nR9iJLniusAvOX6RZeSrm9g4434zBUd49YBucH7P2
wglpq41wvrdh5jPFl+vh/HvshtY8cWsR4bn1wJMH7ivg/AVyB/JFzOfA+Yxn
hUxLrKbD+UnVqb8u206C89uDC+rTm7rgfK8NolzqnQ1wviWr/vIHT0vgfABp
jo9I
      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQbcmqv/zB0xL7Pycdw/NmXd9/t+jLapOjVXD+mjsh
p29Ft8P5F7fEB+QtmA/nL6vtmlt+ciWcL/BI3uXP3W1w/nKnvTHzsg/A+U+e
il+6l3IKzp/osnMxv/4lON/MPiBgB8NdOP/tnOI6g5eP4Xy9DOU9zEzv4Pys
o+0z5ld+gfObrlqZb7rxE85/4VslF3X7H5zP+HO1gLQqkwOMb/o/YVvwOhY4
/3SLybljWuxwfvMl1kTeFg4431rh+ufgu5xwvkJI4LPMOi44n63j9I16eW44
/+dCjktcBQj+m92up6ceQPAzmaZ27riC4D/zeOJ++wWCr/KGe/mbTwh+TcYa
/t6vCD4AjbL3Ew==
      "]], 
     LineBox[{{3.5051020408163263`, 0.3120929766556457}, {3.5083632805278593`,
       0.3120929766556457}, {3.5280270660699493`, 0.3120929766556457}, {
      3.54769085161204, 0.3120929766556457}, {3.7182095766732504`, 
      0.3120929766556457}, {3.8887283017344614`, 0.3120929766556457}, {
      4.223529572081371, 0.3120929766556457}, {4.535768132040524, 
      0.3120929766556457}, {4.874423573448655, 0.3120929766556457}, {
      5.190516304469029, 0.3120929766556457}, {5.5330259169383815`, 
      0.3120929766556457}, {5.869299349632222, 0.3120929766556457}, {
      6.183010071938305, 0.3120929766556457}, {6.523137675693366, 
      0.3120929766556457}, {6.681920122377019, 0.3120929766556457}, {
      6.840702569060671, 0.3120929766556457}, {6.918534747458619, 
      0.3120929766556457}, {6.994897959183673, 0.3120929766556457}}], 
     LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQfeC0ZoUlq4zDdt9Pvl9LPuzf/UCdxY4NwV8m/NPc
khvBn+R2KttEAMHPXJNzWUsKwXcQ4rdWVEHw390N5uKzQPDnrJxx85c3gv/D
QaniSjGCH3pjtdi62Qi+zW9XkdkesnC+stwDwY6vCD5LnXm8u4U8wj0mu29y
eivA+Ss9kxbs+4bgf34tJfBsmiKcvznYnXmKixKcX+vROn/LMwT/nNALax0z
ZThf/q7XjcWtCP4y40j3gxsQfJ2u9G33biP45+S1hZY9Q/Dzt77Lzf2I4Ds0
XJC++A3BF/DedNLkD5J9Uq+dk/8i+AA7Qeef
      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGAQBmIQ/fCpyJ45TCoOYgVsK1/ZP7H3+t3i58WC4G96UKr6
hw3B/8r9906XDIJvYd4yRdIIwT+5SvN4bxOCHyV3/ifjZQT/86neRwWNqnD+
NJa4kiAVNThf8N7WRUxHEHzm2sYQy0J1OP/firj1j4Q04PyCWet7hQ4h+Lu1
OzgE8zThfH6vIp0mPi04/5buhcuVexD8dfPsVZ7EacP5LOq7ZzWsQ/Dvf+Fi
YPiH4AMAGgGCNA==
      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGAwBmIQLc/99f9/Rh0HBijgYdvF08yM4KdurOYyY0Pw98XY
crzkQPDFOP6zzuFG8PM3H2D250PwFbhc/m8RRvArtrL+TRdD8C8mHP8lJYng
N233+tYgh+A/SQl866OJ4NsICL/+r43gT9195cUmPQTfTSjiiYQJgr9if9zt
J3YIfo5UzsmaEAT/yFHd4/rhCL5s4fsjjyIR/HPHiw54xCP4BqWV20WyEPyv
59uWrqlH8OtaFzbeWYXgc5ezeyWuRfBnZOQKPVuP4G/0tlz8fguSfwUvHmHa
j+B7zmPg0LyM4Itsj+8r/Y3gr34hO5vPRxfOb5vbmnDPD8FPCnqrui4QwZfa
s2eDbziC39EffawnCcFPM5v5kasSwVdsEfFgX4bg/7Go4b2+AsG/8fbxpWWr
EfwJ4Ztj3TYi+P+0gopb9yD4dy72z2O+jODvaPuefPkqgj/FOl5z8Q0E33up
3hanewj+roqzJxtfIvjTdE37A98g+IWP5oQovkfwNXxy7h/4guCzMF5ZMuE7
gv9gq3VWwi8Ef0/WYn2Dvwj+dHAGQfAB3Xivpg==
      "]]}, {}}, {{}, {}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{-1, 0},
  Method->{},
  PlotRange->{{-1, 15}, {-1.0285542530808536`, 0.6328023244163912}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{
  3.577701411662038*^9},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]],

Cell["First and second derivatives at x = 0.", "Text",
 CellChangeTimes->{{3.482664394578125*^9, 3.482664468984375*^9}, {
   3.482664514625*^9, 3.482664539265625*^9}, {3.48275498540625*^9, 
   3.48275501025*^9}, {3.482755052734375*^9, 3.48275518615625*^9}, {
   3.48491260909375*^9, 3.484912650578125*^9}, 3.48491287253125*^9, {
   3.48497766284375*^9, 3.484977663578125*^9}, {3.484979246015625*^9, 
   3.4849792499375*^9}, {3.484996455*^9, 3.484996511484375*^9}, {
   3.4860392656875*^9, 3.48603926659375*^9}},
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"derD1f1x0", "=", " ", 
  RowBox[{
   RowBox[{"D", "[", 
    RowBox[{
     RowBox[{"Evaluate", "[", 
      RowBox[{"f1", "[", "x", "]"}], "]"}], ",", "x"}], "]"}], " ", "/.", " ", 
   RowBox[{"x", "\[Rule]", "0"}]}]}]], "Input",
 CellChangeTimes->{{3.4849789611875*^9, 3.48497897071875*^9}, {
  3.484996362078125*^9, 3.484996404453125*^9}}],

Cell[BoxData["8.370203386434223`"], "Output",
 CellChangeTimes->{3.577701411683235*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"derD2f1x0", "=", " ", 
  RowBox[{
   RowBox[{"D", "[", 
    RowBox[{
     RowBox[{"Evaluate", "[", 
      RowBox[{"f1", "[", "x", "]"}], "]"}], ",", "x", ",", "x"}], "]"}], " ", 
   "/.", " ", 
   RowBox[{"x", "\[Rule]", "0"}]}]}]], "Input",
 CellChangeTimes->{{3.4849789611875*^9, 3.484978974875*^9}, {
  3.48499639340625*^9, 3.48499640853125*^9}}],

Cell[BoxData[
 RowBox[{"-", "1.0285542530808536`"}]], "Output",
 CellChangeTimes->{3.577701411704854*^9}]
}, Open  ]],

Cell["First and second derivatives at x = 14.", "Text",
 CellChangeTimes->{{3.482664394578125*^9, 3.482664468984375*^9}, {
   3.482664514625*^9, 3.482664539265625*^9}, {3.48275498540625*^9, 
   3.48275501025*^9}, {3.482755052734375*^9, 3.48275518615625*^9}, {
   3.48491260909375*^9, 3.484912650578125*^9}, 3.48491287253125*^9, {
   3.48497766284375*^9, 3.484977663578125*^9}, {3.484979246015625*^9, 
   3.4849792499375*^9}, {3.484996455*^9, 3.484996511484375*^9}},
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"derD1f4x14", "=", " ", 
  RowBox[{
   RowBox[{"D", "[", 
    RowBox[{
     RowBox[{"Evaluate", "[", 
      RowBox[{"f4", "[", "x", "]"}], "]"}], ",", "x"}], "]"}], " ", "/.", " ", 
   RowBox[{"x", "\[Rule]", "14"}]}]}]], "Input",
 CellChangeTimes->{{3.484912499015625*^9, 3.484912547140625*^9}, 
   3.484914509015625*^9, 3.484916429015625*^9, {3.48491741003125*^9, 
   3.48491741365625*^9}, {3.4849753231875*^9, 3.484975343109375*^9}, {
   3.484975489859375*^9, 3.48497549940625*^9}, {3.484996419484375*^9, 
   3.484996437296875*^9}}],

Cell[BoxData["3.3549744514577697`"], "Output",
 CellChangeTimes->{3.577701411734062*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"derD2f4x14", "=", " ", 
  RowBox[{
   RowBox[{"D", "[", 
    RowBox[{
     RowBox[{"Evaluate", "[", 
      RowBox[{"f4", "[", "x", "]"}], "]"}], ",", "x", ",", "x"}], "]"}], " ", 
   "/.", " ", 
   RowBox[{"x", "\[Rule]", "14"}]}]}]], "Input",
 CellChangeTimes->{{3.484912499015625*^9, 3.484912565265625*^9}, 
   3.484914510296875*^9, 3.48491643084375*^9, {3.4849174166875*^9, 
   3.484917420078125*^9}, {3.484975326515625*^9, 3.4849753331875*^9}, {
   3.48497550234375*^9, 3.484975511625*^9}, {3.48499642209375*^9, 
   3.48499642996875*^9}}],

Cell[BoxData["0.3120929766556457`"], "Output",
 CellChangeTimes->{3.577701411761031*^9}]
}, Open  ]],

Cell["\<\
We verify continuity of first derivative at first internal knot (3.5)\
\>", "Text",
 CellChangeTimes->{{3.482664394578125*^9, 3.482664468984375*^9}, {
   3.482664514625*^9, 3.482664539265625*^9}, {3.48275498540625*^9, 
   3.48275501025*^9}, {3.482755052734375*^9, 3.48275518615625*^9}, {
   3.48491260909375*^9, 3.484912650578125*^9}, 3.48491287253125*^9, {
   3.48497766284375*^9, 3.484977663578125*^9}, {3.484979246015625*^9, 
   3.4849792499375*^9}, {3.484979322359375*^9, 3.484979372375*^9}, {
   3.48499652175*^9, 3.484996562421875*^9}},
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"derf1dx", "=", " ", 
  RowBox[{
   RowBox[{"D", "[", 
    RowBox[{
     RowBox[{"Evaluate", "[", 
      RowBox[{"f1", "[", "x", "]"}], "]"}], ",", "x"}], "]"}], " ", "/.", " ", 
   RowBox[{"x", "\[Rule]", "3.5"}]}]}]], "Input",
 CellChangeTimes->{{3.484912499015625*^9, 3.484912547140625*^9}, 
   3.484914509015625*^9, 3.484916429015625*^9, {3.48491741003125*^9, 
   3.48491741365625*^9}, {3.484917496828125*^9, 3.4849175061875*^9}, {
   3.484975242015625*^9, 3.48497524375*^9}, {3.484979378046875*^9, 
   3.4849793979375*^9}}],

Cell[BoxData["4.770263500651236`"], "Output",
 CellChangeTimes->{3.577701411789888*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"derf2sx", "=", " ", 
  RowBox[{
   RowBox[{"D", "[", 
    RowBox[{
     RowBox[{"Evaluate", "[", 
      RowBox[{"f2", "[", "x", "]"}], "]"}], ",", "x"}], "]"}], " ", "/.", " ", 
   RowBox[{"x", "\[Rule]", "3.5"}]}]}]], "Input",
 CellChangeTimes->{{3.484912499015625*^9, 3.484912565265625*^9}, 
   3.484914510296875*^9, 3.48491643084375*^9, {3.4849174166875*^9, 
   3.484917420078125*^9}, {3.48491749928125*^9, 3.484917501984375*^9}, {
   3.484975247296875*^9, 3.4849752493125*^9}, {3.484979400703125*^9, 
   3.484979430734375*^9}}],

Cell[BoxData["0.07799819657348994`"], "Output",
 CellChangeTimes->{3.5777014117973146`*^9}]
}, Open  ]]
}, Open  ]],

Cell["Part V", "Text",
 CellChangeTimes->{
  3.484992245703125*^9, {3.484992316015625*^9, 3.4849923314375*^9}, {
   3.48499253890625*^9, 3.484992628625*^9}, {3.484994235171875*^9, 
   3.484994236890625*^9}, {3.48499689084375*^9, 3.48499689559375*^9}, {
   3.48767985275*^9, 3.4876798598125*^9}, {3.560539989233566*^9, 
   3.5605399935075*^9}, {3.572683032405257*^9, 3.5726830337403336`*^9}, {
   3.5726830889644923`*^9, 3.5726830891085005`*^9}},
 FontFamily->"Times New Roman",
 FontSize->36,
 FontColor->RGBColor[0, 0, 1],
 Background->RGBColor[1, 0.9, 0.8]],

Cell[TextData[{
 "We check that the reconstruction conincides with the result given by ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "."
}], "Text",
 CellChangeTimes->{{3.4822341378707695`*^9, 3.4822341540168734`*^9}, {
  3.48499855896875*^9, 3.48499856028125*^9}, {3.559508878093765*^9, 
  3.559508878656044*^9}, {3.559508923401692*^9, 3.559508937468286*^9}, {
  3.559541764068054*^9, 3.559541767750527*^9}, {3.559542684134254*^9, 
  3.559542715594304*^9}, {3.56053836865784*^9, 3.560538389643898*^9}},
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"Chop", "[", 
    RowBox[{
     RowBox[{"parabolicSpline", "[", "x", "]"}], " ", "-", " ", 
     RowBox[{"f", "[", "x", "]"}]}], "]"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"x", ",", " ", "0", ",", " ", "14"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.559509211208383*^9, 3.559509211209626*^9}, {
   3.559541778864373*^9, 3.559541780206865*^9}, 3.55954274758951*^9, 
   3.56053840146544*^9}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxTTMoPSmViYGAQAWIQvTBi9fYOncl2DFCw5JdY0+JphfYwvm83q2bttEY4
f9Hlmj+Z0ybC+WfKLdISpi2E8x96is2OnrYRzn9j1GoaOe0gnF+4fA9TxLSL
cL6e3tqZm4Ifwfna+z8W1Fm9hvMZ2y9ke//6COevnBJkzrrtG5w/rdZ/0UOF
33D+/jNlS7Nf/Yfzs/dq/jjrx+QA40s0heZ+r2eB8x9XTltX/oANzg+4P8W+
U4ITzjf+kvsl15Ubzs+9vS339jcEHwBq+0+w
      "]], 
     LineBox[{{3.7039364975712723`, 0.}, {3.9792294951605354`, 0.}, {
      4.277637264017654, 0.}, {4.5705883755712, 0.}, {4.843797115535458, 
      0.}, {5.1401206267675725`, 0.}, {5.4167017664104, 0.}, {
      5.7163976773210825`, 0.}, {6.010636930928192, 0.}, {6.285133812946015, 
      0.}, {6.582745466231692, 0.}, {6.860614747928083, 0.}, {
      6.995535714285714, 0.}}], 
     LineBox[{{7.133027372320901, 0.}, {7.428554767981574, 0.}, {
      7.704339792052961, 0.}, {8.003239587392203, 0.}, {8.296682725427873, 
      0.}, {8.570383491874257, 0.}, {8.867199029588495, 0.}, {
      9.144272195713446, 0.}, {9.415888704534824, 0.}, {9.710619984624058, 
      0.}, {9.985608893124004, 0.}, {9.995535714285714, 0.}}], 
     LineBox[CompressedData["
1:eJxTTMoPSmViYGBQBmIQPVnQ5pjTRBUHBihgcrmkekJeFc73U4r3a1qN4Cf5
ftQUclaD8+9dLopsu4DgKy3/aX0hUx3Od1Yrf+7HoAHnn2V48mxjD4IvrxE2
85WKJpx/c9X2+eybEfzCm/z5kXZacP6FkNyPDVcR/Bnau473JGnD+Tdelkxh
SkXwJVboJ1akI/gzVZb+Ss5B8GfJTtC1LkPwZ/OnTX7ZieDP+ywY77YRwb+3
8Yz2ns0IvlxB+w/DbQj+/Dd/JsruRvAXPH1+5MsRBH/h9b1ai28g+I+mVnyX
uI3gK4UYH+m7i+AvurAituoREv/k5AmBb5D0t/vFHn+HpN+NU8v2I4K/+FDd
YY1vCP6TBssJ834g+Cr2X2JEfiP4KX/XaXb9RfCX7M789v8/gg8A1S+Adg==

      "]]}, {}}, {{}, {}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  Method->{},
  PlotRange->{{0, 14}, {-1., 1.}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{
  3.577701411847699*^9},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]]
},
AutoGeneratedPackage->None,
CellGrouping->Manual,
WindowSize->{1438, 813},
WindowMargins->{{288, Automatic}, {Automatic, 44}},
Magnification->1.5,
FrontEndVersion->"9.0 for Linux x86 (64-bit) (January 25, 2013)",
StyleDefinitions->"Zosi-direi-buono.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[557, 20, 512, 12, 112, "Text"],
Cell[1072, 34, 6148, 144, 930, "Text"],
Cell[CellGroupData[{
Cell[7245, 182, 242, 5, 45, "Input"],
Cell[7490, 189, 466, 10, 33, "Message"]
}, Open  ]],
Cell[CellGroupData[{
Cell[7993, 204, 119, 2, 45, "Input"],
Cell[8115, 208, 193, 5, 45, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[8345, 218, 102, 1, 45, "Input"],
Cell[8450, 221, 124, 2, 45, "Output"]
}, Open  ]],
Cell[8589, 226, 505, 10, 106, "Text"],
Cell[CellGroupData[{
Cell[9119, 240, 661, 18, 75, "Text"],
Cell[9783, 260, 879, 22, 45, "Input"],
Cell[CellGroupData[{
Cell[10687, 286, 233, 4, 45, "Input"],
Cell[10923, 292, 69, 1, 45, "Output"]
}, Open  ]],
Cell[11007, 296, 474, 11, 45, "Input"],
Cell[CellGroupData[{
Cell[11506, 311, 1082, 27, 104, "Input"],
Cell[12591, 340, 25113, 421, 376, 11641, 198, "CachedBoxData", "BoxData", \
"Output"]
}, Open  ]]
}, Open  ]],
Cell[37731, 765, 504, 10, 106, "Text"],
Cell[CellGroupData[{
Cell[38260, 779, 673, 13, 71, "Text"],
Cell[38936, 794, 653, 14, 71, "Text"],
Cell[CellGroupData[{
Cell[39614, 812, 239, 6, 45, "Input"],
Cell[39856, 820, 266, 9, 45, "Output"]
}, Open  ]],
Cell[40137, 832, 347, 10, 72, "Text"],
Cell[CellGroupData[{
Cell[40509, 846, 246, 4, 45, "Input"],
Cell[40758, 852, 257, 6, 45, "Output"]
}, Open  ]],
Cell[41030, 861, 252, 5, 70, "Text"],
Cell[CellGroupData[{
Cell[41307, 870, 444, 8, 45, "Input"],
Cell[41754, 880, 217, 5, 45, "Output"]
}, Open  ]],
Cell[41986, 888, 247, 5, 70, "Text"],
Cell[42236, 895, 392, 7, 45, "Input"],
Cell[CellGroupData[{
Cell[42653, 906, 526, 10, 100, "Text"],
Cell[43182, 918, 823, 19, 81, "Input"],
Cell[44008, 939, 919, 25, 45, "Input"],
Cell[CellGroupData[{
Cell[44952, 968, 3641, 90, 394, "Input"],
Cell[48596, 1060, 86435, 1461, 361, 41995, 731, "CachedBoxData", "BoxData", \
"Output"]
}, Open  ]]
}, Open  ]],
Cell[135058, 2525, 307, 5, 70, "Text"],
Cell[CellGroupData[{
Cell[135390, 2534, 1009, 24, 104, "Input"],
Cell[136402, 2560, 13503, 351, 510, "Output"]
}, Open  ]],
Cell[149920, 2914, 1433, 39, 104, "Text"]
}, Open  ]],
Cell[151368, 2956, 505, 10, 106, "Text"],
Cell[CellGroupData[{
Cell[151898, 2970, 1103, 19, 129, "Text"],
Cell[153004, 2991, 667, 13, 70, "Text"],
Cell[CellGroupData[{
Cell[153696, 3008, 809, 17, 45, "Input"],
Cell[154508, 3027, 250, 5, 47, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[154795, 3037, 815, 17, 45, "Input"],
Cell[155613, 3056, 232, 5, 47, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[155882, 3066, 833, 17, 45, "Input"],
Cell[156718, 3085, 181, 4, 47, "Output"]
}, Open  ]],
Cell[156914, 3092, 614, 10, 70, "Text"],
Cell[CellGroupData[{
Cell[157553, 3106, 822, 17, 45, "Input"],
Cell[158378, 3125, 248, 5, 47, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[158663, 3135, 869, 18, 45, "Input"],
Cell[159535, 3155, 247, 6, 47, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[159819, 3166, 875, 18, 45, "Input"],
Cell[160697, 3186, 250, 5, 47, "Output"]
}, Open  ]],
Cell[160962, 3194, 615, 10, 70, "Text"],
Cell[CellGroupData[{
Cell[161602, 3208, 879, 18, 45, "Input"],
Cell[162484, 3228, 247, 5, 47, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[162768, 3238, 828, 17, 45, "Input"],
Cell[163599, 3257, 243, 6, 47, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[163879, 3268, 737, 16, 45, "Input"],
Cell[164619, 3286, 248, 5, 47, "Output"]
}, Open  ]],
Cell[164882, 3294, 616, 10, 70, "Text"],
Cell[CellGroupData[{
Cell[165523, 3308, 783, 17, 45, "Input"],
Cell[166309, 3327, 216, 5, 47, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[166562, 3337, 825, 17, 45, "Input"],
Cell[167390, 3356, 219, 6, 47, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[167646, 3367, 639, 15, 45, "Input"],
Cell[168288, 3384, 207, 5, 47, "Output"]
}, Open  ]],
Cell[168510, 3392, 456, 8, 70, "Text"],
Cell[CellGroupData[{
Cell[168991, 3404, 1491, 35, 75, "Input"],
Cell[170485, 3441, 15855, 282, 361, 4895, 100, "CachedBoxData", "BoxData", \
"Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[186377, 3728, 1094, 27, 75, "Input"],
Cell[187474, 3757, 24054, 416, 364, 8700, 162, "CachedBoxData", "BoxData", \
"Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[211565, 4178, 1138, 28, 75, "Input"],
Cell[212706, 4208, 26742, 459, 364, 10626, 193, "CachedBoxData", "BoxData", \
"Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[239485, 4672, 1072, 27, 75, "Input"],
Cell[240560, 4701, 24481, 422, 364, 9955, 182, "CachedBoxData", "BoxData", \
"Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[265078, 5128, 1087, 27, 75, "Input"],
Cell[266168, 5157, 23507, 407, 364, 8330, 156, "CachedBoxData", "BoxData", \
"Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[289712, 5569, 1118, 28, 75, "Input"],
Cell[290833, 5599, 15204, 269, 361, 4297, 88, "CachedBoxData", "BoxData", \
"Output"]
}, Open  ]],
Cell[306052, 5871, 1600, 34, 106, "Text"],
Cell[307655, 5907, 678, 13, 69, "Text"],
Cell[CellGroupData[{
Cell[308358, 5924, 312, 7, 45, "Input"],
Cell[308673, 5933, 2627, 70, 155, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[311337, 6008, 591, 12, 45, "Input"],
Cell[311931, 6022, 242, 6, 47, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[312210, 6033, 640, 13, 45, "Input"],
Cell[312853, 6048, 13242, 226, 363, 2116, 42, "CachedBoxData", "BoxData", \
"Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[326132, 6279, 824, 15, 45, "Input"],
Cell[326959, 6296, 220, 5, 45, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[327216, 6306, 645, 13, 45, "Input"],
Cell[327864, 6321, 16675, 281, 356, 4996, 88, "CachedBoxData", "BoxData", \
"Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[344576, 6607, 871, 16, 45, "Input"],
Cell[345450, 6625, 245, 5, 47, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[345732, 6635, 691, 14, 45, "Input"],
Cell[346426, 6651, 14563, 248, 369, 2066, 41, "CachedBoxData", "BoxData", \
"Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[361026, 6904, 684, 13, 45, "Input"],
Cell[361713, 6919, 244, 5, 47, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[361994, 6929, 774, 15, 45, "Input"],
Cell[362771, 6946, 13604, 232, 371, 2061, 41, "CachedBoxData", "BoxData", \
"Output"]
}, Open  ]],
Cell[376390, 7181, 672, 11, 69, "Text"],
Cell[CellGroupData[{
Cell[377087, 7196, 1108, 25, 75, "Input"],
Cell[378198, 7223, 32117, 542, 372, 18461, 316, "CachedBoxData", "BoxData", \
"Output"]
}, Open  ]]
}, Open  ]],
Cell[410342, 7769, 534, 11, 106, "Text"],
Cell[CellGroupData[{
Cell[410901, 7784, 780, 17, 98, "Text"],
Cell[CellGroupData[{
Cell[411706, 7805, 296, 7, 45, "Input"],
Cell[412005, 7814, 2500, 72, 215, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[414542, 7891, 415, 12, 45, "Input"],
Cell[414960, 7905, 18982, 325, 339, 6535, 119, "CachedBoxData", "BoxData", \
"Output"]
}, Open  ]],
Cell[433957, 8233, 148, 3, 70, "Text"],
Cell[CellGroupData[{
Cell[434130, 8240, 310, 8, 45, "Input"],
Cell[434443, 8250, 2007, 59, 215, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[436487, 8314, 462, 12, 45, "Input"],
Cell[436952, 8328, 6276, 114, 339, 3438, 66, "CachedBoxData", "BoxData", \
"Output"]
}, Open  ]],
Cell[443243, 8445, 556, 9, 70, "Text"],
Cell[CellGroupData[{
Cell[443824, 8458, 363, 9, 45, "Input"],
Cell[444190, 8469, 87, 1, 45, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[444314, 8475, 373, 10, 45, "Input"],
Cell[444690, 8487, 105, 2, 45, "Output"]
}, Open  ]],
Cell[444810, 8492, 510, 8, 70, "Text"],
Cell[CellGroupData[{
Cell[445345, 8504, 558, 12, 45, "Input"],
Cell[445906, 8518, 88, 1, 45, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[446031, 8524, 566, 13, 45, "Input"],
Cell[446600, 8539, 88, 1, 45, "Output"]
}, Open  ]],
Cell[446703, 8543, 597, 11, 70, "Text"],
Cell[CellGroupData[{
Cell[447325, 8558, 551, 12, 45, "Input"],
Cell[447879, 8572, 87, 1, 45, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[448003, 8578, 555, 12, 45, "Input"],
Cell[448561, 8592, 91, 1, 45, "Output"]
}, Open  ]]
}, Open  ]],
Cell[448679, 8597, 559, 11, 106, "Text"],
Cell[449241, 8610, 555, 12, 70, "Text"],
Cell[CellGroupData[{
Cell[449821, 8626, 460, 11, 45, "Input"],
Cell[450284, 8639, 5919, 107, 379, 1873, 39, "CachedBoxData", "BoxData", \
"Output"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
