(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     67635,       1679]
NotebookOptionsPosition[     63776,       1569]
NotebookOutlinePosition[     64190,       1587]
CellTagsIndexPosition[     64147,       1584]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["\<\
Evaluation time:
\[CapitalDelta]t < 5 s\
\>", "Text",
 CellChangeTimes->{
  3.484992245703125*^9, {3.484992316015625*^9, 3.4849923314375*^9}, {
   3.48499253890625*^9, 3.484992628625*^9}, {3.484994235171875*^9, 
   3.484994236890625*^9}, {3.48499689084375*^9, 3.48499689559375*^9}, {
   3.48767985275*^9, 3.4876798598125*^9}, {3.560539989233566*^9, 
   3.5605399935075*^9}, {3.572683149268942*^9, 3.572683161356633*^9}},
 FontSize->18,
 FontColor->RGBColor[0, 0, 1],
 Background->RGBColor[1, 0.9, 0.8]],

Cell[TextData[{
 StyleBox["Interpolation using B-splines of order 3 (i.e. degree 2)\n\n",
  FontSize->24,
  FontWeight->"Bold"],
 "\n",
 StyleBox["Warning! \nIn Section 6.4, it is clearly stated that   order = \
degree + 1. \nIn Mathematica, the command InterpolationOrder refers to the \
degree of the interpolating polynomial,\ntherefore,  InterpolationOrder -> 2  \
considers parabolae, etc.\n",
  FontColor->RGBColor[0.5, 0, 0.5]],
 "\n",
 StyleBox["Introduction",
  FontSize->16,
  FontSlant->"Italic"],
 "\n\nThe main purpose of this nb is to examine the properties of the \
functions  ",
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["B", "i", "3"], TraditionalForm]]],
 "(x) (B-spline of third order, second degree).\n\nTo this end,   by means of \
the expression\n\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"S", "(", "x", ")"}], " ", "=", " ", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"i", "=", "1"}], "M"], 
     RowBox[{
      SubscriptBox["\[Alpha]", "i"], " ", 
      RowBox[{
       SubsuperscriptBox["B", "i", "3"], "(", "x", ")"}]}]}]}], 
   TraditionalForm]]],
 ",  \n\nwe interpolate the same set of points {",
 Cell[BoxData[
  FormBox[
   SubscriptBox["x", 
    RowBox[{"i", ","}]], TraditionalForm]]],
 " ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["f", "i"], TraditionalForm]]],
 "} given in the text (Chapter \\ref{chap:splines}, Section \
\\ref{subsec:uniform-cubic}).\n\n In the first section we use the command \n \
\n ",
 StyleBox["parabolicSpline =  Interpolation[points, InterpolationOrder \
\[Rule] 2, Method \[Rule] \"Spline\"]",
  FontFamily->"Courier"],
 "\n\nIn the second section we access  the information contained in  \
parabolicSpline, that is, the coefficients ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Alpha]", "i"], TraditionalForm]]],
 " of the splines and the set of knots.\n              \nIn the third  \
section we extract the polynomial representation of each Bspline and \
reconstruct the complete spline.\n\nIn the fourth  section we check the ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["C", "1"], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["C", "2"], TraditionalForm]]],
 "  and the boundary conditions of S(x).\n         \nIn the fifth  section we \
check that our reconstruction coincides with the one given by Mathematica.\n"
}], "Text",
 CellChangeTimes->{{3.4822342910645547`*^9, 3.4822343209855466`*^9}, {
   3.4827529496875*^9, 3.482752986359375*^9}, {3.482753058375*^9, 
   3.48275329565625*^9}, {3.482754376203125*^9, 3.4827544480625*^9}, {
   3.48275486803125*^9, 3.482754928265625*^9}, {3.482755560515625*^9, 
   3.48275556246875*^9}, {3.4827556411875*^9, 3.48275569015625*^9}, {
   3.48351817559375*^9, 3.483518182875*^9}, {3.483518280890625*^9, 
   3.4835183170625*^9}, {3.484914080453125*^9, 3.48491409403125*^9}, {
   3.484982273*^9, 3.484982330890625*^9}, {3.48499031065625*^9, 
   3.48499031225*^9}, {3.484991693046875*^9, 3.4849918995*^9}, {
   3.484991929671875*^9, 3.484992071828125*^9}, {3.484992112015625*^9, 
   3.48499219953125*^9}, {3.484992274671875*^9, 3.484992288953125*^9}, {
   3.48499252521875*^9, 3.48499252659375*^9}, {3.484992681984375*^9, 
   3.484992822796875*^9}, {3.4849957348125*^9, 3.4849958199375*^9}, {
   3.484996916859375*^9, 3.484997034578125*^9}, {3.484998766484375*^9, 
   3.484998831421875*^9}, {3.484999638984375*^9, 3.48499968971875*^9}, {
   3.484999752609375*^9, 3.4849998213125*^9}, {3.485845938390625*^9, 
   3.485845955046875*^9}, 3.486032339453125*^9, {3.486037365875*^9, 
   3.48603750078125*^9}, {3.486037535953125*^9, 3.486037636859375*^9}, {
   3.48603782975*^9, 3.48603789246875*^9}, 3.486037925296875*^9, 
   3.48603796115625*^9, {3.486038164078125*^9, 3.486038197546875*^9}, {
   3.486038247203125*^9, 3.486038345859375*^9}, {3.486038501484375*^9, 
   3.486038610640625*^9}, {3.48603864065625*^9, 3.486038657*^9}, {
   3.486038689890625*^9, 3.48603873975*^9}, {3.486038935171875*^9, 
   3.486039040234375*^9}, 3.48767391171875*^9, {3.487674100546875*^9, 
   3.48767410190625*^9}, 3.48767422915625*^9, {3.487674321171875*^9, 
   3.487674338859375*^9}, {3.487679923796875*^9, 3.487680016453125*^9}, {
   3.560539123899595*^9, 3.560539175993996*^9}, {3.560539245033219*^9, 
   3.560539266249639*^9}, {3.560539807589909*^9, 3.560539897319377*^9}, {
   3.560539928614897*^9, 3.560539936182129*^9}, {3.572682995818165*^9, 
   3.57268300098246*^9}, {3.5726832293225203`*^9, 3.572683230621595*^9}, {
   3.5759820885876875`*^9, 3.5759821324191947`*^9}, {3.5759821938517084`*^9, 
   3.575982416195426*^9}, {3.5771145566773157`*^9, 3.577114605384102*^9}, {
   3.577455456006997*^9, 3.577455579496814*^9}, 3.577701502280445*^9},
 FontFamily->"Times New Roman",
 FontColor->RGBColor[0, 0, 1],
 Background->RGBColor[1, 1, 0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"Remove", "[", "\"\<Global`*\>\"", "]"}], ";", 
  RowBox[{"$Line", "=", "0"}], ";"}]], "Input",
 CellChangeTimes->{{3.48351269165625*^9, 3.48351271565625*^9}, {
  3.507637742033667*^9, 3.507637746368614*^9}}],

Cell[BoxData[
 RowBox[{"Date", "[", "]"}]], "Input",
 CellChangeTimes->{{3.5076377665006247`*^9, 3.50763776796949*^9}}],

Cell[BoxData["$Version"], "Input",
 CellChangeTimes->{{3.5076377504385023`*^9, 3.507637752584931*^9}}],

Cell["Part I", "Text",
 CellChangeTimes->{
  3.484992245703125*^9, {3.484992316015625*^9, 3.4849923314375*^9}, {
   3.48499253890625*^9, 3.484992628625*^9}, {3.484994235171875*^9, 
   3.484994236890625*^9}, {3.48499689084375*^9, 3.48499689559375*^9}, {
   3.48767985275*^9, 3.4876798598125*^9}, {3.560539989233566*^9, 
   3.5605399935075*^9}, {3.572683032405257*^9, 3.5726830337403336`*^9}},
 FontFamily->"Times New Roman",
 FontSize->36,
 FontColor->RGBColor[0, 0, 1],
 Background->RGBColor[1, 0.9, 0.8]],

Cell[CellGroupData[{

Cell[TextData[{
 "Construction of the interpolating function S(x) over the points  {",
 Cell[BoxData[
  FormBox[
   SubscriptBox["x", 
    RowBox[{"i", ","}]], TraditionalForm]]],
 " ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["f", "i"], TraditionalForm]]],
 "} by means of  B-splines of order 3."
}], "Text",
 CellChangeTimes->{
  3.484992245703125*^9, {3.484992316015625*^9, 3.4849923314375*^9}, {
   3.48499253890625*^9, 3.484992628625*^9}, {3.484994235171875*^9, 
   3.484994236890625*^9}, {3.48499689084375*^9, 3.48499689559375*^9}, {
   3.48767985275*^9, 3.4876798598125*^9}, {3.560539989233566*^9, 
   3.5605399935075*^9}},
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"points", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}], ",", "  ", 
     RowBox[{"{", 
      RowBox[{"2", ",", "2"}], "}"}], ",", "  ", 
     RowBox[{"{", 
      RowBox[{"5", ",", "3"}], "}"}], ",", "  ", 
     RowBox[{"{", 
      RowBox[{"9", ",", "5"}], "}"}], ",", "  ", 
     RowBox[{"{", 
      RowBox[{"11", ",", "2"}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"14", ",", "1"}], "}"}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.482465335703125*^9, 3.48246537171875*^9}, {
   3.482562224859375*^9, 3.482562705859375*^9}, {3.482563028953125*^9, 
   3.4825630511875*^9}, 3.48256308603125*^9, {3.48266181428125*^9, 
   3.482661845375*^9}, {3.482661878609375*^9, 3.48266189509375*^9}, {
   3.484992237328125*^9, 3.484992239*^9}, {3.560540011679805*^9, 
   3.560540015432552*^9}}],

Cell[BoxData[
 RowBox[{"numpoints", "=", 
  RowBox[{"Length", "[", "points", "]"}]}]], "Input",
 CellChangeTimes->{{3.487596017078125*^9, 3.487596021859375*^9}, 
   3.487673975046875*^9, {3.560540003858188*^9, 3.560540007826174*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"parabolicSpline", "=", 
   RowBox[{"Interpolation", "[", 
    RowBox[{"points", ",", 
     RowBox[{"InterpolationOrder", "\[Rule]", "2"}], ",", 
     RowBox[{"Method", "\[Rule]", "\"\<Spline\>\""}]}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{
  3.482232981299215*^9, 3.482563196046875*^9, {3.482662067734375*^9, 
   3.482662069859375*^9}, {3.482662414515625*^9, 3.48266242134375*^9}, 
   3.484991111609375*^9, 3.560540019292644*^9}],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"parabolicSpline", "[", "x", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "14"}], "}"}], ",", 
   RowBox[{"AxesOrigin", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "1"}], ",", "0"}], "}"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "1"}], ",", "15"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "6"}], "}"}]}], "}"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"Epilog", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Red", ",", 
      RowBox[{"PointSize", "[", "Medium", "]"}], ",", 
      RowBox[{"Point", "[", "points", "]"}]}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{
  3.482232990035215*^9, {3.482662078546875*^9, 3.482662109859375*^9}, {
   3.482662150546875*^9, 3.4826622134375*^9}, {3.484979612859375*^9, 
   3.484979664171875*^9}, {3.4849796941875*^9, 3.4849797615625*^9}, 
   3.484991112828125*^9, {3.560540092011394*^9, 3.560540096045826*^9}}]
}, Open  ]],

Cell["Part II", "Text",
 CellChangeTimes->{
  3.484992245703125*^9, {3.484992316015625*^9, 3.4849923314375*^9}, {
   3.48499253890625*^9, 3.484992628625*^9}, {3.484994235171875*^9, 
   3.484994236890625*^9}, {3.48499689084375*^9, 3.48499689559375*^9}, {
   3.48767985275*^9, 3.4876798598125*^9}, {3.560539989233566*^9, 
   3.5605399935075*^9}, {3.572683032405257*^9, 3.572683048796195*^9}},
 FontFamily->"Times New Roman",
 FontSize->36,
 FontColor->RGBColor[0, 0, 1],
 Background->RGBColor[1, 0.9, 0.8]],

Cell[CellGroupData[{

Cell[TextData[{
 "Access to various information contained in the ",
 StyleBox["InterpolatingFunction.", "Input"]
}], "Text",
 CellChangeTimes->{{3.482233312453421*^9, 3.482233325558337*^9}, {
   3.482233750040195*^9, 3.482233753784411*^9}, {3.484993382796875*^9, 
   3.484993390234375*^9}, {3.484993463875*^9, 3.4849934725*^9}, {
   3.484993612375*^9, 3.48499369059375*^9}, {3.484993903390625*^9, 
   3.4849939055625*^9}, {3.48499398996875*^9, 3.484994000125*^9}, {
   3.484994033875*^9, 3.48499412828125*^9}, {3.484994219125*^9, 
   3.484994243046875*^9}, {3.48499690290625*^9, 3.484996904171875*^9}, 
   3.560540140130722*^9},
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[TextData[{
 "The ",
 StyleBox["BSplineFunction ", "Input"],
 " is stored  in 4th place."
}], "Text",
 CellChangeTimes->{{3.482233312453421*^9, 3.482233325558337*^9}, {
   3.482233750040195*^9, 3.482233753784411*^9}, {3.484993382796875*^9, 
   3.484993390234375*^9}, {3.484993463875*^9, 3.4849934725*^9}, {
   3.484993612375*^9, 3.48499369059375*^9}, {3.484993903390625*^9, 
   3.4849939055625*^9}, {3.48499398996875*^9, 3.484994000125*^9}, {
   3.484994033875*^9, 3.48499412828125*^9}, 3.484994219125*^9, {
   3.4860324106875*^9, 3.486032443421875*^9}, {3.560540151381531*^9, 
   3.560540152231888*^9}},
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{"bspfun", "=", 
  RowBox[{"parabolicSpline", "[", 
   RowBox[{"[", 
    RowBox[{"4", ",", "1"}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4822332962139254`*^9, 3.482233307867051*^9}, 
   3.484994515921875*^9}],

Cell[TextData[{
 "The coefficients ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Alpha]", "i"], TraditionalForm]]],
 " for the basis B-splinesbasis are named  \[OpenCurlyDoubleQuote]Control \
points\[CloseCurlyDoubleQuote]"
}], "Text",
 CellChangeTimes->{{3.559482737098605*^9, 3.55948274359533*^9}},
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{"coeff", "=", 
  RowBox[{"bspfun", "[", "\"\<ControlPoints\>\"", "]"}]}]], "Input",
 CellChangeTimes->{{3.4822343225455565`*^9, 3.4822343308448095`*^9}, 
   3.4849929160625*^9, {3.507638118600814*^9, 3.507638119331163*^9}}],

Cell["The set of knots being used", "Text",
 CellChangeTimes->{{3.4822343342300315`*^9, 3.4822343385356593`*^9}, {
  3.484993012875*^9, 3.48499302471875*^9}, {3.559482762046647*^9, 
  3.559482776161458*^9}},
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{"knotsx", "=", 
  RowBox[{"Flatten", "[", 
   RowBox[{"bspfun", "[", "\"\<Knots\>\"", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4822333526865635`*^9, 3.4822333562589407`*^9}, {
   3.4822337669515705`*^9, 3.482233768386853*^9}, {3.4822338392615557`*^9, 
   3.482233842178793*^9}, {3.482662276328125*^9, 3.482662277625*^9}, 
   3.487674823375*^9, 3.487675352796875*^9, {3.56054076508379*^9, 
   3.56054077150636*^9}}],

Cell["The degree, for later use", "Text",
 CellChangeTimes->{{3.4822343410950756`*^9, 3.482234344433497*^9}, {
  3.4849930594375*^9, 3.4849930729375*^9}, {3.559482957028283*^9, 
  3.55948296530249*^9}},
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"degx", " ", "=", " ", "2"}], ";"}]], "Input",
 CellChangeTimes->{{3.482233357163735*^9, 3.4822333657904797`*^9}, {
   3.482233770648984*^9, 3.4822337722246747`*^9}, {3.4822338341446466`*^9, 
   3.482233836235117*^9}, {3.482662458*^9, 3.482662458859375*^9}, 
   3.487674759234375*^9, {3.5076378135469837`*^9, 3.507637841595442*^9}, 
   3.560541094075318*^9}],

Cell[CellGroupData[{

Cell["\<\
We are using non-uniform (thus non-uniform knots) degree 3 B-spline basis.
We plot the (6) Bases along the  x-direction. The internal knotes are marked \
with \"\[FivePointedStar]\".\
\>", "Text",
 CellChangeTimes->{{3.482234042054359*^9, 3.482234050026061*^9}, {
   3.4849943335*^9, 3.484994358125*^9}, {3.48499459071875*^9, 
   3.484994612359375*^9}, 3.484994668703125*^9, {3.486032497859375*^9, 
   3.486032526109375*^9}, {3.487679281953125*^9, 3.487679285453125*^9}},
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"symB1", "=", " ", 
   SubsuperscriptBox["B", "1", "3"]}], ";", " ", 
  RowBox[{"symB2", "=", " ", 
   SubsuperscriptBox["B", "2", "3"]}], ";", 
  RowBox[{"symB3", "=", " ", 
   SubsuperscriptBox["B", "3", "3"]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"symB4", "=", " ", 
   SubsuperscriptBox["B", "4", "3"]}], ";", " ", 
  RowBox[{"symB5", "=", " ", 
   SubsuperscriptBox["B", "5", "3"]}], ";", 
  RowBox[{"symB6", "=", 
   SubsuperscriptBox["B", "6", "3"]}], ";"}]}], "Input",
 CellChangeTimes->{{3.483703373765625*^9, 3.483703378671875*^9}, {
  3.48370352328125*^9, 3.483703539609375*^9}, {3.4837036211875*^9, 
  3.4837036309375*^9}, {3.48370469346875*^9, 3.483704720125*^9}, {
  3.48663741703125*^9, 3.48663746434375*^9}, {3.560541100551261*^9, 
  3.560541109236298*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"symKnots", " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"Text", "[", 
      RowBox[{
       RowBox[{"Style", "[", 
        RowBox[{"\"\<\[FivePointedStar]\>\"", ",", "Medium"}], "]"}], ",", 
       "#"}], "]"}], "&"}], "/@", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"3.5", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"7.", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"10.", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"14", ",", "0"}], "}"}]}], "}"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.559486202627114*^9, 3.559486214635637*^9}, {
  3.559486301576712*^9, 3.559486302571568*^9}, {3.559486366049752*^9, 
  3.559486368770009*^9}, {3.560543713016664*^9, 3.560543726445463*^9}, {
  3.560543826129165*^9, 3.56054384044953*^9}}],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"Evaluate", "[", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"BSplineBasis", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"degx", ",", "knotsx"}], "}"}], ",", "k", ",", "x"}], "]"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{"k", ",", "0", ",", "5"}], "}"}]}], "]"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "14"}], "}"}], ",", "\[IndentingNewLine]", 
   "    ", 
   RowBox[{"Epilog", "->", 
    RowBox[{"{", 
     RowBox[{"{", "\[IndentingNewLine]", 
      RowBox[{"symKnots", ",", "\[IndentingNewLine]", " ", 
       RowBox[{"Text", "[", 
        RowBox[{
         RowBox[{"Style", "[", "\"\<3.5\>\"", "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"3.5", ",", 
           RowBox[{"-", "0.09"}]}], "}"}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Text", "[", 
        RowBox[{
         RowBox[{"Style", "[", "\"\<7\>\"", "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"7", ",", 
           RowBox[{"-", "0.09"}]}], "}"}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Text", "[", 
        RowBox[{
         RowBox[{"Style", "[", "\"\<10\>\"", "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"10", ",", 
           RowBox[{"-", "0.09"}]}], "}"}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Text", "[", 
        RowBox[{
         RowBox[{"Style", "[", "symB1", "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"0.6", ",", "0.9"}], "}"}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Text", "[", 
        RowBox[{
         RowBox[{"Style", "[", "symB2", "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"2.5", ",", "0.75"}], "}"}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Text", "[", 
        RowBox[{
         RowBox[{"Style", "[", "symB3", "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"5", ",", "0.8"}], "}"}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Text", "[", 
        RowBox[{
         RowBox[{"Style", "[", "symB4", "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"8.5", ",", "0.85"}], "}"}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Text", "[", 
        RowBox[{
         RowBox[{"Style", "[", "symB5", "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"11.5", ",", "0.7"}], "}"}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Text", "[", 
        RowBox[{
         RowBox[{"Style", "[", "symB6", "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"13.4", ",", "0.9"}], "}"}]}], "]"}]}], "}"}], "}"}]}], ",",
    "\[IndentingNewLine]", 
   RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.4822338086527767`*^9, 3.4822338219915457`*^9}, {
   3.482233861491841*^9, 3.4822339121320906`*^9}, {3.48256328578125*^9, 
   3.48256328990625*^9}, {3.48256332328125*^9, 3.482563376203125*^9}, {
   3.48266249828125*^9, 3.4826625106875*^9}, {3.484916641671875*^9, 
   3.484916680765625*^9}, {3.484916723734375*^9, 3.4849167388125*^9}, {
   3.484916772609375*^9, 3.48491687671875*^9}, {3.484980861421875*^9, 
   3.48498086334375*^9}, {3.484994385328125*^9, 3.484994389234375*^9}, {
   3.48499455128125*^9, 3.4849945548125*^9}, {3.48500009903125*^9, 
   3.485000242453125*^9}, 3.4860324928125*^9, {3.48603720228125*^9, 
   3.4860372225*^9}, 3.487674760140625*^9, 3.487674824921875*^9, 
   3.487675354203125*^9, {3.48767608575*^9, 3.48767611534375*^9}, {
   3.48767643309375*^9, 3.48767662653125*^9}, {3.560541115495524*^9, 
   3.560541139399583*^9}, {3.560543730691453*^9, 3.56054379465246*^9}}]
}, Open  ]],

Cell["It is instructive to Piesewise expand  the basis functions.", "Text",
 CellChangeTimes->{{3.482234065314257*^9, 3.4822340765776014`*^9}, {
   3.48499443396875*^9, 3.484994447921875*^9}, 3.4849946855625*^9, {
   3.560541197550055*^9, 3.560541201201146*^9}},
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"bsplines", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"PiecewiseExpand", "[", 
      RowBox[{
       RowBox[{"BSplineBasis", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"degx", ",", "knotsx"}], "}"}], ",", "k", ",", "x"}], "]"}],
        ",", "\[IndentingNewLine]", 
       RowBox[{"Method", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<OrderlessConditions\>\"", "\[Rule]", "False"}], 
         "}"}]}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"k", ",", "0", ",", "5"}], "}"}]}], "]"}]}], ";", 
  RowBox[{"bsplines", "//", "Column"}]}]], "Input",
 CellChangeTimes->{{3.482234083410489*^9, 3.482234133487131*^9}, {
   3.482662576265625*^9, 3.482662577359375*^9}, {3.4826639286875*^9, 
   3.482663929375*^9}, {3.487595990984375*^9, 3.487595993171875*^9}, 
   3.487674760953125*^9, 3.4876748258125*^9, 3.48767535721875*^9, {
   3.560541203841139*^9, 3.560541205708734*^9}, {3.560541353112389*^9, 
   3.560541368365471*^9}}],

Cell[TextData[{
 "We observe that, in the first interval ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{"0", ",", "3.5"}], ")"}], TraditionalForm]]],
 ", only three Bsplines ",
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["B", "1", "3"], TraditionalForm]],
  FontSize->10],
 StyleBox[", ",
  FontSize->10],
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["B", "2", "3"], TraditionalForm]],
  FontSize->10],
 StyleBox[", ",
  FontSize->10],
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["B", "3", "3"], TraditionalForm]],
  FontSize->10],
 StyleBox[" ",
  FontSize->10],
 "give a contibution. The same observation holds for every other interval."
}], "Text",
 CellChangeTimes->{{3.482664394578125*^9, 3.482664468984375*^9}, {
  3.482664514625*^9, 3.482664539265625*^9}, {3.48275498540625*^9, 
  3.48275501025*^9}, {3.482755052734375*^9, 3.482755109421875*^9}, {
  3.48497849896875*^9, 3.484978499578125*^9}, {3.484978533796875*^9, 
  3.484978604484375*^9}, {3.484978754390625*^9, 3.48497876734375*^9}, {
  3.484994730125*^9, 3.484994889828125*^9}, {3.48499492471875*^9, 
  3.484994988171875*^9}, {3.484995021609375*^9, 3.48499506625*^9}, {
  3.487659286171875*^9, 3.487659317546875*^9}, {3.4876805590625*^9, 
  3.487680561609375*^9}, {3.559483857982459*^9, 3.559483930729468*^9}, {
  3.5605406961833*^9, 3.560540696705807*^9}, {3.560541256759673*^9, 
  3.560541267581703*^9}},
 FontSize->14,
 Background->GrayLevel[0.85]]
}, Open  ]],

Cell["Part III", "Text",
 CellChangeTimes->{
  3.484992245703125*^9, {3.484992316015625*^9, 3.4849923314375*^9}, {
   3.48499253890625*^9, 3.484992628625*^9}, {3.484994235171875*^9, 
   3.484994236890625*^9}, {3.48499689084375*^9, 3.48499689559375*^9}, {
   3.48767985275*^9, 3.4876798598125*^9}, {3.560539989233566*^9, 
   3.5605399935075*^9}, {3.572683032405257*^9, 3.572683058756765*^9}},
 FontFamily->"Times New Roman",
 FontSize->36,
 FontColor->RGBColor[0, 0, 1],
 Background->RGBColor[1, 0.9, 0.8]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["It is convenient to extract the polynomial representation of the \
segments of",
  FontFamily->"Times New Roman"],
 " B-splines on each of the four subintervals formed by the knots.\nThe \
Interpolating spline S(x), together with the first and second derivatives, \
are plotted."
}], "Text",
 CellChangeTimes->{{3.482664394578125*^9, 3.482664468984375*^9}, {
   3.482664514625*^9, 3.482664539265625*^9}, {3.48275498540625*^9, 
   3.48275501025*^9}, {3.482755052734375*^9, 3.482755109421875*^9}, {
   3.48497849896875*^9, 3.484978499578125*^9}, {3.484978533796875*^9, 
   3.484978604484375*^9}, {3.484978754390625*^9, 3.48497884175*^9}, {
   3.484978883515625*^9, 3.484978886390625*^9}, {3.48499516884375*^9, 
   3.484995178203125*^9}, {3.48499522409375*^9, 3.4849953056875*^9}, {
   3.484995706578125*^9, 3.484995708015625*^9}, {3.4849960660625*^9, 
   3.484996119171875*^9}, 3.4849968864375*^9, {3.487679648203125*^9, 
   3.487679666359375*^9}, {3.487679864890625*^9, 3.487679878234375*^9}, {
   3.560541288395127*^9, 3.560541311944597*^9}},
 Background->RGBColor[0.9, 1, 1]],

Cell["\<\
We extract the segments of the B-spline which give a contribution  on the \
first interval\
\>", "Text",
 CellChangeTimes->{{3.482664394578125*^9, 3.482664468984375*^9}, {
   3.482664514625*^9, 3.482664539265625*^9}, {3.48275498540625*^9, 
   3.48275501025*^9}, {3.482755052734375*^9, 3.482755109421875*^9}, {
   3.48497849896875*^9, 3.484978499578125*^9}, {3.484978533796875*^9, 
   3.484978604484375*^9}, {3.484978754390625*^9, 3.48497884175*^9}, {
   3.484978883515625*^9, 3.484978931140625*^9}, {3.48499782309375*^9, 
   3.4849978416875*^9}, {3.487678947921875*^9, 3.487679004125*^9}, 
   3.487680630375*^9},
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"bsplines", "[", 
   RowBox[{"[", 
    RowBox[{"1", ",", "1", ",", "1", ",", "1"}], "]"}], "]"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     SuperscriptBox[
      SubscriptBox["B", "1"], "3"], "   ", "0."}], " ", "\[LessEqual]", " ", 
    "x", " ", "<", " ", "3.5"}], " ", "*)"}]}]], "Input",
 CellChangeTimes->{{3.482664695234375*^9, 3.482664696796875*^9}, {
   3.484912448203125*^9, 3.4849124485625*^9}, {3.48491807028125*^9, 
   3.484918106625*^9}, {3.484918140140625*^9, 3.484918141765625*^9}, {
   3.48491841321875*^9, 3.484918450671875*^9}, {3.4849185378125*^9, 
   3.484918538265625*^9}, 3.484918575984375*^9, {3.48491869765625*^9, 
   3.484918698015625*^9}, {3.484918768078125*^9, 3.4849187769375*^9}, {
   3.560541545920249*^9, 3.560541562785468*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"bsplines", "[", 
   RowBox[{"[", 
    RowBox[{"2", ",", "1", ",", "1", ",", "1"}], "]"}], "]"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     SuperscriptBox[
      SubscriptBox["B", "2"], "3"], "   ", "0"}], " ", "\[LessEqual]", "  ", 
    "x", " ", "<", " ", "3.5"}], " ", "*)"}], "  "}]], "Input",
 CellChangeTimes->{{3.4826639458125*^9, 3.48266394865625*^9}, {
   3.48266465525*^9, 3.4826646664375*^9}, {3.484918169609375*^9, 
   3.484918194828125*^9}, {3.484918550640625*^9, 3.484918569953125*^9}, {
   3.48491867809375*^9, 3.484918680265625*^9}, 3.484918746984375*^9, {
   3.484918778953125*^9, 3.48491878215625*^9}, {3.48759757971875*^9, 
   3.487597580453125*^9}, {3.487597615296875*^9, 3.487597616203125*^9}, {
   3.560541564932166*^9, 3.560541580110403*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"bsplines", "[", 
   RowBox[{"[", 
    RowBox[{"3", ",", "1", ",", "1", ",", "1"}], "]"}], "]"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     SuperscriptBox[
      SubscriptBox["B", "3"], "3"], "   ", "0"}], " ", "\[LessEqual]", "  ", 
    "x", " ", "<", " ", "3.5"}], " ", "*)"}], "        "}]], "Input",
 CellChangeTimes->{{3.4826639458125*^9, 3.48266394865625*^9}, {
  3.48266465525*^9, 3.4826646664375*^9}, {3.482664763515625*^9, 
  3.48266478965625*^9}, {3.484914455515625*^9, 3.484914455765625*^9}, {
  3.484918226015625*^9, 3.484918240453125*^9}, {3.484918629546875*^9, 
  3.4849186456875*^9}, {3.484918747921875*^9, 3.484918748234375*^9}, {
  3.48491878525*^9, 3.484918786640625*^9}, {3.487597594640625*^9, 
  3.4875975955625*^9}, {3.560541593799525*^9, 3.560541609471902*^9}}],

Cell["...  on the second interval", "Text",
 CellChangeTimes->{{3.482664394578125*^9, 3.482664468984375*^9}, {
  3.482664514625*^9, 3.482664539265625*^9}, {3.48275498540625*^9, 
  3.48275501025*^9}, {3.482755052734375*^9, 3.482755109421875*^9}, {
  3.48497849896875*^9, 3.484978499578125*^9}, {3.484978533796875*^9, 
  3.484978604484375*^9}, {3.484978754390625*^9, 3.48497884175*^9}, {
  3.484978883515625*^9, 3.484978931140625*^9}, {3.48499782309375*^9, 
  3.4849978416875*^9}, {3.487678947921875*^9, 3.487679004125*^9}, {
  3.487679036984375*^9, 3.4876790456875*^9}},
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"bsplines", "[", 
   RowBox[{"[", 
    RowBox[{"2", ",", "1", ",", "2", ",", "1"}], "]"}], "]"}], 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     SuperscriptBox[
      SubscriptBox["B", "2"], "3"], "  ", "3.5"}], " ", "\[LessEqual]", " ", 
    "x", " ", "<", " ", "7.0"}], " ", "*)"}]}]], "Input",
 CellChangeTimes->{{3.482664695234375*^9, 3.482664696796875*^9}, {
   3.484912448203125*^9, 3.4849124485625*^9}, {3.484917832671875*^9, 
   3.48491783290625*^9}, {3.48491790596875*^9, 3.484917977078125*^9}, {
   3.484918312125*^9, 3.484918321234375*^9}, {3.484918499265625*^9, 
   3.48491853634375*^9}, {3.484918573890625*^9, 3.48491857434375*^9}, 
   3.48491885628125*^9, {3.4849189955*^9, 3.48491899634375*^9}, 
   3.484975175890625*^9, {3.560541612309511*^9, 3.560541640470606*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"bsplines", "[", 
   RowBox[{"[", 
    RowBox[{"3", ",", "1", ",", "2", ",", "1"}], "]"}], "]"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     SuperscriptBox[
      SubscriptBox["B", "3"], "3"], "  ", "3.5"}], " ", "\[LessEqual]", " ", 
    "x", " ", "<", " ", "7.0"}], " ", "*)"}], " "}]], "Input",
 CellChangeTimes->{{3.4826639458125*^9, 3.48266394865625*^9}, {
  3.48266465525*^9, 3.4826646664375*^9}, {3.482664763515625*^9, 
  3.48266478965625*^9}, {3.484914455515625*^9, 3.484914455765625*^9}, {
  3.484918029859375*^9, 3.484918030171875*^9}, {3.484918369875*^9, 
  3.48491837971875*^9}, {3.484918590390625*^9, 3.48491859365625*^9}, {
  3.484918886796875*^9, 3.48491889828125*^9}, {3.484918983734375*^9, 
  3.484919007453125*^9}, {3.487597671125*^9, 3.4875976725*^9}, {
  3.560541643512006*^9, 3.560541667513589*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"bsplines", "[", 
   RowBox[{"[", 
    RowBox[{"4", ",", "1", ",", "1", ",", "1"}], "]"}], "]"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     SuperscriptBox[
      SubscriptBox["B", "4"], "3"], "  ", "3.5"}], " ", "\[LessEqual]", " ", 
    "x", " ", "<", " ", "7.0"}], " ", "*)"}], " "}]], "Input",
 CellChangeTimes->{{3.4826639458125*^9, 3.48266394865625*^9}, {
  3.48266465525*^9, 3.4826646664375*^9}, {3.48266474965625*^9, 
  3.482664751828125*^9}, {3.48491439440625*^9, 3.484914451171875*^9}, {
  3.4849147040625*^9, 3.484914723890625*^9}, {3.48491894675*^9, 
  3.484918967484375*^9}, {3.484919010046875*^9, 3.484919011359375*^9}, {
  3.484919228046875*^9, 3.484919228421875*^9}, {3.48497494140625*^9, 
  3.484974942046875*^9}, {3.487597701671875*^9, 3.487597723265625*^9}, {
  3.560541669370417*^9, 3.560541691076755*^9}}],

Cell["...  on the third interval", "Text",
 CellChangeTimes->{{3.482664394578125*^9, 3.482664468984375*^9}, {
  3.482664514625*^9, 3.482664539265625*^9}, {3.48275498540625*^9, 
  3.48275501025*^9}, {3.482755052734375*^9, 3.482755109421875*^9}, {
  3.48497849896875*^9, 3.484978499578125*^9}, {3.484978533796875*^9, 
  3.484978604484375*^9}, {3.484978754390625*^9, 3.48497884175*^9}, {
  3.484978883515625*^9, 3.484978931140625*^9}, {3.48499782309375*^9, 
  3.4849978416875*^9}, {3.487678947921875*^9, 3.487679004125*^9}, {
  3.487679057640625*^9, 3.487679064640625*^9}},
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"bsplines", "[", 
   RowBox[{"[", 
    RowBox[{"3", ",", "1", ",", "3", ",", "1"}], "]"}], "]"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     SuperscriptBox[
      SubscriptBox["B", "3"], "3"], "  ", "7"}], " ", "\[LessEqual]", " ", 
    "x", " ", "<", " ", "10.0"}], " ", "*)"}], "     "}]], "Input",
 CellChangeTimes->{{3.4826639458125*^9, 3.48266394865625*^9}, {
  3.48266465525*^9, 3.4826646664375*^9}, {3.482664763515625*^9, 
  3.48266478965625*^9}, {3.484914455515625*^9, 3.484914455765625*^9}, {
  3.484918029859375*^9, 3.484918030171875*^9}, {3.484918369875*^9, 
  3.48491837971875*^9}, {3.484918590390625*^9, 3.48491859365625*^9}, {
  3.484918886796875*^9, 3.48491889828125*^9}, {3.484918983734375*^9, 
  3.484919007453125*^9}, {3.484919077921875*^9, 3.48491910540625*^9}, {
  3.560541693782122*^9, 3.560541708389437*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"bsplines", "[", 
   RowBox[{"[", 
    RowBox[{"4", ",", "1", ",", "2", ",", "1"}], "]"}], "]"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     SuperscriptBox[
      SubscriptBox["B", "4"], "3"], "  ", "7"}], " ", "\[LessEqual]", " ", 
    "x", " ", "<", " ", "10.0"}], " ", "*)"}], " "}]], "Input",
 CellChangeTimes->{{3.4826639458125*^9, 3.48266394865625*^9}, {
  3.48266465525*^9, 3.4826646664375*^9}, {3.48266474965625*^9, 
  3.482664751828125*^9}, {3.48491439440625*^9, 3.484914451171875*^9}, {
  3.4849147040625*^9, 3.484914723890625*^9}, {3.484919149796875*^9, 
  3.484919185109375*^9}, {3.48491925015625*^9, 3.484919286953125*^9}, {
  3.48491937034375*^9, 3.484919370796875*^9}, {3.487597794484375*^9, 
  3.487597795359375*^9}, {3.560541711072585*^9, 3.560541735813311*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"bsplines", "[", 
   RowBox[{"[", 
    RowBox[{"5", ",", "1", ",", "1", ",", "1"}], "]"}], "]"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     SuperscriptBox[
      SubscriptBox["B", "5"], "3"], "  ", "7"}], " ", "\[LessEqual]", " ", 
    "x", " ", "<", " ", "10.0"}], " ", "*)"}], " "}]], "Input",
 CellChangeTimes->{{3.4826639458125*^9, 3.48266394865625*^9}, {
  3.48266465525*^9, 3.4826646664375*^9}, {3.48266474965625*^9, 
  3.482664751828125*^9}, {3.48491439440625*^9, 3.484914451171875*^9}, {
  3.484919309734375*^9, 3.484919351984375*^9}, {3.487597797484375*^9, 
  3.487597798328125*^9}, {3.560541743270293*^9, 3.560541769807501*^9}, {
  3.560541860297443*^9, 3.560541862505116*^9}}],

Cell["and  on the fourth interval", "Text",
 CellChangeTimes->{{3.482664394578125*^9, 3.482664468984375*^9}, {
  3.482664514625*^9, 3.482664539265625*^9}, {3.48275498540625*^9, 
  3.48275501025*^9}, {3.482755052734375*^9, 3.482755109421875*^9}, {
  3.48497849896875*^9, 3.484978499578125*^9}, {3.484978533796875*^9, 
  3.484978604484375*^9}, {3.484978754390625*^9, 3.48497884175*^9}, {
  3.484978883515625*^9, 3.484978931140625*^9}, {3.48499782309375*^9, 
  3.4849978416875*^9}, {3.487678947921875*^9, 3.487679004125*^9}, {
  3.487679075640625*^9, 3.487679091765625*^9}},
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"bsplines", "[", 
   RowBox[{"[", 
    RowBox[{"4", ",", "1", ",", "3", ",", "1"}], "]"}], "]"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     SuperscriptBox[
      SubscriptBox["B", "4"], "3"], "  ", "10"}], " ", "\[LessEqual]", " ", 
    "x", " ", "<", " ", "14.0"}], " ", "*)"}], " "}]], "Input",
 CellChangeTimes->{{3.4826639458125*^9, 3.48266394865625*^9}, {
  3.48266465525*^9, 3.4826646664375*^9}, {3.48266474965625*^9, 
  3.482664751828125*^9}, {3.48491439440625*^9, 3.484914451171875*^9}, {
  3.484919309734375*^9, 3.484919313453125*^9}, {3.484919409390625*^9, 
  3.48491945521875*^9}, {3.484919517671875*^9, 3.4849195189375*^9}, {
  3.487597852109375*^9, 3.487597852953125*^9}, {3.560541792279954*^9, 
  3.56054181501201*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"bsplines", "[", 
   RowBox[{"[", 
    RowBox[{"5", ",", "1", ",", "2", ",", "1"}], "]"}], "]"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     SuperscriptBox[
      SubscriptBox["B", "5"], "3"], "  ", "10"}], " ", "\[LessEqual]", " ", 
    "x", " ", "<", " ", "14.0"}], " ", "*)"}], " "}]], "Input",
 CellChangeTimes->{{3.4826639458125*^9, 3.48266394865625*^9}, {
  3.48266465525*^9, 3.4826646664375*^9}, {3.48266474965625*^9, 
  3.482664751828125*^9}, {3.48491439440625*^9, 3.484914451171875*^9}, {
  3.484919309734375*^9, 3.484919351984375*^9}, {3.48491950746875*^9, 
  3.484919512984375*^9}, {3.48491956040625*^9, 3.484919581984375*^9}, {
  3.484975095125*^9, 3.484975095609375*^9}, {3.48759785465625*^9, 
  3.4875978554375*^9}, {3.560541872342458*^9, 3.560541885594566*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"bsplines", "[", 
   RowBox[{"[", 
    RowBox[{"6", ",", "1", ",", "1", ",", "1"}], "]"}], "]"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     SuperscriptBox[
      SubscriptBox["B", "6"], "3"], "  ", "10"}], " ", "\[LessEqual]", " ", 
    "x", " ", "<", " ", "14.0"}], " ", "*)"}], " "}]], "Input",
 CellChangeTimes->{{3.4826639458125*^9, 3.48266394865625*^9}, {
  3.48266465525*^9, 3.4826646664375*^9}, {3.48266474965625*^9, 
  3.482664751828125*^9}, {3.48491439440625*^9, 3.48491448825*^9}, {
  3.484919547640625*^9, 3.484919584640625*^9}, {3.560541887586315*^9, 
  3.560541902073401*^9}}],

Cell["We plot the BSplines separately", "Text",
 CellChangeTimes->{{3.482664394578125*^9, 3.482664468984375*^9}, {
   3.482664514625*^9, 3.482664539265625*^9}, {3.48275498540625*^9, 
   3.48275501025*^9}, {3.482755052734375*^9, 3.48275518615625*^9}, {
   3.4827552320625*^9, 3.48275526790625*^9}, {3.48499732775*^9, 
   3.48499733709375*^9}, {3.484997378734375*^9, 3.4849973836875*^9}, 
   3.48499786365625*^9},
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{"p1", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{"BSplineBasis", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"degx", ",", "knotsx"}], "}"}], ",", "0", ",", "x"}], "]"}], 
     "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", "14"}], "}"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
    RowBox[{"Epilog", "->", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Text", "[", 
        RowBox[{
         RowBox[{"Style", "[", "symB1", "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"2", ",", "0.6"}], "}"}]}], "]"}], ",", " ", 
       RowBox[{"Text", "[", 
        RowBox[{
         RowBox[{"Style", "[", "\"\<\[FivePointedStar]\>\"", "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "0"}], "}"}]}], "]"}], ",", "symKnots"}], 
      "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.48759641690625*^9, 3.487596459359375*^9}, {
   3.48759658953125*^9, 3.487596589984375*^9}, 3.487674764046875*^9, 
   3.4876748324375*^9, 3.487675357234375*^9, {3.487676704890625*^9, 
   3.487676737234375*^9}, {3.4876767755*^9, 3.487676857984375*^9}, 
   3.487677198359375*^9, {3.48767722984375*^9, 3.48767726196875*^9}, {
   3.4876776701875*^9, 3.487677672546875*^9}, {3.4876777235*^9, 
   3.4876778080625*^9}, 3.487678289359375*^9, {3.560541929551568*^9, 
   3.560541964074728*^9}, {3.560542035760143*^9, 3.560542048837446*^9}, {
   3.560543861689001*^9, 3.560543878322206*^9}}],

Cell[BoxData[
 RowBox[{"p2", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{"BSplineBasis", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"degx", ",", "knotsx"}], "}"}], ",", "1", ",", "x"}], "]"}], 
     "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", "14"}], "}"}], ",", 
    RowBox[{"Epilog", "->", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Text", "[", 
        RowBox[{
         RowBox[{"Style", "[", "symB2", "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"5", ",", "0.4"}], "}"}]}], "]"}], ",", "symKnots"}], 
      "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.48759641690625*^9, 3.487596504953125*^9}, {
   3.4875965946875*^9, 3.487596595421875*^9}, 3.48767476465625*^9, 
   3.48767483321875*^9, 3.487675357234375*^9, {3.4876768743125*^9, 
   3.487676902609375*^9}, {3.48767718575*^9, 3.48767718778125*^9}, {
   3.48767797740625*^9, 3.48767801840625*^9}, 3.48767805196875*^9, 
   3.487678286359375*^9, {3.560542067621826*^9, 3.560542088134289*^9}, {
   3.560543896738544*^9, 3.560543900912682*^9}}],

Cell[BoxData[
 RowBox[{"p3", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{"BSplineBasis", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"degx", ",", "knotsx"}], "}"}], ",", "2", ",", "x"}], "]"}], 
     "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", "14"}], "}"}], ",", 
    RowBox[{"Epilog", "->", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Text", "[", 
        RowBox[{
         RowBox[{"Style", "[", "symB3", "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"8", ",", "0.5"}], "}"}]}], "]"}], ",", "symKnots"}], 
      "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.48759641690625*^9, 3.487596459359375*^9}, {
   3.487596489421875*^9, 3.487596507265625*^9}, {3.48759660015625*^9, 
   3.487596600875*^9}, 3.4876747651875*^9, 3.48767483371875*^9, 
   3.48767535725*^9, {3.487676924765625*^9, 3.4876769491875*^9}, 
   3.4876771784375*^9, {3.487677844546875*^9, 3.487677925140625*^9}, {
   3.48767806865625*^9, 3.4876781044375*^9}, 3.48767828446875*^9, {
   3.560542100544751*^9, 3.56054214418454*^9}, {3.560543911261594*^9, 
   3.560543914388486*^9}}],

Cell[BoxData[
 RowBox[{"p4", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{"BSplineBasis", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"degx", ",", "knotsx"}], "}"}], ",", "3", ",", "x"}], "]"}], 
     "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", "14"}], "}"}], ",", 
    RowBox[{"Epilog", "->", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Text", "[", 
        RowBox[{
         RowBox[{"Style", "[", "symB4", "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"11.5", ",", "0.5"}], "}"}]}], "]"}], ",", "symKnots"}], 
      "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.48759641690625*^9, 3.487596459359375*^9}, {
   3.487596492140625*^9, 3.487596509359375*^9}, {3.487596604234375*^9, 
   3.48759660490625*^9}, 3.487674765703125*^9, 3.487674834234375*^9, 
   3.48767535725*^9, {3.487676959859375*^9, 3.487676988109375*^9}, 
   3.48767716859375*^9, {3.4876781398125*^9, 3.487678161*^9}, 
   3.487678282609375*^9, {3.560542150066072*^9, 3.560542184110415*^9}, 
   3.56054392508077*^9}],

Cell[BoxData[
 RowBox[{"p5", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{"BSplineBasis", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"degx", ",", "knotsx"}], "}"}], ",", "4", ",", "x"}], "]"}], 
     "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", "14"}], "}"}], ",", 
    RowBox[{"Epilog", "->", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Text", "[", 
        RowBox[{
         RowBox[{"Style", "[", "symB5", "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"9", ",", "0.5"}], "}"}]}], "]"}], ",", "symKnots"}], 
      "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.48759641690625*^9, 3.487596459359375*^9}, {
   3.48759649453125*^9, 3.487596511875*^9}, {3.48759660684375*^9, 
   3.48759660915625*^9}, 3.487674766421875*^9, 3.487674835546875*^9, 
   3.48767535725*^9, {3.487677004125*^9, 3.487677027484375*^9}, 
   3.48767707025*^9, 3.48767715565625*^9, {3.487678197109375*^9, 
   3.48767822096875*^9}, 3.487678280421875*^9, {3.560542193383422*^9, 
   3.560542218669089*^9}, 3.560543932966192*^9}],

Cell[BoxData[
 RowBox[{"p6", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{"BSplineBasis", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"degx", ",", "knotsx"}], "}"}], ",", "5", ",", "x"}], "]"}], 
     "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", "14"}], "}"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
    RowBox[{"Epilog", "->", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Text", "[", 
        RowBox[{
         RowBox[{"Style", "[", "symB6", "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"12.", ",", "0.6"}], "}"}]}], "]"}], ",", "symKnots"}], 
      "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.48759641690625*^9, 3.487596459359375*^9}, {
   3.487596497375*^9, 3.487596514078125*^9}, {3.487596612*^9, 
   3.487596612578125*^9}, 3.48767476703125*^9, 3.487674836171875*^9, 
   3.48767535725*^9, {3.48767700725*^9, 3.48767701378125*^9}, {
   3.48767708440625*^9, 3.48767714296875*^9}, {3.487678245703125*^9, 
   3.487678274984375*^9}, {3.560542228571639*^9, 3.560542243106405*^9}, 
   3.560543946197765*^9}],

Cell[TextData[{
 "We remind that the support of ",
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["B", "1", "2"], TraditionalForm]]],
 "(x) is formed by  4 knots, of which the first three are coincident; in the \
support for  ",
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["B", "2", "2"], TraditionalForm]]],
 "(x),   the first two knots are coincident; all the knots for  ",
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["B", "3", "2"], TraditionalForm]]],
 "(x)   are distinct."
}], "Text",
 CellChangeTimes->{{3.482664394578125*^9, 3.482664468984375*^9}, {
   3.482664514625*^9, 3.482664539265625*^9}, {3.48275498540625*^9, 
   3.48275501025*^9}, {3.482755052734375*^9, 3.48275518615625*^9}, 
   3.484914425703125*^9, {3.484914587328125*^9, 3.484914590265625*^9}, {
   3.4849790056875*^9, 3.484979036765625*^9}, 3.48499291775*^9, {
   3.4849973990625*^9, 3.48499747065625*^9}, {3.484997518078125*^9, 
   3.484997519515625*^9}, {3.486033256890625*^9, 3.486033259125*^9}, {
   3.4860333613125*^9, 3.4860333878125*^9}, {3.486033419140625*^9, 
   3.486033420671875*^9}, {3.486033454171875*^9, 3.48603354928125*^9}, {
   3.486033587921875*^9, 3.486033646125*^9}, {3.4860336766875*^9, 
   3.48603369671875*^9}, {3.487677327484375*^9, 3.48767743590625*^9}, {
   3.487677468828125*^9, 3.48767752884375*^9}, {3.48767759678125*^9, 
   3.4876776201875*^9}, {3.487678337703125*^9, 3.487678360234375*^9}, {
   3.48767911278125*^9, 3.48767911421875*^9}, {3.560542304410742*^9, 
   3.560542311434954*^9}},
 FontFamily->"Times New Roman",
 FontSize->14,
 FontColor->GrayLevel[0],
 Background->GrayLevel[0.85]],

Cell["\<\
We reconstruct the spline and plot the resultant on each subdomain formed by \
the four knots\
\>", "Text",
 CellChangeTimes->{{3.482664394578125*^9, 3.482664468984375*^9}, {
   3.482664514625*^9, 3.482664539265625*^9}, {3.48275498540625*^9, 
   3.48275501025*^9}, {3.482755052734375*^9, 3.48275518615625*^9}, 
   3.484914425703125*^9, {3.484914587328125*^9, 3.484914590265625*^9}, {
   3.4849790056875*^9, 3.484979036765625*^9}, 3.48499291775*^9, {
   3.4849973990625*^9, 3.48499747065625*^9}, {3.484997518078125*^9, 
   3.484997519515625*^9}, {3.559508322045296*^9, 3.559508328452069*^9}},
 FontFamily->"Times New Roman",
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", "x_", "]"}], "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"coeff", ".", "bsplines"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.559507412758713*^9, 3.559507440327875*^9}, {
  3.559508155235904*^9, 3.559508183032079*^9}, {3.559542860157253*^9, 
  3.559542870016616*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"f1", "[", "x_", "]"}], "=", 
  RowBox[{
   RowBox[{"f", "[", "x", "]"}], "[", 
   RowBox[{"[", 
    RowBox[{"1", ",", "3", ",", "1"}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.482664798328125*^9, 3.482664876421875*^9}, {
  3.482665070609375*^9, 3.482665072234375*^9}, {3.484914595796875*^9, 
  3.48491461284375*^9}, {3.484917527796875*^9, 3.48491757125*^9}, {
  3.484992918484375*^9, 3.484992919515625*^9}, {3.487597965578125*^9, 
  3.487597966796875*^9}, {3.560542421629487*^9, 3.56054243631225*^9}, {
  3.56054276181186*^9, 3.560542797077459*^9}}],

Cell[BoxData[
 RowBox[{"segment1", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{"f1", "[", "x", "]"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", "3.5"}], "}"}]}], "]"}], " "}]], "Input",
 CellChangeTimes->{{3.4826639558125*^9, 3.48266397771875*^9}, {
   3.482664893203125*^9, 3.48266489575*^9}, {3.4826649806875*^9, 
   3.482664982765625*^9}, {3.482665113578125*^9, 3.482665156546875*^9}, {
   3.482665204203125*^9, 3.482665208359375*^9}, 3.4849145061875*^9, {
   3.48499787665625*^9, 3.484997877140625*^9}, {3.48499791696875*^9, 
   3.48499791890625*^9}, 3.560542444274894*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"f2", "[", "x_", "]"}], "=", 
  RowBox[{
   RowBox[{"f", "[", "x", "]"}], "[", 
   RowBox[{"[", 
    RowBox[{"1", ",", "4", ",", "1"}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.482664798328125*^9, 3.482664876421875*^9}, {
  3.482665070609375*^9, 3.482665072234375*^9}, {3.484914595796875*^9, 
  3.48491461284375*^9}, {3.48491465646875*^9, 3.48491468153125*^9}, {
  3.484914796234375*^9, 3.48491482015625*^9}, {3.484914870453125*^9, 
  3.48491489696875*^9}, {3.484917425203125*^9, 3.484917425734375*^9}, {
  3.48491749365625*^9, 3.484917494078125*^9}, {3.484975188671875*^9, 
  3.48497523265625*^9}, {3.48499291996875*^9, 3.48499292084375*^9}, {
  3.487597989765625*^9, 3.487597993375*^9}, {3.56054245098733*^9, 
  3.560542466863947*^9}, {3.560542814080294*^9, 3.560542814283745*^9}}],

Cell[BoxData[
 RowBox[{"segment2", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{"f2", "[", "x", "]"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "3.5", ",", "7.0"}], "}"}]}], "]"}], " "}]], "Input",
 CellChangeTimes->{{3.4826639558125*^9, 3.48266397771875*^9}, {
   3.482664893203125*^9, 3.48266489575*^9}, {3.4826649806875*^9, 
   3.482664982765625*^9}, {3.482665113578125*^9, 3.482665156546875*^9}, {
   3.482665204203125*^9, 3.482665208359375*^9}, 3.4849145061875*^9, {
   3.484975271390625*^9, 3.484975284296875*^9}, {3.484997882078125*^9, 
   3.484997911578125*^9}, 3.560542472978189*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"f3", "[", "x_", "]"}], "=", 
  RowBox[{
   RowBox[{"f", "[", "x", "]"}], "[", 
   RowBox[{"[", 
    RowBox[{"1", ",", "2", ",", "1"}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.482664798328125*^9, 3.482664876421875*^9}, {
  3.482665070609375*^9, 3.482665072234375*^9}, {3.484914595796875*^9, 
  3.48491461284375*^9}, {3.48491465646875*^9, 3.48491468153125*^9}, {
  3.484914796234375*^9, 3.48491482015625*^9}, {3.484914870453125*^9, 
  3.48491489696875*^9}, {3.484917425203125*^9, 3.484917425734375*^9}, {
  3.48497532003125*^9, 3.484975320453125*^9}, {3.48497535390625*^9, 
  3.48497538434375*^9}, {3.484975434296875*^9, 3.48497543875*^9}, {
  3.484992921234375*^9, 3.48499292203125*^9}, {3.48759802596875*^9, 
  3.48759802946875*^9}, {3.560542484282909*^9, 3.560542509449363*^9}, {
  3.560542834682199*^9, 3.560542837640813*^9}}],

Cell[BoxData[
 RowBox[{"segment3", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{"f3", "[", "x", "]"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "7", ",", "10"}], "}"}]}], "]"}], " "}]], "Input",
 CellChangeTimes->{{3.4826639558125*^9, 3.48266397771875*^9}, {
   3.482664893203125*^9, 3.48266489575*^9}, {3.4826649806875*^9, 
   3.482664982765625*^9}, {3.482665113578125*^9, 3.482665156546875*^9}, {
   3.482665204203125*^9, 3.482665208359375*^9}, 3.4849145061875*^9, {
   3.484975271390625*^9, 3.484975284296875*^9}, {3.484975398203125*^9, 
   3.484975417578125*^9}, {3.48499788959375*^9, 3.484997906578125*^9}, 
   3.560542519280049*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"f4", "[", "x_", "]"}], "=", 
  RowBox[{
   RowBox[{"f", "[", "x", "]"}], "[", 
   RowBox[{"[", "2", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.482664798328125*^9, 3.482664876421875*^9}, {
   3.482665070609375*^9, 3.482665072234375*^9}, {3.484914595796875*^9, 
   3.48491461284375*^9}, {3.48491465646875*^9, 3.48491468153125*^9}, {
   3.484914796234375*^9, 3.48491482015625*^9}, {3.484914870453125*^9, 
   3.48491489696875*^9}, {3.484917425203125*^9, 3.484917425734375*^9}, {
   3.484992922453125*^9, 3.484992923234375*^9}, {3.487598037453125*^9, 
   3.48759804065625*^9}, {3.560542525017014*^9, 3.560542529823891*^9}, 
   3.560542859186751*^9}],

Cell[BoxData[
 RowBox[{"segment4", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{"f4", "[", "x", "]"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "10", ",", "14"}], "}"}]}], "]"}], " "}]], "Input",
 CellChangeTimes->{{3.4826639558125*^9, 3.48266397771875*^9}, {
   3.482664893203125*^9, 3.48266489575*^9}, {3.4826649806875*^9, 
   3.482664982765625*^9}, {3.482665113578125*^9, 3.482665156546875*^9}, {
   3.482665204203125*^9, 3.482665208359375*^9}, 3.4849145061875*^9, {
   3.484914830375*^9, 3.48491483578125*^9}, {3.484914908546875*^9, 
   3.4849149094375*^9}, {3.484916414625*^9, 3.48491641496875*^9}, {
   3.48497546071875*^9, 3.484975465046875*^9}, {3.48499789678125*^9, 
   3.484997898375*^9}, 3.560542605198299*^9}],

Cell["We plot the complete spline", "Text",
 CellChangeTimes->{{3.482664394578125*^9, 3.482664468984375*^9}, {
   3.482664514625*^9, 3.482664539265625*^9}, {3.48275498540625*^9, 
   3.48275501025*^9}, {3.482755052734375*^9, 3.48275518615625*^9}, {
   3.48491260909375*^9, 3.484912650578125*^9}, 3.48491287253125*^9, {
   3.48497766284375*^9, 3.484977663578125*^9}, {3.484979246015625*^9, 
   3.4849792499375*^9}, {3.484979322359375*^9, 3.484979372375*^9}, {
   3.484979455421875*^9, 3.48497947915625*^9}, {3.48603562734375*^9, 
   3.486035649875*^9}, {3.5605429039791*^9, 3.560542908362828*^9}},
 FontFamily->"Times New Roman",
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{"graphSx", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"f", "[", "x", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", 
      RowBox[{"-", "1"}], ",", "15"}], "}"}], ",", 
    RowBox[{"AxesOrigin", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "0"}], "}"}]}], ",", 
    RowBox[{"PlotPoints", "\[Rule]", "500"}], ",", 
    RowBox[{"Epilog", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Red", ",", 
       RowBox[{"PointSize", "[", "Medium", "]"}], ",", 
       RowBox[{"Point", "[", "points", "]"}]}], "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{
  3.482232990035215*^9, {3.482662078546875*^9, 3.482662109859375*^9}, {
   3.482662150546875*^9, 3.4826622134375*^9}, {3.48266495928125*^9, 
   3.4826649904375*^9}, {3.484975777125*^9, 3.48497580125*^9}, {
   3.48497956090625*^9, 3.484979579671875*^9}, {3.48498021971875*^9, 
   3.48498023115625*^9}, {3.484997551734375*^9, 3.48499757775*^9}, {
   3.4860350655625*^9, 3.486035078453125*^9}, {3.486035127015625*^9, 
   3.48603512909375*^9}, {3.560542925730338*^9, 3.560542955965399*^9}}]
}, Open  ]],

Cell["Part IV", "Text",
 CellChangeTimes->{
  3.484992245703125*^9, {3.484992316015625*^9, 3.4849923314375*^9}, {
   3.48499253890625*^9, 3.484992628625*^9}, {3.484994235171875*^9, 
   3.484994236890625*^9}, {3.48499689084375*^9, 3.48499689559375*^9}, {
   3.48767985275*^9, 3.4876798598125*^9}, {3.560539989233566*^9, 
   3.5605399935075*^9}, {3.572683032405257*^9, 3.5726830337403336`*^9}, 
   3.5726830760287523`*^9},
 FontFamily->"Times New Roman",
 FontSize->36,
 FontColor->RGBColor[0, 0, 1],
 Background->RGBColor[1, 0.9, 0.8]],

Cell[CellGroupData[{

Cell[TextData[{
 "We can check graphically and manually  the ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["C", "1"], TraditionalForm]]],
 " and boundary conditions.\nIt is verified that no boundary conditions are \
introduced."
}], "Text",
 CellChangeTimes->{{3.4849789611875*^9, 3.48497897071875*^9}, {
   3.484979148703125*^9, 3.484979160640625*^9}, {3.484979192*^9, 
   3.484979203421875*^9}, {3.4849961621875*^9, 3.4849962291875*^9}, {
   3.48499627365625*^9, 3.48499632746875*^9}, 3.484996906109375*^9, {
   3.486039064921875*^9, 3.486039067234375*^9}, {3.4860391213125*^9, 
   3.486039158296875*^9}, {3.487681740421875*^9, 3.48768174615625*^9}, {
   3.560542971804951*^9, 3.560542983357932*^9}},
 FontFamily->"Times New Roman",
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{"dSpline1", "=", " ", 
  RowBox[{"D", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{"f", "[", "x", "]"}], "]"}], ",", "x"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.560543005172978*^9, 3.560543006914804*^9}, {
  3.560584632971844*^9, 3.560584633263458*^9}}],

Cell[BoxData[
 RowBox[{"graD1", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{"dSpline1", ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", 
      RowBox[{"-", "1"}], ",", "15"}], "}"}], ",", 
    RowBox[{"AxesOrigin", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "0"}], "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{
  3.560543015946636*^9, {3.560584638796559*^9, 3.56058463911704*^9}}],

Cell["Second derivative of S (x)", "Text",
 CellChangeTimes->{{3.486038846015625*^9, 3.4860388865*^9}},
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{"dSpline2", "=", " ", 
  RowBox[{"D", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{"f", "[", "x", "]"}], "]"}], ",", "x", ",", "x"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.560543273364825*^9, 3.560543275170184*^9}, {
  3.560584642481761*^9, 3.560584642701956*^9}}],

Cell[BoxData[
 RowBox[{"graD2", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{"dSpline2", ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", 
      RowBox[{"-", "1"}], ",", "15"}], "}"}], ",", 
    RowBox[{"AxesOrigin", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "0"}], "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.486038846015625*^9, 3.48603889146875*^9}, 
   3.560543034663514*^9, {3.560584645776663*^9, 3.560584645979656*^9}}],

Cell["First and second derivatives at x = 0.", "Text",
 CellChangeTimes->{{3.482664394578125*^9, 3.482664468984375*^9}, {
   3.482664514625*^9, 3.482664539265625*^9}, {3.48275498540625*^9, 
   3.48275501025*^9}, {3.482755052734375*^9, 3.48275518615625*^9}, {
   3.48491260909375*^9, 3.484912650578125*^9}, 3.48491287253125*^9, {
   3.48497766284375*^9, 3.484977663578125*^9}, {3.484979246015625*^9, 
   3.4849792499375*^9}, {3.484996455*^9, 3.484996511484375*^9}, {
   3.4860392656875*^9, 3.48603926659375*^9}},
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{"derD1f1x0", "=", " ", 
  RowBox[{
   RowBox[{"D", "[", 
    RowBox[{
     RowBox[{"Evaluate", "[", 
      RowBox[{"f1", "[", "x", "]"}], "]"}], ",", "x"}], "]"}], " ", "/.", " ", 
   RowBox[{"x", "\[Rule]", "0"}]}]}]], "Input",
 CellChangeTimes->{{3.4849789611875*^9, 3.48497897071875*^9}, {
  3.484996362078125*^9, 3.484996404453125*^9}}],

Cell[BoxData[
 RowBox[{"derD2f1x0", "=", " ", 
  RowBox[{
   RowBox[{"D", "[", 
    RowBox[{
     RowBox[{"Evaluate", "[", 
      RowBox[{"f1", "[", "x", "]"}], "]"}], ",", "x", ",", "x"}], "]"}], " ", 
   "/.", " ", 
   RowBox[{"x", "\[Rule]", "0"}]}]}]], "Input",
 CellChangeTimes->{{3.4849789611875*^9, 3.484978974875*^9}, {
  3.48499639340625*^9, 3.48499640853125*^9}}],

Cell["First and second derivatives at x = 14.", "Text",
 CellChangeTimes->{{3.482664394578125*^9, 3.482664468984375*^9}, {
   3.482664514625*^9, 3.482664539265625*^9}, {3.48275498540625*^9, 
   3.48275501025*^9}, {3.482755052734375*^9, 3.48275518615625*^9}, {
   3.48491260909375*^9, 3.484912650578125*^9}, 3.48491287253125*^9, {
   3.48497766284375*^9, 3.484977663578125*^9}, {3.484979246015625*^9, 
   3.4849792499375*^9}, {3.484996455*^9, 3.484996511484375*^9}},
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{"derD1f4x14", "=", " ", 
  RowBox[{
   RowBox[{"D", "[", 
    RowBox[{
     RowBox[{"Evaluate", "[", 
      RowBox[{"f4", "[", "x", "]"}], "]"}], ",", "x"}], "]"}], " ", "/.", " ", 
   RowBox[{"x", "\[Rule]", "14"}]}]}]], "Input",
 CellChangeTimes->{{3.484912499015625*^9, 3.484912547140625*^9}, 
   3.484914509015625*^9, 3.484916429015625*^9, {3.48491741003125*^9, 
   3.48491741365625*^9}, {3.4849753231875*^9, 3.484975343109375*^9}, {
   3.484975489859375*^9, 3.48497549940625*^9}, {3.484996419484375*^9, 
   3.484996437296875*^9}}],

Cell[BoxData[
 RowBox[{"derD2f4x14", "=", " ", 
  RowBox[{
   RowBox[{"D", "[", 
    RowBox[{
     RowBox[{"Evaluate", "[", 
      RowBox[{"f4", "[", "x", "]"}], "]"}], ",", "x", ",", "x"}], "]"}], " ", 
   "/.", " ", 
   RowBox[{"x", "\[Rule]", "14"}]}]}]], "Input",
 CellChangeTimes->{{3.484912499015625*^9, 3.484912565265625*^9}, 
   3.484914510296875*^9, 3.48491643084375*^9, {3.4849174166875*^9, 
   3.484917420078125*^9}, {3.484975326515625*^9, 3.4849753331875*^9}, {
   3.48497550234375*^9, 3.484975511625*^9}, {3.48499642209375*^9, 
   3.48499642996875*^9}}],

Cell["\<\
We verify continuity of first derivative at first internal knot (3.5)\
\>", "Text",
 CellChangeTimes->{{3.482664394578125*^9, 3.482664468984375*^9}, {
   3.482664514625*^9, 3.482664539265625*^9}, {3.48275498540625*^9, 
   3.48275501025*^9}, {3.482755052734375*^9, 3.48275518615625*^9}, {
   3.48491260909375*^9, 3.484912650578125*^9}, 3.48491287253125*^9, {
   3.48497766284375*^9, 3.484977663578125*^9}, {3.484979246015625*^9, 
   3.4849792499375*^9}, {3.484979322359375*^9, 3.484979372375*^9}, {
   3.48499652175*^9, 3.484996562421875*^9}},
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{"derf1dx", "=", " ", 
  RowBox[{
   RowBox[{"D", "[", 
    RowBox[{
     RowBox[{"Evaluate", "[", 
      RowBox[{"f1", "[", "x", "]"}], "]"}], ",", "x"}], "]"}], " ", "/.", " ", 
   RowBox[{"x", "\[Rule]", "3.5"}]}]}]], "Input",
 CellChangeTimes->{{3.484912499015625*^9, 3.484912547140625*^9}, 
   3.484914509015625*^9, 3.484916429015625*^9, {3.48491741003125*^9, 
   3.48491741365625*^9}, {3.484917496828125*^9, 3.4849175061875*^9}, {
   3.484975242015625*^9, 3.48497524375*^9}, {3.484979378046875*^9, 
   3.4849793979375*^9}}],

Cell[BoxData[
 RowBox[{"derf2sx", "=", " ", 
  RowBox[{
   RowBox[{"D", "[", 
    RowBox[{
     RowBox[{"Evaluate", "[", 
      RowBox[{"f2", "[", "x", "]"}], "]"}], ",", "x"}], "]"}], " ", "/.", " ", 
   RowBox[{"x", "\[Rule]", "3.5"}]}]}]], "Input",
 CellChangeTimes->{{3.484912499015625*^9, 3.484912565265625*^9}, 
   3.484914510296875*^9, 3.48491643084375*^9, {3.4849174166875*^9, 
   3.484917420078125*^9}, {3.48491749928125*^9, 3.484917501984375*^9}, {
   3.484975247296875*^9, 3.4849752493125*^9}, {3.484979400703125*^9, 
   3.484979430734375*^9}}]
}, Open  ]],

Cell["Part V", "Text",
 CellChangeTimes->{
  3.484992245703125*^9, {3.484992316015625*^9, 3.4849923314375*^9}, {
   3.48499253890625*^9, 3.484992628625*^9}, {3.484994235171875*^9, 
   3.484994236890625*^9}, {3.48499689084375*^9, 3.48499689559375*^9}, {
   3.48767985275*^9, 3.4876798598125*^9}, {3.560539989233566*^9, 
   3.5605399935075*^9}, {3.572683032405257*^9, 3.5726830337403336`*^9}, {
   3.5726830889644923`*^9, 3.5726830891085005`*^9}},
 FontFamily->"Times New Roman",
 FontSize->36,
 FontColor->RGBColor[0, 0, 1],
 Background->RGBColor[1, 0.9, 0.8]],

Cell[TextData[{
 "We check that the reconstruction conincides with the result given by ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "."
}], "Text",
 CellChangeTimes->{{3.4822341378707695`*^9, 3.4822341540168734`*^9}, {
  3.48499855896875*^9, 3.48499856028125*^9}, {3.559508878093765*^9, 
  3.559508878656044*^9}, {3.559508923401692*^9, 3.559508937468286*^9}, {
  3.559541764068054*^9, 3.559541767750527*^9}, {3.559542684134254*^9, 
  3.559542715594304*^9}, {3.56053836865784*^9, 3.560538389643898*^9}},
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"Chop", "[", 
    RowBox[{
     RowBox[{"parabolicSpline", "[", "x", "]"}], " ", "-", " ", 
     RowBox[{"f", "[", "x", "]"}]}], "]"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"x", ",", " ", "0", ",", " ", "14"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.559509211208383*^9, 3.559509211209626*^9}, {
   3.559541778864373*^9, 3.559541780206865*^9}, 3.55954274758951*^9, 
   3.56053840146544*^9}]
},
AutoGeneratedPackage->None,
CellGrouping->Manual,
WindowSize->{1438, 813},
WindowMargins->{{7, Automatic}, {Automatic, 0}},
Magnification->1.5,
FrontEndVersion->"9.0 for Linux x86 (64-bit) (January 25, 2013)",
StyleDefinitions->"Zosi-direi-buono.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[557, 20, 512, 12, 112, "Text"],
Cell[1072, 34, 4801, 101, 958, "Text"],
Cell[5876, 137, 242, 5, 45, "Input"],
Cell[6121, 144, 119, 2, 45, "Input"],
Cell[6243, 148, 102, 1, 45, "Input"],
Cell[6348, 151, 505, 10, 106, "Text"],
Cell[CellGroupData[{
Cell[6878, 165, 661, 18, 75, "Text"],
Cell[7542, 185, 879, 22, 45, "Input"],
Cell[8424, 209, 233, 4, 45, "Input"],
Cell[8660, 215, 474, 11, 45, "Input"],
Cell[9137, 228, 1082, 27, 104, "Input"]
}, Open  ]],
Cell[10234, 258, 504, 10, 106, "Text"],
Cell[CellGroupData[{
Cell[10763, 272, 673, 13, 103, "Text"],
Cell[11439, 287, 653, 14, 103, "Text"],
Cell[12095, 303, 239, 6, 64, "Input"],
Cell[12337, 311, 347, 10, 102, "Text"],
Cell[12687, 323, 246, 4, 64, "Input"],
Cell[12936, 329, 252, 5, 102, "Text"],
Cell[13191, 336, 444, 8, 64, "Input"],
Cell[13638, 346, 247, 5, 102, "Text"],
Cell[13888, 353, 392, 7, 64, "Input"],
Cell[CellGroupData[{
Cell[14305, 364, 526, 10, 144, "Text"],
Cell[14834, 376, 823, 19, 111, "Input"],
Cell[15660, 397, 919, 25, 64, "Input"],
Cell[16582, 424, 3641, 90, 552, "Input"]
}, Open  ]],
Cell[20238, 517, 307, 5, 102, "Text"],
Cell[20548, 524, 1009, 24, 147, "Input"],
Cell[21560, 550, 1433, 39, 106, "Text"]
}, Open  ]],
Cell[23008, 592, 505, 10, 159, "Text"],
Cell[CellGroupData[{
Cell[23538, 606, 1103, 19, 135, "Text"],
Cell[24644, 627, 667, 13, 102, "Text"],
Cell[25314, 642, 809, 17, 64, "Input"],
Cell[26126, 661, 815, 17, 64, "Input"],
Cell[26944, 680, 833, 17, 64, "Input"],
Cell[27780, 699, 614, 10, 102, "Text"],
Cell[28397, 711, 822, 17, 64, "Input"],
Cell[29222, 730, 869, 18, 64, "Input"],
Cell[30094, 750, 875, 18, 64, "Input"],
Cell[30972, 770, 615, 10, 102, "Text"],
Cell[31590, 782, 879, 18, 64, "Input"],
Cell[32472, 802, 828, 17, 64, "Input"],
Cell[33303, 821, 737, 16, 64, "Input"],
Cell[34043, 839, 616, 10, 102, "Text"],
Cell[34662, 851, 783, 17, 64, "Input"],
Cell[35448, 870, 825, 17, 64, "Input"],
Cell[36276, 889, 639, 15, 64, "Input"],
Cell[36918, 906, 456, 8, 102, "Text"],
Cell[37377, 916, 1491, 35, 64, "Input"],
Cell[38871, 953, 1094, 27, 64, "Input"],
Cell[39968, 982, 1138, 28, 64, "Input"],
Cell[41109, 1012, 1072, 27, 64, "Input"],
Cell[42184, 1041, 1087, 27, 64, "Input"],
Cell[43274, 1070, 1118, 28, 64, "Input"],
Cell[44395, 1100, 1600, 34, 105, "Text"],
Cell[45998, 1136, 678, 13, 102, "Text"],
Cell[46679, 1151, 312, 7, 64, "Input"],
Cell[46994, 1160, 591, 12, 64, "Input"],
Cell[47588, 1174, 640, 13, 64, "Input"],
Cell[48231, 1189, 824, 15, 64, "Input"],
Cell[49058, 1206, 645, 13, 64, "Input"],
Cell[49706, 1221, 871, 16, 64, "Input"],
Cell[50580, 1239, 691, 14, 64, "Input"],
Cell[51274, 1255, 684, 13, 64, "Input"],
Cell[51961, 1270, 774, 15, 64, "Input"],
Cell[52738, 1287, 672, 11, 102, "Text"],
Cell[53413, 1300, 1108, 25, 64, "Input"]
}, Open  ]],
Cell[54536, 1328, 534, 11, 159, "Text"],
Cell[CellGroupData[{
Cell[55095, 1343, 780, 17, 144, "Text"],
Cell[55878, 1362, 296, 7, 64, "Input"],
Cell[56177, 1371, 415, 12, 64, "Input"],
Cell[56595, 1385, 148, 3, 102, "Text"],
Cell[56746, 1390, 310, 8, 64, "Input"],
Cell[57059, 1400, 462, 12, 64, "Input"],
Cell[57524, 1414, 556, 9, 102, "Text"],
Cell[58083, 1425, 363, 9, 64, "Input"],
Cell[58449, 1436, 373, 10, 64, "Input"],
Cell[58825, 1448, 510, 8, 102, "Text"],
Cell[59338, 1458, 558, 12, 64, "Input"],
Cell[59899, 1472, 566, 13, 64, "Input"],
Cell[60468, 1487, 597, 11, 102, "Text"],
Cell[61068, 1500, 551, 12, 64, "Input"],
Cell[61622, 1514, 555, 12, 64, "Input"]
}, Open  ]],
Cell[62192, 1529, 559, 11, 159, "Text"],
Cell[62754, 1542, 555, 12, 102, "Text"],
Cell[63312, 1556, 460, 11, 64, "Input"]
}
]
*)

(* End of internal cache information *)
