(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    540540,      10245]
NotebookOptionsPosition[    532236,       9978]
NotebookOutlinePosition[    532622,       9995]
CellTagsIndexPosition[    532579,       9992]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["\<\
Evaluation time:
\[CapitalDelta]t < 5 s \
\>", "Text",
 CellChangeTimes->{
  3.484992245703125*^9, {3.484992316015625*^9, 3.4849923314375*^9}, {
   3.48499253890625*^9, 3.484992628625*^9}, {3.484994235171875*^9, 
   3.484994236890625*^9}, {3.48499689084375*^9, 3.48499689559375*^9}, {
   3.486039583859375*^9, 3.486039584453125*^9}, {3.559482005654936*^9, 
   3.559482006444809*^9}, {3.5726834909894867`*^9, 3.572683498155897*^9}},
 FontSize->18,
 FontColor->RGBColor[0, 0, 1],
 Background->RGBColor[1, 0.9, 0.8]],

Cell[TextData[{
 "Interpolation using B-splines of order 4 (i.e. degree 3)\n\n",
 StyleBox["Warning! \nIn Section 6.4, it is clearly stated that   order = \
degree + 1. \nIn Mathematica, the command InterpolationOrder refers to the \
degree of the interpolating polynomial,\ntherefore,  InterpolationOrder -> 2  \
considers parabolae, etc.\n",
  FontColor->RGBColor[0.5, 0, 0.5]],
 "\nIntroduction\n\nThe main purpose of this notebook is to examine the \
properties of the  ",
 Cell[BoxData[
  FormBox[
   RowBox[{"functions", " ", 
    SubsuperscriptBox["B", "i", "4"]}], TraditionalForm]]],
 "(x)  (B-splines of third degree, fourth order).\nTo this end, by means of \
the expression\n                          \n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"S", "(", "x", ")"}], " ", "=", " ", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"i", "=", "1"}], "M"], 
     RowBox[{
      SubscriptBox["\[Alpha]", "i"], " ", 
      RowBox[{
       SubsuperscriptBox["B", "i", "4"], "(", "x", ")"}]}]}]}], 
   TraditionalForm]]],
 ", \n\nwe interpolate the same set of points {",
 Cell[BoxData[
  FormBox[
   SubscriptBox["x", 
    RowBox[{"i", ","}]], TraditionalForm]]],
 " ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["f", "i"], TraditionalForm]]],
 "} given in the text (Chapter \\ref{chap:splines}, Section \
\\ref{subsec:uniform-cubic})\n\n In the first section we use the command \n \n\
 ",
 StyleBox["cubicSpline =  Interpolation[points, InterpolationOrder \[Rule] 3, \
Method \[Rule] \"Spline\"]",
  FontFamily->"Courier"],
 "\n\nIn the second section we access  the information contained in  \
cubicSpline, that is, the coefficients ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Alpha]", "i"], TraditionalForm]]],
 " of the splines and the set of knots.\n              \nIn the third  \
section we extract the polynomial representation of each Bspline and \
reconstruct the complete spline.\n\nIn the fourth  section we check the ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["C", "1"], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["C", "2"], TraditionalForm]]],
 "  and the boundary conditions of S(x).\n         \nIn the fifth  section we \
check that our reconstruction coincides with the one given by Mathematica."
}], "Text",
 CellChangeTimes->{{3.4822342910645547`*^9, 3.4822343209855466`*^9}, {
   3.4827529496875*^9, 3.482752986359375*^9}, {3.482753058375*^9, 
   3.48275329565625*^9}, {3.482754376203125*^9, 3.4827544480625*^9}, {
   3.48275486803125*^9, 3.482754928265625*^9}, {3.482755560515625*^9, 
   3.48275556246875*^9}, {3.4827556411875*^9, 3.48275569015625*^9}, {
   3.48351817559375*^9, 3.483518182875*^9}, {3.483518280890625*^9, 
   3.4835183170625*^9}, {3.484914080453125*^9, 3.48491409403125*^9}, {
   3.484982273*^9, 3.484982330890625*^9}, {3.48499031065625*^9, 
   3.48499031225*^9}, {3.484991693046875*^9, 3.4849918995*^9}, {
   3.484991929671875*^9, 3.484992071828125*^9}, {3.484992112015625*^9, 
   3.48499219953125*^9}, {3.484992274671875*^9, 3.484992288953125*^9}, {
   3.48499252521875*^9, 3.48499252659375*^9}, {3.484992681984375*^9, 
   3.484992822796875*^9}, {3.4849957348125*^9, 3.4849958199375*^9}, {
   3.484996916859375*^9, 3.484997034578125*^9}, {3.484998766484375*^9, 
   3.484998831421875*^9}, {3.484999638984375*^9, 3.48499968971875*^9}, {
   3.484999752609375*^9, 3.4849998213125*^9}, {3.485845938390625*^9, 
   3.485845955046875*^9}, 3.486032339453125*^9, {3.486037365875*^9, 
   3.48603750078125*^9}, {3.486037535953125*^9, 3.486037636859375*^9}, {
   3.48603782975*^9, 3.48603789246875*^9}, 3.486037925296875*^9, 
   3.48603796115625*^9, {3.486038164078125*^9, 3.486038197546875*^9}, {
   3.486038247203125*^9, 3.486038345859375*^9}, {3.486038501484375*^9, 
   3.486038610640625*^9}, {3.48603864065625*^9, 3.486038657*^9}, {
   3.486038689890625*^9, 3.48603873975*^9}, {3.486038935171875*^9, 
   3.486039040234375*^9}, {3.4860395724375*^9, 3.486039576578125*^9}, {
   3.4860401415625*^9, 3.486040176078125*^9}, {3.4876802559375*^9, 
   3.487680272515625*^9}, {3.487681597484375*^9, 3.487681605515625*^9}, {
   3.559481405755838*^9, 3.55948140707919*^9}, {3.559481466382803*^9, 
   3.559481506594187*^9}, {3.559481560546674*^9, 3.559481708779786*^9}, {
   3.55948203592665*^9, 3.559482044108379*^9}, {3.559508966468197*^9, 
   3.559508967354209*^9}, {3.559541621201445*^9, 3.559541633240987*^9}, {
   3.560536798026518*^9, 3.560536811979471*^9}, {3.560537311999555*^9, 
   3.560537316248664*^9}, {3.560537360395359*^9, 3.56053737909953*^9}, {
   3.560537712425122*^9, 3.560537789677993*^9}, {3.560539282328968*^9, 
   3.560539288987124*^9}, {3.560539840758474*^9, 3.560539862031093*^9}, {
   3.5605431803099*^9, 3.560543208706775*^9}, {3.572683467730157*^9, 
   3.572683474414539*^9}, {3.5726835294756885`*^9, 3.5726835304357433`*^9}, {
   3.575982434918497*^9, 3.5759824351975126`*^9}, {3.577114671842903*^9, 
   3.577114710124092*^9}, 3.577455598872048*^9, 3.5777015863854017`*^9, 
   3.577701640728661*^9},
 FontSize->16,
 FontColor->RGBColor[0, 0, 1],
 Background->RGBColor[1, 1, 0.85]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Remove", "[", "\"\<Global`*\>\"", "]"}], ";", 
  RowBox[{"$Line", "=", "0"}], ";"}]], "Input",
 CellChangeTimes->{{3.48351269165625*^9, 3.48351271565625*^9}, {
  3.5076381993481483`*^9, 3.50763820358489*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Remove", "::", "rmnsm"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"There are no symbols matching \
\\\"\[NoBreak]\\!\\(\\\"Global`*\\\"\\)\[NoBreak]\\\". \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/Remove/rmnsm\\\", \
ButtonNote -> \\\"Remove::rmnsm\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.577701679674964*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["$Version"], "Input",
 CellChangeTimes->{{3.507638206475212*^9, 3.507638212763978*^9}}],

Cell[BoxData["\<\"9.0 for Linux x86 (64-bit) (January 24, 2013)\"\>"], \
"Output",
 CellChangeTimes->{3.5777016799371433`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Date", "[", "]"}]], "Input",
 CellChangeTimes->{{3.507638216964425*^9, 3.507638218281106*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "2013", ",", "5", ",", "16", ",", "16", ",", "1", ",", 
   "19.984639`8.053271291603844"}], "}"}]], "Output",
 CellChangeTimes->{3.5777016799907312`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"SetOptions", "[", 
   RowBox[{"Plot", ",", 
    RowBox[{"PlotPoints", "\[Rule]", "150"}]}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.559509527491418*^9, 3.559509533105295*^9}, {
  3.559509660118734*^9, 3.559509664133732*^9}}],

Cell["Part I", "Text",
 CellChangeTimes->{
  3.484992245703125*^9, {3.484992316015625*^9, 3.4849923314375*^9}, {
   3.48499253890625*^9, 3.484992628625*^9}, {3.484994235171875*^9, 
   3.484994236890625*^9}, {3.48499689084375*^9, 3.48499689559375*^9}, {
   3.486039583859375*^9, 3.486039584453125*^9}, {3.559482005654936*^9, 
   3.559482006444809*^9}, {3.572683638740938*^9, 3.572683640652047*^9}},
 FontSize->36,
 FontColor->RGBColor[0, 0, 1],
 Background->RGBColor[1, 0.9, 0.8]],

Cell[TextData[{
 "Construction of the interpolating function S(x) over the points  {",
 Cell[BoxData[
  FormBox[
   SubscriptBox["x", 
    RowBox[{"i", ","}]], TraditionalForm]]],
 " ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["f", "i"], TraditionalForm]]],
 "} by means of Bsplines of order 4."
}], "Text",
 CellChangeTimes->{
  3.484992245703125*^9, {3.484992316015625*^9, 3.4849923314375*^9}, {
   3.48499253890625*^9, 3.484992628625*^9}, {3.484994235171875*^9, 
   3.484994236890625*^9}, {3.48499689084375*^9, 3.48499689559375*^9}, {
   3.486039583859375*^9, 3.486039584453125*^9}, {3.559482005654936*^9, 
   3.559482006444809*^9}},
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"points", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}], ",", "  ", 
     RowBox[{"{", 
      RowBox[{"2", ",", "2"}], "}"}], ",", "  ", 
     RowBox[{"{", 
      RowBox[{"5", ",", "3"}], "}"}], ",", "  ", 
     RowBox[{"{", 
      RowBox[{"9", ",", "5"}], "}"}], ",", "  ", 
     RowBox[{"{", 
      RowBox[{"11", ",", "2"}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"14", ",", "1"}], "}"}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.482465335703125*^9, 3.48246537171875*^9}, {
   3.482562224859375*^9, 3.482562705859375*^9}, {3.482563028953125*^9, 
   3.4825630511875*^9}, 3.48256308603125*^9, {3.48266181428125*^9, 
   3.482661845375*^9}, {3.482661878609375*^9, 3.48266189509375*^9}, {
   3.484992237328125*^9, 3.484992239*^9}, {3.559482056671697*^9, 
   3.559482058855683*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"numpoints", "=", 
  RowBox[{"Length", "[", "points", "]"}]}]], "Input",
 CellChangeTimes->{{3.487659246921875*^9, 3.48765925203125*^9}, {
  3.560537436229043*^9, 3.560537442018693*^9}}],

Cell[BoxData["6"], "Output",
 CellChangeTimes->{3.577701680096483*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"cubicSpline", "=", 
  RowBox[{"Interpolation", "[", 
   RowBox[{"points", ",", 
    RowBox[{"InterpolationOrder", "\[Rule]", "3"}], ",", 
    RowBox[{"Method", "\[Rule]", "\"\<Spline\>\""}]}], "]"}]}]], "Input",
 CellChangeTimes->{
  3.482232981299215*^9, 3.482563196046875*^9, {3.482662067734375*^9, 
   3.482662069859375*^9}, {3.482662414515625*^9, 3.48266242134375*^9}, 
   3.484991111609375*^9, {3.486039589421875*^9, 3.4860395903125*^9}, {
   3.55948212675018*^9, 3.559482132878461*^9}, 3.560543213083099*^9}],

Cell[BoxData[
 TagBox[
  RowBox[{"InterpolatingFunction", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"{", 
      RowBox[{"0", ",", "14"}], "}"}], "}"}], ",", "\<\"<>\"\>"}], "]"}],
  False,
  Editable->False]], "Output",
 CellChangeTimes->{3.5777016801184387`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"cubicSpline", "[", "x", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "14"}], "}"}], ",", 
   RowBox[{"AxesOrigin", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "1"}], ",", "0"}], "}"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"PlotRange", "\[Rule]", "All"}], ",", "\[IndentingNewLine]", 
   RowBox[{"Epilog", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Red", ",", 
      RowBox[{"PointSize", "[", "Medium", "]"}], ",", 
      RowBox[{"Point", "[", "points", "]"}]}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{
  3.482232990035215*^9, {3.482662078546875*^9, 3.482662109859375*^9}, {
   3.482662150546875*^9, 3.4826622134375*^9}, {3.484979612859375*^9, 
   3.484979664171875*^9}, {3.4849796941875*^9, 3.4849797615625*^9}, 
   3.484991112828125*^9, {3.559482848976316*^9, 3.55948284929403*^9}, {
   3.560540043240449*^9, 3.560540066401287*^9}, 3.560543216089972*^9, {
   3.5726838503600416`*^9, 3.572683850753064*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV1nc8lV8YAHB7lnkvRdzXdq9VVqk4D6XsikKSyiahLSGhSFFZRVJmQiLc
a0S2qIRktBAyMuKHMuJ3+ofP9/Ny3vd5zvM850g5+li6sDAxMcnhH/9+c1X8
Fv667ZLeyqndGsc/XtNLzXWWmZa2Qdr5Sba72J3Ri9CcwpfSbui4oTaLCus5
VO7zzi9d+iKyij+lb7AWiqqGHb4kSIejwFRPtdu/Y1H1Y4XoO9L3UO1RFyqM
piP9VV63KOknyLUPDBuaixCLStCHm9IMNFR39RyKqkPix/r5UsVfo9j1vzw4
ez+gifao2pTRdsSd7ypV1vAFUdKGvTmyulF0X2zwTOR39HytXWKx7yvi4rev
ftD2A2U/y9ze2D2AdNNCdqsnjCP5tDy3j3+HUIWBfXjimSl0+9l+8y3kUSRk
01+uwDKDmLftCD/6exxd5Ot9MhY7i6S4fQ3ei06hotX0G7Mqcygzbz474uov
pPPHlpoYP4/U+pnXt03PoGUhJmubgQUksLVoy/bA/1B4oM7nUfU/6MK78OB1
v+bQ4YipK68PLyKNcOY7zCELSGRsteRK2BJyedu8nLzuD2o6IiSfFL+MxA+U
3H0csIieXL37XTt0BSkuGo428i6jpw27ug3P/kXl/Yvuh4JX0Afm8hc5u1ZR
+k/LHA7SKlK7ejPHk7yGmEOW9jo8XkPvtmdbEZ1raCb3Oyf/DSYI9BPfkL+T
CaKzxcyCDzDDStCu5123mWByt3Nm5joWiMjqcR/vZgJOhY/KkvUssFU/7HjL
RmZ4m3SfpHiTFX5cGdt+3J4ZrPJPCf7YzQaHcvr/nkhghutW8d5afOygpqkn
rd/ODGf1hha7P7BDeq3r6TBOFpBp3p2keosDRu6kFp/aygJBw7+TRA5ywr6G
3zun3VngQerLghd8XJC3VGhkHs8CZ9Oz51IbuKCDdeZX4CsW+K09cl/6FjeE
61+eN55gAV3PrZY2hjwQMD/87AGZFVTVPp2U4OOFBxnMbScMWGEgNjrpXjMv
dNXkNad5scI+Pc/fzlfXAcEQgrEEVvDwv19cZ7Qe0HrVqxqNrGBo3XO9i4UP
KIlvO6TnWOFtnWeZ/1s+uPYOkRwV2YDvoqzYmRh+GP9se7vAgQ24h383RcsJ
QBV7DPuVODY43s2h8eyGALQx2mfrO9jgfmJKttyIAHSdF0jjE2SH/FXjkiYD
QeBYcPDytWSHpDzJM+pZgqAun5ZbkMIObrQAnd8sQnAkr/zG3p/swD3DUhjm
JgTONxyPlu/mgBt2D1/taBHCedt15XY6B4zHVveYyQuDvWvhxnIWTpASWZ8m
HykMk67VQ3WnOUHH/ft5uxFhmBFUC9Ue4AR51oFFazMSrMQW1Cw7csEM/EcK
fE6C+yvOrZwTXPDQInr7X14yKHvYms2f4wZKpqXAHl8ysCy5nnojzAMhbx79
Gn1HBpKcqvHHQh6ojWNyL6GKgJ/3sgv3IV7oyYq8bRIlAg8zInfv5lsH7yMe
1uiMi8DPtErT9pp1kFzUmz5jIQrBuuhDTOR62HOVKvGhUBQO/vyP0XCQD9ol
WVL5+DZAhRzvyASJH9TZ2T4KndkAvGGxcoKj/HCuIlr49PsNML9r+MUJGwGI
JamM/aFtBFPiXTVvmQBE0Oe8jaM3guhrxtEWaUFwUDRc+298IyRF/v32KkwQ
eAarkNs+MejN7Rh9MCkI907VRGo+E4M3V3b415sLAfODbi8lbnHglPDcMvZU
CPQFRdfGvcRhWkv21BSPMDja9D1gaxGHwJ4OK11HYTj8o230h+om2G7fWlz1
UhhUNnS9nb27CXrXHp0aECDB943OFbZTmyBfupiRYUeCU87iduGWEmC+K29q
LIMEvUFHWAUKJGBQpEbAaYgE0juf76rllYSHGqkNaZvIoG+grKnrIwlNnfdN
fCzJkHh4Q0SBryR01KUqUq3IMOPL9kXmjCSw8YzHf8dOffQllOe8JFiNvJI4
eIgMzH9vfej2l4SceY2+LbZkqGFMnjlzXRLeDHzk6zmK11d5XvjkoSSsX6k3
b3XH3qCuJvRWEm7a+RYcCSTDy85vmRnvJOF45+xt9iAybLt7c9PW95Kg5ib1
PR9blWeY275DEnYqjn1du0KGTSv3hjJ7JGGD6bTqgxAyLPT9TdQZloT4vK1k
RjgZ8p40s51YlQRSRsNwyF0yKDpfuPzfmiTYatq1icWQIZ2Qmb3GTAGpE+8U
X2AnJQb05bBRoKS/RLovlgzhN9XK53goMJ1zRFs9gQyOPvE+EaIU8GSzr3iZ
RAbRrSc+Pd9MgcU7O9Uc08kgaeD5e7s6Beq28UsMY8uanyU1alAgRNzzklsG
GdSdrll80aZArbxCoGcmGSxuP63l0qVAhmt9nscTMoSNzOScMKYAh+TLW2a5
ZPh1L+SysCMFBldkD6S/IMPvtJv3U5woECR9u1m4iAyrz+JKqC4U0KYt5IZi
89ZnTSN3Csyeo+afKCaD/K8WJy9vCnRwK2WI0Mlw1EjYrMGfAo51LdrOZWRo
+ZO+6WIsBQ5yMv+59YoMAgrdqSNx2BquskPY1od4FGwTKCDUc7hlezUZBgt9
t+gkUqAt+kLID+wVT909yykUeNJo+nhrLRnUvnb5XMmhwDaeBL/qejJc4OWZ
n86lwDEJ/s38DXh/dXT9jz+jgG+J3rGj2EYJ6WH6Bfj5RVPZP9iO+3wTWekU
KLMZMFRoIkNcDXddeA0FejXV3p1sJsOn6Z1Gf2opsDqzc7YQW0rS9517PQV2
AjXqN3a+f1e3cRMF1sUqyF5tIUOTRvoE7zsKmCtc/RD1hgxLmTtF7vRQoKa4
RyIKz5VjkT4e96cpEMBIiZFuJ8Pro06CijMUOCBdkXUEW32LTRljFu/vYW5S
HDZHjx539zwF6gszFlk6cH3J8T0lr1Bg6G7ZRA924HHrc8ZsBAhH+B5w6cT/
b7LfSJCdgLW/HCOx2D80TDb1YrMYn/9Qg72fU6/enZMAp36DAvGPuF7y5UgR
PASwpoedb8JuWZ4rahQg4MlP+vq1LjJcGZ4KjxYkQGFGYU26mwya70ePWAvh
9TpFDPdgp6R9Yf0hTMBkUfe7SOzTxvVW7KIELHm+buXtwfWgUaXwDnt6jOc4
DfvTptLluA0EuJqk7DbC3v0rN11WjICZLVKcIdgb7sX+t0uCgF9U/1OT2O+C
o5p4JQnw3yUfz9FLhhDP8AcfsHMNFvgo2D91L+9yIgggnTv5xxz7scJ5USUp
Ag65Nbg5Yx8U9Pk5i21em6foj1015BgbIkNA0JaolHTss632biayBLzk2GHF
wFYstd4hJEdAQ0OfbQt2zE2TwVR5AkxDL1pPYe89v5vhoUBAuwHFYg17xUHv
5hZFAtS9FRL4P5HBRV1do4ZKwMPIWhFV7HIV/YrLNJyfE8aOO7D5qPt3aSsR
YPtpL8kIu5TibZWrTEDtni25x7DXiQd+dlEh4AtH321P7BMit5wIVQIsmCI/
ncPmWZ9zNl6NAL+tR1PDsR24ypb3bcbfp28kcQe7iPV1KM8WAko20VfvYXOt
dfE2YFerRRg+wrZfGo69ok7Alf5HM5nYBfNz4ts1CGCO/8aSh80+w5oxh32g
SO5SIbbdhJDyc00CQlKtD9Kx80ekij20CHjcYBlXjs0yuHmnrDYBldeWt1Vh
23xD9d+wR/aqG9Rg5/VamCVuJUD1TM/zOmymj0c7rbYR8Mjz/dUG7ENtXvZ8
OgQY3fvDaMTOeXN56DW2noOWZRP2amOkV+h2Am7Jue3/Z6vaxDndHQQgK58X
//4+uzI74A+2m7ma37/1VkoZbEU7CdjgH5H6730HihtvndIlwB7Zq/77nqzn
H0mKegQYst6S/Pe9SzlDyd+xvyktnv4Xz76s/2QfIgJ2UK4p/os3I5XlmQ0Q
4L5L0OBfPv4kC2oJ6RNwdjWoKhfb7D5R+Rbbh/784b98psaqGYYbEODZHtaX
gr0QrfdOfxeB509f6L/9MIk0P7SCHfs6NfI29qNr9l/puwn47pv333XsueCT
LqcNCThJGqgKxH548cb5H3twvwybX/bAnj1z/+/jvQQsfjPycsDe4/3k2hEj
vH9e/1VZYv9ybohvMyagqOdLhA727uOdEjdNcL2EfVtTwk48MphpaErA7BFy
jwS2gSUzvdyMAB357Nx/9ZxgLqB33hz3+3Bj1vS//jKiNKpZ4PXdH7P0Ycch
3a6MfQTUHeD+UoH9Q/nSQrQlnj99h4W8sbcrRgQZWxFAjMzzH8a+LXOPg+0g
jnfQ5tQu7G1iJSKXDhEwdeC/PSLYNzlntJ1sCRBVVTtT/G9e0FSFxA7j+VV+
aToJu9rs5GQb9tmJvvZg7Lm7w+l6RwgQmbzZYILtsOmTgJgD3k/tHS7deP78
0ROdaMP2KN3BVYYdc+JgU/gxAuzQaf4k7Kas1sD54wTU83KZ2GFv3lI33uZE
QKFPpdcHPO9arJgaw51xvY7pqRZgO1/QTdVzwfOhic/qFnZiBcMmz5UAZWf5
RgNslj159eEeBFj/XL8vG8/Pj3bxKXo+OP7ysI5DeN76BnZcmsd+quhRoYjN
85j/UJ4vAW9ftrIvfyCD3vANXrEzOL8cOVUPsbN9gvzmzxGwbvJS5Wc83/3D
3Czz/AlYH2/YpYPPA9KTDBWnywRIM5c1s2DnNw9wiQXg91v1b3rThs9LPvtX
4YEE7LbrHjiMbZa4X9kpmIBNdWjQ5z0ZKPk6HGLX8fdHVOcE4vPIRKb7TD+2
lZjsojb2hfvn+rLCCRimZ0RMvyVDa8jzUo0bBCQzPDwdsINs5E6a38L5PL2s
qYHPt29Mgm3BMQRcSmBpLH2N47uQv3NvLAFbImZJrtjaP02fro8j4KrcizQh
7OiP10OS4gnQ5F3v74HPW72cFc3i+7geN9FIfI34PLEaTRxJIUCO1vhRvQ7v
x+trHPmPCJCK9mLqxOf9gq7M2XOPCRjQi3c7h22h6GDGnEbAb9VP4y9q8LxY
+bAqlonn+yCtRh7fFxyyXjlZ5OJ5IFN0a+wlvi8tJqiUMAjw/ulz+XMJGcav
GFt4lxKQuUeS4oVN51jxVigj4NjTuQ0r+D5jTjpRkFhOAO+NSH4x7AA1JY2g
Stzfb07zWuD70SeXV9v21uH4VUasE/Jx/3SM7OptxfU7rcHyNAvfLw4nOce8
J/D9JDVVFlu13+yaaRsB742rkh7h+1jDZGFjZTuePzv9k2LxfW2OK8A4rRPP
u3X8H86mkcESCew7+QnPLxkXfXIKPj/yttn9Hcb9w7jR8yWODF7XTNc1/iBg
4+EEpq3YzQ4OVdEjBHQ0WnvcwffJMMEwaWKMgNPsoX8B3zeXLrwfN5jA58+q
n2bibTIM67tejpjF9XjIbkUuEt+XumOThdcIiLGami7E918P1ulv1A1SMG2m
s+eBCxlcp0QMh7EZzMHtnc64P3r1ch9vlIJOrQ+V67EdnkdfFBWXgo+HSOWB
jvj7j6gKsEtKgSi39m7rY2TYWXRKv19GCha/Pigdw/d1PqeJ9AQ1KThuJjKd
ZEqG4toxd9a9UhASN7WsrEYGbyvvqplzUsB2YL9N0i8SxEZwetVnScHJtRHD
iTQSZMsNS+7+KAVXpndEFB4ggaJbNzWbUxqI5MKwZ7+EQdTfiklKRxry+k4n
90UIw8Kc8Jc9btIgfjZiqZ8QBiCN8R9IlIaLle4B7dlCcPkBizHXa2mYr3yf
Za8uBLJzmead89h7LEn0UkHYNnM0J0xBBp5E7PLjVhMEXWu7dd8PyYAGN+NO
8VMBeHbsZKNMhAxY/3KvdCUJwM3tHGb+ZTKQ15a3g3eZD+wCh7sCR2RA6tnA
6f5P6yHOubfMZaMstAzzfGBNXgdVRYJpS3tl4Uziu7Pup3jB6onD97P+ssDI
jA1WkOIBGy+tKeY8WSigXMhN7ub6199rOz/Jgu3jgSmFNE7I9Qx2t18nB6eW
mkYCD3DAcvpcl+IOObhZ3OHLJcoO5fmzAjwecpBw0OR9xCArDB5lT3+fJAfn
mSaSuu6xwN9z9tsNmuWgwcXxBosLM4Rsfk1NXJYDTfVXWYGbmOBCZeUQm4o8
NBbLZ2tV/UV2L35nSByRx32qrrX10jJ6arqnUixKHg4KxXEcElxEY2a9n+or
5KGzciz44cACukdZqAsdk4f687fiFt7OoYIEBXYFcQWwf7VjcD5lFpWff2h6
0VgB3isfipzO+YXUFhXGcy8rQMDWMqdpk0kUN7QQFZWjAEuU/VN36GPIPXXf
39AeBZhaEF944foDPWGprHfgUYTV0Ok3T3kHUdcb77s/timCKReT5UP5fuSr
o0W3PKkInKwCwB33CV3yu5b1IVkRijU2DRTc+ojOUMSSmd8oQtrS6a1+nu3o
cf3+4WbspNWPpIbD7eidR7hqzFtFOGBtkLTJuB0pFs9VS7cqQm6DXNZPhXb0
zej98K52RajnLGbi+dGGTM+EqV3vVgQjrfYSY+c2JNswVcszpAh35C2im9tb
UZdn3ZjwX0UwuMEftF7+DUqX4h9pxU47thD8h/cN8u2xG7qxqgjet+sEfs+0
IN49s9/W1hTB/8mjYdWqFgRSUp0/WagQ42vYcsOmBeV2B1XVcVHhjFhg/nRU
MwrevT32LIkKsj4m9vHcr5HF8rU7qmQqWEyLci/ONCHxF+1RY9g9SvoM309N
iE7xiDgmSgXiupZ8cm4T+rl0L9BUjAruF24VD1o0IevCeTcZggrbFhVrtyU2
IiXJwp0flKgwQWsRI+k2IL0VWlSkMhX4Fl/2uys2IMtPGV/1VajwRSRmf7tw
A/JLuB9UoEqFx4FJO76O16N6vuDqqC1UWE2QfzSQWI/s1yx2G22lQvESJD9a
rkO3+idMKw2ocDxO3oertRY9qnJNPreLCpFUWZHeilr0Irl/Qmk3FbTHKzsr
n9aiHtvOqCRDKkRQA7PqrtUi2faK9xeNcPygslKtV4sqayKt1C2owPXe3fda
cQ2aSlM88uQwFexC5gPMn1ej2A8sut52VHg7fzboYEo12sb2VVLrCBVqbzY/
ORtVja663P1ea4/zyxsUunSyGpEUlzy+HaPC/tYnvTRaNdr+7I0f2ZUKmwSL
czWsX6FrDO+E0DNUsGVX8XgUVIloo0Z+JmepsMHk1eHXjpWodYOMneA5KvyK
13shvbcSbfDvlnh0ngqaYuuqTgpUopydkFnuh/P7aqP2/syXqK1GsHgmiAoZ
b+kHPHsq0Ka3xe3HbuLnB16EEc7l6DhfhtvGW1TIs/O58ntfOcrcH/u3AzvO
av7M0o5ypPrxNHVPNH5fZ8fxMFI5gm+qV5XvUkHZRJjytKkMOf/K3ryYQIXq
zPRjO7XLULb6/cYX96gwx/ppZ5dsGZo8F27vdZ8Km82Kw5KFy9CFRZeIvkQq
/LF945s/U4oiWGT6G5Kp8PJ+7dXR56Uoj/TwdkwaFc7ZvK+u0CxFv6xvyZml
4/3PVE2hyJcircTLFewZ+P3d62wLREtRlYTdiF8mji/9ZaDtMgO1yYuiY9lU
OChCta2vZyCSB8fHDU+pwEav6r/NYKDDufOeHdgb6NVBETkM9F2tM8EwF39P
fLAo810Gmtt2d0opnwrArRYqcJyBtl0ODhvGVhxwDTI8yECBlT5ij57jek74
0/TEiIE4DCz2CBVS4b71Y8e5LQy0wZQ35U8RridnCMznYKAdR6+ZN5RRIdj+
5dW8UjoSmu08F12O3SSbvpxPR6PXZZNtKqjw+tbHsOBMOoorqBsfe0kF33qL
Z0qxdDTByhLBV437Scf6DtdpOqq9f+B5N/av14xCDg86uq+S2vW4hgqlU98+
bz9BR4Y2IKdRRwWmBy+9DS3pKCUnqNamkQqjr0/eGtKmo3OodYxoosId+4KZ
2M10ZNIpITiO7Vu7NfsSjY4W/r48FtCM/z/dXGVUko7exqwLN2zB8Xgtrz+9
kY7SFOzz+d7g/sqiOW8m0dG+A8srj9/i/eEyi7fkoSP5Hyaynu+oIBB8NKSE
nY5W/JNMNVpxfbCrce9jpqPsDJ2khvdUaOvdzyW/WIKCdG7URLfh/bhYHeM0
X4IOtvaM2rTj9apVP3fPlCCmPxe3jnfg/C8Ytjj/LEFdt5ocij5gb+ELDRwt
QXlSotcDOvH304Ul3w2XoBC66zPDj3h/VFwzrAZLkK0pvZOvC/ebLpkiOFCC
VPvZV7qxuaI332PvK0Fs5w/JpHbjedbYRN7ytQR94s408eyhgtHt8fTYzyWo
MGXutEYvznd0tonKpxIUobE7cQXb6JSg8GpPCXJ4HVvd8IkK2e2aHBzYmkcH
R6I/YztJqxh2lyCeWXV+2y94/ZaxOxVdJaj/eoi21FcqFOQnbffApot3HB3H
fkzfrWGBfatA6lrRN5yPyN+hntiOhqfzAvrwem21WlXY2z5VfzDsp0L/FvoB
Y7w+n4/AMt8Aju/QQD8vfv8Q63HpHuzN360m2HtLUMX958ap33E+giUCt+Lv
j1FZ8/UcxPXWZZ78GMfnXmtxX2MI5y9qzlIfx69nk/JqBbvaVCpnI84PaWLy
R8MwroeywRwqzt94sC7f7R84ngBTh9M4v9XkKC3bEbyenvu7Xzj/CTlf7KVG
cf9kGTNn4/3xQsph49g9dmss9/D+GXRezi0aw2ZN/Fw5VYI2eLzpCBjH+2Es
H7dptgQ1xHhK8U/geAztmq/i+ui3GH3QiS1gd5X1/N8StMLjKpI0iev9auD2
FFxPmqEneOWmcf8dhJoYXH/7Ud+1cew/GcrSDvx05LVsz1TwC9ebpU7aMVyv
GWdt57fP4vwKrkmxU+ioWq3Lh+k/KnQ2flV/KktHX35ajTdgO8sqXgvF/UBy
3te3fx7Xv5SpwGfcP6EH9zS7/qHCkHJvgci//hKo36W8iPNHk608dZiOyt/q
V81gFzif3rd8nI5md+sWBSzj86z3qGK5Lx05amk+jFnF/fM+6kFTDB0FzRSK
2q7h86tisenDAzpKeqYWI8FEg7hLq1UieB50yCmFZzPTwLlYQk0fzw99EenT
VWz4uVotJ3WAjuw7Hv0MZafB8ULWSxM/6cgvWsLVmIMG9xPPLf5YoKMCjo1H
Ojlp0DOiZnJ1PQMRv/kNx3loIBsmLm6my0A7i6JePeelgb3ByPxrYway9eHd
fn4dDSaW/WQDrRnozgiHGhMfDZRzdR7d9GWgte6/G0QEafCFFS3rP2EgsbjL
sZ+xzTKNnf1LGEh7/+L6VCEa9HcVuIzXMZD36zkWZRIN5jT7rU4PMNC30p8T
+qI0uDXc/k6cUooqE3urT0ng58culY5nlCI/N69pOUkaGKW9TD1VUoo0tdYk
vmETV6QcpBrx+dAme9mCwM/zpL3ER0tREqevlpoMDTKsGh7ZqZYhv/McOb8U
sdseXeatL0OauxJ7sqk0OLia25vSXYamBZQ5T9Bo8MdG1t/pZxlyzTvg3K5E
A1tN5ZRg4XJ0aDBZ8oUqDUr5j2jxupYj9QMasWc1sY2N6W6kCjQl2VijpEWD
0aCmQCGlCvR0wvbXIDbTmZWFKf0KREQEmR/cSgM/7aNiur4ViP9VM6fWdhwv
4+WI6vsKNKF8PGAB0YArhrPIO+ElyuKKcrlkSgN3X6+Xt02q0H+KwXL6ZjQo
MBSPmvWoQmB8dpjLnAZ3GJe679yoQp9vHHa5b0GDX4p1K1eaq5AAr7wL4wAN
SIZ/rlLNXqHL6185z9vg9Wq0HtqqVqP9QjNOp53x+69XvHI/VIMeqg/J6LjQ
IEThypFP7jVo3LJ7kMmVBp7nBA08A2rQtdhKpztuNOCbOs48nF6DykmRTs89
8X6eGKzfM1eD5ERlnCZ9adBxRFv/VVItWhI/5OgRSAM7MlkifbUOjZgf7ZIJ
okGrZ4vhYVI96rziYvINO/lNgQWNVo/yB8+rWwXTYMXpCr+EdT1yzE1g0Q2l
Qdh32gvD5/XozfaeNIEbOD+5s+lZrg0o+fCRQUYcrjdulsvVY43oxk0nmzPx
NND08nvSy9KELlSefKOcgOvvarwC36YmtF8qoCj1Hq5/P/Utzfj+yTaWHHoz
Ce9/9GpreEkTOuX3TebYY9xP4yJHaRGvkd69E84cebie2NnZJQ1aUKV4i0cb
9oSt7ALviRa087G6T9IzGkR8fB0qFtyCdJ6y+qs+x/X4feV6Ir5Pa1Zk3rZ+
QYPOszHPKLpvEK1vrDyrlAY8bQFX9sNbJKJwRnBvA94vItHa+VgrmqSHVIV/
o8G3UenxnOB29MJxo6hFHw26ihq5J2Lb0QW+Ah9SPw0sHOjeuk/a0arLVyJ1
AL9fnSoo2NqOBMjbQsuHaMCxojR/eVMH0jw7uXdyHMevRiEcX3agADXbdsvf
NFhYDdO6wtWJeLNVhiQElGBfSPzK+Y4utJFZgv+EnhJYuLaW7qz4gmJWiZgI
XyVYfyxwy6+N39GKk4fY0UdKsCi85lIt9gN1Ju3w3vNOCZqLwa34+jha4r9w
ULBVCU4qKxw79mAcEdcKtn/B9juVsI1UMI68fOQ4z7QpQUB8SdyD3nHEvpv/
8cMPSvA6OERISuUn0p783j7XqwQX+umKXF0/USKK1Er/oQTm2ZHfLdQmUXVx
vbj3iBLILZHNthlOoh/UNWadUSUIc7R/qXRkEqmTzrW2jilBS3V1yebwSdQy
etRtaUIJ2BhnlYv6JtHK3S2JB/5Tgq9Z31UexEwhaU6vK5vmlIDKlhwt93QK
GQVkuYxgF6Q85Sp/NYXiXMXVAxeUYMNHN3PmySmksoP9TfaiEsyarOhwG02j
gwWo8OySEtTFD14bcphG/nL+9/SWlYCp8ORc8/lp1Mg/7dS5ogSlaWx6RenT
aCKMavLorxJwpriLM8qnkdCS02bPVSUILxImGtqn0TafFBGtNSV4dF7N/Ovo
NHIY6llZwy69MJy+tjaN/gezBE1+
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{-1, 0},
  Epilog->{
    RGBColor[1, 0, 0], 
    PointSize[Medium], 
    PointBox[{{0, 0}, {2, 2}, {5, 3}, {9, 5}, {11, 2}, {14, 1}}]},
  Method->{},
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.577701680214127*^9},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]],

Cell["Part II", "Text",
 CellChangeTimes->{
  3.484992245703125*^9, {3.484992316015625*^9, 3.4849923314375*^9}, {
   3.48499253890625*^9, 3.484992628625*^9}, {3.484994235171875*^9, 
   3.484994236890625*^9}, {3.48499689084375*^9, 3.48499689559375*^9}, {
   3.486039583859375*^9, 3.486039584453125*^9}, {3.559482005654936*^9, 
   3.559482006444809*^9}, {3.572683638740938*^9, 3.5726836619402647`*^9}},
 FontSize->36,
 FontColor->RGBColor[0, 0, 1],
 Background->RGBColor[1, 0.9, 0.8]],

Cell[TextData[{
 "Access to various information contained in the ",
 StyleBox["InterpolatingFunction.", "Input"]
}], "Text",
 CellChangeTimes->{{3.482233312453421*^9, 3.482233325558337*^9}, {
  3.482233750040195*^9, 3.482233753784411*^9}, {3.484993382796875*^9, 
  3.484993390234375*^9}, {3.484993463875*^9, 3.4849934725*^9}, {
  3.484993612375*^9, 3.48499369059375*^9}, {3.484993903390625*^9, 
  3.4849939055625*^9}, {3.48499398996875*^9, 3.484994000125*^9}, {
  3.484994033875*^9, 3.48499412828125*^9}, {3.484994219125*^9, 
  3.484994243046875*^9}, {3.48499690290625*^9, 3.484996904171875*^9}, {
  3.55948257750246*^9, 3.559482578679842*^9}},
 FontFamily->"Times New Roman",
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[TextData[{
 "The ",
 StyleBox["BSplineFunction ", "Input"],
 "is stored  in 4th place."
}], "Text",
 CellChangeTimes->{{3.482233312453421*^9, 3.482233325558337*^9}, {
   3.482233750040195*^9, 3.482233753784411*^9}, {3.484993382796875*^9, 
   3.484993390234375*^9}, {3.484993463875*^9, 3.4849934725*^9}, {
   3.484993612375*^9, 3.48499369059375*^9}, {3.484993903390625*^9, 
   3.4849939055625*^9}, {3.48499398996875*^9, 3.484994000125*^9}, {
   3.484994033875*^9, 3.48499412828125*^9}, 3.484994219125*^9, {
   3.4860324106875*^9, 3.486032443421875*^9}, {3.55948268237094*^9, 
   3.559482725244359*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"bspfun", "=", 
  RowBox[{"cubicSpline", "[", 
   RowBox[{"[", 
    RowBox[{"4", ",", "1"}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4822332962139254`*^9, 3.482233307867051*^9}, 
   3.484994515921875*^9, 3.560543218211531*^9}],

Cell[BoxData[
 TagBox[
  RowBox[{"BSplineFunction", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"{", 
      RowBox[{"0.`", ",", "14.`"}], "}"}], "}"}], ",", "\<\"<>\"\>"}], "]"}],
  False,
  Editable->False]], "Output",
 CellChangeTimes->{3.577701680387545*^9}]
}, Open  ]],

Cell[TextData[{
 "The coefficients ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Alpha]", "i"], TraditionalForm]]],
 " for the basis B-splinesbasis are named  \[OpenCurlyDoubleQuote]Control \
points\[CloseCurlyDoubleQuote]"
}], "Text",
 CellChangeTimes->{{3.559482737098605*^9, 3.55948274359533*^9}},
 FontFamily->"Times New Roman",
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"coeff", "=", 
  RowBox[{"bspfun", "[", "\"\<ControlPoints\>\"", "]"}]}]], "Input",
 CellChangeTimes->{{3.4822343225455565`*^9, 3.4822343308448095`*^9}, 
   3.4849929160625*^9, {3.507638244287081*^9, 3.507638245209584*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.`", ",", "3.0778622383560656`", ",", "1.093319422537529`", ",", 
   "8.83618179107891`", ",", 
   RowBox[{"-", "2.4488290858661204`"}], ",", "1.`"}], "}"}]], "Output",
 CellChangeTimes->{3.577701680459702*^9}]
}, Open  ]],

Cell["The set of knots being used", "Text",
 CellChangeTimes->{{3.4822343342300315`*^9, 3.4822343385356593`*^9}, {
  3.484993012875*^9, 3.48499302471875*^9}, {3.559482762046647*^9, 
  3.559482776161458*^9}},
 FontFamily->"Times New Roman",
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"knotsx", "=", 
  RowBox[{"Flatten", "[", 
   RowBox[{"bspfun", "[", "\"\<Knots\>\"", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4822333526865635`*^9, 3.4822333562589407`*^9}, {
   3.4822337669515705`*^9, 3.482233768386853*^9}, {3.4822338392615557`*^9, 
   3.482233842178793*^9}, {3.482662276328125*^9, 3.482662277625*^9}, 
   3.48768167925*^9, {3.559482786385959*^9, 3.559482793290051*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.`", ",", "0.`", ",", "0.`", ",", "0.`", ",", "5.333333333333333`", ",", 
   "8.333333333333332`", ",", "14.`", ",", "14.`", ",", "14.`", ",", "14.`"}],
   "}"}]], "Output",
 CellChangeTimes->{3.5777016805862303`*^9}]
}, Open  ]],

Cell["The degree, for later use", "Text",
 CellChangeTimes->{{3.4822343410950756`*^9, 3.482234344433497*^9}, {
  3.4849930594375*^9, 3.4849930729375*^9}, {3.559482957028283*^9, 
  3.55948296530249*^9}},
 FontFamily->"Times New Roman",
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"degx", " ", "=", " ", "3"}], ";"}]], "Input",
 CellChangeTimes->{{3.482233357163735*^9, 3.4822333657904797`*^9}, {
   3.482233770648984*^9, 3.4822337722246747`*^9}, {3.4822338341446466`*^9, 
   3.482233836235117*^9}, {3.482662458*^9, 3.482662458859375*^9}, 
   3.48768164940625*^9, {3.507638248113097*^9, 3.5076382557574263`*^9}, 
   3.559482968212733*^9}],

Cell["\<\
We are using non-uniform (thus non-uniform knots) degree 3 B-spline basis.
We plot the six basis splines. The internal knots are marked with \"\
\[FivePointedStar]\".\
\>", "Text",
 CellChangeTimes->{{3.482234042054359*^9, 3.482234050026061*^9}, {
   3.4849943335*^9, 3.484994358125*^9}, {3.48499459071875*^9, 
   3.484994612359375*^9}, 3.484994668703125*^9, {3.486032497859375*^9, 
   3.486032526109375*^9}, {3.559482989552015*^9, 3.559483009809551*^9}},
 FontFamily->"Times New Roman",
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell["Here are some shortcuts for commonly used symbols:", "Text",
 CellChangeTimes->{{3.559483086374864*^9, 3.559483123854011*^9}},
 FontFamily->"Times New Roman",
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[BoxData[{
 RowBox[{
  RowBox[{
  "symB1", "=", " ", 
   "\"\<\!\(\*SubsuperscriptBox[\(B\), \(1\), \(4\)]\)\>\""}], ";", " ", 
  RowBox[{
  "symB2", "=", " ", 
   "\"\<\!\(\*SubsuperscriptBox[\(B\), \(2\), \(4\)]\)\>\""}], ";", 
  RowBox[{
  "symB3", "=", " ", 
   "\"\<\!\(\*SubsuperscriptBox[\(B\), \(3\), \(4\)]\)\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
  "symB4", "=", " ", 
   "\"\<\!\(\*SubsuperscriptBox[\(B\), \(4\), \(4\)]\)\>\""}], ";", " ", 
  RowBox[{
  "symB5", "=", " ", 
   "\"\<\!\(\*SubsuperscriptBox[\(B\), \(5\), \(4\)]\)\>\""}], ";", 
  RowBox[{
  "symB6", "=", "\"\<\!\(\*SubsuperscriptBox[\(B\), \(6\), \(4\)]\)\>\""}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.483703373765625*^9, 3.483703378671875*^9}, {
  3.48370352328125*^9, 3.483703539609375*^9}, {3.4837036211875*^9, 
  3.4837036309375*^9}, {3.48370469346875*^9, 3.483704720125*^9}, {
  3.48663741703125*^9, 3.48663746434375*^9}, {3.487680374140625*^9, 
  3.487680400203125*^9}, {3.559483103609563*^9, 3.559483136534923*^9}, {
  3.55954262167305*^9, 3.559542650365658*^9}, {3.560537521909388*^9, 
  3.560537538006072*^9}, {3.560539350820756*^9, 3.560539360123719*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"symKnots", " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"Text", "[", 
      RowBox[{
       RowBox[{"Style", "[", 
        RowBox[{"\"\<\[FivePointedStar]\>\"", ",", "Medium"}], "]"}], ",", 
       "#"}], "]"}], "&"}], "/@", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"5.33", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"8.33", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"14", ",", "0"}], "}"}]}], "}"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.559486202627114*^9, 3.559486214635637*^9}, {
  3.559486301576712*^9, 3.559486302571568*^9}, {3.559486366049752*^9, 
  3.559486368770009*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"Evaluate", "[", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"BSplineBasis", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"degx", ",", "knotsx"}], "}"}], ",", "k", ",", "x"}], "]"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{"k", ",", "0", ",", "5"}], "}"}]}], "]"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "14"}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"Epilog", "->", 
    RowBox[{"{", 
     RowBox[{"{", "\[IndentingNewLine]", 
      RowBox[{"symKnots", ",", "\[IndentingNewLine]", 
       RowBox[{"Text", "[", 
        RowBox[{"\"\<5.33\>\"", ",", 
         RowBox[{"{", 
          RowBox[{"5.33", ",", "0.05"}], "}"}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Text", "[", 
        RowBox[{"\"\<8.33\>\"", ",", 
         RowBox[{"{", 
          RowBox[{"8.3", ",", "0.05"}], "}"}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Text", "[", 
        RowBox[{"symB1", ",", 
         RowBox[{"{", 
          RowBox[{"0.6", ",", "0.9"}], "}"}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Text", "[", 
        RowBox[{"symB2", ",", 
         RowBox[{"{", 
          RowBox[{"2.5", ",", "0.6"}], "}"}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Text", "[", 
        RowBox[{"symB3", ",", 
         RowBox[{"{", 
          RowBox[{"5", ",", "0.7"}], "}"}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Text", "[", 
        RowBox[{"symB4", ",", 
         RowBox[{"{", 
          RowBox[{"8.5", ",", "0.7"}], "}"}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Text", "[", 
        RowBox[{"symB5", ",", 
         RowBox[{"{", 
          RowBox[{"11.5", ",", "0.6"}], "}"}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Text", "[", 
        RowBox[{"symB6", ",", 
         RowBox[{"{", 
          RowBox[{"13.4", ",", "0.9"}], "}"}]}], "]"}]}], "}"}], "}"}]}], ",",
    "\[IndentingNewLine]", 
   RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.4822338086527767`*^9, 3.4822338219915457`*^9}, {
   3.482233861491841*^9, 3.4822339121320906`*^9}, {3.48256328578125*^9, 
   3.48256328990625*^9}, {3.48256332328125*^9, 3.482563376203125*^9}, {
   3.48266249828125*^9, 3.4826625106875*^9}, {3.484916641671875*^9, 
   3.484916680765625*^9}, {3.484916723734375*^9, 3.4849167388125*^9}, {
   3.484916772609375*^9, 3.48491687671875*^9}, {3.484980861421875*^9, 
   3.48498086334375*^9}, {3.484994385328125*^9, 3.484994389234375*^9}, {
   3.48499455128125*^9, 3.4849945548125*^9}, {3.48500009903125*^9, 
   3.485000242453125*^9}, 3.4860324928125*^9, {3.48603720228125*^9, 
   3.4860372225*^9}, 3.486039667484375*^9, {3.487680361671875*^9, 
   3.4876803631875*^9}, {3.4876804413125*^9, 3.487680533640625*^9}, {
   3.487681650109375*^9, 3.487681679921875*^9}, {3.559483151130657*^9, 
   3.559483152567132*^9}, {3.559483214718173*^9, 3.55948326640926*^9}, {
   3.559483361302782*^9, 3.559483403205857*^9}, {3.559483433275409*^9, 
   3.559483690924403*^9}, {3.559483722491504*^9, 3.559483726791054*^9}, {
   3.559486306932803*^9, 3.559486317491908*^9}, {3.559509407502039*^9, 
   3.559509431374259*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxN1Xc019//AHCbrLf3+/16mZGRWXbKyOteUSEqu8jeW1GkCGVHhWQmRBKS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     "]]}, 
   {Hue[0.9060679774997897, 0.6, 0.6], LineBox[CompressedData["
1:eJxN13k0lN//APCZQYTslXXmya4iFKE89x1SWbNky75kVyhFqSgRpYXImi37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     "]]}, 
   {Hue[0.1421359549995791, 0.6, 0.6], LineBox[CompressedData["
1:eJwV1nc8Vf8bAHArGjJyr72y3SNZFeI8T1GUUUaItGyJykjbqhAalJGEir5C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     "]]}, 
   {Hue[0.37820393249936934`, 0.6, 0.6], LineBox[CompressedData["
1:eJwV1nc41W8bAHCbkr2icI7NQYWsX773k1lGw6oUKiQSURSpbJGQkZGE7L2S
EZGRVZRZ2ScjiigVhfd5/znn+lzXGd/nfu5FPu9m6kBHQ0NjjV/+/85S95tn
VN2bqBoUOH+1Y00zvcBefEnsBES7CZ+5ORurVR6YX/ZCzBE+7jkivzbTrNV5
8t0cjZU7dIlapdV3TmjVur258VTsOjzw+I+veuaHVkFIB4v+gi+EMxmx67jR
E2/fnjf+ecof0u6E0id1chL6H8/G6RFB4CN4WfdvnhDRMG0z8lAsFIyNZ8MS
ZsQJ1eUzEnNM4WAr9v7xGwt5ouSflYvGQgS4JXmny7opEzIspyrDe6Kg/5j4
0rdRDaI3jLL57dQDyJFQehbSiYiIKLkM/u4YcDQcndp7So84FC+rD0QcZIm9
PzWVZ0gwPJKZdyyNB8qnnLVmh2NEY5p0ZLRYAvwXaqgbOmNG+GZLKdXEJcJG
0hXvsrEThHqh5OAkUzIsJdQw1licIX6WSfhs934ErwOm5MLzzhKlz8VFlBdS
IE9ZcGG3mx3hUi/26rR1Koyn9a4dvXOBkGkmXwjqeQJPI07eHxt1IjzsOYMH
09JAvYZmJDDyMnFslmNo/lQ6uFzbEXmr8wqh6Mwhu8WdAVOuf5rurHsQO76x
3+TpzoDdCl8lpE55EvNu7G+kg5+CZjSH6ZG560T7CpvoASITrLzDPw/k+RDZ
nmzux35nwuOOoOvJT24RQX92NNuXZgHnPp6+Fw5+xMFNVsf7YjmgcuMO+c5M
IEHyZ61J/5QDav2vru7pCyY26VlZq+JyIf6hrGHuWChRu217yRhTPpRwltUU
W0QQiRHbaH+8zIegvLVvgs2RhBfHNjNm7wK49czKNSgvmlDiY/m9Z6EQ/vEu
RPG7xRKcicyHdTOL4GhQGXPatzhiUYj50UnrYuB0+vD70J2HRD6JCfx7SuDv
Vc+RwdEkouVdQLuhbimUh99KzS94RCjHBiz3p5XCr9/s125GPia4+AN0vpwq
g6effNZvdKYRfkP+LlerymDJd0m1eSSd+J7oH7/BXQ68tS86fdYziLe7/Ge5
usvB+c/PVtKpLEJr1I8zRaYCppdl40KSs4nCVD8NqeAKaL1uFHpoLocIJ/vd
0yQqQV9wLq8nL59Ym7pT2ZJcCXsUFNAOkULiYuad0SO/K4G1YaU99kkRoS99
Z49d6TNIfNoBNQ6lBJ3C7b57Ys8htlWI8+ZMBWGgllM4FvIcKrwD6dq/VRIR
B3uD9y08ByW2flOazWcEn6WY+lBFNaReMt7bpVFNWJ014pLbWQP76Rl68hxq
iFTna/O+vjXgydO8yPqolpC505YiplcLZ9Wu96+I1ROXw5Y8PfNqIVfgX0Gz
ZwNRHrvzaDtbHSxvy5Uuff+SOJDrTOs6WAefbQwFai2aiKPv2C/UONYD9fDR
6ouuLUTcJzXY0V0Pcckpe8y1W4nh6bM7bfc2QCybcMr0rjbi/Hp5J8NaA0hK
G1zQn3hN1D0oEJDRawSJJkVN3tIuYowfBR2/3gjjL+gHdSq6CZqU/u8+eY2w
7xolvOzFG0I3e6PjDVsTWE7RmcRO9RBva4/6Xh1sghS5idPaxHviO3yeS2F5
BSrUiPaRD+8JntYbFm2ar8CgbcV06kYfcbInXVHwySsQWSnrMG/qJyapPyYa
HJvhm7yn76TvEMHgdNdkLqkZgoLP846rDBNSi7trubqbQXUg8VPs92HC+Y9e
rP3eFtBDuTSHr34kfu5I1Nu+1gKODzqmFrJHCf4Y+XJlSisoL3kqFd0aIzQE
mkSsrVuhg/PvK/eT48Rt8vzvkqZWeP2q4ATf/QmCRfVAvkV4G6yji2vljlPE
LtsJ9vRd7aAUR7DkB80QisY1ftcN2+FprBzdF5ZZAmnErJh4t8OWTNWgbNQs
cYFHd3B9sB3m0r6GN6bPEeWvcx6bx3QAe3zy7eLxecJwr5s8y7Yu8GIVDFtq
WiKshQ+ljql1QbCtwVF2le/Ele1kzmcXuoBhV1+97t3vxMPP73+ca+mCId8N
ekGVZWIqUbWu7k43JPVt2cUnrRA+tJuH3X69Adodnd8iH68S9xcH6/Qk30IX
5fTiPfpfRNqnEoXd5m9hhy7R8dr5F9H27BxXR9lbSH2a3EWv9Zvgcm4dFrvc
A++Z2JWav/8hzJ3alBfce2H10SINV8I/Ymy83MUyrBcqLjuOU7k2CEfLJ1lN
ab2QdaQikjdyg/DRuSGQ2NMLHwPthRPCN4k0Ybm/ugrvIPO4QTzFkAa+vrv/
KnXuHVj53AVNLzpQ2Afn4rbeQQGV+9vDejpwjf6+Fcb/HuwzVOLyGelh6YiZ
lqfuexi5MnVtPYEeVrp2VhulvYeEUAdmy1YGWGt9WvTnRB+UHv5b2K7DDJqS
FsaLrn0w5H/Ami6BGXyCmBaowX2QaZr9mHaBGf5pO8n0VPQBC0fiNfN4FqBp
VHyaxdEPCTIedA4/tgFTbU2i6et+0I5Y+bAxsAMMBC+pHRrrB63Xm6sb+9ng
7o3dg1qr/SA61qL+/iEbbFO7wyMrPgB238WG163YYUelbuTW7QEoH8lkvPCN
A7iLewILVQdhqXGYUv2YC0Qzpl2ZsodA8ln96dMH+eChWbrGYsMQyC0Uj3QE
8cEORmuGwaEhGKO96NDWzgd/HPuTsrYNg+J5jqlLpvzwTqG5RffyMMDng303
XAQgsCZNKFDlA7xJKfq2+4UgzPaebtt69RE+mVu3pb0RAZsAgQeznz7CwfaU
8e/iotCv3He65+dHoHsa/WTSRxQaHxoup0p9goqomgozPhIkndHYTYR/gj5e
wX3z7SQwmuP38D0+AlqCLIqPQAxKtt4Jr42PgntrUAz/ZUkQmd5zSe33KAx+
3iWEnkhCROf9ak/2MfhvLLfk+TtJcI4/bLZyYAyMS979eqAmBRKUprsLSWMw
//dR3BqTNCRalv4YNRsH+65/zJ2VMtBo+dp+0m4CojP/eyxwRB6uH/a65+c2
AWrjfvtuhMuD4gHJctGbE5DmKeWg+FoeHpMDt6xjJmCBsTEl5aAC+Hwlkj82
TsDQtNPXEE1FUAmo6ukTnoRsgSZ6e5G9kFuUpdk2NAl/Mlk2j2srgU/Hqes2
nyfhgWJspoCTEhhPs1X++j4JqgzuzLzRSvB9t5eC9PYpCBLQSykbUwL1CH3S
3QNTcM1bQiPotjK0O88yGqZPQTTD5V+57SowKy377o0zFSSZI1Q2Q9WgWmeU
7cJ1KhT9NNgx80wNwm0fGG4GUsHBxMh922c1UExYa1Z8TAXUon+L/qA6eDF1
VkX1UGH8/Exf+4Y6ME07pxxX+QwNWp5KtQGaIJVR6Diw8RmsNNSd9eq0wFxJ
Z0hp+zSkhLpHLi5pgf+rD/rR/NPguZr/YkCCgJEpJimjPdPgoLLabhNFQKz4
uc+NZ6eB16b9sa0jAE0W37nC5mloodRwpD5A8DHntlVg2AyImUSOljhoA4s6
X+dE/AxYb708xxKkDfvbCzSIjBlg7jNRCsjQhui54Z1rtTMwfdaJ9uO4NhjI
Kg+5fp0BpWxOy91ndKAyf9bM6ugseJpmdv+10oWoomMm+/jmwJ2N4V6Whz5U
n1DfrCHNQXnlxrPVGH2YoiWVaMvPgdHP4H77Cn1QtVziNNeZg3173KXTfurD
2Ob9fi/3OXir+vdVxA0DkD/WdfrFmzl4kynWbBhyCNpX9JwNQr7ASvWsd1ON
IdCq/xdq/XseKHnRpoOBR0GfVebIOP0CIItL0FJyFMLHePnOcS7AhvGfhY+f
jgJP8GKGvewC0N/ucTwodAwk36c3XDq9AK57Cy+OXz0Gh11Yfnm/XICgFjLp
n9xxeJA2YP8w9Cs8fy5yeT3XFMjbrmj3CCyChubFaqEZCzj/q8jQV3wRbG9p
MWZsWUAGdcFUds8i7Lc/T9YStASJBke7QP1FKG4ymSk2tgSpq7ZBap6LEHTg
vrd/pSXIjx5pe/J+EQTUm32/hJ4A1TIFwyv3l+DNjYLida1TkFW4mnvX/zuU
lroG98ydgT0TtGy9S8tQb3+jyD/iPHCqVezTvPUDrjs596p3OYLXm1C/Hd9/
wmdLZYMPfpdBOZQ2mjbgF+yJGC4yM/MAh+6Ovyk7/sA1jkn3Uisv2HX82YM0
3zUYq2tMuPnIB2TW9ObaWP/Cj12/V1O67kDtxNpFC79/oDM5f/RVcgA8XTDN
Z+LdhKYPriofRoOBNmDdwCZtC/YHjdkFXQqD5YIpZo4wGmTu9uPcJc77EJkr
ZOx3nBYVzov6CJVHwzdd+6ysHXTotbQkCpmJAWbpAXmRFjqkVaSqzkvEQ3dy
Iq/MPXrkagG95zYTwKz4MteMLgPSnuWJV25JhhCzeNf97IyIm2y0zkGbCleJ
z2tDfYzoZchGXU5VGoh36CYrRjAhZW31EQ2XDLg9/TuZ35wZlSkJKl5wzIRH
6S9Ky9lZUNyfMHX/s9lw9Wnuz/RWFlRfpeZy2DUXfqvOJopFbEPvBX0m5brz
QctZzfSE3nZkOCWvliFeBIp7Pl4SZmdFwv/lBI30lcBkbGRyQgcrurhrrahD
qwyOEs6/7f13oJSBC/KDKeXg5JNY2XyIDVWINnSJK1aCnuVwyCAdO3oS78zs
Uf0Mupuda3y62VFuMfnBB+/nwH5dQsgjhgP1Tn/9QWNYA9umf7+OlOREW9VP
s9Y56uDsEJNyURgn2hshHV7EUw+JSam5krOc6Fq00M581pdQvHn42WttLnRl
gdOyILQRkgtFPJSyuRAYPpxsLmgCRzlfjd903Mii7UyZfPsr2LZMVxbkyI2M
WU91Zm5rgTCrxy//6+RGMyyNd8ZNW2E+tnHYWIoHTUQ2/bWKaQMyP1uGVDgP
srG17S5afw0aF6c8rWZ5UC0ffRKc7AAp+sk1S2NetLZit1E92QnL6AfvrRJe
pDcvw7j/ajc8PhKpucHKhz7b+c7G/n4DolmmnPpX+FArdY1vtaAHArqefJ97
w4dsPuWj2txeeBVHc/GZLD+KqmXu0Lr1Doazw6MM7/OjNJANiXB6Dz13Hzdp
zPMjV9lDWdWGfZBS8eHp8hEB9MOQ88WSdj/o+8sK95UJoL1HbdL/aAzAOxG6
dHb2nciqjnt/ktggKDEyDHB77ETuLj1MjqQhuFYXyePesxPpD7wY2GQbhlhe
hS9/5AQRrxlPW+evYbhb9dP1cKQgUrtOZrm88gFsZPS2fswLosrQTNdwPIe3
UxvA8agQmnzdPhQ+8AkSLjeFqxQJofe2Icfy60aA9tGQC2XbLmS8o5f/YtIo
HOQS2Jp32YX0uF7ZNgSNwfkT448YOnehkNVF6yarcTg10zs3o7gbiZp4jfUK
T4DCzsHulQe7UV7N83SVuxMwJWhfd3JxNxJjvPbv5uwEXLbfZRVqKoxUO+TP
MRtOwofbp+k5S4XRgysGVnLpkyB2oETnFasIkovZWZezPAkHteVVtNxE0GqI
jOc2nSk4uFNpD3e3CAqUTO6lD5sCAbVzH0v2iqI/gc8SFt5MQeefp7uvx4qi
SKj3EtpOBdtwN6fEJVFEXffyU/iPCu3Wdlwyy6LIQ+no2xVspX0nap6viCIB
nYW45weowDRMbBtaFUWXI9fuAUGFQkn2PL5/oshUUkPk8EEq3Dpree0wAwkF
8CTUaBtQofPvz4o2ThIiLdptvjXFc1VJSblJloQ4/ZfN9S5SoVbhYN1NORIq
r3MXHcVmlz2mo0ohIXqmmsvXnKhQLepqViBPQjXHtOLT8dzezpZ/NX4PCam7
+bH9cqFC8Sy50mk/CR0+wR4Z6k6FPylc+7kPktDitv0yxj5UME4k1XdjM6Wc
1OrHTo/doxeqTUJPPQ36Tt+kgmG4icU/HRKyD5H2d/KlwuPrYZ4z+iQ0+tZ8
6vZtKmib0lbVGpOQR4B/1oMAKtxjXla1O0lCxvkcdy3DqSAlp8gtdIqECsOs
5buxG40vfevFXn0WZXbwHhV+Pph+SpwmoSgGAzm5CCrY7P7IKWRDQprT936t
3qfC3n3N8712+Pzsr355PqDCgFV8KuFGQs/7ff7wJ1Lhyq333qvYSfVNb3yx
t6dxWBReISEaV2HxKWxiOoxVyIOEKlVqTAqSqJDrdvvG6jUS+t2yI03tERXv
146mhT4kpGB0XVI9lQqixRpMQiEktNz4k2/4KT6/+JDHBLZq+k3m/ZlU8Eq8
Np4dSkJxjpy2D7DfBpRUK4eRkGHtdziURYXbJyQvmUSQkA3txdbibCqM0XD1
+sWQkL49W5tNHn4+r+IDBrEkFPJzfXs5tuqCUR5bHAkl1shVMuRTIXIgJCA5
noQmVkeVcrGJ/H8qlYkk1NjoOjZbQIVUs7mk2VQc/298A4eLcf60BzMVPyGh
DMGSY7HYv7TEr15LI6GV9gbFEewjMjbGtBn491rfcrmUUGHzX9+mUBYJPXsV
cSWoFMc7+6XdkQIc71fnrieUU0Fk7aHCs+ckdOfu3E39KirM3zl8xLWahPr7
hxNuYFcx/XOVriGhGKUIuXxsE95zpUm1ON+m/CpZn1PBdw9F+XY9Cf06Hnim
Hfujw0t1g2YSCnL/xSpTQ4Xsr+6naFpI6LiZVMpxbI+rEj412Pb68pk+2Nv8
w+oobSRkTtra1YWtnmJGcHaQkAw1vdChlgoP38/qfHhLQmMZ02f966hw/lSy
fUwPrp+dwV4Z2IoTxsFGvTi+qWyMzdit38ra6t+RUFOqyH26FzjfWHwPZ/ST
UG4h2egmdmOUovPpARKamp+XTcSO4J8M5x0kof21UgGV2OIS+t0hQyTE0635
ZAHbFDiPXvpIQoH/nt03q8fxanvlJvGJhDToVzVcsOeNPaNHsX8K7T0bhO1v
9fHd0VESuq41LlSBXeqZaa4yQUKukXRG2xtwvP5Zen7DFrWm7xDBPhS47WH2
JAm1vAhrUsIej3Yd2kkloYXFS2KnsNkL1a02pknI2cYx6wm2S7DRjrYZEpL2
/WJaht1hY9MQOYvzfWSP/SvsIK4gMdIXEpLYPFs+hT01/7B/Dns9/PrSMja0
5IWUzZNQ8EpeNM1LKqx79cxrfyWhzC81W7uwTx6bSmH9huOv1/xGBvuZ7OqR
fuxDPIhmP/aVEaEKhyUS0nqyEGOE/eaZgoPidxJilNX/YYEtF4UEfmMfqb9U
bYs9ffDCzbsruB4eu7m7Y2vv8lY4/oOEZiu9Hbyx037eGxf8SUJfXbMb/LA3
3qQ+mMI2LWO9FYptlVOmU7BKQlznX6bdx672a1m9+gvfv+OQbCw2n9VQzoHf
JOST7bQzEdtDef4U4x8SEmCKcEnB7t2xwfoW+8clc6k0bMUZjoaHa7j/NQzr
PcW+91Lsiu06Pt+UYlcW9lzifjGZv7heGlyqcrD1PQ71f8fW1chlzsPONDod
UvMP91O13w3/N62kq3rABgkVp7mN/N82m37zhpskdPuU9Nn/+8VQbArPFglZ
HFIxzMUWKss+MoKtYFaYnI19PbyGJouGjGjPZh3PxO636y6/TEtG7eb73dKx
lbTG7VXpyMhXwOPHY+wo/hX+LWyBSPexJOyvSwwdr+nJKC718N54bMMOgZvR
DGQ0o8j5JQo7J0NO4RQjGbFLfmIJx2bw1RonM+H/c2yMCsQ+b3HswTx29ceB
W77YLxXtdCqYyWjvhX1917B3s3it3mQhI9uluSgXbJ/Juzm628gIznBX2mEP
1T46xbadjDpjmsEKO+ZyU30qKxm1/OSN1MP+rt/v5riDjKS+ThzTxDYhzZL3
spHRTr2Im4rYLH07QprYySimYpiFD/tCoah6OAcZscZnXWLGbg5WmjflJKN1
tzzVNZy/t9VPHvnMRUbC+UWMn7BHuC7RFHGTkc7Ah21d2BoLt8o9ecio+UGc
Vy32z8dP+Zn5yKjGki08AduJfmlMdicZ1au5PzLEvrDIrzeNffuDuaEatv0H
oiBNEMfXt9VTHNumJPK6wC4yiuKJ117H9Wx6WpGTUYSMRmomnqVjH9W39GrE
TooWNQrHNt53e+SmKBkVMftYe2AbML/NXSGRUYpUxxrCPlBx+eCEOBm1WTRz
D+P+opEan/NIgoy8rd/HvMBWDatnOyFJRvRZ96LTsPfasn18I0VGJ3V0GR2x
JVmLPOpkyejQQuPAN9zv2O2+Pn24h4zkrfzFqLhfsh7h3W66l4yeP48KfonN
onHgCts+fJ44B8dH2PQcEQeClMiIW7Ak5zj2n1rKgPt+MjoQULi7GvffSe5L
TCb/kZG2zvysSzWeZxsxLiwHyChspgsOYo/M1b5vxs40iBHgwx5s2P5EkyAj
rlhegzrc/zud89VkDpLRtltTObTYla++XKQ3ICMrDi0/r2dU+N0PYnXY9NHK
VB1szdn4Tx6HyKjxuFA3J3Yjq/aRqcNktLvr7568Sip0mScrNxnj/Pr9+WB/
Be5nM4abt03JKMKY/jEPnl9crIWx69ZkxOnHkq2G55+5MJ1JuQ3O9/zY2dUi
PD/2nGRytiUjlXyZsgrs3eYM3h/OklGqbcWIArbM4zM21XY4vrRiCbsLqYD2
sMl6OZHRhrJALhXPa1cz14bla2R0YWWtZCee99rVEttqPMnoRp6mRhPeBwSE
P5n5eeH88H6r5oTdOGPwhf0GGXnI6sU/x/sEtw+ZV/4mjpfM6z6TDCo8T+t3
uuBPRhJ5E+5nn1CBZlGT79N9MlIc9G8XwftKv+mybUYk/vxiqWQV3mfynufk
O0WRkZne5Loxtqk/L/oTTUbbPR6xeSdQIYt30ZkvjozOyL4d7IzH9f9feuPR
ZHx+3u/bLWKoEHuX2aUlm4yMN7SiGfD+xbL13vl2DhkZlLCqxuL9zNcz1Uk9
F8c/p8aRjG1/fr9jYR4Z1Ur8cz0QhvPxgN35uEIyemtFz3E5lArDSw0n7ctx
vgiczqwOxPPwhJceQwMZ2fUopa7h/TFXclpEdwD3K8VHqVKX8D66yFnCNkhG
Jl56kxF4X618fgCGsB2FS9JW8D7beDjO1nmYjK7oCT58gffd4cs6adGfcD2S
qqwNL+DnrUonj06SkRjp5lWTc1S4qG8j4bWIz6N003zFEt8fngO5zGJonvlR
Wx3C9+FjRkPWEEO/Dug6X+HA+9FPnhF9RzH0LzpcZv7jFCDeLxzHk8RQ8ol3
nBKPpuDmI7rDLO1iiPddTMWtU1Mg8TPLpH9VDMn3LX8p5JkC9WXr/CBpcTRm
Hjgg8moStCytdkxZiKMfJ8UNPl2ZhCLbS23id8URw/OvE548k3BPk8nYp0Yc
8Y/aP68unwCrW9ODt2bFEZtV430D8wmIs/9Q4yAogSKdU14I941DQwVXxrqB
BFrU9+N1YhgHsxybqas+Ekj1ikLI4u4xOOGyf5G2UAIZMZ5TqVMaBeOkY1sH
PkqgDPV3R9NNR6DA2e/imR2SyHmEhV3R6hP8ffpzUOY/SdRFl9CZefkj1Bav
cG53kkQquzgTGAM+ANWa8WlPsiTiOrHL4sPtYdi4dkZTu0MSzW2c7lINH4KA
ve2ySX8lUYDagmzl7UHwqq//zKAghfqbJc6aeg2AVfnvTOHTUmhnSZrji9v9
kGekXy90XwrdEUvjfuPeB1+MP3xsqZNCnMSnF1+83kOC6K/mwC9S6OLlEsM8
/3dQ+lCaUXqXNOo+QPJYvNELtZ6Pja4flkb2ib7Mycw9sGdNer7gpjTywE3W
b60b4j7/un8/XxrRnImj9eDtgovpRzcCh6XR5pjVi/fQATl09S0222VQpzYJ
/I1fw2CX64MZdRn0JFnCiyuoFa5o7K8yvSSD6vVzspTTm8H7RnB2X4oMahNa
uW7e3wQeokIptF0yqFuiree0ciMMOjd/4dmQQTukp94f2ngBFJGyA30UWbR7
2uKvwLcaWMyQOZ1zShZx2p2hecP6HHZ3V76zvSeLFsl7/BO4KuE/62CT1hpZ
FFd6o47+Shm0xjiTOb7KoqfFBcsygUVQn/Sh8bKwHNJNHT47nZIL2Sz3HbyN
5FDDEUt7dbtMWN9lcd7plhxSMrq/YKKcBkTCOXumQjm084/tr7YzSfCtKqAh
dEwOtRt8DiOlxUD5eUGBI+NyqFp4pf9BaAx4sZe68U7Ioe0iw2zcbjGw6TBK
Sp+UQ0ePNJgBEQOcfOqBtZ/l0CGdJW+T0QegcvWbwbd5OUS779UdTZEHeJ8/
+c70txzCH5jos4wC1lyFz8KcFORyeqbKfjYMrjh8+D6IzRjq9am4MQz6xYI3
orgoKIJkKs6bHAYpj0f46Xgo6Cozv+JekzCQj713eIaPgvSj1nKKK+/Ckdtf
iot3UdDBEa/F9ruhEGOe5Q3SFDQgGNwbrRcMv7iOh/zB/p7DXmIgFgxWPf9i
ymQoSGxNVVNoKwjEDc0LxeUo6PDRSEfumiCoBPpxZgUKgiq/h0cVg2BQ7pxu
rxIFZTXXMdGKBIIgrTDHOYKCZMJaNW24/YGdS7ZIFiio4ERt2OySHzCQ9xut
YMtZHaGNeeMH35FJaOBBCrrgqOxnGOYH7X63trJ0Kcgtns3SkM4PbtCMLc0b
UpBEbrMF7+otGNxK7b12goJyN3b4nWPxgW6OAletkxSUzKni1dflDa9En+9g
OkVBQYeid4VFeUMx9BxKsKKgqc3sJy8FvCH4zlZjjTUF7boU/NKKcgNUtmzL
Nu0oqPZi65KprRfEbJJi7l6hoIdglJaw7gEyJO3POu4UVKVzgIWx0wPqD9qp
bmHzlEg+LU7ygLmgrI+eVylIQeF2fJWGBwCrnLidFwXxzUc4JPu6w1cB5Uot
XwpS9LW6VcN2BQz26Q2uhFJQlPZGrXSdM4yYXpApvktBqUJ32/c5OYPHtVAf
pzAKCp/v9KwScIbU5x0iE+H4eU6W/drj5QQ/tY44vrlPQWcqooKm1S9ChuGJ
Pzmx+PuhDA7OAw7wz85JyPoJBWku246cuHQOhgurX/KmUdDw12JZSblzULHK
7NCNPbNi6eX85Sw4h2aX/JdBQfbtb49ZO52FoXyqrlAWBfE/NG7sGrWB8mVr
t6F8Clo4e01BjHwaIjWLeKMKKGi5a+Fyd5EVOAX+q9EvpKCMnPXWi/9ZAYnv
EUNVEQX5M+7UuXHqFNxXH06KK6UglpdTu3+lnYCLd0xbjldR0D15nYJwa3PQ
bU932vacgi52fBG9sGYGolzL7E3YL5TYWvc/NIPBjKhTe2vw+V/SS5e/NwWd
tu5F9hc4PpIHV8VOHAcRNgPB7iYKMjTm3MOw2wTWLR42BL6ioE4Hx8dnPYxh
IHXa7r9mCurpCUjN6zSCiL1BxfktFFQO3g50/oawZtakE/aagsbNQ60HGQ5B
f/J/rvpvKIjbmijRdtKBdQ4vc663FMT6x2SnYK82kIJLNUewy7lEF000tMHF
TZLZo5eCjiZyGvZzHwRGXY60x30UZJ63ZlrXogXyNYdDLvZTEIpsrz9ffQBM
FYNclAcoqPutXn536X+QunNNvWOQgozZzo3Ml2iA6repdz8/UJCwXrm7/ex+
OHNeuPrlR3wfzfeqlGn3Q8DQidTwTxRk8oeQ7BJVgZ6mbmfSKH7+/YfMLS4p
wcWHVfTGExQUHf03fOC6IkSyLn/hn6QgunveRiJ/5KHSj9I7id1VRFtKF0AB
mktpKdepOJ86TrNllstAEoTvfzqD62/yQvmVUHForGzZ5TpLQW05DvIN5mIw
I7tFqzFHQSPHW5PLKWRQ4r329u0XCtI2y1qjfBOGk2HFlUnzuD+xyodxDOyC
25tzyfYLFCSl3XXcuFcQOuesHde/4vr7nDc2QsMP360TTVq/UZBTIa+Rqiov
8Pe9V45exPVauIh+3uYGu3oDGqnvFPRgd6SSaTw7hCsFzHzHLkqcNDB6xAql
OS+665YpqPJfI6dEOwv8e7Av6fgPCmr43Gt97yE9iDG73Nn9k4IeiZ1UklSn
hUO+2Q6z2DFX9lU5024SrssTRuWrFOTM6EsTOLFGxF3YpXTrFwU9rp+JTWX7
RdR+sth56De+f7P2xva7K8TEsehN7j+4P24tFgtmLhJMbZ2fR7F3rscf+/p+
jlD4j7Erd42CwhiUmUmpVMK8FMqurlNQr/LszEPWMcJH0ieB+Iv7gcN2l+28
g0RacuWtbf9wPn83b4gqeEu0cSzZ9WML5+nSr6U3E1+DZA2fbOD+H6JsZilQ
RXCv2+113qSgehWZXrrMp4S6Wyr//i2cH07PzLWzAgmbz8P/trA5rH7oC7k2
H/gfztKckw==
     "]]}, 
   {Hue[0.6142719099991583, 0.6, 0.6], LineBox[CompressedData["
1:eJxF13k8VN/7AHBbEqJiFkt2c0fkI0uh3POQiEoiKWt2SZJQFCEqa0SFVtok
iSiyVEQiWshaMWMnFSVSlt/p9fp9mT9mXu/XnXPmnuc+53nOyDoftHDj4uDg
0MJv/z75SidFPmsHkRz//8q45yr/Xc4a/c8PT2bnl8l5zLvkYMPRG3JH5v20
z+HTBbnT835+nUhIlLs4b/1ZAY94uTvz5lod2hQrVzRvCUeWUIbEq3mPvI+v
vDr4ft7SmX0+vLdb5/1g7v3Kqa7P8866f0v3ZSt73ozMHI/mmd55n71vvm0N
ZXDenNrrT9tPDs9bdomvwVvat3nfyvmVdSZ8dN7/sTiXvvs+Nu9l6wrW6Ib8
nHdgw+kwwdHxeWuc5kzkjJiYt1t97d/Lgr8X1rvjUdL141PzZk5tGnwp8Hch
vqwpT6uw6Xnf+GKRzSs6u3D/EX+MHa7PzXvsXvdi4WgO+J8TssS3hu3gnPdX
Q9dbtwS55r2YaFaRqlpwfXqqKDOWe96WuQeW9xvyzPuU5XkfLaFF8z5M9k61
Ni1YvtYwXTWOd96hfZPp1J2L530poyzvoRDfwvgbWeMZ1QueXDuQKhe3ZN56
XussrDfxz1v1v479K4UE5s1OTki/WLvg7aTXpGu44Lz3BacWvti8dN6bdrWd
auESWljvC68nwfULFjqiIO53TnjeS/omaxIUl817byuvxv3oBaemXc1SHFhw
7qzJoxqD5fNOz5HyU7+9YI9Vx3UmuVYszD/GlR/pseBomyvP1tcteDj5edtW
hsi8ZalLMxkxC9bx7A6wGVgwg5s9tWur6LzH4KdoyIMFXzFL0J0RoMz7t2Of
fcLSBVsc2hAuLbxg3pThGv0VC/ZpN7I6RV8w6Tp3UFhxwZ1BvrdkyQVrx9a8
eogWfO6y1MhG/QUbPatXdzdccC6P0vNs0wXzUcN61m9dsDPRytuwbcFU06ht
380X7Gv7yTfMYsF13hopy3cuWCE0pijTigJHR4olvi8DvdCz7A4NawpEdf9K
4sgt12u7rj1btZsCd+hLT48LDOipPzwru8uGAuI+y0+yX3GScS/6DQdssWNO
yCnLi5L9H/Q8j9pT4KAJj+wtGXkS+lNilzhSgPNc2r10bTUyffJLbvpeCvC/
CtSL8dIhx/k2Nio7UwDUmzUjawxIM/H0X2UuFIiM6FYKPW1KZimP0c3cKND0
vtm4SdSC5NLbvKHLnQLIb/qY9pg1aWd2zdHXkwJfTUyCmT8dyMeOExGcXhRQ
hHdRPuku5LJD226f208BJ6nD08aenqRXxM1a+QMUcLA8EaU3eoCsSv47UuhD
gX1BBVyPpf1I6VsWy4x8KXCD30ztaH4AWdzedKnsEAXCP6c7b/YOIi2ErAiN
wxS4WZQ7UJgQQo4YtDy8608BU85XXPzC4eSpI9akTCAFFM7LcXaePUnK5LTV
XjhCgd3bhpPCt54in7D2WC0NokClvVzbNeNocsTEzvvPMQoc1jh6ZpozkTwV
+nnSN4QCv9xeKmzqSyKlCxxODoTi+dSanGS/JpPFA11CDmEU0FWVed8vfoG0
kHRK/xBOgeZpVZ4vB1PJEfNuxS0nKRChFR538ms6GRXlkl8Ridd/KPXvovNX
yOJvbq9yT+N4qgt5nS3IIC3kBywVoykgt8pITc30BvnF2rPrUgy+v7YewUO/
b5JSFV4TZ+Ip4H3BUiX0ahZZ/OtL+FwCBZLhDsf1i9nkjlUHlgYmUqCi1UVo
6b0cMjL5oIJLMgWsI+OnnyTlkVKvRh+0p1Dg5dXXBeyqfLJo+tB68wsUSKpD
aZG8BeSwm7+FXhoFTo1vCUt6/Ig01w4Ko13D8X4d+kSqqZQc9v4jkHCdAicK
f38KPFlOnsw4dpEnkwIBvfd2/DJ8Rj7mD80du4m//0l6r31oBWmO5nQ8b1Pg
4nlf/ZagSnLocFh15x0KJD6TEo0PfUFKfo749DqbAq5rd+5yvFlNPl7O42mQ
g/NxeP2qd9Uvye1GUT+L71Ng4qN+sdJYDRnx4DT/7TwKGG7Z91rfvY4cCo/T
DntMgdmf+7fkv3lLRjxeWjVRRIH2q9WPl2S+IyW/JGw/8IQC69fc+rrH+T1p
vjPJ3aYMXz+puWb1eCP5mHEhRbOSAidz174Zd2ghzW1pMvde4PyI9awf39xK
Dp1NvSdbTQFhOeUnpE4bKTmVXin0igJe/ZWVi1Z3kBGvr40ONuB4XOza+dil
k7xjFiK3+y0F6u7s9so+3kXWv7fZWfOOAreGWxsYZiyS2kYpvtVEge2vdXt/
H2GT2b2xJ5zbKbBLsG+j368e8q3Hvvz3HRSILntrV3mllxwfNuqBT3j90Yzg
EpM+khzjNJbuosAbbuuZupx+snHmiNCnXjw/I6jq1PUhcjLMCrb0U6DlcPA1
NY9hUpJHw69kgAKsEddfjWu+kO7835pThynwdkhjm1LTCPmH6nrFapQC0uwi
xUvyo6ScmrnK278UsN/Iu+Ht7E/SuGC1AzlDAee1wUEbI8dJ77UCifdnKTDa
0OXFI/iLfLzh5c9YTipYq0qfDpObIE1NNpRuXkyFtvha/2/7f5MH68W+FvFR
oTZUUdaKZ4pM2T4pRfBTIelSfpnatSmy0+phxKKlVLC9PNVp8+kP6efMNK1c
QQWblBvXFgfMkBf7Fh1fI0qFvPKPKZmys2SZZ8/96xQqqKVHFHa8myV5D15d
foJOBaLNfvMlCQ6Ufky0fb0UHk+ReCl6jhNVpnB4PlKiws5zy6PyK3gQf/nV
so3KVOgp0FLavW4RsuzbsLxRhQpbvDfIFOcuQr1aQSXf/qOC4562z3mZvGhR
65ggcy0V8jXSjnRd40ObxXry0w2oUGRXRHD8EESJ+uG8SoZUmEwSUiqPXIra
9knbFm2iwm79njZ3MSG0r8SW58NmKlTWfBGP3yyMYmw/7Fq6nQodyDUSdS1D
DVeq/56wpYLgGdGanigRRH3pYi5kTwX3WjVLzy4R5PCN89ZlByq46OzpndYR
Rd9I0uyJExVcuQzC7X6IomWsx9d/eFCB/jz9vJwvFVnIZW1y86fCCtlbd9dk
iKG22zFnTeOpsCHzRNUWPxm094fF1qcJ+Hnk/Nazvy+DBvUklqgnUiGgJDTk
76AM+v3hXoRYMhUeZZwfZjnJIhp3Q8BgKhWOjTGfO9nIoV2OwnanblJhs2Kx
X4O7AurMbqX/uUUFIdWHSVPZCsh94lrzgTtUkDHc3F/2XQEFxqttt8qmwgMb
lXqBY4rofOkOA4U8KoieFHrzKZWBPtBSmJWlVNhhvrTq8xgT2bnY9WmVU0Hg
z9Hw10gJ9eYqZN59SgXdUuFemwQlNL7pkURSBRWijTI1nVavQiL+LUJ7a6hw
qPG8kdRhZWTxjv5rppEKbLNo45GVqujtmSsVOsNUkGJIGBX+WYOCgxgZ9V9w
fKQ+zqWoqSOG14Mwx69UeJ1sO8ZyV0fHt1SgqFG8nsiHCmUf1BFTqK/83QQV
lMw2e8c+0kARySolHtw0GFU/d2w4VgutvVr68LwkDVTiU0LPJeggdoLhOaYU
DUKkd1OzGnVQ3ImGQ6XSNPiUGKa6lqaLevZ2qbHlaLDyimh0eYYuSpTnfqCi
RANRtfZTkWXr0VCW6b0XWjQwHrbIMF9CossF7TfGzGhA5ZhLdw3XR40/niqF
mNOgLGBrSVq2PlqifvMBnwUNjhfyWQh/0EeBeT6l0lb4eu2XgjLCAO24z920
zZYGETP/VSg2GiDeO6u5sj1oYNa2jcNewxAdSg/f6xxGA493tYueM41RVrt7
/9dwGhz5fP6Km40x6qRv9Q46SYNl6ZUTO+KM0daL1KOJp2iw09Hu8dyoMWKk
3Dv7NI4GJZWuw4Xlm9Gn+Oan4mk0aNzgrvDQ1RQZhSutbMqnwfgharP18DZU
1qMtYFhAg727uU2QrBlSN9o8VVhIA31Pj4p9u82QtIBH84UiGnyvrnc+U2OG
fqfcjLcpp4FC5bnO0azt6G6W9Cz7FQ3e8kqvMykzR4LvKF2jXTRgazXWiN+2
QBHqig1ObBqI0MvM+6st8HjN0sZuGmSnPB9s7rNAvXssLxb20aBA79FFWYYl
Ku9J3H70Cw22+SeqHMiyRD6TAs/nJmhQm04IDhTsRO+luDKEhOjgyJ95eLx/
F/JiNOZfFaaD2zvrxlAha8SjmlmpupwOi9CLtLVrrZG2nkGvmSgdvux/Xad6
yhpdtY0gzorTYbWjSIIhczfySuXKFSboEBcpai8ZsAdxreAuXQZ0+B7np6Oh
bocuizW9vq5PB9+VNdQrjnZIS/bGJ7WNdIhavPPKung75Km2cdbciA7TJCE0
N2iH3pid1E/aSofn5xWtOzLtUXos96vle+jQXiJq2i7tiNQX8TSv8KPDi0Yl
z1ZpJySgNrvtzGE6vPsoHDK5zgn12vx+OeNPB32CX03V3AldyBspHjxChyla
YnpXmBP6Y9t8+WkIHVJc1mRb9jihyoe3Xb2i6dD8xGQiOscZWe41Ga+4Toc8
SqNVkLkr8i9NEDn0lg4b5Y0bC1geqE2zT73rHR34Iimta2c9kF7ueottjXQQ
0p+Ta5TwRLwZg4lKzfj3KbzFO6w9UeopA6HuDjpcEOL/FvDWE5XtmOCz7KcD
Z5T6RtuqfYhn0H5Wc4YOXOHIruv5fpQsunro9yoxOPoxriGE2xeJaxgqn1IR
g46n9iUTVF+UucP2gIiqGCzV/rzvxCpf9DAhemz1GjForN676vkOX9TI1z/l
vE4MLm961TN33Rctm7nK37BRDHpjz9SFGBxCCX3LVDLsxMC9e8vfa0l+6Mzj
cR+TBDE4p/w6qtspAJn/1hIrOysG5QZxikNHAhBN98gL1SQxcPmxkzUbH4Bu
l0/RRFPE4O/K3FLrkgD0omr2eWeaGDwr2pX+TCQQzTbyifjfEoMDkTqh3rWB
6PB3yaKrZWIw/WsJ1RGOIgfmprmfw2KQ1D6lUWt/DPH3PEUe28WBFS77OiI8
HF08UBGjeV8c1NLEnbizoxDnpVZv5SUS8HmVimKEVQzSX06bG/aWAI+1cpS5
pYnI2brrEk8dvs65zK5DPBnt6X832K8qCeTQrgyTxgtoNb2l/keSJOQpMie1
h9JRt5hr6e5vkjATuSPTSOEaOuAqYXPaYiX05zXK24hnovZQW+5leSthfYVG
2KOCm0huw4ONlQJSMEzmPuc+dgfpG6ho6h2Ugg/yJ1OKX2Qjfbr6fyvqpcBq
82HnGlouoq1z6nigJg2yYz4qHBz5qO73DckjydJgzL261EakADnGHNyX+l0a
NHvkO1yYj5CburpGhZIMNATdjmtMKUKxi8fWuuyWgZfK59jynCVIOleHV/yU
DAS3OgVLR5chqakLqx8VyUBnfs24c+AzJJSjbTPTJwNJnWIV+qoVaB/3904l
uix8yNEO0G2pRIWVQ57cxrLQr3PE4b5/FfKx9Hk65i8LTwhuWqH4S5R8ZrF3
1W1ZyOvuWa4yXoOyFPukDJtloSz8x83ZklrE9GhVylosB0tuSZfOFrxGtGBL
DlkdOWj3XRS2KLcBTYyLfDLykINKVWTrEv8WgeiQ8I40ObjUwGq40vAOHbvE
ZcL3Sg7qUlT+clW/Rwrjt7Z9+CUHIS49/SeLG5H2mH12JCEP+wdrAz49b0J6
u2wEu63k4f2q5vyaxx/Qfcf9L+XPyIOUQtP2mGfNKFaXd2vwE3kIOq5clvm8
BdmE9LWEDODxSZI1szmtKMW1/YmbmAJsfyx09XZWG3pasDzzj7ECbLz4LEsv
oR1Z3nHoPhysAEfX6DnphnUga2+tb5w5ClB2+MnMV7ePaGua+dyGDgXY9hXp
G2t+Qve8wjztBBXBJr///h7+z+jvjfEW5npF+NB2ukL/1WdUkvtjGf8+RXDI
VJUgj3aiHvtFN96mK4JCxWq3+lVdaMbfTtegVhFynQbKRqu6UITaK6W0v4pg
pNwdkK/KQoHl5b08qxlwVN58+vohFrJ5OHlzpS0DLrMbes9msdCzkd1pfdjO
+ZMpB+6ykAJREn/fjgFZ9O5C02wW+n7peKCeAwMGn/ht5M5hocgozs32Tgxo
vNx+8cADFsrdLfDlsgcDqEm+HMRjFuKak1oj6c+AG2m7+5VfsNDdLUbl4vEM
GLUryw/8iL9/scytGbtdNJ1P/hMLFfSoCyUmMGBzQnDHG+zyY9KOixIZIP2m
5ZtCJwu9v/ebY/QcAw6UcbbWsVhoSuCeYXUqA4yVtsTP9LGQSb1w/cGbDND+
8adx5jsLmdFP+a+6xQD44mmVNspClq7Tkn3Y3wcPbdccYyH76cEDNncYkP5n
4K7nDxY6pFIpvCmbAb35+37VjbNQWpy/pXgeAySMvr4JmGKhoa3tHVWlDDAt
2NjgwsVGms9DWo6V4fjV1e36gh2qIdeoXs6ASNGpPX7cbCQqvr/2+lMG/L7Y
Wx/Kw0bkwHTR8QoGuFYxnZN42SglXOa8Zg2+3y+jGlf42Qgee2y/2cgAXbWO
52Yr2ChWSXCLbROen5mwrRq75XKe0YoPDPBeUWi+XoSN9p+c0gtrxuNXfH+i
KMpGF8xjVezaGHBCyZIyTmGjkeHcJaKdDMj55tAeKMZGF6UnXpwcYkD3uc5u
ERk28u/7Y246zIBdtd3Xw7HN7819XvaFAdtuMJ98w+Zbt+T3lREGqEhMTL6U
ZaNgM0mV4u8M8BXkundQno0cQgxSRn4xYDpidV0Gg410NxrLFkww4Mj+r5KL
CDaiLdmaGzTJAD777hoP7HcpVq94pxjwTnNQUZnJRvo5ntMy0wwozmqYvavE
RgofE1ytuAho+2/74jMqbMSRkTwmwU1AoDznGxb2Z/fU0G7s0qiPw9qr8Xp/
ZKQeXETAtYOnGAPYi/kf1UfzEXCuTipz/X9sNKz9UfOpEAHiynfjq9awUd4F
YhEhQYArb4a51Vo2UvHRN2Jh98bFyqRgZ22yPZ0mSYBClMCeRuzr4wlLBKUI
GNnoxL1tHRslWUwsHZMhoMUkWHe9Nhv5CVVTSxkEvB8Vlfirw0bf+jqt/QkC
NlZ2eKjpspFX+e/U1UwCUoZiJdywXbxVJK4rEcB6uKmoHntnXbJ0lAoBO0+s
Lk9Zz0Zap5yZ29UJcAkK+7JYj40e2h/fx6dBwKvWE+ka2KpaF7IrsFV8n+c6
YDN6a1U0tQiYrUnnLcCmGqxZI6ZNwIxzne9Oko3OiW3xa8ROZw0ZHcMWGnMt
iNUhYHNMQHgG9uLrqVqzugR0dbjLj2D/npnT6dEjQO55DS0Y4fxoFjt2mSQg
+KuD0GXs0RyNMitEwA/teM9y7EFbD/IVELDlhqHxLHb7kzcG9zcS0Cqqde8o
sNGupMGT7oYE7Iu4VHoeu9GTq1p6EwGrOKpUH2LX0dYanzPC93NrdMMQdknA
lS1HTAiQ6Hvza7s+G726RpMCUwL2cAWKeWG31CaN8m0hwP3A7pMnscdWnjqf
vpWA5qPGSoXYs8Ycni7bCFiDlrm9xhb0C9ZVMcPzX4vrZ2MzX/p0lW8nIPUo
vUTQgI3Wjg7mnzInoI7WKyCLbSjuErl9BwG3Ln/M1MTe62OtxLYgwOTGy2t7
sH1S3/+9a0kA35bARfuxj1dueeO3k4C9CnUPjmFfpMJhnl0E1Ba1vE/Hvgkl
mxqwGy9uMbmL/dBLk37BmgCnX594irCfp+QOO+wmwK/Hk6cK+81TZjmxhwCu
gAbjd9ifBjPPjmLzlw+++Yg9vGKl8xMbAs68SU3rx+b1WL54ix2eP+2/qSls
0aTYdhF7Ai4GNcZzbWQjudJFOZ+wn/pEuPFjq/WdCL3lQIBh3Mqw5dh6wn/M
fRwJUOwL/0zDNtXxl1+3lwC7uPiQldi7Xb79msPuS5HaK4ftHu/56pUTAWXL
RaIY2P5F3elJzgR8pJiMKGFHsO0O2LgQgAqvnlfBThRoRfKueH/NjYWpYl/V
2rFiBLtKQDb3P+wcx9e9hW4EdAwvWamGXRK9qSjEHd9PXkzDv+uvCp5FG3kQ
cNkn/Nm/8S2fdeyEPfH8OvU//s3fs7hQtQ2bT97EYxX26BpVzox9OD/JFkkC
e9Y2q2mfFwGT13aIyGMLnpK7rb6fAOqeNFMpbPG8y0f/Ym8Oia2kYzM7qFuq
vAmIluY9tgJ7LU/SyvgDeL9bDBwWwDZUFRi18iFAadXS+9zYFrujKqUOEnCi
2Irx91++RMylDGA3LrvWNfYvX3KCPPJ8CZAyqmkb+JcvLT91gg7hfNmfs/wz
djSHj6CBH65XySox77EvrBrs5D9MQN57RYPqf/mz0zm/CfuxdqBO8b98ydq1
yy0A539DSt+lf/nS+I6pGojXLyudHvcvX6ZN/05ghw0djT+O/dscXT9zlIBO
BRE1G+z/pojhe8cI6N6t4vQv/z9pFvl6HMf1Vm/70d94f8T4Gk3KhRCQtFqk
vwe7f8CVJz0UP/9c4epi7MstGVJnwgnwrGqOt8E2XbHm1sYIAp7E/N2ljz25
7bnyHDavY18AgW1R3akdGEmAasGFwjG8v/kKJSxdTxPwJ8VLPRT78ffsdukz
BOzfde+2I7aLsu7ej9jLlZoOAvbTzN0HLGJwfE7u4+DADkg6fxricTxS79GO
4HrT7SNcJplMQPmVPbybcP1KzL5q0IZdnEkvk8DW619dm5xCgM0znuoxXB9T
7be28F/A+VXx6+0lbLOt0aO/U3E98tOqGdjARqVK3IrNV3H96Z2Tc8T12NPt
3L3Ea/h5JF+ZXYVNzZBV33qdAFunXOUJXL/xX0P0IoOAhLaSoBhs5uKQPfk3
CcitCOrOxv0gpXciPj4b7+d2lzd1uH+cNi702HSPgMy7p3/EYQdnH9Kfwc5J
3nDADNvJd2Tc+z4B+iljbm9x/1GdZttuzSPAe98Dp1otNqoVaVASeEyA5eGC
/Vc02KgsMIb7BXa33KORndh57cafg4sImPC+UymAfeFaZeJwMY533i/vI+ps
5KpcPFlbSoCD+N5iI9wPZw1uVJ+pIEAz4pZItSqup7f2XoNKAiLlQloPYffy
SQX9xj7aefPbSuzXb1JVPKtwfkQfp/rjfptqk5BsXENA6JvDJnTcnzX8gpx4
G3B/kytVBNzPPTO2z5xsIyDRL4BzKT4vfN11wHNLO36+QtuWXZLD8ROMbVrR
QcA2dzlzJvbxIy/vZnzE+9Fb3xnweSNxm96uZ514P93NrXeXZqPiqVUP/vQS
MPdS80qcBM4nC16nQ2O4v3u6G/47D8UvVqjX/oH7XV2q+gN8XlpRrr+O4ycB
d3sztslhSzJDlp4dx/XZoWAJ73JcD2d/PsmZJCDOaM2FF0K43mWzVwzOEPD9
2ekeKj6P3eEqr3LgZ0KyNtVjJQcb1dd+76ELMCHmoMqH8DkWGk2U427Cnnr4
KKpvloV0pc/oGy9lwlbrR4+yZ1iofr3l0/+WMSGi099I5S8L/fAfKuKgMsFX
xVJEcIKFz4OUe5myTCgZDb2i94WFXHI319nJMUG6O9M1ZpiFzgQcG6LKM6H8
ert3yxA+/3KziVgFJhSFiID3IAu5yuTcPEwwYcuJqm8J+Pwbs8fgquFq/Pv9
QVZ5XSzU8tonqV+bCTw+CrHOTSwU18dpkKfDhOi9AWtPNbLQxrmUH0G6TEiR
TZvJes9Ceeqllks3MIHz4tvOL29ZKDptMVUTMcFh0doh93oW2uBxPT18ExOq
Mlrm1lSz0A2uxhuSFkxY5/5howQ+7/vqaD222M+EvCjVTPXzLOQdPPGE7s2E
Vz+ObpZNYSHP0qLyTuybAnH8wskstFdPt9rLhwlWSjHsgUQW2qGPPkQcYoLh
IevWhDgWUjcx+fHwCBOC6RXV+SdZaHy3vapIJBPIr0SdKf7/EnQ06nbTZSaY
/p62rDRhIT9p8cucr5nwLTdrrcpIF2rxejEkMsMEObd1kyX0LqQslb+hSVkJ
gnQT6PprO9G3TKbtnT1KkK5epCe34TOSrC987xirBM8Crwk6CH5C6+2jtlU/
UQKvLI4Hl953oOpzXrLCI0pg91atxWJPOypPa39+YOUqqGw6XeLwohXd5ot3
C9qyCh4SgY46RAv6I2HlvC9kFfRFVrnlG3xA5EUnV96cVeDqOMLcaNOIvj6O
eHq6cxUwzEY0b8q8QwJZq3tXLlMGC4rotfGE10iMc6WwE6kMBvV59BjWS3Ru
VubcGV9l6O/uiH14pAJNu+wTt7+mDJWbDl9qVStGH9LX+xg1KMPo9ksirpRs
9Ec4cOfyN8rgL9vZujzvLpKJytP9hL1Y+cfWO6Z3kfdBxcV+75Th7rk3EH0i
Cy0yFL5+pUkZzPetXKE0eBut/dr9frxdGdz7tQ+1FN5AaShG60a/MpzTUrqV
fyQdPS+skvAZUAbvihuDo7fTUL/SHKfOoDJ8iXjNOdecitRF/d+8GVKGPdM3
bpzWuIjqBu09/owowydNLmXTkWQ0nbQmbcdPPJ9G6JDM3Rgkt9j7hOS4Mgxl
egkGckajzcdvuw1gz6IyM889p1GKu4R6yIQyHCtMElLgi0Sr1y96nTWlDFxP
1AS/VwSjnXko//AfZRiXinDY530EBSsGXyT/KsOyu1kuK6n+6KXwd5cP08pQ
PTse5vrGC41EKplem1EGvynzYcWVrmjFHxc1r1lloIy9sCn8YIO0D16las0p
w/XC7Ms8babIobdteg4bdux/db/Qi/w/ZTy6yQ==
     "]]}, 
   {Hue[0.8503398874989481, 0.6, 0.6], LineBox[CompressedData["
1:eJxN1Hk0VV3cB3DzPBUpY+dcs5uxlPHs32OKTIWQDJV5FlIhlQZTJE2mJMoQ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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  Epilog->{{{
      InsetBox[
       FormBox[
        StyleBox["\"\[FivePointedStar]\"", Medium, StripOnInput -> False], 
        TraditionalForm], {0, 0}], 
      InsetBox[
       FormBox[
        StyleBox["\"\[FivePointedStar]\"", Medium, StripOnInput -> False], 
        TraditionalForm], {5.33, 0}], 
      InsetBox[
       FormBox[
        StyleBox["\"\[FivePointedStar]\"", Medium, StripOnInput -> False], 
        TraditionalForm], {8.33, 0}], 
      InsetBox[
       FormBox[
        StyleBox["\"\[FivePointedStar]\"", Medium, StripOnInput -> False], 
        TraditionalForm], {14, 0}]}, 
     InsetBox[
      FormBox["\"5.33\"", TraditionalForm], {5.33, 0.05}], 
     InsetBox[
      FormBox["\"8.33\"", TraditionalForm], {8.3, 0.05}], 
     InsetBox[
      FormBox[
      "\"\\!\\(\\*SubsuperscriptBox[\\(B\\), \\(1\\), \\(4\\)]\\)\"", 
       TraditionalForm], {0.6, 0.9}], 
     InsetBox[
      FormBox[
      "\"\\!\\(\\*SubsuperscriptBox[\\(B\\), \\(2\\), \\(4\\)]\\)\"", 
       TraditionalForm], {2.5, 0.6}], 
     InsetBox[
      FormBox[
      "\"\\!\\(\\*SubsuperscriptBox[\\(B\\), \\(3\\), \\(4\\)]\\)\"", 
       TraditionalForm], {5, 0.7}], 
     InsetBox[
      FormBox[
      "\"\\!\\(\\*SubsuperscriptBox[\\(B\\), \\(4\\), \\(4\\)]\\)\"", 
       TraditionalForm], {8.5, 0.7}], 
     InsetBox[
      FormBox[
      "\"\\!\\(\\*SubsuperscriptBox[\\(B\\), \\(5\\), \\(4\\)]\\)\"", 
       TraditionalForm], {11.5, 0.6}], 
     InsetBox[
      FormBox[
      "\"\\!\\(\\*SubsuperscriptBox[\\(B\\), \\(6\\), \\(4\\)]\\)\"", 
       TraditionalForm], {13.4, 0.9}]}},
  Method->{},
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.577701680930521*^9},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]],

Cell["It is instructive to Piesewise expand  the basis functions.", "Text",
 CellChangeTimes->{{3.482234065314257*^9, 3.4822340765776014`*^9}, {
   3.48499443396875*^9, 3.484994447921875*^9}, 3.4849946855625*^9, {
   3.559483753556153*^9, 3.559483757594501*^9}},
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"bsplines", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"PiecewiseExpand", "[", 
      RowBox[{
       RowBox[{"BSplineBasis", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"degx", ",", "knotsx"}], "}"}], ",", "k", ",", "x"}], "]"}],
        ",", 
       RowBox[{"Method", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<OrderlessConditions\>\"", "\[Rule]", "False"}], 
         "}"}]}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"k", ",", "0", ",", "5"}], "}"}]}], "]"}]}], ";", 
  RowBox[{"bsplines", "//", "Column"}]}]], "Input",
 CellChangeTimes->{{3.482234083410489*^9, 3.482234133487131*^9}, {
  3.482662576265625*^9, 3.482662577359375*^9}, {3.4826639286875*^9, 
  3.482663929375*^9}, {3.487659209421875*^9, 3.487659210453125*^9}, {
  3.4876816508125*^9, 3.487681680515625*^9}, {3.559483782275836*^9, 
  3.55948380242433*^9}, {3.559484716440413*^9, 3.55948472752096*^9}, {
  3.559484888425267*^9, 3.559484889578448*^9}, {3.559485921092246*^9, 
  3.559485921113735*^9}, {3.560541380328013*^9, 3.560541381806736*^9}}],

Cell[BoxData[
 TagBox[GridBox[{
    {
     TagBox[GridBox[{
        {"\[Piecewise]", GridBox[{
           {
            RowBox[{"1.`", "\[VeryThinSpace]", "-", 
             RowBox[{"0.5625`", " ", "x"}], "+", 
             RowBox[{"0.10546875`", " ", 
              SuperscriptBox["x", "2"]}], "-", 
             RowBox[{"0.006591796875`", " ", 
              SuperscriptBox["x", "3"]}]}], 
            RowBox[{
            "0.`", "\[LessEqual]", "x", "\[LessEqual]", 
             "5.333333333333333`"}]},
           {"0", 
            TagBox["True",
             "PiecewiseDefault",
             AutoDelete->True]}
          },
          AllowedDimensions->{2, Automatic},
          Editable->True,
          
          GridBoxAlignment->{
           "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{1.}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.84]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}},
          Selectable->True]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
          "RowsIndexed" -> {}},
       GridBoxItemSize->{
        "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
         "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.35]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      "Piecewise",
      DeleteWithContents->True,
      Editable->False,
      SelectWithContents->True,
      Selectable->False]},
    {
     TagBox[GridBox[{
        {"\[Piecewise]", GridBox[{
           {
            RowBox[{"0.`", "\[VeryThinSpace]", "+", 
             RowBox[{"0.5625`", " ", "x"}], "-", 
             RowBox[{"0.17296875`", " ", 
              SuperscriptBox["x", "2"]}], "+", 
             RowBox[{"0.013510546875000001`", " ", 
              SuperscriptBox["x", "3"]}]}], 
            RowBox[{"0.`", "\[LessEqual]", "x", "<", "5.333333333333333`"}]},
           {
            RowBox[{"2.777777777777779`", "\[VeryThinSpace]", "-", 
             RowBox[{"1.0000000000000007`", " ", "x"}], "+", 
             RowBox[{"0.12000000000000008`", " ", 
              SuperscriptBox["x", "2"]}], "-", 
             RowBox[{"0.004800000000000004`", " ", 
              SuperscriptBox["x", "3"]}]}], 
            RowBox[{
            "5.333333333333333`", "\[LessEqual]", "x", "\[LessEqual]", 
             "8.333333333333332`"}]},
           {"0", 
            TagBox["True",
             "PiecewiseDefault",
             AutoDelete->True]}
          },
          AllowedDimensions->{2, Automatic},
          Editable->True,
          
          GridBoxAlignment->{
           "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{1.}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.84]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}},
          Selectable->True]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
          "RowsIndexed" -> {}},
       GridBoxItemSize->{
        "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
         "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.35]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      "Piecewise",
      DeleteWithContents->True,
      Editable->False,
      SelectWithContents->True,
      Selectable->False]},
    {
     TagBox[GridBox[{
        {"\[Piecewise]", GridBox[{
           {
            RowBox[{"0.`", "\[VeryThinSpace]", "+", 
             RowBox[{"0.06750000000000002`", " ", 
              SuperscriptBox["x", "2"]}], "-", 
             RowBox[{"0.00852589285714286`", " ", 
              SuperscriptBox["x", "3"]}]}], 
            RowBox[{"0.`", "\[LessEqual]", "x", "<", "5.333333333333333`"}]},
           {
            RowBox[{
             RowBox[{"-", "2.8717948717948723`"}], "+", 
             RowBox[{"1.6153846153846156`", " ", "x"}], "-", 
             RowBox[{"0.23538461538461547`", " ", 
              SuperscriptBox["x", "2"]}], "+", 
             RowBox[{"0.01040439560439561`", " ", 
              SuperscriptBox["x", "3"]}]}], 
            RowBox[{
            "5.333333333333333`", "\[LessEqual]", "x", "<", 
             "8.333333333333332`"}]},
           {
            RowBox[{"3.9909502262443417`", "\[VeryThinSpace]", "-", 
             RowBox[{"0.8552036199095018`", " ", "x"}], "+", 
             RowBox[{"0.061085972850678696`", " ", 
              SuperscriptBox["x", "2"]}], "-", 
             RowBox[{"0.0014544279250161595`", " ", 
              SuperscriptBox["x", "3"]}]}], 
            RowBox[{
            "8.333333333333332`", "\[LessEqual]", "x", "\[LessEqual]", 
             "14.`"}]},
           {"0", 
            TagBox["True",
             "PiecewiseDefault",
             AutoDelete->True]}
          },
          AllowedDimensions->{2, Automatic},
          Editable->True,
          
          GridBoxAlignment->{
           "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{1.}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.84]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}},
          Selectable->True]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
          "RowsIndexed" -> {}},
       GridBoxItemSize->{
        "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
         "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.35]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      "Piecewise",
      DeleteWithContents->True,
      Editable->False,
      SelectWithContents->True,
      Selectable->False]},
    {
     TagBox[GridBox[{
        {"\[Piecewise]", GridBox[{
           {
            RowBox[{"0.`", "\[VeryThinSpace]", "+", 
             RowBox[{"0.0016071428571428575`", " ", 
              SuperscriptBox["x", "3"]}]}], 
            RowBox[{"0.`", "\[LessEqual]", "x", "<", "5.333333333333333`"}]},
           {
            RowBox[{"1.7672583826429977`", "\[VeryThinSpace]", "-", 
             RowBox[{"0.9940828402366862`", " ", "x"}], "+", 
             RowBox[{"0.18639053254437868`", " ", 
              SuperscriptBox["x", "2"]}], "-", 
             RowBox[{"0.010042265426880812`", " ", 
              SuperscriptBox["x", "3"]}]}], 
            RowBox[{
            "5.333333333333333`", "\[LessEqual]", "x", "<", 
             "8.333333333333332`"}]},
           {
            RowBox[{
             RowBox[{"-", "8.325013820355842`"}], "+", 
             RowBox[{"2.639135152842896`", " ", "x"}], "-", 
             RowBox[{"0.24959562662517126`", " ", 
              SuperscriptBox["x", "2"]}], "+", 
             RowBox[{"0.0073971809399011905`", " ", 
              SuperscriptBox["x", "3"]}]}], 
            RowBox[{
            "8.333333333333332`", "\[LessEqual]", "x", "\[LessEqual]", 
             "14.`"}]},
           {"0", 
            TagBox["True",
             "PiecewiseDefault",
             AutoDelete->True]}
          },
          AllowedDimensions->{2, Automatic},
          Editable->True,
          
          GridBoxAlignment->{
           "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{1.}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.84]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}},
          Selectable->True]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
          "RowsIndexed" -> {}},
       GridBoxItemSize->{
        "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
         "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.35]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      "Piecewise",
      DeleteWithContents->True,
      Editable->False,
      SelectWithContents->True,
      Selectable->False]},
    {
     TagBox[GridBox[{
        {"\[Piecewise]", GridBox[{
           {
            RowBox[{
             RowBox[{"-", "0.6732412886259038`"}], "+", 
             RowBox[{"0.37869822485207094`", " ", "x"}], "-", 
             RowBox[{"0.0710059171597633`", " ", 
              SuperscriptBox["x", "2"]}], "+", 
             RowBox[{"0.004437869822485206`", " ", 
              SuperscriptBox["x", "3"]}]}], 
            RowBox[{
            "5.333333333333333`", "\[LessEqual]", "x", "<", 
             "8.333333333333332`"}]},
           {
            RowBox[{"8.514401473207773`", "\[VeryThinSpace]", "-", 
             RowBox[{"2.9288531694080526`", " ", "x"}], "+", 
             RowBox[{"0.3259002501514515`", " ", 
              SuperscriptBox["x", "2"]}], "-", 
             RowBox[{"0.01143837686996339`", " ", 
              SuperscriptBox["x", "3"]}]}], 
            RowBox[{
            "8.333333333333332`", "\[LessEqual]", "x", "\[LessEqual]", 
             "14.`"}]},
           {"0", 
            TagBox["True",
             "PiecewiseDefault",
             AutoDelete->True]}
          },
          AllowedDimensions->{2, Automatic},
          Editable->True,
          
          GridBoxAlignment->{
           "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{1.}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.84]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}},
          Selectable->True]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
          "RowsIndexed" -> {}},
       GridBoxItemSize->{
        "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
         "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.35]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      "Piecewise",
      DeleteWithContents->True,
      Editable->False,
      SelectWithContents->True,
      Selectable->False]},
    {
     TagBox[GridBox[{
        {"\[Piecewise]", GridBox[{
           {
            RowBox[{
             RowBox[{"-", "3.1803378790962715`"}], "+", 
             RowBox[{"1.144921636474658`", " ", "x"}], "-", 
             RowBox[{"0.13739059637695897`", " ", 
              SuperscriptBox["x", "2"]}], "+", 
             RowBox[{"0.0054956238550783595`", " ", 
              SuperscriptBox["x", "3"]}]}], 
            RowBox[{
            "8.333333333333332`", "\[LessEqual]", "x", "\[LessEqual]", 
             "14.`"}]},
           {"0", 
            TagBox["True",
             "PiecewiseDefault",
             AutoDelete->True]}
          },
          AllowedDimensions->{2, Automatic},
          Editable->True,
          
          GridBoxAlignment->{
           "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{1.}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.84]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}},
          Selectable->True]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
          "RowsIndexed" -> {}},
       GridBoxItemSize->{
        "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
         "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.35]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      "Piecewise",
      DeleteWithContents->True,
      Editable->False,
      SelectWithContents->True,
      Selectable->False]}
   },
   DefaultBaseStyle->"Column",
   GridBoxAlignment->{"Columns" -> {{Left}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Column"]], "Output",
 CellChangeTimes->{3.5777016812743387`*^9}]
}, Open  ]],

Cell[TextData[{
 "We observe that, in the first interval ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{"0", ",", "3.5"}], ")"}], TraditionalForm]]],
 ", only four Bsplines ",
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["B", "1", "3"], TraditionalForm]],
  FontSize->10],
 StyleBox[", ",
  FontSize->10],
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["B", "2", "3"], TraditionalForm]],
  FontSize->10],
 StyleBox[", ",
  FontSize->10],
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["B", "3", "3"], TraditionalForm]],
  FontSize->10],
 StyleBox[", ",
  FontSize->10],
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["B", "4", "3"], TraditionalForm]],
  FontSize->10],
 " give a contibution. The same observation holds for every other interval."
}], "Text",
 CellChangeTimes->{{3.482664394578125*^9, 3.482664468984375*^9}, {
  3.482664514625*^9, 3.482664539265625*^9}, {3.48275498540625*^9, 
  3.48275501025*^9}, {3.482755052734375*^9, 3.482755109421875*^9}, {
  3.48497849896875*^9, 3.484978499578125*^9}, {3.484978533796875*^9, 
  3.484978604484375*^9}, {3.484978754390625*^9, 3.48497876734375*^9}, {
  3.484994730125*^9, 3.484994889828125*^9}, {3.48499492471875*^9, 
  3.484994988171875*^9}, {3.484995021609375*^9, 3.48499506625*^9}, {
  3.487659286171875*^9, 3.487659317546875*^9}, {3.4876805590625*^9, 
  3.487680561609375*^9}, {3.559483857982459*^9, 3.559483930729468*^9}, {
  3.5605406961833*^9, 3.560540696705807*^9}},
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell["Part III", "Text",
 CellChangeTimes->{
  3.484992245703125*^9, {3.484992316015625*^9, 3.4849923314375*^9}, {
   3.48499253890625*^9, 3.484992628625*^9}, {3.484994235171875*^9, 
   3.484994236890625*^9}, {3.48499689084375*^9, 3.48499689559375*^9}, {
   3.486039583859375*^9, 3.486039584453125*^9}, {3.559482005654936*^9, 
   3.559482006444809*^9}, {3.572683638740938*^9, 3.5726836695567007`*^9}},
 FontSize->36,
 FontColor->RGBColor[0, 0, 1],
 Background->RGBColor[1, 0.9, 0.8]],

Cell["\<\
It is instructive to extract the polynomial representation of the B-splines \
on each of the four subintervals formed by the knots and to reconstruct the \
interpolating spline by hand.
The Interpolating spline S(x), together with the first and second \
derivatives, are plotted.\
\>", "Text",
 CellChangeTimes->{{3.482664394578125*^9, 3.482664468984375*^9}, {
   3.482664514625*^9, 3.482664539265625*^9}, {3.48275498540625*^9, 
   3.48275501025*^9}, {3.482755052734375*^9, 3.482755109421875*^9}, {
   3.48497849896875*^9, 3.484978499578125*^9}, {3.484978533796875*^9, 
   3.484978604484375*^9}, {3.484978754390625*^9, 3.48497884175*^9}, {
   3.484978883515625*^9, 3.484978886390625*^9}, {3.48499516884375*^9, 
   3.484995178203125*^9}, {3.48499522409375*^9, 3.4849953056875*^9}, {
   3.484995706578125*^9, 3.484995708015625*^9}, {3.4849960660625*^9, 
   3.484996119171875*^9}, 3.4849968864375*^9, {3.559483984151433*^9, 
   3.559483985287563*^9}, {3.559484046686684*^9, 3.559484058960876*^9}, {
   3.559485250553541*^9, 3.559485282145678*^9}, {3.559508253977063*^9, 
   3.559508280060243*^9}},
 FontFamily->"Times New Roman",
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell["\<\
We extract the segments of the B-spline which give a contribution  on the \
first interval\
\>", "Text",
 CellChangeTimes->{{3.482664394578125*^9, 3.482664468984375*^9}, {
   3.482664514625*^9, 3.482664539265625*^9}, {3.48275498540625*^9, 
   3.48275501025*^9}, {3.482755052734375*^9, 3.482755109421875*^9}, {
   3.48497849896875*^9, 3.484978499578125*^9}, {3.484978533796875*^9, 
   3.484978604484375*^9}, {3.484978754390625*^9, 3.48497884175*^9}, {
   3.484978883515625*^9, 3.484978931140625*^9}, {3.48499782309375*^9, 
   3.4849978416875*^9}, {3.487678947921875*^9, 3.487679004125*^9}, 
   3.487680630375*^9},
 FontFamily->"Times New Roman",
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"bsplines", "[", 
   RowBox[{"[", 
    RowBox[{"1", ",", "1", ",", "1", ",", "1"}], "]"}], "]"}], 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     SuperscriptBox[
      SubscriptBox["B", "1"], "4"], " ", "0."}], " ", "\[LessEqual]", " ", 
    "x", " ", "<", " ", "5.33"}], " ", "*)"}]}]], "Input",
 CellChangeTimes->{{3.482664695234375*^9, 3.482664696796875*^9}, {
   3.484912448203125*^9, 3.4849124485625*^9}, {3.48491807028125*^9, 
   3.484918106625*^9}, {3.484918140140625*^9, 3.484918141765625*^9}, {
   3.48491841321875*^9, 3.484918450671875*^9}, {3.4849185378125*^9, 
   3.484918538265625*^9}, 3.484918575984375*^9, {3.48491869765625*^9, 
   3.484918698015625*^9}, {3.484918768078125*^9, 3.4849187769375*^9}, {
   3.48500047140625*^9, 3.485000475484375*^9}, {3.485001215421875*^9, 
   3.485001216484375*^9}, {3.559545478473512*^9, 3.559545488792449*^9}, {
   3.559545715734236*^9, 3.559545717192671*^9}, {3.56053938716565*^9, 
   3.560539394157857*^9}}],

Cell[BoxData[
 RowBox[{"1.`", "\[VeryThinSpace]", "-", 
  RowBox[{"0.5625`", " ", "x"}], "+", 
  RowBox[{"0.10546875`", " ", 
   SuperscriptBox["x", "2"]}], "-", 
  RowBox[{"0.006591796875`", " ", 
   SuperscriptBox["x", "3"]}]}]], "Output",
 CellChangeTimes->{3.577701681531907*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"bsplines", "[", 
   RowBox[{"[", 
    RowBox[{"2", ",", "1", ",", "1", ",", "1"}], "]"}], "]"}], 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     SuperscriptBox[
      SubscriptBox["B", "2"], "4"], " ", "0"}], " ", "\[LessEqual]", "  ", 
    "x", " ", "<", 
    StyleBox[" ",
     FontSize->24], "5.33"}], " ", "*)"}]}]], "Input",
 CellChangeTimes->{{3.4826639458125*^9, 3.48266394865625*^9}, {
   3.48266465525*^9, 3.4826646664375*^9}, {3.484918169609375*^9, 
   3.484918194828125*^9}, {3.484918550640625*^9, 3.484918569953125*^9}, {
   3.48491867809375*^9, 3.484918680265625*^9}, 3.484918746984375*^9, {
   3.484918778953125*^9, 3.48491878215625*^9}, 3.4850004820625*^9, {
   3.48500051653125*^9, 3.48500052084375*^9}, {3.48765934115625*^9, 
   3.48765934171875*^9}, {3.559545516390523*^9, 3.559545522277*^9}, {
   3.559545721059914*^9, 3.5595457221235*^9}, {3.560539399511015*^9, 
   3.560539399658458*^9}, {3.560539571199048*^9, 3.560539574145058*^9}}],

Cell[BoxData[
 RowBox[{"0.`", "\[VeryThinSpace]", "+", 
  RowBox[{"0.5625`", " ", "x"}], "-", 
  RowBox[{"0.17296875`", " ", 
   SuperscriptBox["x", "2"]}], "+", 
  RowBox[{"0.013510546875000001`", " ", 
   SuperscriptBox["x", "3"]}]}]], "Output",
 CellChangeTimes->{3.577701681561192*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"bsplines", "[", 
   RowBox[{"[", 
    RowBox[{"3", ",", "1", ",", "1", ",", "1"}], "]"}], "]"}], 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     SuperscriptBox[
      SubscriptBox["B", "3"], "4"], " ", "0"}], " ", "\[LessEqual]", "  ", 
    "x", " ", "<", " ", "5.33"}], " ", "*)"}], "    "}]], "Input",
 CellChangeTimes->{{3.4826639458125*^9, 3.48266394865625*^9}, {
   3.48266465525*^9, 3.4826646664375*^9}, {3.482664763515625*^9, 
   3.48266478965625*^9}, {3.484914455515625*^9, 3.484914455765625*^9}, {
   3.484918226015625*^9, 3.484918240453125*^9}, {3.484918629546875*^9, 
   3.4849186456875*^9}, {3.484918747921875*^9, 3.484918748234375*^9}, {
   3.48491878525*^9, 3.484918786640625*^9}, 3.485000486203125*^9, {
   3.4850005416875*^9, 3.4850005419375*^9}, {3.48500121725*^9, 
   3.48500121771875*^9}, {3.559545534734786*^9, 3.559545539163333*^9}, {
   3.559545726282887*^9, 3.559545727327804*^9}, {3.560539577802354*^9, 
   3.560539581603265*^9}}],

Cell[BoxData[
 RowBox[{"0.`", "\[VeryThinSpace]", "+", 
  RowBox[{"0.06750000000000002`", " ", 
   SuperscriptBox["x", "2"]}], "-", 
  RowBox[{"0.00852589285714286`", " ", 
   SuperscriptBox["x", "3"]}]}]], "Output",
 CellChangeTimes->{3.577701681591515*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"bsplines", "[", 
   RowBox[{"[", 
    RowBox[{"4", ",", "1", ",", "1", ",", "1"}], "]"}], "]"}], 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     SuperscriptBox[
      SubscriptBox["B", "4"], "4"], " ", "0"}], " ", "\[LessEqual]", "  ", 
    "x", " ", "<", " ", "5.33"}], " ", "*)"}], "    "}]], "Input",
 CellChangeTimes->{{3.4826639458125*^9, 3.48266394865625*^9}, {
   3.48266465525*^9, 3.4826646664375*^9}, {3.482664763515625*^9, 
   3.48266478965625*^9}, {3.484914455515625*^9, 3.484914455765625*^9}, {
   3.484918226015625*^9, 3.484918240453125*^9}, {3.484918629546875*^9, 
   3.4849186456875*^9}, {3.484918747921875*^9, 3.484918748234375*^9}, {
   3.48491878525*^9, 3.484918786640625*^9}, 3.485000486203125*^9, {
   3.4850005416875*^9, 3.4850005419375*^9}, {3.48500057615625*^9, 
   3.485000587609375*^9}, {3.487659345046875*^9, 3.487659345484375*^9}, {
   3.559545541057353*^9, 3.559545542526918*^9}, {3.559545579526224*^9, 
   3.559545585811461*^9}, {3.559545731237384*^9, 3.559545732188877*^9}, {
   3.560539585240372*^9, 3.560539587961415*^9}}],

Cell[BoxData[
 RowBox[{"0.`", "\[VeryThinSpace]", "+", 
  RowBox[{"0.0016071428571428575`", " ", 
   SuperscriptBox["x", "3"]}]}]], "Output",
 CellChangeTimes->{3.577701681624716*^9}]
}, Open  ]],

Cell["...  on the second interval", "Text",
 CellChangeTimes->{{3.482664394578125*^9, 3.482664468984375*^9}, {
  3.482664514625*^9, 3.482664539265625*^9}, {3.48275498540625*^9, 
  3.48275501025*^9}, {3.482755052734375*^9, 3.482755109421875*^9}, {
  3.48497849896875*^9, 3.484978499578125*^9}, {3.484978533796875*^9, 
  3.484978604484375*^9}, {3.484978754390625*^9, 3.48497884175*^9}, {
  3.484978883515625*^9, 3.484978931140625*^9}, {3.48499782309375*^9, 
  3.4849978416875*^9}, {3.487678947921875*^9, 3.487679004125*^9}, {
  3.487679036984375*^9, 3.4876790456875*^9}},
 FontFamily->"Times New Roman",
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"bsplines", "[", 
   RowBox[{"[", 
    RowBox[{"2", ",", "1", ",", "2", ",", "1"}], "]"}], "]"}], 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     SuperscriptBox[
      SubscriptBox["B", "2"], "4"], " ", "5.33"}], " ", "\[LessEqual]", " ", 
    "x", " ", "<", " ", "8.33"}], " ", "*)"}]}]], "Input",
 CellChangeTimes->{{3.482664695234375*^9, 3.482664696796875*^9}, {
   3.484912448203125*^9, 3.4849124485625*^9}, {3.484917832671875*^9, 
   3.48491783290625*^9}, {3.48491790596875*^9, 3.484917977078125*^9}, {
   3.484918312125*^9, 3.484918321234375*^9}, {3.484918499265625*^9, 
   3.48491853634375*^9}, {3.484918573890625*^9, 3.48491857434375*^9}, 
   3.48491885628125*^9, {3.4849189955*^9, 3.48491899634375*^9}, 
   3.484975175890625*^9, {3.4850006569375*^9, 3.48500067240625*^9}, {
   3.485000754046875*^9, 3.48500075446875*^9}, {3.485000791125*^9, 
   3.485000791640625*^9}, {3.4850011061875*^9, 3.48500110915625*^9}, {
   3.4850012266875*^9, 3.48500122715625*^9}, {3.48765939428125*^9, 
   3.487659394609375*^9}, {3.559545600759519*^9, 3.559545604784223*^9}, {
   3.55954568711392*^9, 3.559545687975394*^9}, {3.560539592381041*^9, 
   3.560539596193262*^9}}],

Cell[BoxData[
 RowBox[{"2.777777777777779`", "\[VeryThinSpace]", "-", 
  RowBox[{"1.0000000000000007`", " ", "x"}], "+", 
  RowBox[{"0.12000000000000008`", " ", 
   SuperscriptBox["x", "2"]}], "-", 
  RowBox[{"0.004800000000000004`", " ", 
   SuperscriptBox["x", "3"]}]}]], "Output",
 CellChangeTimes->{3.577701681652173*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"bsplines", "[", 
   RowBox[{"[", 
    RowBox[{"3", ",", "1", ",", "2", ",", "1"}], "]"}], "]"}], 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     SuperscriptBox[
      SubscriptBox["B", "3"], "4"], " ", "5.33"}], " ", "\[LessEqual]", " ", 
    "x", " ", "<", " ", "8.33"}], " ", "*)"}]}]], "Input",
 CellChangeTimes->{{3.4826639458125*^9, 3.48266394865625*^9}, {
   3.48266465525*^9, 3.4826646664375*^9}, {3.482664763515625*^9, 
   3.48266478965625*^9}, {3.484914455515625*^9, 3.484914455765625*^9}, {
   3.484918029859375*^9, 3.484918030171875*^9}, {3.484918369875*^9, 
   3.48491837971875*^9}, {3.484918590390625*^9, 3.48491859365625*^9}, {
   3.484918886796875*^9, 3.48491889828125*^9}, {3.484918983734375*^9, 
   3.484919007453125*^9}, 3.48500067925*^9, {3.485001136671875*^9, 
   3.485001137125*^9}, {3.485001231328125*^9, 3.485001231765625*^9}, {
   3.4876593994375*^9, 3.487659399921875*^9}, {3.55954560659847*^9, 
   3.559545621751461*^9}, {3.559545682820032*^9, 3.559545683751814*^9}, {
   3.560539600100677*^9, 3.560539603048744*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "2.8717948717948723`"}], "+", 
  RowBox[{"1.6153846153846156`", " ", "x"}], "-", 
  RowBox[{"0.23538461538461547`", " ", 
   SuperscriptBox["x", "2"]}], "+", 
  RowBox[{"0.01040439560439561`", " ", 
   SuperscriptBox["x", "3"]}]}]], "Output",
 CellChangeTimes->{3.577701681680294*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"bsplines", "[", 
   RowBox[{"[", 
    RowBox[{"4", ",", "1", ",", "2", ",", "1"}], "]"}], "]"}], 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     SuperscriptBox[
      SubscriptBox["B", "4"], "4"], " ", "5.33"}], " ", "\[LessEqual]", " ", 
    "x", " ", "<", " ", "8.33"}], " ", "*)"}]}]], "Input",
 CellChangeTimes->{{3.4826639458125*^9, 3.48266394865625*^9}, {
   3.48266465525*^9, 3.4826646664375*^9}, {3.48266474965625*^9, 
   3.482664751828125*^9}, {3.48491439440625*^9, 3.484914451171875*^9}, {
   3.4849147040625*^9, 3.484914723890625*^9}, {3.48491894675*^9, 
   3.484918967484375*^9}, {3.484919010046875*^9, 3.484919011359375*^9}, {
   3.484919228046875*^9, 3.484919228421875*^9}, {3.48497494140625*^9, 
   3.484974942046875*^9}, 3.48500068178125*^9, {3.48500115834375*^9, 
   3.485001158703125*^9}, {3.487659403734375*^9, 3.4876594040625*^9}, {
   3.559545624323874*^9, 3.559545641792288*^9}, {3.559545678733473*^9, 
   3.559545679491757*^9}, {3.560539612775582*^9, 3.560539615375175*^9}}],

Cell[BoxData[
 RowBox[{"1.7672583826429977`", "\[VeryThinSpace]", "-", 
  RowBox[{"0.9940828402366862`", " ", "x"}], "+", 
  RowBox[{"0.18639053254437868`", " ", 
   SuperscriptBox["x", "2"]}], "-", 
  RowBox[{"0.010042265426880812`", " ", 
   SuperscriptBox["x", "3"]}]}]], "Output",
 CellChangeTimes->{3.5777016817101727`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"bsplines", "[", 
   RowBox[{"[", 
    RowBox[{"5", ",", "1", ",", "1", ",", "1"}], "]"}], "]"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     SuperscriptBox[
      SubscriptBox["B", "5"], "4"], " ", "5.33"}], " ", "\[LessEqual]", " ", 
    "x", " ", "<", " ", "8.33"}], " ", "*)"}]}]], "Input",
 CellChangeTimes->{{3.48500119525*^9, 3.48500119878125*^9}, {
  3.48500123746875*^9, 3.485001239875*^9}, {3.487659407296875*^9, 
  3.487659407375*^9}, {3.487659489296875*^9, 3.487659489703125*^9}, {
  3.559545644258776*^9, 3.559545673720457*^9}, {3.560539605774153*^9, 
  3.560539609469966*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "0.6732412886259038`"}], "+", 
  RowBox[{"0.37869822485207094`", " ", "x"}], "-", 
  RowBox[{"0.0710059171597633`", " ", 
   SuperscriptBox["x", "2"]}], "+", 
  RowBox[{"0.004437869822485206`", " ", 
   SuperscriptBox["x", "3"]}]}]], "Output",
 CellChangeTimes->{3.5777016817396297`*^9}]
}, Open  ]],

Cell["and  on the third interval", "Text",
 CellChangeTimes->{{3.482664394578125*^9, 3.482664468984375*^9}, {
  3.482664514625*^9, 3.482664539265625*^9}, {3.48275498540625*^9, 
  3.48275501025*^9}, {3.482755052734375*^9, 3.482755109421875*^9}, {
  3.48497849896875*^9, 3.484978499578125*^9}, {3.484978533796875*^9, 
  3.484978604484375*^9}, {3.484978754390625*^9, 3.48497884175*^9}, {
  3.484978883515625*^9, 3.484978931140625*^9}, {3.48499782309375*^9, 
  3.4849978416875*^9}, {3.487678947921875*^9, 3.487679004125*^9}, {
  3.487679036984375*^9, 3.4876790456875*^9}, {3.48768067259375*^9, 
  3.487680702234375*^9}},
 FontFamily->"Times New Roman",
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"bsplines", "[", 
   RowBox[{"[", 
    RowBox[{"3", ",", "1", ",", "3", ",", "1"}], "]"}], "]"}], 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     SuperscriptBox[
      SubscriptBox["B", "4"], "4"], " ", "8.33"}], " ", "\[LessEqual]", " ", 
    "x", " ", "<", " ", "14.0"}], " ", "*)"}], " "}]], "Input",
 CellChangeTimes->{{3.4826639458125*^9, 3.48266394865625*^9}, {
  3.48266465525*^9, 3.4826646664375*^9}, {3.48266474965625*^9, 
  3.482664751828125*^9}, {3.48491439440625*^9, 3.484914451171875*^9}, {
  3.484919309734375*^9, 3.484919313453125*^9}, {3.484919409390625*^9, 
  3.48491945521875*^9}, {3.484919517671875*^9, 3.4849195189375*^9}, {
  3.485001272859375*^9, 3.48500129928125*^9}, {3.487659426203125*^9, 
  3.487659426671875*^9}, {3.559545747894636*^9, 3.559545756676601*^9}, {
  3.560539619633887*^9, 3.560539622249725*^9}}],

Cell[BoxData[
 RowBox[{"3.9909502262443417`", "\[VeryThinSpace]", "-", 
  RowBox[{"0.8552036199095018`", " ", "x"}], "+", 
  RowBox[{"0.061085972850678696`", " ", 
   SuperscriptBox["x", "2"]}], "-", 
  RowBox[{"0.0014544279250161595`", " ", 
   SuperscriptBox["x", "3"]}]}]], "Output",
 CellChangeTimes->{3.577701681770042*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"bsplines", "[", 
   RowBox[{"[", 
    RowBox[{"4", ",", "1", ",", "3", ",", "1"}], "]"}], "]"}], 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     SuperscriptBox[
      SubscriptBox["B", "4"], "4"], "  ", "8.33"}], " ", "\[LessEqual]", " ", 
    "x", " ", "<", " ", "14.0"}], " ", "*)"}], " "}]], "Input",
 CellChangeTimes->{{3.4826639458125*^9, 3.48266394865625*^9}, {
   3.48266465525*^9, 3.4826646664375*^9}, {3.48266474965625*^9, 
   3.482664751828125*^9}, {3.48491439440625*^9, 3.484914451171875*^9}, {
   3.484919309734375*^9, 3.484919313453125*^9}, {3.484919409390625*^9, 
   3.48491945521875*^9}, {3.484919517671875*^9, 3.4849195189375*^9}, 
   3.48500130790625*^9, {3.485001362109375*^9, 3.48500136253125*^9}, {
   3.559545758537632*^9, 3.559545773190339*^9}, {3.560539625124831*^9, 
   3.560539627449423*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "8.325013820355842`"}], "+", 
  RowBox[{"2.639135152842896`", " ", "x"}], "-", 
  RowBox[{"0.24959562662517126`", " ", 
   SuperscriptBox["x", "2"]}], "+", 
  RowBox[{"0.0073971809399011905`", " ", 
   SuperscriptBox["x", "3"]}]}]], "Output",
 CellChangeTimes->{3.5777016818004637`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"bsplines", "[", 
   RowBox[{"[", 
    RowBox[{"5", ",", "1", ",", "2", ",", "1"}], "]"}], "]"}], 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     SuperscriptBox[
      SubscriptBox["B", "5"], "4"], "  ", "8.33"}], " ", "\[LessEqual]", " ", 
    "x", " ", "<", " ", "14.0"}], " ", "*)"}], " "}]], "Input",
 CellChangeTimes->{{3.4826639458125*^9, 3.48266394865625*^9}, {
   3.48266465525*^9, 3.4826646664375*^9}, {3.48266474965625*^9, 
   3.482664751828125*^9}, {3.48491439440625*^9, 3.484914451171875*^9}, {
   3.484919309734375*^9, 3.484919351984375*^9}, {3.48491950746875*^9, 
   3.484919512984375*^9}, {3.48491956040625*^9, 3.484919581984375*^9}, {
   3.484975095125*^9, 3.484975095609375*^9}, 3.48500130996875*^9, {
   3.48765943234375*^9, 3.487659432734375*^9}, {3.559545777453155*^9, 
   3.559545795679684*^9}, {3.560539630842718*^9, 3.560539631050738*^9}, {
   3.560539713421746*^9, 3.56053971446927*^9}}],

Cell[BoxData[
 RowBox[{"8.514401473207773`", "\[VeryThinSpace]", "-", 
  RowBox[{"2.9288531694080526`", " ", "x"}], "+", 
  RowBox[{"0.3259002501514515`", " ", 
   SuperscriptBox["x", "2"]}], "-", 
  RowBox[{"0.01143837686996339`", " ", 
   SuperscriptBox["x", "3"]}]}]], "Output",
 CellChangeTimes->{3.577701681834467*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"bsplines", "[", 
   RowBox[{"[", 
    RowBox[{"6", ",", "1", ",", "1", ",", "1"}], "]"}], "]"}], 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     SuperscriptBox[
      SubscriptBox["B", "6"], "4"], "  ", "8.33"}], " ", "\[LessEqual]", " ", 
    "x", " ", "<", " ", "14.0"}], " ", "*)"}], " "}]], "Input",
 CellChangeTimes->{{3.4826639458125*^9, 3.48266394865625*^9}, {
   3.48266465525*^9, 3.4826646664375*^9}, {3.48266474965625*^9, 
   3.482664751828125*^9}, {3.48491439440625*^9, 3.48491448825*^9}, {
   3.484919547640625*^9, 3.484919584640625*^9}, 3.485001312078125*^9, {
   3.559545799431747*^9, 3.559545812707259*^9}, {3.560539717606169*^9, 
   3.560539720621361*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "3.1803378790962715`"}], "+", 
  RowBox[{"1.144921636474658`", " ", "x"}], "-", 
  RowBox[{"0.13739059637695897`", " ", 
   SuperscriptBox["x", "2"]}], "+", 
  RowBox[{"0.0054956238550783595`", " ", 
   SuperscriptBox["x", "3"]}]}]], "Output",
 CellChangeTimes->{3.577701681847333*^9}]
}, Open  ]],

Cell["We plot the B-Splines separately", "Text",
 CellChangeTimes->{{3.482664394578125*^9, 3.482664468984375*^9}, {
   3.482664514625*^9, 3.482664539265625*^9}, {3.48275498540625*^9, 
   3.48275501025*^9}, {3.482755052734375*^9, 3.48275518615625*^9}, {
   3.4827552320625*^9, 3.48275526790625*^9}, {3.48499732775*^9, 
   3.48499733709375*^9}, {3.484997378734375*^9, 3.4849973836875*^9}, 
   3.48499786365625*^9, 3.559508299363243*^9},
 FontFamily->"Times New Roman",
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"p1", "=", " ", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"bsplines", "[", 
     RowBox[{"[", "1", "]"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", "14"}], "}"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
    RowBox[{"Epilog", "->", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Text", "[", 
        RowBox[{
         RowBox[{"Style", "[", 
          RowBox[{"symB1", ",", "Medium"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"2", ",", "0.6"}], "}"}]}], "]"}], ",", " ", "symKnots"}], 
      "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4826639558125*^9, 3.48266397771875*^9}, {
  3.48498071790625*^9, 3.48498075084375*^9}, {3.4849971371875*^9, 
  3.484997151921875*^9}, {3.484997229890625*^9, 3.484997235328125*^9}, {
  3.487680759609375*^9, 3.487680814046875*^9}, {3.559485153716068*^9, 
  3.55948516247113*^9}, {3.559485441300609*^9, 3.559485451797678*^9}, {
  3.559485903809112*^9, 3.559485906463521*^9}, {3.559485979922824*^9, 
  3.559485988347174*^9}, {3.55948639520236*^9, 3.55948640479852*^9}, {
  3.559486454195708*^9, 3.559486456389125*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxl0Xc81e0bB/Bj75U9Kg4hmSEr9/UNlURlF2VkE6kkaR2erEQeSScNKyXh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      "]], LineBox[CompressedData["
1:eJxN0HlM02cYB/CW06GhXBNoKZdiqayTFXHlds7hELxABIFCODoOS0FgILA6
hyIEgoQjsnKIygSmiKDIxhAiWA0DBAmIlBiXIRRKEIZWJoXSbcny+/ZNnrz5
/PHkeb6PTVSSP0+DRCIJ/63//rPFf046BX28l/T/m7jK2RAHw+y7xTYnQmDp
mEfcGS58mFr5/kE0bHXD38A7Gf5VMlr14DTsrx/IcEqFL2YEeVqnwws+YXxF
tlr/Iq+vOQ8+ysk8Z1oL5wzU/jX3FO4tJ8XdZ25FnvqC4oNF8HB+TY/LPFx9
T1K3fNiUsPcPTPpoKzxiqXFNX98M99DWem6UAqd1XjI+PQyXmbBkH3aaE85v
lwt8LsHh9l+p3s3Deq+7vWKPUAlXJPYU7L4Nk6te8B0+ohH+wtBUNc+Ho4L+
qNLqh09Kn81JP7UgzDIbH3xbAk+Zx3QGL8KJMbSQPH86YcnZUE2DFtjW/c6X
vZstMX/fJ7s9ktRsxt5lNAibfh45ecfRinD/hzqLjDI4oiAp/sclmMdmO/Uw
rQkX6i7viQ6GrZpddKgXYcvVy6z7v8D6TZwQ5Qwcr7n0imlmQ7itVxaneQAW
BAi6l9PgsnxdvrgebrSbsdz/HLaPfcFs1LVFvqwAko0LvCI3fukdC+81kVGO
ieDsKg2fTX3wdvmNQ2PvYc4y9+YFxjbCHidCtkwFwrcjTj3Zlg8Xuur4ZXXA
IcKZceEsXB4j6eCZbyfcfc/wuuIAHNAQPpWaBQfxnRfJTbCf6KjKfRK+lXAu
LmyLHeG1Ovm4vRv8W/NbA714+DVXu264Elamhbnu+x3Ocexjitbg9K6uaS3W
DuS5+/dP9FD4Z1/vLmoRLPOTTIo74QqrlUfnZXDLZYY2g8bAft/W+Gb4wLtW
GfO3suHy6ZWioptw3LUjyvMTcINGlzhcz57w+ICgRMqBk12c2/1PwZlncutH
q+EUK2o1eUCtP+GRzFgJO1i2uo86MAkvXrcPbTgJWwy2jUQUwm7c3EOPO+DH
pQk2lAW4SyR5mEjfSbh+UxEv0xdW0AKj4oWwZ0VkjE4T/KY9pzvvFby5kTVN
N3AgbE6mUyI94dIN69L8ZHg9Op7KrYXHKt0E3k9hBSX9uOEQbJ3b4vpSzfwk
O92UZ7D2fsrVmlF4z5upEbkEFnkVONdJ4YdtYppgFpYyVWSXOZhtkjY0JIP7
57ixigW1/Us+Ex17B9vq8r+3kMNff1fPm1Vz+Tc0tnAFZrlpDzSuwsdbvFpT
FXCWXVaF5xr8hLIUPbYOL1xgHqxVwkaKaMeEDZiTdGWrswoOn55YV6n5HxmK
pdc=
      "]]}, {}}, {{}, {}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  Epilog->{
    InsetBox[
     FormBox[
      StyleBox[
      "\"\\!\\(\\*SubsuperscriptBox[\\(B\\), \\(1\\), \\(4\\)]\\)\"", Medium, 
       StripOnInput -> False], TraditionalForm], {2, 0.6}], {
     InsetBox[
      FormBox[
       StyleBox["\"\[FivePointedStar]\"", Medium, StripOnInput -> False], 
       TraditionalForm], {0, 0}], 
     InsetBox[
      FormBox[
       StyleBox["\"\[FivePointedStar]\"", Medium, StripOnInput -> False], 
       TraditionalForm], {5.33, 0}], 
     InsetBox[
      FormBox[
       StyleBox["\"\[FivePointedStar]\"", Medium, StripOnInput -> False], 
       TraditionalForm], {8.33, 0}], 
     InsetBox[
      FormBox[
       StyleBox["\"\[FivePointedStar]\"", Medium, StripOnInput -> False], 
       TraditionalForm], {14, 0}]}},
  Method->{},
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.577701681905755*^9},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"p2", "=", " ", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"bsplines", "[", 
     RowBox[{"[", "2", "]"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", "14"}], "}"}], ",", 
    RowBox[{"Epilog", "->", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Text", "[", 
        RowBox[{
         RowBox[{"Style", "[", 
          RowBox[{"symB2", ",", "Medium"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"5", ",", "0.4"}], "}"}]}], "]"}], ",", " ", "symKnots"}], 
      "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4826639558125*^9, 3.482664008109375*^9}, {
   3.48498076878125*^9, 3.484980775265625*^9}, {3.484981148359375*^9, 
   3.48498114865625*^9}, 3.484997240046875*^9, 3.487680889640625*^9, {
   3.48768092903125*^9, 3.4876809698125*^9}, {3.559485893728352*^9, 
   3.559485898399949*^9}, {3.559485935629669*^9, 3.559486072261866*^9}, {
   3.559486413639844*^9, 3.559486417541002*^9}, {3.559509003934311*^9, 
   3.559509017314349*^9}, {3.559509548378906*^9, 3.559509550375968*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV13k8VHsUAPC5MyNEdi/Zyq5CVFR6nFOpJ1lLlCch26iUFPHqVUoSSbwU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      "]], LineBox[CompressedData["
1:eJwt03k8VWsXB/DDVaLIGBnqdI25yFBCzrMOSgjhVI6MGW5J5shQQkSUhoMM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      "]], LineBox[CompressedData["
1:eJxNz30s1AEYB/BDXibriAnn/aVzmZF27byElZGQvNXCMS+X144h5ZDyskyz
RcZO5K3OhYySop0sL1NKRHIyf8jbmZepS3Mc1dZ+33u2Z88+fzzPvo9JZJI/
S55EIjH/9r9ZF1Krk9Bs7Er6X0UU5qhWC9x5T+L0TcaHMunasa1wj2/z0O12
2HC73PrFS3glx/M8+5XMPaVdNrUL9tGKaON2w1k2ViduCuBp1huGRx9c/nnp
jHBEJk8LI1i6AMcpbMzSdEwId7wVxSp4wOwAds9mGny/UDmxnwfzLRYM3b7A
ljFfaXxlU8JHOAEkE3t4S6w54x4Du2qJyH5cOPOBvKfKEGwufuwz8QtmbDKb
8qlmhE9dDFabC4KfhicMmhXCdx2UvDldcHD2wmT2ElwWLexi6ZoT7nmuUS/x
gAMaw+ZSOfClRPq6XAvszb2w7zQNN8ffig1VsyC80yCetHSEu1t/qKvGwd+Z
ig2fKmFpWqjD6Xdwru0QjbsDpwsE8wesj+KfZ78fGYTAT7zcBXrFsMhbON3/
Gq4w2urLE8Ft5VRFKoWKfNeqva57wjbb1JXmTLhsfqu4uAmOrfOV5k3BjfKC
/jBVS8KTw+ySRQacbE/v9E+AM24U8Mar4BQjvSq5YZn9+D6RphS2Mmx3Grei
EV6vtwxpvAzrf+gYC78LOzILfAa64IHSeBPyKizgCnuvGhwjzFMpZmV4wRJK
UGRcNuxcERGt1AKvdeb23JmFD/Kt5w3UrQjryhmQI5zh0j3j0sJkeDcqTo9Z
A09UOrLdP8IScnqgxghsXNDmMCPjxCQL5ZRRWNGNXFs9Dp9cmxsTC2GuSxG9
YRHu7einsJfgRdq+nP0ybKeVNjIigt8vM2MkqzL5S45z/X7CpsqJOfpi+GwW
j7Uk47IrFLvsLdjaUXGYvw0Htrm0p0pgjgWnwnkHHiRvRE3swqv5tHM1Uviw
JMo2fg9mJD3Upu/DYfNTu/sy/gNT+EKI
      "]]}, {}}, {{}, {}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  Epilog->{
    InsetBox[
     FormBox[
      StyleBox[
      "\"\\!\\(\\*SubsuperscriptBox[\\(B\\), \\(2\\), \\(4\\)]\\)\"", Medium, 
       StripOnInput -> False], TraditionalForm], {5, 0.4}], {
     InsetBox[
      FormBox[
       StyleBox["\"\[FivePointedStar]\"", Medium, StripOnInput -> False], 
       TraditionalForm], {0, 0}], 
     InsetBox[
      FormBox[
       StyleBox["\"\[FivePointedStar]\"", Medium, StripOnInput -> False], 
       TraditionalForm], {5.33, 0}], 
     InsetBox[
      FormBox[
       StyleBox["\"\[FivePointedStar]\"", Medium, StripOnInput -> False], 
       TraditionalForm], {8.33, 0}], 
     InsetBox[
      FormBox[
       StyleBox["\"\[FivePointedStar]\"", Medium, StripOnInput -> False], 
       TraditionalForm], {14, 0}]}},
  Method->{},
  PlotRange->{{0, 14}, {0., 0.5442085311866631}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{
  3.577701682031973*^9},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"p3", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"bsplines", "[", 
     RowBox[{"[", "3", "]"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", "14"}], "}"}], ",", 
    RowBox[{"Epilog", "->", 
     RowBox[{"{", " ", 
      RowBox[{
       RowBox[{"Text", "[", 
        RowBox[{
         RowBox[{"Style", "[", 
          RowBox[{"symB3", ",", "Medium"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"8", ",", "0.5"}], "}"}]}], "]"}], ",", "symKnots"}], 
      "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4826639558125*^9, 3.482664036125*^9}, {3.482664124*^9, 
   3.482664124828125*^9}, {3.482664276875*^9, 3.482664305078125*^9}, {
   3.484981143859375*^9, 3.48498116409375*^9}, 3.484997243734375*^9, {
   3.48768100396875*^9, 3.48768103378125*^9}, {3.487681065109375*^9, 
   3.487681097328125*^9}, {3.487681462046875*^9, 3.487681474953125*^9}, {
   3.559486430179135*^9, 3.559486450617174*^9}, {3.559486545945367*^9, 
   3.559486548398707*^9}, {3.559508987787552*^9, 3.559508993288877*^9}, 
   3.559509556704695*^9}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV1nk8VU8UAHAe2XrWdy9CKrtCtoTqnalICxGSSItEWUuRdluyJYVQdolk
T4qIZO8lS5YfWR+lkr1eFH7TX/P5fubcmTNzzr2fu87ew/wUhY2NjYudje3f
yPOKRevTvUTP0YhWs/ep3Zr61EF2UuYQGJSvv79OyJ9eFJBdWC7jBFayL7OX
BdLoTdatY2w25+DCVFn4R9NiepnHe590mYsQNdy5pMFfTX8a1Miz6/tVCFb3
/WykxaA3N9sbzx32g6MZA04Txh/pu3qORxvSA+Ez9VqdWUov/fXo0U/3ZW5B
fKp8eSvvMF1n+ojcGFcoGCXRzx9r/0zP/2vjqvc9HHJ+yVRUqIzTlXgOF4d+
uAPeIjpO43zT9JaQDUs/Dt+FuNb/3PYbzdHD76xPE2XcgxavRuqVdyz67hjl
XUCPBq3yA0dPx/6hV6UoRkTKxMKXuxvfqHFQ4OpjBc3S6DiIHXhdk2XJCbo5
8p1DXA/g5m8tq8lGLih4ISut9T0BjLjOHGpeQwXXCplqW7sk2PjSa+gImyAo
vV3nGPghGSq72MTMKcJg9kWw69vhVNh2IS5VbisBas6CyssiaZB8XiiqeZYE
6g+BKzRGGjS0EWz7KsSgYYZ/zVb6Iwh2E3QqvCkJ25dWOt2WyQSFFM9I1s91
sNZvZWlqbya8KXZtnxWXhSWOlStLorPAouSS+wcDOSjj5cvv58qGr/0zpWte
KIAmycPa+D0H8mzdKRQuFRCK495j8CgX2t2o9p0eqjAhwf3Q2i4PVqzn0/Yd
VoPstVzg9yEfwm/IJylOq4OwqP/Or4cL4Ys1S+qTvDb4dvm5ni8pBOGD+2r4
lrRhKs4vZlGkCFoCf2ok92yCZkm/L8KMItiaN/D5V8pmCF3nG6ZPL4bO88Kn
zOy3AEX1enuYzAuIjYy4G9m7HYw2Z+b0B72AOun9zh+9d0D49pabGt9fgDs9
fyGT2AmklYxu17OXcGW2Ke/vIQNQulGXIGNYBvnX4m0PLO4C01YBx1KnCvC2
Xe1nWm0M0b2bgcqoALesRyHHgkyge/S4+DH11yASnvLnt/F+sF8oauKcfw21
3c7BdUOm8OruUzElwypwPb0taTD6ADSXmV493/kG7HbwOrivOghTMDKWwFMN
P6cbBLLvHARarc/BOv1qCPBQMVLktgLrD6lqq5KrQXbTqtjReSsYYs4OvnZ6
C5Q7MhtdJ6xhjhpnyDdfAx2ppVJeNDuQPDYokCrZAF+1hJ35FE6CmnGp78W9
DfCUPaa62eMkIL17MyaXGiA26nSIVNlJcKQZdC50NkDYrz5BSzMHKKrPTLS8
1wipNhJv1ANOwV51DxUe3ndwKTupIoJyGi6zL+3x+PUeBAYXHUyc3OD2ROcr
Q/lm+Jx/sVKs2g1SevNVpSybwbJbl3V6tTvUPT8h3FjYDIHyZ3OSO9xB2Lm2
W8btA9x6coqlqnAWLM/UaX0/1wL/Bf79cf3JORhvvV2dNNYKoKb6YcPwBVDV
gBPRy62Qb8Y4+UnUC9wjp5ZDRNsgZ9dIOGOfF0zut9jmZdAG6eUML5cSL5h5
J/5yX0ob9GxJi0qL8Ib52vTc34faYWLIM/jHXh/gKiuNM6//CB9SDJOLZq7A
mrRRd67HXWBbu5PptuQH9y1S9SZed0GBetqoj6w/UFfYcXZ2dcH06gBm5m5/
+O30MT6DtxvQEYnSc1H+0Kr6tsbArRtmL1VKF68PgIDSFIkA7f+A1TDuOnEs
EL602NYtV/dA1UbxPv7RIMhfbl09P9AHPLMd+5Osw0F6dKPLZlYfcFy4r+MU
EA7hTbdfegn0Q5hB4ur9eeHgHLPHYmZrP+zrcO7w4rwNchveBH+P74fb5b7H
VIpuQ5xVwWyfxQA09Hhc0qDdgSqreoehk4Nw4XbEgfKfkZCVm6Ff1zUESmOD
Q1PzUaCQluPUsTgCulWLrz2MHsKdXDMTDXIM9gRryBeUpAK77pZbdqxv8Gid
YSM5kQHreM/u+CA2AcYvc399nsiGjJyfWcF+U+D0KHR+8G8+bBxk52+ZnAaT
fSmx2x4VgdDmZxr612aBk8lqSSh8Dt7vb/lSp+aAIr7goY3fM61b7JHs/r8g
9268Q4p0OZxiNP5JoP4GgV9B3tUplSB54PndlKvzEHHqbodswBtQmjccq1v5
B6ZN99zKcH4LZYPzpw/6/oWZjcfsLKEW0r+bZ3MRSzC8ujnz7u56YPdfMDqa
sgzrT8yCjWUjTD8d5hYMYUNV1AWzU7veQUSWhLHvAXZUU50mvsHlPfwwcMjI
oFJQW9PzPec8PwC3YoeKdA0FVZ9LOmFX1gKMB3GEUhgHul5i9iukvRUs8tyE
PxtwIjPba9bWvW0QZBHjvklgBWp4kkkVWmiH8/SR+a72FUhkysjwIa0DZBsN
HqiFc6FQ34v0uFWdcH2U9UDUkhtlKd8dMNXugoep5QVFAjwoNpBxmq7fDefT
s+ZSa3nQRfqn9mBd3Ec6X+JkwnnRnyCdPX9398A2583mhwz5ULTHz587d/aC
2sYel9UCK9H8vL7sPZNPMBQV8SC2cSX609ti24P6wJTuzHLwo6KnN76b5in3
w5nLccVvd/Mj2ysHpxXXDIChVXdQJ0UA1d5pCJv7OwCMt86llxkCKHukWcHE
cxAELspJeN4TRLe1Y3S3DAwC7yirPkJeCL3zDyzZiobgeBeXVm6IECq1Ko3k
fjQEcfFJWfJfhJCn6au37/4MQd7Snuf1O4QRSzWS29t4GB7kSHtqPhZGDyX1
jz9MHAan9Vf1WBQR1E9E6nEyh4F3mlIY6CSC3tle5GFTZEKITWLlliYRZH3+
Cy+PPRO+RVV1GyvQUBH775T+u0yYrR2FT4o0JKQTZZF0jwl/WXyZLso0dJVf
+ppdFBMEjhz0ClWhIT21ZO2eaCZoyH0TbtCkIcm5+5rvY5ngU0zbtxNoSMXn
gWV8IhO4Ohwr9KxpyCV20L8xiwnrRPnTFEJpSGRoWCywggnOLkfOPQyjIbfH
6dair5lQVPUUCd2mod7BO1JZ2Dtc9g7M36GhVy3xqk2VTHCouiX1PoaGPh7d
5slTzYRMZ0rs+VQakjYSvuBWxwTVSlZY1UsaWuo7wuhuZoI3YWS7qYyG/F/a
7bP9wITXZ+6vz35FQ5qfKfv6sPcTmxqjXtPQiNXXdwMtTDh7xpPLqQbbdKq1
v40Jz2g/fPlb8HpF2n01nUzQOz3sZfOFhtzbuU+q9zPhkf2M08QYDTHg66Ec
bCE7io3/NxpKWdhXrDjAhLEDMvTsHzSU4KWWLjXIhPtb7LkWZmnIUyfWanmI
CXMCw/fj2QgUGum1mDnKhILnQy+6VxGojN8i9uY4E6QKpp+4ShJo5L+gvRPY
wdnsCWyrCSRUw2lv9YMJx5LX+SqtJZAj1adCbgLXJ+TEbh8FAmXLuMqWTTLB
5chQt5gWgU6L8MTUzzBBgWNo3sqYQBRH/GP2mwmrjU3uMU0IdHVxpKcSm4gp
XX/WlEA84glvROaZwKF4zzbEnEDaF4i3JdiDe3dWvLImkJpEYBRrgQnx9zJ8
157C+T8WPnhkkQmRvcKrch0J1Dnpo/MYO1jueqHeaQLVaClfm8T2LrEaNnch
kPMeDn3fJSaY93Ab3DxHIKnFWfcHy0ygyjhzf7tGoDnBywWF7CPA4dKZ7H2D
QBKB3L3T2AvPduhy+BHI09n6jAZlBMYMJc9IBRIoaQOzIA+79gyjaX8ogaRb
Z8ZSOUbgeqFaxLP7BMrRzP3ivGIEvBYeKKA4AhXt5dmZiu26k7uSEY/Pb5zK
1oVt2zEwOZpAIP2nG9IQF/6uz0ceEE8nUJbC7ytU7hGYRrPEtXycb7KMVxDP
CCjlhpCTBXj/uwMz+dhHV60VPVFEIGOjP6Pd2IxpYzHD5wQyGFveoMw7Ao/T
Hq/if0UgHS9i01vsPoFtEjfKCVT8M9F2DJu40i4xXUGgcOGxX1S+EfCzYJPq
qCLQcW6PMEvsI5w20ol1uB7Hpdf3YUednZIWbCDQWvWAuUXspk9Ba/waCRR5
nk9LeuUIbH7+bO0pBp7frkG1wxZx5JdVbcPzLiUqH7F3t6XLJrcTyNJ4xf0p
7Bt0fTnhDgIxfLo9qdQRGBd1kv/ZRaBfKeVBO7Dr66sUK/oIVJVmTmZhL2kd
Uto4gOMPPhCvwtZO+aGUOkig1yoNEV3YaT4S628ycf6at9o5+UfgqvIFFZOv
BELCZ8qtsZ/F8KlWfiMQp/VLS1fsb+ypqhrjBPr0wPTYDexDPe/VyEkCtbBx
v0vH1gxT1OibI1BgtcfCKPYZVoWG6S/cD0c7ZH5ip5y01HzDIlBC80g5h8AI
8G/108pYIFCDWJHhGmyDLDFtsb8EanPcra2CfZnI0w5ZJJCmt160LvbYeM8m
NzYS8VV/yjTFlj58TmeAnUQRF5xsbbAP1nJvPsBBouvtizccsMM1kja/5SRR
/6pw0h27OlFbdxMXicr9lyQvYs/zvtPN5CaRyJ7tUTew1b1P6K3iJdFEJrpy
C9txmKUXxkciy56x9gjsxP0R+osrSbRbUiExBvv3sVG7CH4SMa54WSVgm5/b
6rdGEMfbUZzSsHP8ox4VCJGoLOJZcyY2V/S3+u0iJGrp97idg308Y/v3NhqJ
vKWk0wuwy0riBBxInL9ohmAxNtEwqfFTlEQ1D7+3lWC7/7frYJA4iWSudI+/
xG74lugjJkEi9wBzuzJsmb9zD7MkSeQbgOReYV/lN67UW00inb0h2/+5Uzp9
uEmaRMcf057/i1dXX1hxZC2JBh3rrpdih24/oPxjHYmCbYKTXmCPmGcZX5fF
z5sh4jk23WHZQ1Ae359ox0AhdpyXVVSKAol+X1Vlz8OeCcot0VAiUdUBdZ8n
2MZxnD3VyiQaP1lj8Aj78RPbRYsNJLLxb3FMwmZ7VbR2VAXX58qW/lhsGwav
gbcaiczWjGdHYhf3HXfiVidR6JZGRjC2wOSL0DgNEjkkl+70xT7NJpinrIXv
d9UjwX/1rBZ2bC3TJpH9JQ91N2xvbUK8bzPuFzmDs4ewWwxdtrjrkeglVfLO
Puz1h6qPLuuTSFrUnQLY/ZfOZqyjk8i5TvazLLZuWH1DEZCIstLSisS+lyA9
vnM7iQqePpTgwt5VydB0NMDrbaUm/+v3lBZZK5YhPn8T5dhH7IWhy5eCjUi0
Y+qpZzV2HqdyVfZeEolvK4xOwOYR9WVuMSaRFKU3LRjbXrGL670JiRbizTkv
YIvuvWkyaUaiomt1VbuxHWfPXPpoQaI5BeYJaez/AWeSfVo=
      "]], LineBox[CompressedData["
1:eJwVz3s0lAkYBvBxacvlCPm+GYxLNyZRopgcel86FVZyhmLJJdfJcemGlFQq
RGiPkqWE1JZyKTXbutRSySl2xi1GiplvXJKsiS0p7Ld/vOc5vz+ec553eXAs
L0yRwWDspu//TM6R9Fl7EzidttRgTF0GvcXc+ec+BLovcJ+JaFs9yFm+x5dA
7f376gW0h7sc+Ef9CeSpm90+Rdtdr+Df+hACDfd+5avTvr1WznIPI/DChrjy
T2oyUHRwth8IJ5A9NgJ/0xYEfklRiCTQcs4kIou20U2e5vYDBAbE8cuVaD8W
dxbWHyRQ3ZTxTaIqA57GblPrwwT2RcQ+eEo7NcF7i3E8gZrV3PBE2uMue6Nm
jxOYrG7dNaRC9yfCWirTCCw6fW+gdAndXzniufo8gekGR0cSaH/05g8UZhA4
UXHXz422YWPkl/QsApteVJ6fWiyDs7mxq0JyCUxNkczb0fbgJp5iXidQp+F9
SOUiGYxFzaplF9P/FMgcjtE+U3L8inIpgWbt0nPbaAtUkyvlZQR6hZsH9SnL
gP0upf91OYHGA9U4pySDD6cvcE8JCAzOC31pqiiDlNfXJ0fbCFRNulGgOU/B
7+4nVvgI6T3jbs2v5yhobff1eiki8M3zq/xU2mQv8fhmJ4HcuSyt2R8UlMsy
TwaLCZS2uX7t+05Bx1yCRr+MQJthocmZbxSssPQwF34nML6aWRc9TcGOGouA
LXMECrodPjBpR9moXayYJ/DI1I+LjVMUCOybpzIVSORHlu1cRtvVxb7OeTGJ
XufMk6vlFBwK5rg2aZP4V/gzUfsEBU2XGPxHa0jUuawvqR6lQLWhqH7rWhJL
M3fWOtL2HLLX6jAn0SdSNNM+QoFsU2LtxHoSDZ0db00OU7CoR67OsSHRzF+v
2WSIAmdd6n6BE4msCsbGeAkFbddefD/pR2Kf1LOwVExB762MHNcsEjV/e27B
baEg6DPP7Uk2iXukBQ4VLykYddBXsbpIoonWtrbltGe67qbo5pK4bi4+SqWZ
AqZSW9xoPolO7Pl7Hc8o2BO4dG9qGYn1wwpuO59S0MW8xGmqI1Gds7KCekSB
MP1a4+YxEm22jO4uKKHgWKJJSetHEpPudHZKiikwiaw6FfiJxBZhWBOHdtLP
jXBukkSNwVn5wyIKOBpDDaIvJL7S8ihqLqQgJde8NkKJiTFtw9uFlymwKap7
cJnNxJmtzffjz1NwtUZ8Q+7ORHMj3pNVsRRsP73GoPM+E/OjLdf7bqKg3VCx
REODhUtuPdRImpGC1SLlbu1DLHx8x/+wV5UUjtRlLzsoZOEqHfnNulAp5OpY
fJgx08ULZTHCZaQU0gXTMS7ZushwP3F8plYCAZxtC1NjusgZ/zNiOkgCqtQT
iNilh0t4c3L/2UG4Et2YsbFCD4/8ZKK5I28QFAp7otaq6GMZ+23cGctBcNRi
LoxF6SM/XUmbcWIAgr0HCpVf6WP1wNlp09L38MuwaHR4HRu5Pbs6AqregQXr
TevnX9noY5R30ra+H6S6oXU+E2xsyRlf/an7LUSH6vum8QzQI3/pAT9xH4iT
/ZQ0qw0w6Iqd3d2PYlhhX7W1Sc0Qg+wETrcVxODoZL7RIdYQ0VMxME2pFxxZ
Vuu1Ww1xMianYYrsAabtvr4qSyMUuW221WS9gVczN9gJuUY4WRDo5mLcDYEZ
sfvz/zHCA6lPizbYd0GYlZV14xpjHKz5w3fBuRMyF8ttQnyM0SNWOVIQ2QFG
lZt/0ks1xklr22JGXjvUfHtoP3bHGLF/4kf0lAj+A+Dgd2g=
      "]], LineBox[CompressedData["
1:eJw103k8lN37B/ApiUqipIU0DMZWWYvkXHcRyvJYH0spEtKCIkmpyfJYikoi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      "]]}, {}}, {{}, {}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  Epilog->{
    InsetBox[
     FormBox[
      StyleBox[
      "\"\\!\\(\\*SubsuperscriptBox[\\(B\\), \\(3\\), \\(4\\)]\\)\"", Medium, 
       StripOnInput -> False], TraditionalForm], {8, 0.5}], {
     InsetBox[
      FormBox[
       StyleBox["\"\[FivePointedStar]\"", Medium, StripOnInput -> False], 
       TraditionalForm], {0, 0}], 
     InsetBox[
      FormBox[
       StyleBox["\"\[FivePointedStar]\"", Medium, StripOnInput -> False], 
       TraditionalForm], {5.33, 0}], 
     InsetBox[
      FormBox[
       StyleBox["\"\[FivePointedStar]\"", Medium, StripOnInput -> False], 
       TraditionalForm], {8.33, 0}], 
     InsetBox[
      FormBox[
       StyleBox["\"\[FivePointedStar]\"", Medium, StripOnInput -> False], 
       TraditionalForm], {14, 0}]}},
  Method->{},
  PlotRange->{{0, 14}, {0., 0.6267982749944341}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{
  3.577701682086109*^9},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"p4", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"bsplines", "[", 
     RowBox[{"[", "4", "]"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", "14"}], "}"}], ",", 
    RowBox[{"Epilog", "->", 
     RowBox[{"{", " ", 
      RowBox[{
       RowBox[{"Text", "[", 
        RowBox[{
         RowBox[{"Style", "[", 
          RowBox[{"symB4", ",", "Medium"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"12", ",", "0.5"}], "}"}]}], "]"}], ",", "symKnots"}], 
      "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4826639558125*^9, 3.482664047625*^9}, {
   3.482664136953125*^9, 3.482664137453125*^9}, {3.484981178125*^9, 
   3.48498118625*^9}, 3.484997247609375*^9, 3.487681186453125*^9, {
   3.487681404734375*^9, 3.48768144290625*^9}, {3.559486511398406*^9, 
   3.559486539240104*^9}, {3.559509026755076*^9, 3.55950903234272*^9}, 
   3.559509562272065*^9}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVx3c41f/fwHF7ZGdFy8gqo5BV3q9PZqEUUZSGjCiEZKRsIsleoWOVmV1G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      "]], LineBox[CompressedData["
1:eJwV0n0w1VkYB3BKRNGl9Xa93J+MXW5ebjeUWTzPZfIWZVCkiYoGm7fqelnK
YNuLS0oykZK70nppaUuFWwY7layXW9yIkpwJq+mFdc2tNdrTH2fOfOacZ855
vudYHE4KOrJKRUVlJx3fZk5tEMsrWR97yGd9ReMg5P599dNsvz6GjDdge50M
ui+oxN6xMcDsdo0nbqeewuh18Vm/MwZ4GWxERXHPYDD/SpfLnAHG2vjUtvoN
weXbL2rmdxmi0o91/6PHMHjl2JgN/WmIvN0REqWLHJ6ar5Lo6Bihj1TPqWLT
c+CvUZPrHTfC9PhB9RhmBITS4o3HBum6/L58RXsUSr+z+0fJNUZW8MZHvUuj
kH93MdG32Bit0yzWJiy8gAjrHV//nTPG1rxrieLxMdAiHRCzm42jj3tGxPJx
uJjQJXb8g42dkaLABulLUK0cid+saYJh62UGsRWvQKBr+HUu3gR5ut2RHacn
4HDo60q1XhNMV3w40BX+GvZNy2an7U2RCUidkJlNgp3R876FElO81nZP4pg/
CVPG0dKwD6bIWiNczpyZhIRok/C8IDN0fGJ7SMPvDbzI2r+addMMzyV7h3Ml
b2CTa7Nn9zpz5J03kv4+/wYEHraObknmOCuyTtH0nAKBEd9Br88cs60uyVYX
TIHhtkNjzTwOzv5y5+K7/inoVdaYppVyMB8epLK1CESKk+LKP3Jw8ktqtt2P
BHoOROlaz3Mwnb97YIGavyW07d4CB408312450pAfdRdc0TBwdjiz4XgTuCG
lU69/jIH0crF3FdA4NTBvUJfNQbTN15s8/Am0Pvf4u1HLAZZH6JWBoIIHOHz
t3bZUOfMh+yIJdBuJ5BmchnslB7jvKLWsQn0dN7MoIp6W4IwjkArJzG40ZbB
1kC3MslPBLS0G06UOTDIS8rWXoon0DRj0RLnxGBgqE5x3jECysu6TnoCBpWa
Ttb+GQT8y5kHfd9cGeY2TC0pddiR58FgdYr30P5MAn7igD3LngyGiX7IiTtJ
4EpaQcq0F4OygZCprCwCHkGqd9v9aT+5ObUluQQKNeado8IYxIYN+XvFBL7n
2uux99H7FRyw7aPu9D/6XkatvHM2WFBIYLHkbY37fgbz1by53CICEaZjLHYE
rX9buKQ4Q4C35a85WRSt1+leSikhIA8vq3JPoh7OUBqUE0g+9exnBfW5B139
J6m1qjfsuZHM4NpEM8spave3BevYx+l+x7aAxgoCdUlZ6Qohze/h+uptlQQy
TscE3chgcPvONKvtVQQ4TS7qbBGDnzoX9UdraP+WI8cnqXmSTA2nawRSy4Wv
r+cxWB7DiiyhHshtbt1aQPNt/wQ+tQSyQq2OBhQxeFA19mHTdQITKrqy7PMM
+kRrP4qop/dLbXL1LqX9Ln7RukXt/G5nvfYFmncbt0WtgUCxXJR7qYyer3jF
r6N2b1h2bCmn79+ZODHTSKAqeLZiporByff6ct8m+n96flVvukrrjZsDS6mX
3CxPCKtpvj0d9i+pd1lH+Kv+xuDswwHd+GYCK8tDK+xamkd3UfLpmwRuf25x
naun61EnHlveIvA/sfMnCw==
      "]], LineBox[CompressedData["
1:eJwl1nc8ld8fAPBrRUlGilJ6rnk1JFJIzomMrLIyysjIzCo3I75XKJRIRUa6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      "]]}, {}}, {{}, {}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  Epilog->{
    InsetBox[
     FormBox[
      StyleBox[
      "\"\\!\\(\\*SubsuperscriptBox[\\(B\\), \\(4\\), \\(4\\)]\\)\"", Medium, 
       StripOnInput -> False], TraditionalForm], {12, 0.5}], {
     InsetBox[
      FormBox[
       StyleBox["\"\[FivePointedStar]\"", Medium, StripOnInput -> False], 
       TraditionalForm], {0, 0}], 
     InsetBox[
      FormBox[
       StyleBox["\"\[FivePointedStar]\"", Medium, StripOnInput -> False], 
       TraditionalForm], {5.33, 0}], 
     InsetBox[
      FormBox[
       StyleBox["\"\[FivePointedStar]\"", Medium, StripOnInput -> False], 
       TraditionalForm], {8.33, 0}], 
     InsetBox[
      FormBox[
       StyleBox["\"\[FivePointedStar]\"", Medium, StripOnInput -> False], 
       TraditionalForm], {14, 0}]}},
  Method->{},
  PlotRange->{{0, 14}, {0., 0.6171464257613684}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{
  3.577701682144052*^9},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"p5", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"bsplines", "[", 
     RowBox[{"[", "5", "]"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", "14"}], "}"}], ",", 
    RowBox[{"Epilog", "->", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Text", "[", 
        RowBox[{
         RowBox[{"Style", "[", 
          RowBox[{"symB5", ",", "Medium"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"9", ",", "0.4"}], "}"}]}], "]"}], ",", "symKnots"}], 
      "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4826639558125*^9, 3.482664047625*^9}, {
   3.482664136953125*^9, 3.482664137453125*^9}, {3.482664206484375*^9, 
   3.4826642243125*^9}, 3.4834992060625*^9, {3.484981192421875*^9, 
   3.48498120653125*^9}, 3.4849972503125*^9, {3.487681224390625*^9, 
   3.487681241140625*^9}, {3.487681364859375*^9, 3.4876813816875*^9}, {
   3.559486554526794*^9, 3.559486581728078*^9}, 3.559509044734654*^9, 
   3.559509568253172*^9}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJx10H0sFAAUAPC7o0Puw+fVGHYnH7ViWPmq89FR2Qnna9PQjE4qpJUYdlQu
4RLKdWE+drr5jLJWWSzla6zMdGoUcjEpbtS5hGrLe3/1tre33x/v7b3HjEni
xZEIBELAn/xbtZ+pDCdc0tiEf1HdEGu5yAr32HLblfrWDhYf/DRp6HItKxX8
XBE1foclBHdV2YiKWGVgrw1dfiHrPpi0L2skn/UYbBo9Sas27QMvDBe+qJwb
BlvUKBLJdXJwy+awmfrjBFjWJHXrkU+BrWsa+aPrM+CbTYH+DsZzYKKLuzBS
NQ9m6iR7v97xDSxt/C67nr0Etp8kUt8sKsF6zg8d3DKXwZeGhALK0grYSUgs
Iub8AMcN9q+VU1bx3qD2W1UZarCt2meuR3cN/zupjg8V/ALXfuHVk402cP+c
n0eiqjbByoZpLXoewXPLIpkJVxBEBH/lxEqlFBJYy2Z0r/lL9KBEbGSbrwEO
bj6n/5mjCc4Nvp24n7YNfIE9o5aPoC37ORK7AjI4S6GSMEK0wPeqOx600bSx
v1a2Uv0KrTowK2YV6IAPJTjzwn22g+3s358xo+mCp0pEkrJ+dAA7QRWbTQGf
Thc/6j5KBfuEjeW+JdHw3u6EJ+mDaFrqLpOUYjpYR6HqFVnpgU/KyU5NeWjx
3UqZ1Sy6eeNYe6+3PljSaJ7iWIfm78lwVZEMcL6S1HqVj86LqOh0H0DPl3SN
ca0NwUwGtcb6Bto1fvpixCzaWmNKHcY1Ais9l40yW9AVx0Vu67rG4NVoRaSI
iuadP5htQUeTS+d7vQzQie98Q3N3otmxm0l0K/SHtGQpk412ye/ta/NAF5eb
Lxz2Qvt2Djqe4qCbNXd31fuhtRmCT+5cdIyNnDzkj2b4XfNfDEQnnxhPFvDQ
A2edSvVD/u/fz8UR9A==
      "]], LineBox[CompressedData["
1:eJwl1Hk81PkfB3BCK3IUude4jxy/iRJbPu9x5OjQGIncV8hSEskWjTOVMypN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      "]], LineBox[CompressedData["
1:eJwd13k8VN0bAPBBqCiFpOxjmRlbEoXSuQgvKiIVRfYteyiitIhsLyUhMpbK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      "]]}, {}}, {{}, {}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  Epilog->{
    InsetBox[
     FormBox[
      StyleBox[
      "\"\\!\\(\\*SubsuperscriptBox[\\(B\\), \\(5\\), \\(4\\)]\\)\"", Medium, 
       StripOnInput -> False], TraditionalForm], {9, 0.4}], {
     InsetBox[
      FormBox[
       StyleBox["\"\[FivePointedStar]\"", Medium, StripOnInput -> False], 
       TraditionalForm], {0, 0}], 
     InsetBox[
      FormBox[
       StyleBox["\"\[FivePointedStar]\"", Medium, StripOnInput -> False], 
       TraditionalForm], {5.33, 0}], 
     InsetBox[
      FormBox[
       StyleBox["\"\[FivePointedStar]\"", Medium, StripOnInput -> False], 
       TraditionalForm], {8.33, 0}], 
     InsetBox[
      FormBox[
       StyleBox["\"\[FivePointedStar]\"", Medium, StripOnInput -> False], 
       TraditionalForm], {14, 0}]}},
  Method->{},
  PlotRange->{{0, 14}, {0., 0.5394516532099551}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{
  3.5777016822038393`*^9},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"p6", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"bsplines", "[", 
     RowBox[{"[", "6", "]"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", "14"}], "}"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", "All"}], ",", "\[IndentingNewLine]", 
    RowBox[{"Epilog", "->", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Text", "[", 
        RowBox[{
         RowBox[{"Style", "[", 
          RowBox[{"symB6", ",", "Medium"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"12", ",", "0.6"}], "}"}]}], "]"}], ",", "symKnots"}], 
      "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.48498122121875*^9, 3.4849812251875*^9}, 
   3.484997263078125*^9, {3.4876812780625*^9, 3.487681359453125*^9}, {
   3.559486587100634*^9, 3.559486654206524*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxN0H9QE3QUAPBt4BAHkx8TcDiIEQgkkINEUFARUDzEHAVGF5aNG4IwnSTl
KQdkDAbMH6jMIcjYbS6FTUT6BWeCpUIj2HE45DJ+JGytEhbkWOio7vK9vbt3
3/v88d73ved3gMfOJhEIBN6/+d+7vNPs/njjJ3GE/0N6neM/w8zY8tI3P73W
1sXkgr/h9X8sYxaBb09l/XSRKQDfaVorOsOsA2+zUrg1zKtgUmjxUBXzS7D3
/nGq1PsB+HdtTU+jQQv2bZ4qICt0YPWSlmEZewxWtspj7ukmwIHNLdzhF0/A
p1vf3L1+lQFM3LhJ8J7ZCPZzPBw/4PkULG/5S1lROgsOHyc6D86YwC5R7etj
Ts6Bj/ULSpxm58ERAuIZYtkzcLamd/Gy0wLuu7fjbNMJCzjIkmi4R1nE+45b
ct4ueQ6W/ca+RqZZcf6yv3dkNS2BTdcnHVZWEra+tEhJTynZSwT/kcCRy51I
YIe1w+t8vkNrJGJaUJUdOE2V7zqdYA8uT7tQ8AZ1Gfho3BOLbgjt35sgCasm
g4unzBKPtxzA9dKuGzepy7FeppyXfo82b9CLmdWO4NjcKHZG4gpwWPhoHoNK
AU/UiiR1veg9cblmTqkT+OBx8a27O53Biekj5Q9JVNz3bu7XxzVoatGrdP65
lWDHKfN9UYAL+H0dOaK1Ei2+1KgM0KNV1uSO+/GuYEmLD5+lQHNDTkSbSW7Y
30RqO8VFV2Y2fLupD22svTOSEugO9vNwbg4UoqNzJj/K1KMD7SYs6Sk0sGnr
HO2kGt2QKop5QVkF9pWzXZIOo8t+uDJr6Ef3nCfkdAR7gEcUwtO7atADFQ3d
0Ub05fZHMlOqJzipNJgx1IbW+pCkVKoXmLXMftiNjy7sFLkfGUDX0kJ/XQhZ
Da74Yr4gWYTOCkpcmjOiV/xyewt3Dx1cl98tjGxFE+t1h15z9AZvc/VcMh5C
H8gYq7fvQ78zPWiYDlsDDvV6qPnzLHpyNadz31N0Psc7U8BmgB8Vv2vncgPN
3Kze3kPxwf/j10XG8mzsxQp306A9oz4YVb/uC+5bkK0pqkXvF/IOimfQ2SxW
RHfwK+AqB9OGD/ehfVXRZHo5epe/jj9u42PiwjGFAP1jmfqriEp0cUZA3u5q
9M8E18GSc+jGNMMlfSO678FnZNUV9LNY/6OFTejUoKwUYjPa+nzISpejQ/hH
8iZsnK6njlxVoFXa5LZIJXo0Sc9YtDG565Sw+3N0u+XWZqON/wFUvYKe
      "]], LineBox[CompressedData["
1:eJwt03c8le8bB/CTvamkzJDZSaSvknFfT7YQISSr7K2MhEq0NSQNI51SRmSP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      "]]}, {}}, {{}, {}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  Epilog->{
    InsetBox[
     FormBox[
      StyleBox[
      "\"\\!\\(\\*SubsuperscriptBox[\\(B\\), \\(6\\), \\(4\\)]\\)\"", Medium, 
       StripOnInput -> False], TraditionalForm], {12, 0.6}], {
     InsetBox[
      FormBox[
       StyleBox["\"\[FivePointedStar]\"", Medium, StripOnInput -> False], 
       TraditionalForm], {0, 0}], 
     InsetBox[
      FormBox[
       StyleBox["\"\[FivePointedStar]\"", Medium, StripOnInput -> False], 
       TraditionalForm], {5.33, 0}], 
     InsetBox[
      FormBox[
       StyleBox["\"\[FivePointedStar]\"", Medium, StripOnInput -> False], 
       TraditionalForm], {8.33, 0}], 
     InsetBox[
      FormBox[
       StyleBox["\"\[FivePointedStar]\"", Medium, StripOnInput -> False], 
       TraditionalForm], {14, 0}]}},
  Method->{},
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.577701682303763*^9},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]],

Cell["\<\
We reconstruct the spline and plot the resultant on each subdomain formed by \
the four knots\
\>", "Text",
 CellChangeTimes->{{3.482664394578125*^9, 3.482664468984375*^9}, {
   3.482664514625*^9, 3.482664539265625*^9}, {3.48275498540625*^9, 
   3.48275501025*^9}, {3.482755052734375*^9, 3.48275518615625*^9}, 
   3.484914425703125*^9, {3.484914587328125*^9, 3.484914590265625*^9}, {
   3.4849790056875*^9, 3.484979036765625*^9}, 3.48499291775*^9, {
   3.4849973990625*^9, 3.48499747065625*^9}, {3.484997518078125*^9, 
   3.484997519515625*^9}, {3.559508322045296*^9, 3.559508328452069*^9}},
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", "x_", "]"}], "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"coeff", ".", "bsplines"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.559507412758713*^9, 3.559507440327875*^9}, {
  3.559508155235904*^9, 3.559508183032079*^9}, {3.559542860157253*^9, 
  3.559542870016616*^9}}],

Cell[BoxData[
 TagBox[GridBox[{
    {"\[Piecewise]", GridBox[{
       {"0.`", 
        RowBox[{
         RowBox[{"x", ">", "14.`"}], "||", 
         RowBox[{"x", "<", "0"}]}]},
       {
        RowBox[{
         RowBox[{"-", "93.22860398860391`"}], "+", 
         RowBox[{"30.70204971982746`", " ", "x"}], "-", 
         RowBox[{"3.0741504585948993`", " ", 
          SuperscriptBox["x", "2"]}], "+", 
         RowBox[{"0.09727893505671273`", " ", 
          SuperscriptBox["x", "3"]}]}], 
        RowBox[{
        "8.333333333333332`", "\[LessEqual]", "x", "\[LessEqual]", "14.`"}]},
       {
        RowBox[{"22.67429740812457`", "\[VeryThinSpace]", "-", 
         RowBox[{"11.022994782994784`", " ", "x"}], "+", 
         RowBox[{"1.93285488174377`", " ", 
          SuperscriptBox["x", "2"]}], "-", 
         RowBox[{"0.10300127855683412`", " ", 
          SuperscriptBox["x", "3"]}]}], 
        RowBox[{
        "5.333333333333333`", "\[LessEqual]", "x", "<", 
         "8.333333333333332`"}]},
       {
        RowBox[{"x", " ", 
         RowBox[{"(", 
          RowBox[{"1.7312975090752871`", "\[VeryThinSpace]", "-", 
           RowBox[{"0.45857492301936753`", " ", "x"}], "+", 
           RowBox[{"0.046463084240862026`", " ", 
            SuperscriptBox["x", "2"]}]}], ")"}]}], 
        TagBox["True",
         "PiecewiseDefault",
         AutoDelete->True]}
      },
      AllowedDimensions->{2, Automatic},
      Editable->True,
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxItemSize->{
       "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.84]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}},
      Selectable->True]}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxItemSize->{
    "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[0.35]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  "Piecewise",
  DeleteWithContents->True,
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 CellChangeTimes->{3.577701682438465*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"f1", "[", "x_", "]"}], "=", 
  RowBox[{
   RowBox[{"f", "[", "x", "]"}], "[", 
   RowBox[{"[", 
    RowBox[{"1", ",", "3", ",", "1"}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.482664798328125*^9, 3.482664876421875*^9}, {
  3.482665070609375*^9, 3.482665072234375*^9}, {3.484914595796875*^9, 
  3.48491461284375*^9}, {3.484917527796875*^9, 3.48491757125*^9}, {
  3.484992918484375*^9, 3.484992919515625*^9}, {3.48500146815625*^9, 
  3.485001540015625*^9}, {3.487659447484375*^9, 3.487659451*^9}, {
  3.559506917028267*^9, 3.559506956248039*^9}, {3.559507172287964*^9, 
  3.559507189532424*^9}, {3.559507232823027*^9, 3.559507245266136*^9}, {
  3.559507368146588*^9, 3.559507393065906*^9}, {3.559507496215718*^9, 
  3.559507537999896*^9}}],

Cell[BoxData[
 RowBox[{"22.67429740812457`", "\[VeryThinSpace]", "-", 
  RowBox[{"11.022994782994784`", " ", "x"}], "+", 
  RowBox[{"1.93285488174377`", " ", 
   SuperscriptBox["x", "2"]}], "-", 
  RowBox[{"0.10300127855683412`", " ", 
   SuperscriptBox["x", "3"]}]}]], "Output",
 CellChangeTimes->{3.577701682471571*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"segment1", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{"f1", "[", "x", "]"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", "5.33"}], "}"}]}], "]"}], " "}]], "Input",
 CellChangeTimes->{{3.4826639558125*^9, 3.48266397771875*^9}, {
   3.482664893203125*^9, 3.48266489575*^9}, {3.4826649806875*^9, 
   3.482664982765625*^9}, {3.482665113578125*^9, 3.482665156546875*^9}, {
   3.482665204203125*^9, 3.482665208359375*^9}, 3.4849145061875*^9, {
   3.48499787665625*^9, 3.484997877140625*^9}, {3.48499791696875*^9, 
   3.48499791890625*^9}, {3.485001522046875*^9, 3.485001524234375*^9}, 
   3.559507773199627*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV13c8lV8YAHDEXZT7XnuUkWSHEA3vU1FIkUqFFvLLiEiFVCilomSva0R2
UVYllJVQEkKpbKLITFH9Hn/dz/dz7nveM57znOeVsXWzOM7FwcHhysnBsfj7
pUmy4pSWnf6S5elPE3N1gPU+V6mfvZnMmkp0FM/RgY79DS/K2LvJybv7lKOy
dKA0xiokm32MXDXwezAkXQdU9WSnktnu5CoXMfJisg440CnyCWx/cvkqEw/b
CB0ImDhXEcu+Q+Zuj+7R9dWB0AH14Bh2Cqlzpq5xuakOKChHrNts/Yjc7Lem
oKlfGxhmqSWPDUtJo7iR0ohAbehT1FEp4qwkC/7IbTikiO2sFUm2FbVkjWGs
XnytFkzlmR0kVBpIo5+3hFKctSC1gLs44mcT2bdeXnUPQwt69ty8Y2X5jswT
fp0gkrsWmhWeODsHtZLH2u/KH9i3Fu7lK0QPfn1PbvzXMnh1ThOsBDY59Mp2
kmz10DZGqiZsG7tUlmv+kbT37iP3mGuCsC+3Q8/9T6T2UlW+Vz81oLZf9VFU
7xfymMxy0jRdA1T9Gldbr+whQ7Tc8tXNNEDAJHb9O7NeMncy0WPotzo4+usm
0U/0kYwv3v/Z3VcHjTAvldnofvJckjDlkhW2M2/yphYMkBfeh5WtX6YOAif0
BXiGBkn/ftPBUO810DlPO/JGcJgUK55ey+hSA/4/9xb2q30l32QMVOjsUIOS
9r7KqCMj5KRM6ma/fFVokpr+EOk7Sgqq2wdryarCkjSJdQvh38iy6MLqohgV
yOLsLxWp+k6elZ8Ie8mjAhWNF8OmPo2Rtb/2DJdfVIY03U9GW2g/yL1Lxsru
jSnBTOZVp/LEH+Sbsbvl7nZK8M9MrEhceYK8dHbBjd2nCJV2C+G7qybIkQuO
F5WsFWHTg7r4E7snyaVv/jq9+6QANVHJhgVdk+St2P0tbfYKQP1Wd7nj9BSZ
f8zXJKNvNXB6fRj5xDFNsoVbtwudXA2FpzYOlsVOk7aXQm9mj8mDVPI1xkWF
GdL8K1s/1kceYk5+futeOEP+iRAKu8eQh/qMQGUwnSWXOH+U2BK+CgpFhfPG
OmdJodn14mWrVsH+2dnac6d/knkzx0+teCgHNI8+Py3GHGnSman3COTAXe6J
XXPUHDm90lw5q3MlhG/98sFozS8yvPjX4e/OK+Fk7JhPctkv0s2Uf9s+6krY
F0IvUzb+TTZnD+ecSpeF2e+e4Xe6f5M/ecn9G0hZMAt8FdZ+cp50iHJLLeqW
gWPXXeXnKAuky2bve2t8ZcBfWcrGlL1ATl4VHHSTkIGD3E+e+in+IQ18LIJG
K6VhxDj1/u0Xf0j2J5XyWntpWFt79tVFs7/kFgH98ynLpEE7L87b6OtfknL1
i5SFgxQY6tQ3GPr9I2npqYyzxSuA4uOeeofCAbZZOQ9LhFbAdn75nO8WHGCh
8LGK4bwc+kmzl3pxHGD4s9mX2iQJQeTFQqluDvh6+2iJuh76TNvopDInLIuR
aBOLk4D+bSnrij04weiLpHonTQLYuyJfO1Rwgmk8RA+5isOhVbe1HjK4YGep
lcTmj2LgHf0nb9ScC/4bEklh7xWDCTLijACbC57WdHVO1ohCzeUkM+V+LtCq
Yml+3ioKyVH5v7sUl4Cuqfib9S9FoOPL1/HzZ5aA1NmJLvWtIuBSHf2L8WwJ
cGYKWfysFwabLyd3XqNxw9NWU4mPO4QhM/Jx0ZQZN2geucEl3yEE8+L08V+R
3BAmfpDp6ygEOe/9Pb734P/vEY5B04JQourGaFbggQdG9nKbbgiCVOmVbyln
eEA5ZU/GKnFBuCWSnMT3ggdG+jfxaeQJwEF+9f/+o1KgRzu6UX6XAPhvGvbK
20MB3V1mM31DLOChCiUNxVGg8sVTW8WbLAhN2h71pJsCNpFf3F5rsuCc6912
LxUqcJ8ZW13dRsDTDndVhdNUyK6XEA7zJ8DK2/F1dQUVTLZZDskpEsD51UF/
nkGDt6cP/VJsYwL3dEeVzG4auER9U7e8zgQ77dPh2mwaNFJHfzbqMWEFK+Cc
Xj8Nzp+h9Uj180N3WZRKuyIdntdkWq2w4Yd/SS3KtmfoIHCy1ej+62XgszyQ
/FRKh2IbscSQnctgd/NhtiGNAe47Ki80vlwKV6Tv8yeaMUCkaqP2A7OlUK7P
uSc0kgFDrw2s93/mg33hF7rdehiQ+JG4ZnKCD4wuuwaQCrwg2CbcnPGXF6Kz
rrkuePICI+C5JvMOL3xPTFfe85wX1PJFLx9U4oWkNev/xFL4IHn7dWh/w4AH
szOibyz4YKyP15o8xQCxg/LGk7F84FF5IXKDJANu3rAxyf/CB17tlb/bX9Ph
4OTTSGvlpeD5bYK55gIdLs+EzMy6L4WnIz4ZC9p0YKy5nnSpfCmsEEzLXfOd
BjHrbojfpS8Djl0iGwWzaRDw8V9Wodky8DssYbTPjQZ1RezLhfHLQE4o8WjF
Who4Kee7p/UuAyt5nddT/6jg2D6S5b+GH56WSGeMNVDBzUK5YM6HHyKMxK9P
JlCh+UT32yMv+CFm46GeIk8q1H04LPmBwgQ+9XiPSVMqtL25ZuWrxISFvxd+
2ylT4Xj2Wn/nnUzwO3Xz2KulVFiZMmW6+zQTdB6XjJlOUOD2wHfZvCgm6Nuu
vkN8oMAyqQ+eRtFMmDPvHCropEDwgdraHnR+uaWPJTqoIdFJMJYJHGKpFgkd
FAh4aPbIO54JMa2Mt0rtFDh74eFmg2QmaNUe/m3RinEpdOZoZxYT9l6zHm96
QwElwwX2kjImSMo+dzlfTYFtN26sjEN7DT/mVkPbNYlmqZczIeDqzrbuKgok
HNQuPFTBBB/t9dLb0ctcXetLXjAhqCnfRriSApNR3bPOtUzwOH/LpaKCAk+G
q81am5jwaHyoYUMpBYyCQzjv9TJhWHMmo+sRBeKfGvyn0Yfjd2gISkGPDc83
lqHlvnLGOaAjDZ1i3vczYeRdwM6JhxTo/bttDW2ICcGfvOZo6PPuHIecR5lg
KmptvTmPAg8sTz/WmGbCLkdZ/fc5FOAMVFpRjtaJyZdLQe8t6LlsMsOEjgKd
DS7oeX5zM7tZ7C9t+RwX2uiVymDEHBOshObzNbPx3G8YFJhbYMKkr5hkfCYF
BGUOupXzEHAqe9mL2/co0JqUlmdJIYBLsiXDBh2x4sf4GLoyKLBWES0oee2U
FI2AxLzUnOo0CgiIFLn7MfDcl5gL/kmlAGsp4bmFnwBK8ytrr7sUIH7VedWK
EuClL5Yek0SBt+cEnxwWI0AyKyTABR06e+TXLFpl3CkK0MzpWe/VEgSEOprZ
f01Ej8udD1pOgHrCjphNix7wu2Aii/2Jnzz0IwH3q1k34I0yAebB2uQlzFvc
evfv2qgQYP+Z6m2Dnk+WqRpBP/PJ69VDD59icFPVCOCguxvOxFKgitkVSKoT
cOLpYSNXtJf5pev5Wtif7Rg4xuD+NNWEhm0iQMFKbSAgigId69Y/lNYnYNhJ
QsAB3ZT0oPkBusvH/ZQx+plbNKuBJECaf8cTJjqa3zFiyRYCjLbvu5wSSQFT
M74Yz20EPB9ummmIoEDJG4skSzMCEgLubzQIx/YtjlM96P6l+tWq6O6iS9tP
mhPAfXjWSwTNYOeOX95NQOvNZsfRMIx/Zwo83EOAbmfHiUg0F+1pN+8BnL/A
sc6JO/j+82+1otG6luMan9Eq44NBsgdx/tYeJfXofe8FNPSscPxfjY3T0Jlp
J/0dbAiIaR+4dhC9c7OM7IujOJ4GimtjKK5H4bqzpscIsIm1jShFn1XYVd+O
XljlN5SNTuY/7zFmS4DosymBG+jJT62VEscJiIiyCzRBx/gE2Z11JKDxU/zL
ltsUUB1LLOF0ImCaFvm4Bl15rIg3BB38Q/J9CXrUqLcg1ZkAPq3GqAS0vshG
7uaTuJ/bzdROoPsKxtOUPTBefJYXUNH95+JaKtHBHP3n5m9RYHCDIZfVaVyv
o/2nxtHDVXFHgjxxfY4H/GtHj7UYig+cJcDP48WtHPSP6B9GvucIeFzeP52M
nrCOPyfghe1mMrej0NN9P1o3e+N4p9qOBKB/T8XfTjyP67Oh1N0GvVCyrVzb
F/+frOO1B/3n/MS3RvR0QfYjEzQH93aT+QsYXwkuVXpoHsFJ7gN+GH//DewR
R1M6EtaOo110Cn+x0LSE7bZX8V6NWWHdwotmyLErCgMIkBuXlv0bgudBy8iH
CCSgMFBcdQDNmpvMzETrErruX9ACz9jt5FUCmNJLv3aihQ2mtFyv4f5feH26
CS1CS7TjCSIg6F7+1Xq0aKNRWAI6grLhdQ1aYm/ieP117G+19swztKSo8Qrb
GwQYvEh4/xi9omvK9Bda0Dh+tBAtlZx4PvQmjjdHReshWtreOHt1MMbLe9P8
+2hZhemOcnRw8c8j2eiV3xKpliF4nvUUt2ag5T2n7a/cIiCtiz8tBa2gmxQu
cRvXp/2ZTBJaccG48hFaVKn7XQJa6fn0D+NQAqpfnCmJQ6tcSZLqQdOCvZti
0GpGJru87hDQfWZIPBq9hm/Glz+MgA6X0thItPrbpJx0dPehiR0RaM0Ikw+b
wnF8OoEa4WitAzO0NrR0v4dJGFpbMnmdSwQBuXuKo+6gdbpNHJZEYjx67BBe
tG7aTEQc2kVN7VUoWu9EcpVGFD7vaZW36PUqOybr0AvqjXWL3vhjRvpoNM7P
4pLQ4vObCpPNfqJjatwiF332mOfhKzEE7LXk2LD4/gfLjE4SsRi/5quWLo5v
sFTCNxFdbf+Rd3H8KxzHbyjH4fMGUusW52cpXBX7GN2d/P1WFPpWVVSmYTwB
dUpbBRbXp/aUU8k7tHq4ZHUs+u9y/dojCQSY3jybEr84vwai7RtarnpnDhvt
6jXQ580mIHMssWdxP9JXPZmkJGJ+euZgcBf9+V0wZwRa91NKS9pivPkdZcok
EXB0yc7bi/u7S1VL6gH6xBf7c4v7X3Ht48a6ZOzvwuvGfPScVt6OfSmYX1NE
1i/Gk3pvgFUv2h5etJSgkzcqeS3cxXyQvyq4At3x9c/V66k43r7O7KrF8xDd
HCmcRsDc3u6Zl2i/Ca8C9XsEJJe8ZzajHyeaVpah6xjPu9vQP3ZIN5ukE3Dl
6FjXB/TR9Jdj9hm4P+18VovnabO1sFJsFr5/77TDAtqHNqIrn437LZYVw4Xn
8VFR2fYCtK5T0CwNLcs8fvx1Dp6PU090hNFcNQXJnA9wPq5BdZro9R7X8m6h
p79qWa9He0hZl0vkYf9eE2Jb0L3eXF3a+QS8DQ+RsEBXqe0WcXqE94fsjJrn
Yn75KCf/E20QVSNzAa11fU7rSgEBWuk34So6rS/JIrEQ53dolDMWfSVmLORd
Mc7vekL4c7QhVzD3hlJsr+geF8F8OfJv6nsL2sZwji2HvvXHut3lGdYDZd6X
NNAdc8rZiWU4vqysrh1ol/EGM67nmO9ct/8LQId18ca/qkan1vf8Rq/7cPqK
bQ2e3/Br1QzM913tH0/Oow9QnT+Io+VbckD1JcZnYkTSBvSTVzsGQ19h+82F
W5fQ3cU3NQ68wftot9tfJt4/gYVT4hNoyco4Qg6t9Mia+0YT5qftWfvXoT3v
K7eXvsXzWHzY9zCamtbgK9VCwLeVRavz0Gp3eOsG2zEfqB3lssL70df55uEz
PXi+E9Sy2/A+PWAhqcDdi+v3yfnYd/RavfsTYejc/jADHryfRyhNV/L7CPC8
FXpLG33gLitndADzp+6IegxauzP257ERzL/awrnH8X4f25YZumsK86HvDnuZ
aArUq+pZfUIn3JAI00ffE6xf6TKN8w/9b9QabdM7Wnx9BuOt7rh0NLrhwppP
1T8xnt7HhfNj/ZFZWKy4YQHzXfFgPA3rk2OyNZWreVjArcQhKRFPgQ+CcxUF
aC+NEu5N6L1U5TKSwoITmW+Fj6CNvoWW7KeyIHNmeUkqWq3YJvcanQVp/i+H
1LB+mjeejhxayoKOJQGUnWysT91XOmYI4/NvJ2QzsR579dyff7UCC7Su3pPt
xHovf4nxUDl678wNOh3rwahtzApLRRbkqqlK66FtGxNdryqxwOhidFcseqG9
9PWACrZzh945lI7vH5+5mabBAjkTz+HvGVhfLneiyW5gQWuMvKom1qtHfCw4
l+9iQb6pmLIR1su+6VueZKNN3fn6L6Hj3mm665rhd6lmXk0JulVJoGePOQsK
pWa5FApwvh9bnt+wYIFogfJxRiHmj437/OYsWSCtta3mfRHWz3/3/2s5wgKX
Xc+6Qp5QINX/0J8b7iyIOFqf6/kC81Wab+J4NAv8FlLzivD7gu/BCoWUMhZI
Htw5YT+C8+eZL63vZoH9mzi5pZxUCPAanR6hCECu53SeliQVuPSEdS8rCUCh
y9frY+uoQOmpsjuxUwDkEvjWGu+j4v0QqGVwGp33/Kf/OSqIFvnzx0QJQIzp
WBI7lgryPXdu9z4TwPjfWN//nAqPp+XmvHsF8L7+YPf0KxXm9k06XecRhMzI
4YpXBA0c3rUE3FYWBIVgD+G9JH4PJoynLTUTBN2/l4IrnPG72l/KJeCMIHzj
44gawO/suF3vJAziBYEjsVFpeTMNhB0r2i6UC8KVz0lOCVz4nZ34XOtBvyBI
1xkfFFxPB1HZBbYlTQjSBA/oX3ajw1Tw0/EdykLg9bdBwvYeHU5cprgOojem
uTruSafDZ2+Lb34qQvBNo/6dQQYd6hxGhotUhUD3btzc6iw6JIB4r5S6EATL
rg4dz6WDwbR365SWEPjOS49eLqRDlLXek3h9dK+S5osqOvBaBK7TIYUgIfbi
WFE1HfyMmoveopkyHLXZNXRw0nZ8xLNZCAT1z9dGvKQDyR+b47ZVCObm2/mc
GugwXDnH3mokBKI9h3LEWuhw6ImB5Gf0Rp5AUWYrHd7lhcZ5GQvB8MmIZEob
HZ4lKETfN8HxZ1lxTr+nw52zB0JFdgpBoQgvz9sPdKCcTFv2CG2a89vo5Uc6
+Nr9CDbdhe1leRnlXXRwMA+67m8mBNLzB4ruf6bDx22tVElz7N/TwP7eFzqY
b5K+Wow+wOhXZXfToWatC/fu3UKQabuWFdlDh/VKjwNG0bBKjQjppcP/EqbI
TQ==
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0, 3.},
  Method->{},
  PlotRange->{{0, 5.33}, {2.819123620937276, 22.674297013812076`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{
  3.5777016825042*^9},ImageCache->GraphicsData["CompressedBitmap", "\<\
eJztXHdcVUf2v3DfoyoqJkaNSdQYNbGtqVsSY+waW+xGLNh77xp7wd4bViQq
iooN7AXFXlEUAbEXUKpUaW/vd84t78Gbd3F/u/v5/bH7WZ4v7853zsyZ0+bM
mdvCc3T/PkM8Rw/o5Vm+8UjP4f0H9BpVvtGwkdJPop0g2JcTBLsO5QV8NwmC
8mGS/k8fn+IDP//ffxjF/nF0zMt82eLCgVUPen3unGJfpEbPERsDy114liHk
SU87sDai9JlbL/7k4PTKznaCgY1JTLAvUbe036sc1oLaOZbLeuZzu0uNkm+d
i1Ze1Wzg1OELlqyufCAijfXlQX3VSrs1+E2FD/5Wam9sroKTPvO+eXttRlTT
SsVTHItU8m7SZ8zkyTPXf3judbbwJQ13NPvHIH2mL7wzqlJ00YrDXELTTJ3Z
z87SZ0bfqHUdltUburadn79/O3/2t2vE1sUjOvTa+VzIVkfpVCbr5b45MyYs
qRD4MB0jM5qynm326/Fbrbm3UvHfXbgDdWKMiDs5ZlvH38dX2xaWIuSaTCVy
Es4ETmw2uNSB2Oyq+ceaMfvuxMrRbhWHu9xOM/1OndibchPHnfcaUn31HUZP
oHXJ/Dr2eqyQqdKvnXpjYHCNOhsMT7PNFyLrk8Sn0ZWioqIEe/ZpbH77oEdC
uRK1f1h1KfLj6OepQo7UsrM6gtw2MXsaeNfsc1F4azJVsTk+mbCD6d3TxbtG
jCq3+1mW0J1+q5wZMfPFV2XrlziRoA5Gahd9a3GtYqnOrq6Cfaqr9GlMd3U2
5NnbiWlOLq4nytQPtHuTZxJo3mK19LCx96p9yUgJtkciy0qx3KQQ/0ntphYL
ScoVuqpNs/o/WvNDgluJuu5H4vO0lckYELnas/bcGykKUyUO9o37tCRbQbnH
71Mud33xSdlWbueTCzcGxsJ6CSd7+37vsdsQky0vooNoyskqlp70tNtln8HJ
X7uJV4t8u8L4KMvUkSTa2ZR+b9NSz8UuYWkFhiIQnw2SHMT7HOtW7qFrhSEQ
ZdvDkafvaMq8HzqzZqX6XU8kQPo6aRpUOS0iYItX9++ySxjsnjmWa159sSxf
HbU2NVNDFwzouTpSyMg3JpqW0SU3LWrOvgl1st0NjssrDrkqpJj0+KStS9rq
mwMqnC5Vd7d9TK7MJ/yc2e2Bj2fPnhsj7NLzZH11sDPlvZ14bXafChsfvjMf
hzxUSSVjBh5ZNWPLyO6N46u5G012gnjV7dvxxUMScwXbStZJM1k1E0MDnR+n
mwR7remcuxMqPy76WX+Xm6q8u5jSboYPqlqt9sgbqQofiuUlXVgzrf+2H8Iv
aTzqqI49fvextqVzDfbOoWVqNhnXx2ufS2RaXkFDNffu+C8kQ8XGRRN3qp52
Z3qbQXteMoMk/eJkyrh/a34t13DnqlOdwjNk+XEqnfXqaK3Nt5IVUZbk6U7U
mErFx1afFyW8M8m9GTHLOgnBk2b2nNw8rqw8zE6q/ZgwvNWSSJgUoRqN7SOZ
OeRVyPLIXbnmpkZ0PrF9/n3PKq7RjjRm+ZmTpOmP96xv02jYwKU72gX4ewdM
al0hx1ksOub7+ax7edCSTsSsPDDIs9m8wLulXsRGjzq1sGlmKcdSjVofjcdE
ZJGQmr3xCer2abKDGxuwLMISkQeHVvzas8fCzb4evr742/71vutJzJ5V4Y9f
7lValYyGj48t3tGv0xzn8HRFTyUTcmXTCs+/J31WzDHWpVTNqa2nHTa+ylLk
sGju21trvfvVSapQzDHeyb3q7GYTA40xWYoBKpUTGxDRvvJPZnyFGuV0eLWz
fq67PXPP0p9dmHO12Y4RmTbHyT4j6UHJd3Hhzs/T89h/VdbBsA/Df63RPPbV
zS4vz1Ti7dvM0vHxaRVfvEiuHRn55puI+286nDoVPcnX54bHsaOR7U+fiu5x
OChi9I7tt3xnzTg5c+OGq/bjtv15UygaNGZU4LqF88/OX7PqEr7/KT0OGTxw
/6X+ffceHD/ucMCkCUe3zJl9Cq2Dxo4OQluBsIbBe/eEbZk7+7TX2jWXuhw7
FmUPOoJTg2tXn9e7fv0FRlEjOjoeo8LoPoqPT3dNT89uoTOxiexrMbfU1HeA
fn/vXmzTSxefYiLD/Xfdnrlh/dWVSxeHYKSHxo09fHbIoP3X+/TaE925447U
Jo025f380zqhpgmfxZObNdn8vG2bP8O7dtl5tW+fvcdHjji0b+KEo9tmTj+5
evGic3PXrb2MufQ9sP8eGNbw6tVn394Pf/35i+fJ7snJmT/qDHUY++rqmJWV
U/7Vq7d/v3Mnpk1w8EMwBsPc5DX3DIZ4pV+fvc/atfkzs0G9DYIDG1qZnF9+
9o5v8esWDPtan957TowYzoa2fcb0kxKjD1+WFuAPny3XMWUMr/OJ41Hgb6Mr
V561O3Mm2uP40ai/3g2L/eLZsySw6YunTxMrPX+eXCohIR3y4JKRkS0UZeMr
i+/4DX8VXr58+3VExBtg/hIVGYdV+i48/DVWDX2DRrcjhyNAc9GqlRcgFF4S
m6TvF70XzA/eNXXK8cNjRgeZs/11qxY+WfV/We/EplYE04r6vdMOaQoBQWPH
BPnMmX0a8DGS+EEMW5wPefy3sLCYT2NiUhyysnJr6XC5H5ktCARG3Prc2UfD
/P3vLF2x7PzeyZOOYmFf/dbK10jUwWQw+0bvnnsCx405DAmdv2b1pVF+fqGg
3vzC+SegXvnp06SSyckZdUmPXCUeffzmdWq1Rw8Tfrwd+gqDBB/A/+mbNl5d
sXRJCMQGc8fEnnRoty29UYONtJwucS1+9bnXzWNn8NDBB8AiNMfydT98OAJs
/erRo4Ri0gS+oLkWITVXdg7ubNJWOVDMym/F//fbv/03kbwGVKX6w4fx7c6c
jp7ou/UGZPfigP4BCc2bbRFEttZOEPXILp39INvoAiLSMiTkMYxd8ZSUd27/
tSm44idYn89iXqVAqH87G/xoyJ7dd+Z4r7u8dfasU6eGDz2IoTLLY2DDd85o
WH8DfoPFgXKgjz4HD4Q3vnL5GZQC/QnW5mDP19P/Sel/6jcH/ITl/fXihSfj
JV+1Y/q0E/c9uuyk1XSEHTo6emQgXCJWHq4SPsGQk5Mrr9j/j+k4sU/njyT/
hBgF9rX//n13Z6/3vgJJPTN0yIGHnTpsZxhSNOdcyUc+bd922yVJAR91ar99
89w5ZzyDAu//fOvmS/gvB0iqw/tJahcrv3kU8rfatCJgLXQd3mT5sqXnTw8b
ejDx16ab7WlFMOoHnTvtODBhHLx4wNTNm6/ByxZNS8sSyhWSFHHQWczNzfsk
NjYFHqnr0SORcCnr588LvtS/X0B2vbrrpT9vWa9FcDEft//tHKhOHLCXhgVH
Ce8GTwcLCWdIHHBA2BUyaOD+VUsWn4Nl+eHe3dgi6elZFQtJpbRGBZP/5caN
F5B8dCktf4QLf27ssyH7akQAB6WB90bgh1EJ8gjfNm28CRK3cPXKi4isYPcQ
Se/X6foX9rUIFAyCuHGe1xl4/by6ddahYywJ4g5MHMtV9cmTRMwiSKdbijON
GAHYOmjv3jAEEYhq5BEbEWDsnzj+CJxS3Zs3XiBeEY7r9Ps39tVQ5emTxAH7
Au6izzctm/vIXSJK8p018xTUEGRBXjit0+V31OWHiYkZnU6eeAAOQEWpS8OL
tr/5Qg57Bh66jyA6RKc30igXiDnc1wxpY4JgGSqEDpOkJUOINzBg713w8pJO
dzWpO6w8NiTYImC+6Arx9oWB/fdBGkAKJK/qdEe7cWfwZuz2bbcQ8ubII4tt
3XKrZI5OI1yGzxdu6vRFO04X8Bg7DDhoWHH0BenBFgBDQygOibmt010lzT7A
Gi5ZsfwCPAG6e9eg3np4BKx4mbi4NOGeWV+sK9ZDBa0H7NawHYK8oQeocsCk
iUd/P348CkGrEKEzms/I5mBi0CgIhNLPnj8mHYOgQP8f6HRDxtGphRRLSRoU
giAF3SB4wXCUbh7pdFOGusFOCPuEG7167lbYDL7AbGNWT3W6KUXdGLOzc9sG
n3mI3TAiP3QFs+69YF7wXyIj417odPMB++oIh7F45YoLEBx0AR5hXwWxFmJ0
+ihBQ8Hkex06FA7yCmOg09hgQGhe63RDUZpjrQdRcVhuaBe6udu9664Ru3be
hk4L8Tp9FKE+ECTCAsIRoY/Uxg03YrsL1RKSdPogA+6ILTP0QGEJLOnQ3f53
mMi91emDHJxj/evXnsMswmJgdfyn/HEc/oLZslTqQ24q2Dq9cOLRMRLY6d27
nN6HDobf9uzuj7HGSGOGvmLLKGSY09E9fHDkkZK3IMiVoGvsqkEKu2w4WhaX
vyNStLEvcG5gLRZin3bsqwN2oRvmewVDcMAxaBXMB50OKUG/xQGAtS4pH+bw
U2joK2gFFCtNWn+EoEhB5Fn0ZpHKt9ZbNk0bK9bs4sUn8PKYNgw32MCk0mwS
ytzzp+UdaLWk/9FyOEIjYDJu9fRk+v+4Q/ttiJBZZsSM4bQZ5+TUrQ1Y7h+G
AbZEMeNh3bvtgtNnkbeZ7LBTL71kuTWhSCMcUiSIohAdgw5cBfZ5mB/RcTSn
w817WxPxFIJgyCABFoEEHCU2EmbaKtA/lulqFytdJlOX8CvInyARhC6xrLBT
ZkZEhtvOKFtbgEQiAQYgeFMWAJEDMniskZsFCcFWMtgaiQQigfhRkR+oPrb5
EFQzc6rsfS1yxUYrXcZRl7CQiCTQZYTH736YAWZiZuitWr3XmgpDbQGHx4dR
wvKxRiX5cHIxDuVev05FzAbtR05jtN+OUOfMzGzW6EM+/CXBYZpnbVh/BZ4d
cQa8PcIf1ugjPvy5tmIIDWHaMAIEaMgCmrltq/BnxFTEvQivMXdsurCPJA34
mI99QlhsoRFKAguZhAYR9hM+liINB/hdZdYpTRptAtOglazRp3x4tDprE3ZJ
L9u09sWswX8EZqxReTM4Q1OQZISThkBjvIiqsYei8VbkE6RjCwfsNBERYjsC
Mzpzw4YrBslasUaf8+EU5hlhNEESY12zaOE5Ft+yFl/wseGExbYcQZZiqBDP
mgfAVrF3NSuEHDF8CWITGGtVM6ry4WFEGtlwxT0jKir75k0akf6Kj6U42wiO
YYkw5Ucd22+HIyJsdT42lLAwlIjmwG1EeK6qf6nBx9J2ge1RsQVT7AsiaMLa
SIrfICxOGhCGIOyZtnnTNUgkYf/Cx14j7AdJSRlIJIEuNKrmgwfxhP2aj71q
SRf6j3yE5u++4WMva/NFFl2JazS63/GxtOszwhZDhUB3wp++N0XV/33Px14g
LHz+2kULzoJuaM8e/tAuwv6Vjz1PWIgwXAxkA+vL4jCz7bWZ7p4jBDgCzmBl
4FIRkBLiH3xqZzU7pYRA2Enj1MM8SWAVG8w+DVBcJKKgPPjOHtbhw05rwo9E
MEieHzRgH+JyIvkzH0upJiNO52BOIfwQQk0Y6vKxJwgLR4p4HwsKNv3jzu1X
hK3Hx1LKw4iTGxyXKcpeTGVTfT72GLEJcStcJxLh2CSzhw35sCPacHFYiKnC
ceMsikg24mMPExYmVPHaGC7LBbIWjflYyhoZYBMQ+yFox8kie9iUDwskGA7w
AAEUXbCHzfiwgzRSBAOKRcLZJRhNI/2Vjz1AWLhyGH0kSSZt9bnBNmGsRXM+
llJuBmzk4Kvwh+/sYcv8ChZguRQgBIJQGiLUik9oL2HhzLFLxASRwcHOjrCt
+dg9NEh4N5gPiAC8E3vYhg/brc0N+TvMDbaAPWzLh/kTDMkLUEIACp1kD9vx
YTtpgrBP2Ipjgrv/mHwME6YJtudj/QiLnAmCf2zpoM7aCnbgY3fQcJEmg7Ah
FYC0GHvYiQ/bTjC4T+WcHmly9rAzH7aNYNAELD9Of+Hp2cPf+TBfmiCcBhw9
mAMpgLjTBLvwsVsJC6XFmR+wOFHWNmAefKwPDRd5AkgOXAJCdvawGx+2hWA4
hsyUzBSiTnVr050P26wJXEqThpuy69f1lgLdh+xhDz5sE8Gwe4Uxvtmr5+7P
lLDcM78ObqTGcMFKSg0ixhr35NNYry0Akk+Kf8MumpjYi4/1JixUVYnhUbqh
SWdvPnYdDRe1D9h2wYurqtuXD1urrdudHt38wZaOJ0+SS+3Hh60hGDLucGkQ
bFXj+/NhqwkG+cfeCOEV3At7OIAPW0UwUAAlRK44mmAPB/JhKwnWKuTcI/hA
JC5UFRrEh63QpARmCak/xHPs4WCC0cGbm81iZRMr5X05JXB6t4U9Rk2fPWti
35UdB3kXCU3JtZYFWU5UsWYQN5xaq+I2hKhSHqdAzTENBmmPtKl3pn2zt+Jv
+8TYHADTpt+eUmNHxU778d/Wtv/LqEds9CBscN0wq+zh0PxELeoa5SNX97z4
oy9blylbp21wknIMW+ld1Lz46u5fVZl5P9Nq0mEpdTlVMryKeojK/mdYYaj+
mHyuXXJpt9qfrn2SrVRTupmSz8e0/ajIyBqLHqAk0VpqYjHpF/Rp3to1l0Ac
Gz9Nv4abU3fOT13uJ3NC5JxqCc4lfmHVxzJ5J1PG3YgJlZ2PlGx8Ski0Tn6R
Rh4nZyCPxIJGfkRhyKdsudq93GuHD1uwTKNM3sH0LirMq5rzlaLf+YjPc6yS
X0hNwWrFb+Igij0cVSjKvlc8Pn5t/LC5W4hG2dGUWZAyy09S5Z4BoTKqvUAP
0RLrbXRh6GVMC59aNdGp+M/uR+NVes6m9LCosZWcjrk3PCkkWGf0fJkp0k5R
iUYRRrGHYwpDOe+XxFMt35YqWqvC8odZCuVipqSzsS1LFRlTfX4UT8LmaZSR
rocm48iBPRxbQIvNC3JlLS6ZGxf0qmXp0g2aH09QzEiVzPvTE74sUa3y7IhM
a/rkVZAozjrZw3HmBst6Va1mP9Inh838Nqh8Uz/Dy2yTnSkvZd61sV/5VOoW
JL6xbj/mFqSMeJw9HG8x3fz1sPSzA7OQQdO7Luk6fKrXjHG9l3YctsUlPC3P
moWcoxFDwRs8HJJs7OEEvjmfrcEQ6FuMcSIfNkuDYQMGGM6r2cNJfNhMDYag
FDDVDU/mw2YQDFECThIBQ1jMHv7Bh03XVHrntCks1sdOkz2cwodN02Ao/AJs
5E6/UPZwKh82VV5KyV6hOMNCoafpwcRly5edV2wOmbvpfAwNXsSxGTDIRxBm
Bh9DfDKgcgAY5EHUHLY5jKFoLQzQEzAbbFAbz+TToJU34NRdOVhSXdcsPozk
jEUiCObh3NXE6mw+jKTagHNrBGaIRJDhYQ/n8GGkeQakUrFJQQIKeQP2cC4f
RqbCgBNc7OCQ7sChFHvoxYeRWTOgDAKVFvhTc93z+DCyw6zAApQQDoIyezif
D5OvM2A+mBdyqJgne7iADxulqeXJEcMOgpvIfbKHC/mwkZqiKNqMpWcPF+nB
RCX+h26R9C7mY8j3iygAUuJ+wizhY4Zr0oih4ZhBFWIbMIqxDNhoQRphuY1K
2nxpfkUZqkkF8m1IQ6gyuIxPg0JWA85hIBEWwrScDxusSQWO6yEVOGplD1fw
YRTNG7BxgpJYSMVKPoz2DsyggXfgobqjX6UHE7FEWCosGS3Vaj6Gdjciy8NJ
GIgGYdbwMbSRYrtcZZ1UY2MD1s/Giq3lw/pqrMeWDquG1WMP1/FhfQgGCgrr
cV7FHnrzYb0tWY/54dCRPVyvBxM3yO4HsRWxcQMfQxtuUdluIOtMmI18DG3w
mQnFjMI9uuwskpaWrQfz1KQeJ0sWUr8pv2b10DgHU4a1Qm6JNd7Mp9Fd4xxs
EjiHIwP2cIseTMR9DXAB0QVxwYePocSNiCsj0A1NaLfyMfL9O5w8gHPIsqmu
zgbMQ5M+bO8hfSihZQ99+TD57iLMF05KQVFNrv2pBxNR1YqJ4WyaJraNj5Gv
jaIaCAz0Ug30dj5GvveK0wPkqHGpQtVgGzDKJhrAAMV4qqfPO/iwjgQDu88N
HrQfyTTU+LOHfnowEWUtmBhycTSxnXyMfOcWdSGW8dkuPobSsgbcysE6oS5V
PdG3AaNMsAFHeYpklFIkwz+/TlG2mTnsI6NHBcLPq45gN58GwcRpsonAGtN0
9vAxlA8Xm1y+9BShIC4NEWYvH/MbDQ95fCTKkdRV8y02YK01SwEIojM1xArQ
g4mohIKUa4e9+/iYVpYLiwCcMDZKhun4woBDTiwsAixVym3A6IKcASd/OHdE
Ylxd2AN6MBH7HWSZUTJOI6STHXk7W9RGbu79yuPoTEdkmz+JI8iVEb1DRI92
sqjWssjKyXibJXJWy6Ho/InlSCG+8PpqUGdBskB2zEH9Wbdajg7IDLAqOMuA
YiFzzB4G2iQiD1m3eI4oiMhjYxpagURQYbrXraZrarkqqFum7g8XhkVWi+ry
UWhCTRHMwHYjd6Cug20ilBiyUWjH0mN0EmtAkhfij5NaHEKy/o/Y7J8k/P0L
7egMVsSxJzRHO4c+Wghy71Vv18jSimircyw/JYscGP2sX3snsw41xan5Dc4x
cytgPeElF6C+dz1eAyKLszQUsWBzotY3HbeYmPVs1/uX5xFFEUlqWHDEecRH
Ki0odE0eFQuIcO1YD9xSpX5O8u0sFScwX4UKOtx9UQM5GzC6OsI8MM6hcF6D
u7js4Sk9mBqkoySfRniaj6lLv8EDIApGDocwZ/iYnzXDh10Oau9x3lk4mIia
HpwJadYsmI+hihQRU8GUpmzZfJ0wZ/mYnzSmo8IF0bMq2eYwhvpRY7US7+Hk
njU+x6dBMJGl7qRxodKexmXjFgsV9IiKU/KbPvUEYc7zMX/X1AUX0+HfVR+j
CxNxeg2Zx+6XSF3gY6hCicViwGjyfZGPoYooA472UG6F0081FtOFiahuASe0
2kwbl3Z+oN9wtR8cn7zVR5aEy3wMFXsZcDEMkgD1UyXBBky+twRPBbMI86ge
lV7Rg4ks5yyNEGkKGqGNu0Pf0m+4U4aKUeTkCXONj/lGE1nMCFfo1SNZXZia
HNOsw3U+hir8RKRBsFCogiDMjfx6RLez2CYSG3Hc08Buo0DjfAQIJkKvMSit
0tbGHSkqWRSxO8agUJtImFt8TC1teKhYwO0lNVDQhakWVRteKB9DF8tEnMkj
QoC5I4yNe1o1Cg5PPS7XhVkZ3h0+prrl8JA4IkwYH1PNxvB0YaqR1IZ3l4+h
+lsRYQnqDXCQQ5h7fAy9pceAGhskpqAQuBhTOJjIjpak4eEGApEK52OotFhE
iRVcBbvWz57c52OqaOYEBTDIUalJQXMYQ1FjkR3KSYPqt3//PSJg414dvW3G
UDsiIg6XVfFeCTXK1oWJeCsHSLHrWOxJJB9DVd0iy/BKmHULF5wlTBQfQ/cP
WVUNJAcSpOYsdGFs543IBG6TSNm4GkgF6yLuKcGHLVi9SvZh0XwM1cgb4Lew
hwA7XJVUry5MxLUjcAIHAUTqIR9D9yjFLx8/TsR2SAu2HvEx5TXpQSyIlIdq
WHVhIm7qYHj4l0g95mM+I1JIICBaBTlVjnRhLK7DrDA7IvWEj6GbECLeI4Hh
gYuEMb9pySB05YJFQFgaREFqiGHjWibBRLwyAJIAiSACz/gY+cI9rs3AsbAX
XrAnz/mYj7Xlgd5hedRstS5MVXOU+REpG1dEyxIprD7IoPxaXR5dmAhVRdit
ldG/5GPofo2IaxLIy2l69IqPoZv4LCyBiiPHqBZf6cLUqAk3BoiUjYuu8m8o
uMPeSIuaYgkjWHu9pbP56y15VWVW9/wyOQQa8EnYH1iSKyE31Xtfpc3aMqub
V7pYLLK6QIk7uClApOX7u7RFd7H1/kn3DK28rLDVZXS7izl8KByS5zgXNKcs
5xks3iwp//avlpYRVXGcHKFqudY3RJJec+Zk8QpJeaLm5WTvUU1GF65FuGO4
c5QiEMU4C4pCvhdGCvkqyGwVkLE8lTvRwYYH2V2tBl2mI98czvcmyMLXiuWb
Ft3tE1ltvIXUxFuQEyzf7/gvl4q5W0oLkqGqtMSba2S+tzdiAOZvb/yXK8Zk
9uK1XZgvDkFpvgnmCqr3nka9sjGrmkKqLyLehClChpNIJ5qT1nvboqBTN2aL
NNwU/C62qBak5Zwj73WJ8uP3qR4rrrkFOFWtvsLGLf5ilm4BKVo1vNKFqWf9
7HWB7EkyHyPfIsfGDg4Sh2OEsfGCABmDY1lEmdpFHRsYulXOtlDAaEe6KboY
JYTTrsrYwNDVZzXY1hIKqXyMq2z8JP0Dq8FyNeWhCxNhKUCqzq1bcriUZoZh
EDmXDN8LUwaTRi3T+b3LGESIwODcTRdDN9RF7Eoga5oNy+BjKI3OgjHch0X5
gFq1oQsTsQHE5PECBSKVyceQehggykjK4UhRvX+qCxNRv4dZaQdv7/gYWffB
NXAPh3aEydLFoGYYIYvmcGxgjJbajYNcwmTzMQaN48hFgRWqduvCRNQMgOM4
4yBSOXyMfCyAjQAkG1kmleO6MBH5QpDSNgK5fIwcJsGoIyzA+Rth8nQxCLOR
V9GssTmGIGz2KFOB9cCrKVk7k3nfjhZ9S3+IcZHD1AyHRXsH8/aK32dXEtSm
dlbb28t2GU5b3VcVbG9U2kM50DcuuJiNw75AY6wTeyFb/34BWnV+wcYGNFbq
TXHdUmsnFuA2XCwqic06K/juW+xytE2oeSM5mkaZJRriSMiskdGiEeqC0AgF
JNxGrCpR5Xz+RtbExNbA/x2NWJv/IBHB7p+sag2i\
\>"]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"f2", "[", "x_", "]"}], "=", 
  RowBox[{
   RowBox[{"f", "[", "x", "]"}], "[", 
   RowBox[{"[", 
    RowBox[{"1", ",", "2", ",", "1"}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5595077287240868`*^9, 3.559507738690277*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "93.22860398860391`"}], "+", 
  RowBox[{"30.70204971982746`", " ", "x"}], "-", 
  RowBox[{"3.0741504585948993`", " ", 
   SuperscriptBox["x", "2"]}], "+", 
  RowBox[{"0.09727893505671273`", " ", 
   SuperscriptBox["x", "3"]}]}]], "Output",
 CellChangeTimes->{3.577701682530785*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"segment2", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{"f2", "[", "x", "]"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "5.33", ",", "8.33"}], "}"}]}], "]"}], " "}]], "Input",
 CellChangeTimes->{{3.4826639558125*^9, 3.48266397771875*^9}, {
   3.482664893203125*^9, 3.48266489575*^9}, {3.4826649806875*^9, 
   3.482664982765625*^9}, {3.482665113578125*^9, 3.482665156546875*^9}, {
   3.482665204203125*^9, 3.482665208359375*^9}, 3.4849145061875*^9, {
   3.484975271390625*^9, 3.484975284296875*^9}, {3.484997882078125*^9, 
   3.484997911578125*^9}, {3.4850017183125*^9, 3.485001726046875*^9}, 
   3.559507766721583*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV13k4lF0UAPCxlRYZy5gxtimJbEmUhDnZlYSQQt+kbEXZklZEksoSQkmW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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{5.5, 0},
  Method->{},
  PlotRange->{{5.33, 8.33}, {-2.189990241570575, 5.46182409240798}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{
  3.577701682557596*^9},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"f3", "[", "x_", "]"}], "=", 
  RowBox[{
   RowBox[{"f", "[", "x", "]"}], "[", 
   RowBox[{"[", "2", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.559507913166298*^9, 3.559507936878832*^9}, {
  3.559507979912235*^9, 3.559508004442833*^9}}],

Cell[BoxData[
 RowBox[{"x", " ", 
  RowBox[{"(", 
   RowBox[{"1.7312975090752871`", "\[VeryThinSpace]", "-", 
    RowBox[{"0.45857492301936753`", " ", "x"}], "+", 
    RowBox[{"0.046463084240862026`", " ", 
     SuperscriptBox["x", "2"]}]}], ")"}]}]], "Output",
 CellChangeTimes->{3.577701682588139*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"segment3", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{"f3", "[", "x", "]"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "8.33", ",", "14"}], "}"}]}], "]"}], " "}]], "Input",
 CellChangeTimes->{{3.4826639558125*^9, 3.48266397771875*^9}, {
   3.482664893203125*^9, 3.48266489575*^9}, {3.4826649806875*^9, 
   3.482664982765625*^9}, {3.482665113578125*^9, 3.482665156546875*^9}, {
   3.482665204203125*^9, 3.482665208359375*^9}, 3.4849145061875*^9, {
   3.484975271390625*^9, 3.484975284296875*^9}, {3.484975398203125*^9, 
   3.484975417578125*^9}, {3.48499788959375*^9, 3.484997906578125*^9}, {
   3.485001734640625*^9, 3.485001740125*^9}, 3.560542563061752*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV1Xk0lWsbBnBTkpREiUr2PLzJuLXNl5nkFULlHFJK7ZyKlFIJkSZDhoPS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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{9., 10.},
  Method->{},
  PlotRange->{{8.33, 14}, {9.457804727566513, 61.85218275527623}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{
  3.5777016826146193`*^9},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]],

Cell["We plot the complete spline", "Text",
 CellChangeTimes->{{3.482664394578125*^9, 3.482664468984375*^9}, {
   3.482664514625*^9, 3.482664539265625*^9}, {3.48275498540625*^9, 
   3.48275501025*^9}, {3.482755052734375*^9, 3.48275518615625*^9}, {
   3.48491260909375*^9, 3.484912650578125*^9}, 3.48491287253125*^9, {
   3.48497766284375*^9, 3.484977663578125*^9}, {3.484979246015625*^9, 
   3.4849792499375*^9}, {3.484979322359375*^9, 3.484979372375*^9}, {
   3.484979455421875*^9, 3.48497947915625*^9}, {3.559508376208751*^9, 
   3.559508474187669*^9}, {3.559509086440854*^9, 3.559509091388207*^9}, {
   3.55954171593937*^9, 3.559541724775205*^9}, {3.560537809989053*^9, 
   3.56053781902894*^9}},
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"graphSx", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"f", "[", "x", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", "14"}], "}"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"Thickness", "[", "Medium", "]"}]}], ",", 
    RowBox[{"AxesOrigin", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "0"}], "}"}]}], ",", 
    RowBox[{"Epilog", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Red", ",", 
       RowBox[{"PointSize", "[", "Medium", "]"}], ",", 
       RowBox[{"Point", "[", "points", "]"}]}], "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{
  3.482232990035215*^9, {3.482662078546875*^9, 3.482662109859375*^9}, {
   3.482662150546875*^9, 3.4826622134375*^9}, {3.48266495928125*^9, 
   3.4826649904375*^9}, {3.484975777125*^9, 3.48497580125*^9}, {
   3.48497956090625*^9, 3.484979579671875*^9}, {3.48498021971875*^9, 
   3.48498023115625*^9}, {3.484997551734375*^9, 3.48499757775*^9}, {
   3.559508523791254*^9, 3.559508528181573*^9}, {3.559509062991074*^9, 
   3.559509065195182*^9}, {3.559509580866961*^9, 3.559509592355838*^9}, {
   3.560537826509241*^9, 3.560537836331844*^9}, {3.560538420771313*^9, 
   3.560538422492601*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {Hue[0.67, 0.6, 0.6], Thickness[Medium], LineBox[CompressedData["
1:eJwBEQTu+yFib1JlAgAAAEAAAAACAAAACLv3E904eT77bUQzYNWFPqGrZCPv
Ilc/OK6aWEMFZD+yg6qxvCJnP19FNgItA3Q/um/NeKMidz9SlW1BQv+DP77l
XtyWIoc/fqFqL4/3kz/AoCeOkCKXP8FdZSlA6KM/Qf4LZ40ipz9n30BFxcmz
PwItftOLIrc/5MOBdD+Nwz8bX+AOoRvIP5QN8GkH2dM/7NGNwp7o0T8KrmYh
ucXcPx+i5W4Gptc/kN+TgPGK4j+v/9Ed+d/dPwkPXMCb0OY/qK2lOsbX4T89
ooJEMpbqPyairGfV/eQ/vUJch5ly7j+PrVBNMRXoPxVX4LonAvE/ATg7h133
6j94Dtmn6ZPyPyEJcELPF+4/sv6jifIt9D+lrPWoiIHwPzr4WCmZlfU/L+AB
DdDv8T/+EgBWV+H2PxA3szE6ffM/h3052+gy+D92zYeADPD0P1uI7n/IWfk/
M4cBkAGC9j8a6f61f4T6P2XMyfucDPg/xlsSJpqV+z8bUbWRoHz5P6mBkeI2
g/w/KPlF6MYL+z+qxUPXRXP9P7rg+WhVgPw/1AG6sqpD/j+j61KqBhT+PzKB
i6pqFf8/AYL6R16g/z/NOqhTINT/P/Gr4gcPiQBAfngbGK48AECOqBpMgFEB
QP5+Q6/WjwBA7URkpaUMAkCJptho6tcAQAcn1SwexAJAOUGEYMoZAUDMmpgU
KIsDQOh/6TpgXAFAU65tEeZEBEBXquD9YZYBQIZTlW41DgVAMjQ+IkHRAUBz
PuT519MFQKXCZnGEBwJAI8lEmi6MBkDpkKG0bTcCQH7l95oWVAdAUMX3PO9o
AkCbobywsg4IQK/6sUhNlQJAc6Oo9KHFCEDUA/Hwfb8CQPc255gijAlAi0F7
9UnsAkA9ajdSV0UKQH715a2bFQNALi/aax0OC0CcpAHQYUIDQOGTjpqXyQtA
1sGsyaJsA0BPPmr3ZIEMQCS3EkDplgNAaXqYtMNIDUBBDS6BM8YDQEVW2IbW
Ag5AIJnM0iL0A0DMw2q5eswOQIbNPxRiKARADnckGnKSD0Ds21iPsF4EQAnl
98eOJRBAwQWSBX+UBEBg1wYzrYkQQNG30fLE0gRAmJmeqCXnEEDZdRCiDhEF
QK7+SbXHQhFACPZebHBSBUCarB5yMqYRQDEmoquwngVAZyp8OfcCEkBbrLqJ
R+sFQAnxArGEZxJAZoliXbpEBkCJWp2/O8oSQILlQ3+PowZA6pPA2EwmE0Bc
ZrEZugIHQCEWDaImihNA72bA5MNxB0A5aOJ1WucTQPARL4M24QdAJgPh+VZM
FED+k7DB+2IIQPFA8xR9rxRAl/xkzgfsCECdTo46/QsVQC9pWEz1dAlAZvNp
edRTFUA6LsqlnuUJQHhN1DY=
      "]], LineBox[CompressedData["
1:eJwV1nk81csbB3BJCjfr+VK2cxI5WuwpxfFEhCiRZEnWRETSQldJiotWVOom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      "]], LineBox[CompressedData["
1:eJwd1nk81F0XAPChSClLZlIJY98ppaTlXJXKkrRJZcsWkiXVoyxNodSTEh5F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      "]]}, {}}, {{}, {}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{-1, 0},
  Epilog->{
    RGBColor[1, 0, 0], 
    PointSize[Medium], 
    PointBox[{{0, 0}, {2, 2}, {5, 3}, {9, 5}, {11, 2}, {14, 1}}]},
  Method->{},
  PlotRange->{{-1, 14}, {0., 5.463650974757471}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{
  3.577701682663095*^9},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]],

Cell["Part IV", "Text",
 CellChangeTimes->{
  3.484992245703125*^9, {3.484992316015625*^9, 3.4849923314375*^9}, {
   3.48499253890625*^9, 3.484992628625*^9}, {3.484994235171875*^9, 
   3.484994236890625*^9}, {3.48499689084375*^9, 3.48499689559375*^9}, {
   3.486039583859375*^9, 3.486039584453125*^9}, {3.559482005654936*^9, 
   3.559482006444809*^9}, {3.572683638740938*^9, 3.572683640652047*^9}, 
   3.572683680653335*^9},
 FontSize->36,
 FontColor->RGBColor[0, 0, 1],
 Background->RGBColor[1, 0.9, 0.8]],

Cell[TextData[{
 "We can check graphically and manually  the ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["C", "1"], TraditionalForm]]],
 " and boundary conditions.\nIt is verified that no boundary conditions are \
introduced."
}], "Text",
 CellChangeTimes->{{3.4849789611875*^9, 3.48497897071875*^9}, {
   3.484979148703125*^9, 3.484979160640625*^9}, {3.484979192*^9, 
   3.484979203421875*^9}, {3.4849961621875*^9, 3.4849962291875*^9}, {
   3.48499627365625*^9, 3.48499632746875*^9}, 3.484996906109375*^9, {
   3.486039064921875*^9, 3.486039067234375*^9}, {3.4860391213125*^9, 
   3.486039158296875*^9}, {3.487681808125*^9, 3.4876818221875*^9}, {
   3.559508547176159*^9, 3.559508553783866*^9}, 3.560537859615929*^9},
 FontFamily->"Times New Roman",
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell["First derivative of S(x)", "Text",
 CellChangeTimes->{{3.482664394578125*^9, 3.482664468984375*^9}, {
   3.482664514625*^9, 3.482664539265625*^9}, {3.48275498540625*^9, 
   3.48275501025*^9}, {3.482755052734375*^9, 3.48275518615625*^9}, {
   3.48491260909375*^9, 3.484912650578125*^9}, 3.48491287253125*^9, {
   3.48497766284375*^9, 3.484977663578125*^9}, {3.484979246015625*^9, 
   3.4849792499375*^9}, {3.484979322359375*^9, 3.484979372375*^9}, {
   3.484979455421875*^9, 3.48497947915625*^9}, {3.484980267109375*^9, 
   3.484980270515625*^9}, {3.484997590125*^9, 3.484997612640625*^9}},
 FontFamily->"Times New Roman",
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"dSpline1", "=", " ", 
  RowBox[{"D", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{"f", "[", "x", "]"}], "]"}], ",", "x"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.484912715*^9, 3.484912771*^9}, {3.48491306615625*^9, 
  3.4849130966875*^9}, {3.484913129359375*^9, 3.484913129921875*^9}, {
  3.4849139203125*^9, 3.484913921921875*^9}, {3.48491610159375*^9, 
  3.48491611259375*^9}, {3.48497586496875*^9, 3.484975869640625*^9}, {
  3.559508572093324*^9, 3.559508573692653*^9}, {3.559508613621819*^9, 
  3.559508628182948*^9}, {3.559509119308342*^9, 3.559509120908365*^9}, {
  3.560537865460745*^9, 3.560537903545519*^9}}],

Cell[BoxData[
 TagBox[GridBox[{
    {"\[Piecewise]", GridBox[{
       {"0", 
        RowBox[{"x", "<", "0"}]},
       {
        RowBox[{
         RowBox[{"0.046463084240862026`", " ", "x", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "9.869661700504874`"}], "+", 
            RowBox[{"2", " ", "x"}]}], ")"}]}], "+", 
         RowBox[{"0.046463084240862026`", " ", 
          RowBox[{"(", 
           RowBox[{"37.261786154796305`", "\[VeryThinSpace]", "-", 
            RowBox[{"9.869661700504874`", " ", "x"}], "+", 
            SuperscriptBox["x", "2"]}], ")"}]}]}], 
        RowBox[{"0", "<", "x", "<", 
         FractionBox["16", "3"]}]},
       {
        RowBox[{
         RowBox[{"-", "11.022994782994784`"}], "+", 
         RowBox[{"3.86570976348754`", " ", "x"}], "-", 
         RowBox[{"0.3090038356705023`", " ", 
          SuperscriptBox["x", "2"]}]}], 
        RowBox[{
         FractionBox["16", "3"], "<", "x", "<", 
         FractionBox["2345624805922133", "281474976710656"]}]},
       {
        RowBox[{"30.70204971982746`", "\[VeryThinSpace]", "-", 
         RowBox[{"6.148300917189799`", " ", "x"}], "+", 
         RowBox[{"0.2918368051701382`", " ", 
          SuperscriptBox["x", "2"]}]}], 
        RowBox[{
         FractionBox["2345624805922133", "281474976710656"], "<", "x", "<", 
         "14"}]},
       {"0", 
        RowBox[{"x", ">", "14"}]},
       {"Indeterminate", 
        TagBox["True",
         "PiecewiseDefault",
         AutoDelete->True]}
      },
      AllowedDimensions->{2, Automatic},
      Editable->True,
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxItemSize->{
       "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.84]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}},
      Selectable->True]}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxItemSize->{
    "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[0.35]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  "Piecewise",
  DeleteWithContents->True,
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 CellChangeTimes->{3.5777016827747917`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"graD1", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{"dSpline1", ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", "14"}], "}"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"Thickness", "[", "Medium", "]"}]}], ",", 
    RowBox[{"AxesOrigin", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "0"}], "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{
  3.482232990035215*^9, {3.482662078546875*^9, 3.482662109859375*^9}, {
   3.482662150546875*^9, 3.4826622134375*^9}, {3.48266495928125*^9, 
   3.4826649904375*^9}, {3.484975777125*^9, 3.48497580125*^9}, {
   3.484975914828125*^9, 3.484975957578125*^9}, {3.484977919265625*^9, 
   3.48497795284375*^9}, {3.484978079421875*^9, 3.484978085875*^9}, {
   3.559508653656217*^9, 3.559508691211942*^9}, 3.559509599848436*^9, {
   3.560537878214731*^9, 3.56053790709599*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {Hue[0.67, 0.6, 0.6], Thickness[Medium], LineBox[CompressedData["
1:eJwVl3k81Nsbx61j5jtMxVBUlC6pVFy3Qup5EpJKWZKypCJFlrSQJCFL2Soh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      "]], LineBox[CompressedData["
1:eJwVlns4lNsXxzVUNHIL875DZtTviHKLKVLau5IoFSoVGpdkugmh6CIJR3Rc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      "]], LineBox[CompressedData["
1:eJwV1nc81V0YAPBrjzIKlZWLe82UBiH5HakkMjNKyIhCQhHhJSMNepEGkVXJ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      "]]}, {}}, {{}, {}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{-1, 0},
  Method->{},
  PlotRange->{{-1, 14}, {-1.6804355075644182`, 1.8258505024246503`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{
  3.577701682958663*^9},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]],

Cell["Second derivative of S(x)", "Text",
 CellChangeTimes->{{3.482664394578125*^9, 3.482664468984375*^9}, {
   3.482664514625*^9, 3.482664539265625*^9}, {3.48275498540625*^9, 
   3.48275501025*^9}, {3.482755052734375*^9, 3.48275518615625*^9}, {
   3.48491260909375*^9, 3.484912650578125*^9}, 3.48491287253125*^9, {
   3.48497766284375*^9, 3.484977663578125*^9}, {3.484979246015625*^9, 
   3.4849792499375*^9}, {3.484979322359375*^9, 3.484979372375*^9}, {
   3.484979455421875*^9, 3.48497947915625*^9}, {3.484980267109375*^9, 
   3.484980270515625*^9}, {3.48498037325*^9, 3.4849803761875*^9}, {
   3.48499762365625*^9, 3.48499763034375*^9}},
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"dSpline2", "=", " ", 
  RowBox[{"D", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{"f", "[", "x", "]"}], "]"}], ",", "x", ",", "x"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.484912715*^9, 3.484912771*^9}, {3.48491306615625*^9, 
  3.4849130966875*^9}, {3.484913129359375*^9, 3.484913129921875*^9}, {
  3.4849139203125*^9, 3.484913921921875*^9}, {3.48491610159375*^9, 
  3.48491611259375*^9}, {3.48497586496875*^9, 3.484975897078125*^9}, {
  3.560537886767688*^9, 3.560537909632371*^9}}],

Cell[BoxData[
 TagBox[GridBox[{
    {"\[Piecewise]", GridBox[{
       {"0", 
        RowBox[{"x", "<", "0"}]},
       {
        RowBox[{"0.13938925272258607`", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "6.57977446700325`"}], "+", 
           RowBox[{"2", " ", "x"}]}], ")"}]}], 
        RowBox[{"0", "<", "x", "<", 
         FractionBox["16", "3"]}]},
       {
        RowBox[{"3.86570976348754`", "\[VeryThinSpace]", "-", 
         RowBox[{"0.6180076713410046`", " ", "x"}]}], 
        RowBox[{
         FractionBox["16", "3"], "<", "x", "<", 
         FractionBox["2345624805922133", "281474976710656"]}]},
       {
        RowBox[{
         RowBox[{"-", "6.1483009171897995`"}], "+", 
         RowBox[{"0.5836736103402764`", " ", "x"}]}], 
        RowBox[{
         FractionBox["2345624805922133", "281474976710656"], "<", "x", "<", 
         "14"}]},
       {"0", 
        RowBox[{"x", ">", "14"}]},
       {"Indeterminate", 
        TagBox["True",
         "PiecewiseDefault",
         AutoDelete->True]}
      },
      AllowedDimensions->{2, Automatic},
      Editable->True,
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxItemSize->{
       "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.84]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}},
      Selectable->True]}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxItemSize->{
    "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[0.35]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  "Piecewise",
  DeleteWithContents->True,
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 CellChangeTimes->{3.5777016830568743`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"graD2", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{"dSpline2", ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", "14"}], "}"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"Thickness", "[", "Medium", "]"}]}], ",", 
    RowBox[{"AxesOrigin", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "0"}], "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{
  3.482232990035215*^9, {3.482662078546875*^9, 3.482662109859375*^9}, {
   3.482662150546875*^9, 3.4826622134375*^9}, {3.48266495928125*^9, 
   3.4826649904375*^9}, {3.484975777125*^9, 3.48497580125*^9}, {
   3.484975914828125*^9, 3.484975991890625*^9}, {3.4849784160625*^9, 
   3.484978438015625*^9}, {3.559508709986929*^9, 3.55950871274996*^9}, {
   3.560537913978498*^9, 3.560537918782051*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {Hue[0.67, 0.6, 0.6], Thickness[Medium], LineBox[CompressedData["
1:eJxli3s8lPkegI2Ykcu4vS/KpjVyqyhU5Pb9yaWTZtJORWlDVqvt2ElJlmhH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      "]], LineBox[CompressedData["
1:eJwV0Xs01AkUB/CpLe32QFPTjGnwU6sirJiVivndUSkSNRblXSgWeT96rNWs
9cqS9CAbyklqJT3ILttt4mx2kqYQaYsZ1TBF+P3Yimp/+8c993zOud9z7j3X
aHeUJGQ6i8XaytT/PSVP2WPtxYGR9Br3Q6tUZHeZ7afmHRyoebZnwZ8mKtLq
Wp6RpzcHooX67R+NVOSrDvvQZD9mXpkl+ZGtIl35p8cbgxjbBW2XUkrS8LxE
1zGaA2/GOG6ZtUqy/kl7cWMMByojl2e5VCtJibbHcus4DgQO2DbpXlCS6Ule
IiKRA4pnPquLCpXkGyffiA8HOVDfctbw0kEmPxzSUp3BgZwS85F7YiW5zXZ/
KreUA5bOG/N12vpI6b3SkYH7HOh2GKwwv99L3jnOCq01WQSKDvaKRPE/ZHdF
dp7zL4sgdI7fzb9Cu8kHmWdkazSLQJdcE9/xsIP89fqT8lFXLgRybUjNkIJ0
PGyi336VC+AkmullKycfGkw/q63Ngz4/odqd10RazZzRyY7lQWpSl1zWWEfG
N+QuiHnAA3ATTJaVlpEFC80H35nqAUtiUn9v+ynMrKP3OeUyFhFGJ81q0X/F
xs+URg9q9P51Vd2S4ez+W+ReNz6MyAUxYYf/xlORsmzhZT7wxDqCdYEKnFbc
FbHyq8XQol466+RQO4rncz9rIhgPcl8M3O3C3V69xTPki6F+eH9BSuBT3PlK
MfDKQgBfujUI5zr2ojnvcetYvgCE9i0WN3OUqNILbtgxLADfjrCqLI9+jAxe
7J0h0Qczvckl3Rte4pMUny90a/ThUEDT9M0L1LjE7sr6O3MMwOWIx7Jz3QMo
djAT2kcZQGtwl0NyswbFPKtv2K0G0EwebYnKe4Pc1bt6rlgaQnCL7ab+1GGU
vysXJBUYgnNxZ1qZcAQDsqPCCt8agoH7JX4gbxRDrKysZSYEyJUTVX46Y3hk
1qhN0A4CLEafU6/Hx3CZqQWbv5OAtcbSafHvx/C2S/iQgrHDTmOdqakxpPNf
lot8CJDIwk3nzqDQX9Cjy/cnIDH/XaAZm0LLVU0aRRABf6xit0VYUNjpfaJE
FMXkYzdWDu2hMPqHR/vHGbtWDNQmfE/h7DIdj6poAjx7jjR9jKRQ9DJrDj+W
gD0Oj57PS6CwMioleTyegGx2AMfiJwoPpO2VVB0goO1asnRfKYWG1Wu0+OlM
nvrN920Xhc5Lu2L7GNdpiXc3P6UwsTC+tyKDAD7/8d6iXgrbpFfqrbMIUAEr
br2awhQv4/CtOQTE5n6XdWqCwues+YrUYwQcM/lYS3JonJ1YbbepgIAJu2MN
C/VotHm95eK84wR4b1suGxTQmNuZLj19goAlSdtbC76mUXRpSnijkIBrzedV
amsaS9wHitQlBDwKcNU5KqFR3vKzVnUpATZx/QtDPGmcsF8aF19GwOn0ZP5a
bxpdV/i7TDvH3H/5nPGLXTQeODNZf5ex/Pbqlb+H0FjBLjLOLWf+1dFqmRtG
46ep9k/888x+HybW2cbQaBobE65k7K2dI56XQKOnWrv7QgUBt4yMNqmSaZT6
Vm3Yd4HZ99s6l5uHaKx+6HRVWElA+uYtkpxUGnsc1fqTjDU+fV670mjUakzL
ll1k/hWV4GeTSeP19zfsNIwdV5bmf2b8Hxl4UvQ=
      "]], LineBox[CompressedData["
1:eJwVjXk81Hkcxn9utTZEItE4xsz4ZcnRaxz1/SgvR8hZ20W5ykxjdJFIJ9Ix
wpaMdCo52+lSFF8bWV2WSEy2lYSRcv1iG8fs7B/P63m9X8/zeh6T8NjAKEWC
IELk+t+vbb6qv7OUBjZdaTz7kxQ+ZRjSrFtGgw3W9DHDNApXZEpd3su57O9Z
XvIxCs9LctCLvk0Df6e74ZBE4Rq/0sajd2iQP66/toFHYeMfOVYPHtJg6fY+
8zd+FB487LWW/4gG7BWTD3b7yPdUp/mMShp46qp7aHtR2Fc3TCSsokHkUxbH
fxWFD1qTdoeq5XvGMeVN9hQWR2G2Rx0NNN6NO7w0oHDOm/7VnU00GPJQ8Kj/
NI7nlbE3zXymQRFrMadi/zjmKA1/YOmbgIbiyGa+YAzffyqJVvIwgQ1zMrpK
745ifhC/ZnSfCXQsz75q1zWCf0tX49UXmkDmWLSFcf8wLqJ/NnZ7awI2b10Z
3fbfMHPHO1aRmimIPq5P9QodwgsTgwgTR1PIdWJzPTIH8QSl0+W+wxT8R8u5
/h8HMOhKNAOEptDdsrWRmNePky4qeqk3mgJTq9D1ycbP2Jy66dv23RRG8h65
atz+hNmjISUpDDPI9FO7ovThI16xfpNGzzozGAgbXKhq1Y3Lt+5sMEs3A3DR
6dr6exc+7aTqk1gp7/sOnu9a0Ik3JX9uT+43g12LBtNiq97ic5GdlVEG5kA4
h9sG6L3BNfe0r0s9zIH2i6pl9rbXOOhWaM/eRHOoFbAjlyg14F95Dt8UyuT9
ley9M2ersY/QX+Yiludrr0t154twKfdI9BYNOhC94pp4vf14qoBqZzrLWd3z
jDimCFXdHtOay5FzUOsfl/Iq0acQlYK/8uiwrbi5+KRWPZrZt8Vp1XM6gO12
5dx3L9Axm0aWcIoOIydV4pT1W1B8dXWvspUFNIchsc69NrTp7uQNo80WQDvk
r/6zVgcq9navXiSQ5+6SpIcP3iOJT6e4/rEFjARtfORt9A+6sGSi7rjEAvQj
c/e+d/yIRDkMFYYhAzZQf5Zz5nxCVXGXvPd7MaDDIuLVUGUvsv7BGCxNYkC6
9VNBY0YfOtc7IRCUMCBafMZO6DaAoq/5zRzvYEA3+3Tg21EJuqVYXR86lwkJ
Mb663LovqP0lP6uPzQR/t6Sq8bivaJejQ0XgTiZ4jvKU2n2G0YGE1MLWfCYM
MJ/3ZAlG0J4li/IVXjLBp0R7uV3UKGrn1kl0ZphQq/dETPiNIdL4jksryYIN
wfmjnqxx9O06c/OtjSwQ7dR75i4bR4tf3W/ZepoFi/ljkl39FHIOSfV9VsmC
Ilflowtqv6Nn2VwTzSEW+BAJnL6SCVQt7KyNMbIEUW7qvJisSVSoLog64G0J
9orP6fzof5HUcF04J9kSmtfzMy4G/EArL4RFqpZZQspBL85qUoq+VhyrOfHB
EvwFaecXLpxCPxVZ9RppkdC9P+TQtdkpZKBgpBm2koQzdtzOm+3TKHuWlp2+
iwQfcUdqe+0Mmo7gLAq5QoJ9YPKNoxdnUVueM9/9NQltBY8P9+yWIalmfLB2
Ewm8QNvB83EyREsVOXXJWVmhONjrgAzxYulqe5pJWBqawxIdkSEVN82rl1rl
f/q7W5PPytDyrz0tVKf8T2DBMCiXISE65VDQR0J9fFaT34AM1d6vN+T3k7CF
ru6oNCRDfSyZguMACVTroYKKYRmy1d3X1CQhwXwZL8FoUoZeDITskA6RUBNn
lvVdkYDprGXCgHESjG1mneq0CTBV4x1eTJHAPeE4kq9DgOfBwqh+OVd82Hcz
fgEB57Yb2iZPkLBG8EXT0oAAK2eVl0U/SEgc7OjNpBEQLEJ39kpJeOGqm8c1
JSCRnnhh5RQJ84V+fm7mBDRoDke0TZNQ4tFQOckgYCiFtebKDAkTlxViW1gE
zJdG2HBnSVg14WJeShLAjr2s5yAjIcM3oTPFioDQ3o5pmZzbb9zLCLUm4D+U
9LZW
      "]]}, {}}, {{}, {}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{-1, 0},
  Method->{},
  PlotRange->{{-1, 14}, {-1.2834972609832782`, 2.0231295727322545`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{
  3.577701683098312*^9},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]],

Cell["Third derivative of S(x)", "Text",
 CellChangeTimes->{{3.482664394578125*^9, 3.482664468984375*^9}, {
   3.482664514625*^9, 3.482664539265625*^9}, {3.48275498540625*^9, 
   3.48275501025*^9}, {3.482755052734375*^9, 3.48275518615625*^9}, {
   3.48491260909375*^9, 3.484912650578125*^9}, 3.48491287253125*^9, {
   3.48497766284375*^9, 3.484977663578125*^9}, {3.484979246015625*^9, 
   3.4849792499375*^9}, {3.484979322359375*^9, 3.484979372375*^9}, {
   3.484979455421875*^9, 3.48497947915625*^9}, {3.484980267109375*^9, 
   3.484980270515625*^9}, {3.48498037325*^9, 3.4849803761875*^9}, {
   3.48499762365625*^9, 3.48499763034375*^9}, {3.48500188915625*^9, 
   3.4850018921875*^9}},
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"dSpline3", "=", " ", 
  RowBox[{"D", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{"f", "[", "x", "]"}], "]"}], ",", "x", ",", "x", ",", "x"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.484912715*^9, 3.484912771*^9}, {3.48491306615625*^9, 
  3.4849130966875*^9}, {3.484913129359375*^9, 3.484913129921875*^9}, {
  3.4849139203125*^9, 3.484913921921875*^9}, {3.48491610159375*^9, 
  3.48491611259375*^9}, {3.48497586496875*^9, 3.484975897078125*^9}, {
  3.48500189665625*^9, 3.485001903015625*^9}, {3.560537921993818*^9, 
  3.560537927310957*^9}}],

Cell[BoxData[
 TagBox[GridBox[{
    {"\[Piecewise]", GridBox[{
       {"0", 
        RowBox[{"x", "<", "0"}]},
       {"0.27877850544517213`", 
        RowBox[{"0", "<", "x", "<", 
         FractionBox["16", "3"]}]},
       {
        RowBox[{"-", "0.6180076713410046`"}], 
        RowBox[{
         FractionBox["16", "3"], "<", "x", "<", 
         FractionBox["2345624805922133", "281474976710656"]}]},
       {"0.5836736103402764`", 
        RowBox[{
         FractionBox["2345624805922133", "281474976710656"], "<", "x", "<", 
         "14"}]},
       {"0", 
        RowBox[{"x", ">", "14"}]},
       {"Indeterminate", 
        TagBox["True",
         "PiecewiseDefault",
         AutoDelete->True]}
      },
      AllowedDimensions->{2, Automatic},
      Editable->True,
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxItemSize->{
       "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.84]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}},
      Selectable->True]}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxItemSize->{
    "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[0.35]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  "Piecewise",
  DeleteWithContents->True,
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 CellChangeTimes->{3.577701683216308*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"graD3", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{"dSpline3", ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", "14"}], "}"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"Thickness", "[", "Medium", "]"}]}], ",", 
    RowBox[{"AxesOrigin", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "0"}], "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{
  3.482232990035215*^9, {3.482662078546875*^9, 3.482662109859375*^9}, {
   3.482662150546875*^9, 3.4826622134375*^9}, {3.48266495928125*^9, 
   3.4826649904375*^9}, {3.484975777125*^9, 3.48497580125*^9}, {
   3.484975914828125*^9, 3.484975991890625*^9}, {3.4849784160625*^9, 
   3.484978438015625*^9}, {3.48500190496875*^9, 3.48500190940625*^9}, {
   3.559508726886991*^9, 3.559508759993059*^9}, {3.56053793165449*^9, 
   3.560537937368455*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {Hue[0.67, 0.6, 0.6], Thickness[Medium], LineBox[CompressedData["
1:eJxFz1tM0gEUBnBAAw1ETbRNpw1LsFY6deVtoRl2cVIKZZutyxyK2lJmq4ZT
h64kU+niXETpvAxjhtjNta66LImGK6aGa1noJJxlyrT+kSnVg+c8nJ39Hr6z
87FzioW5FBKJtPPf/N8eTwi/sTgZb/j5jKnSYk7asUyX1IfeSloxZUvFUG3o
Q3DQMSuzNeg1+Ju5/kXzlBm8rs1WRO2wgLtd5mDn5zGwtkuTMGAZB3PadJKR
pUnwpa4MQZT/FJgcl6g4QkyD2Z7SlLdrv4M1uh/aC5Vz4Egr2evdrAPsE3s/
KqF8HnxmUCFnzC2AYxTky+Sqn+Bck3HxJuMX9s3sudJS5gSHO1OnBuiL4MdW
Z/5B+R9w+1dhJ5W1jP9X/d59tMUFdtyeoHnXkJJXrNQGpsszyeAZvlijYVDA
NO7I5pCXaJNaxQqvdQOL9Cd9v/DdwdWixqKtzFXgU7xJp2UIvd7IV0fUUcEV
NkIdcIAGvtH69M49pgfm27ULra/QxDa7KrTOE7y9MFZ4KHU1OCLyw4lgJh08
3qBUXzOi9/MKCXElA1xQqnrQv8cLnJo1Wv2ewsS+/YWPSk1o5tkNgSVXvcGe
NsKgDPMBH7dQY7pq0KrrzdowO1q/vLfHkOILVutCSqI70JJNZfEEZQ3ed1Du
npOga7KbehPfoKcb+kbTOX5gdoBXG+ciOj5/4nS2Hc1xG3dmpbPAjuR5Vnk3
2mDo4z4bQzftUyYs0f3BPLGr2DsM/Ukm1bB56F29pug8PlrvvrGvMw2dw7VQ
BwXogLTzgtkMtPTwR6lciM6bL5ANi9B/AUKwarM=
      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGDQA2IQ7bLdwfBamKhD4zElth3HHu+v6394yzgcwfeTmvV1
TzKCL780SMCtAMEPsKhsEJ+P4Dednv/hxVkE/9AUhoytmmJw/o1lXf1evQj+
+Y65By1fIfhzNt9c/NFPHM53a9SUvbwRwb8ox7SQj08CzjdiZbkqVITgl+zu
Ey48j+BPFtF9+UNLEs7v2PYlz7MPwY/TcP3/+RWCz/V4n326vxScPz33YJfJ
WgSfcfb1HG1OaTjfUVD8/6scBD8p/P5sllMIfuSzCy+e6cnA+boS1858mojg
P5JM2R3xDsHPTZGOag+ShfNv1kUzC2xA8JVs1jsf4pZD2O+kY2Kbj8SXMNIX
OoPgi5sn3lpvIA/nn/qxWKZ8MoIf35WfOeM9gp9qZGR8UFMBzu9m/2iWHIHg
X42aOs8uH8GXX2fJJtWG4N9jELzQMAnBnxf8YubzeQi+n0acD+MiBP/fn8v/
pJYi+GHP+W4sX4bgr7voudFkBYJ/y+257G8kPtuelq6DKxH8zT+32LxC4gMA
3mtqIQ==
      "]], LineBox[CompressedData["
1:eJxN0FtM0gEUBnDAvMxc2mxLMVBSA3KsXtwQTO0ymENn6awFgtNkChi5sos4
WmkuluMhcjjMVkoBibYss1GDtdRGs8tKM3HNBwIdrWw2onkhqpf/18PZt9/D
2c53GLUnyuUUEom09+/8yz7JrRSVPaOIV3de2DzkLXSV2d0Xh2H6ipHz6DFs
fL+43/MG3jTIFYf9sCLq+zw7hUF45HmgIUoIqyvUruVm+JoutnHcAtuy/fQD
H2BW/Ue2LXY74a2aChIjDw4Fkz8J6uGiLYHEQya49TqlOM4NZwXvlE7/hLnL
0oFLzEzCew6LE7yV8FC16kWmDu7kxZRoHLBY65/RLsJddR6HPDUL/3y4uX9V
CFdYZd5TGvhIY+4SeRAuMR2M5M/BduWFhqqEbMJr5uAMiw8/ufcjKV4Bf5ZG
m9/2wOHmKt6+l3DbbjfbtAafcTp9Gzg70OfBr9s0CXxXJHBS9XCgxDM3/hTu
Tg+NtQfg+0ZmNDONiftO3xCdLYZ3rTC/2FvhLl9Irx+AG/rKwu2zsJXiHJfF
swjPTKqvLnDhprzc0XIV3HKuwzLVC59Mp/aSJ//bV44FksNwDn04fyqHTXip
nyWxHoW3vRp5V90J86UdpRMOeMKgZCR+hZ0mz7PjtJ2ELXF6eYsIXk2rrFVo
4YLumrqYQfjbaJvr8jy80cbx0ZJyCKeSaYk1BbDhd4ZB1wSvH1NQpTfh6R6+
WvAaNhVeyTUvwDLf7HokAv8B3YzM/Q==
      "]]}, {}}, {{}, {}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{-1, 0},
  Method->{},
  PlotRange->{{-1, 14}, {-0.6180076713410046, 0.5836736103402764}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{
  3.577701683242975*^9},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]],

Cell["First and second derivatives at x = 0.", "Text",
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"derD1f1x0", "=", " ", 
  RowBox[{"Limit", "[", 
   RowBox[{
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{"Evaluate", "[", 
       RowBox[{"f", "[", "x", "]"}], "]"}], ",", "x"}], "]"}], " ", ",", 
    RowBox[{"x", "\[Rule]", "0"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4849789611875*^9, 3.48497897071875*^9}, {
   3.484996362078125*^9, 3.484996404453125*^9}, 3.560537947540439*^9, {
   3.560538007026204*^9, 3.560538013044164*^9}}],

Cell[BoxData["1.7312975090752871`"], "Output",
 CellChangeTimes->{3.577701683344928*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"derD2f1x0", "=", " ", 
  RowBox[{"Limit", "[", 
   RowBox[{
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{"Evaluate", "[", 
       RowBox[{"f", "[", "x", "]"}], "]"}], ",", "x", ",", "x"}], "]"}], " ", 
    ",", 
    RowBox[{"x", "\[Rule]", "0"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4849789611875*^9, 3.484978974875*^9}, {
   3.48499639340625*^9, 3.48499640853125*^9}, 3.560537953536343*^9, {
   3.560538029006048*^9, 3.560538034752427*^9}}],

Cell[BoxData[
 RowBox[{"-", "0.9171498460387351`"}]], "Output",
 CellChangeTimes->{3.577701683397561*^9}]
}, Open  ]],

Cell[TextData[{
 "First and second derivatives at x=14, we approach ",
 Cell[BoxData[
  FormBox[
   RowBox[{"x", "=", "14"}], TraditionalForm]]],
 " from the left."
}], "Text",
 CellChangeTimes->{{3.482664394578125*^9, 3.482664468984375*^9}, {
   3.482664514625*^9, 3.482664539265625*^9}, {3.48275498540625*^9, 
   3.48275501025*^9}, {3.482755052734375*^9, 3.48275518615625*^9}, {
   3.48491260909375*^9, 3.484912650578125*^9}, 3.48491287253125*^9, {
   3.48497766284375*^9, 3.484977663578125*^9}, {3.484979246015625*^9, 
   3.4849792499375*^9}, {3.484996455*^9, 3.484996511484375*^9}, {
   3.560538260176859*^9, 3.560538303389987*^9}},
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"derD1f4x14", "=", 
  RowBox[{"Limit", "[", " ", 
   RowBox[{
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{"Evaluate", "[", 
       RowBox[{"f", "[", "x", "]"}], "]"}], ",", "x"}], "]"}], " ", ",", " ", 
    RowBox[{"x", "\[Rule]", "14"}], ",", " ", 
    RowBox[{"Direction", "\[Rule]", "1"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.484912499015625*^9, 3.484912547140625*^9}, 
   3.484914509015625*^9, 3.484916429015625*^9, {3.48491741003125*^9, 
   3.48491741365625*^9}, {3.4849753231875*^9, 3.484975343109375*^9}, {
   3.484975489859375*^9, 3.48497549940625*^9}, {3.484996419484375*^9, 
   3.484996437296875*^9}, {3.485001927109375*^9, 3.4850019275*^9}, 
   3.560537975316038*^9, {3.560538040465978*^9, 3.560538045901245*^9}, {
   3.560538244889351*^9, 3.560538247914576*^9}}],

Cell[BoxData["1.8258506925173568`"], "Output",
 CellChangeTimes->{3.577701683429446*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"derD2f4x14", "=", " ", 
  RowBox[{"Limit", "[", 
   RowBox[{
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{"Evaluate", "[", 
       RowBox[{"f", "[", "x", "]"}], "]"}], ",", "x", ",", "x"}], "]"}], " ", 
    ",", 
    RowBox[{"x", "\[Rule]", "14"}], ",", 
    RowBox[{"Direction", "\[Rule]", "1"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.484912499015625*^9, 3.484912565265625*^9}, 
   3.484914510296875*^9, 3.48491643084375*^9, {3.4849174166875*^9, 
   3.484917420078125*^9}, {3.484975326515625*^9, 3.4849753331875*^9}, {
   3.48497550234375*^9, 3.484975511625*^9}, {3.48499642209375*^9, 
   3.48499642996875*^9}, {3.485001932015625*^9, 3.485001932484375*^9}, {
   3.560538051945494*^9, 3.560538061218772*^9}, {3.56053825488422*^9, 
   3.560538255172863*^9}}],

Cell[BoxData["2.0231296275740704`"], "Output",
 CellChangeTimes->{3.577701683450191*^9}]
}, Open  ]],

Cell["\<\
We verify continuity of first derivative at first internal knot (5.33)\
\>", "Text",
 CellChangeTimes->{{3.482664394578125*^9, 3.482664468984375*^9}, {
   3.482664514625*^9, 3.482664539265625*^9}, {3.48275498540625*^9, 
   3.48275501025*^9}, {3.482755052734375*^9, 3.48275518615625*^9}, {
   3.48491260909375*^9, 3.484912650578125*^9}, 3.48491287253125*^9, {
   3.48497766284375*^9, 3.484977663578125*^9}, {3.484979246015625*^9, 
   3.4849792499375*^9}, {3.484979322359375*^9, 3.484979372375*^9}, {
   3.48499652175*^9, 3.484996562421875*^9}, {3.48500198090625*^9, 
   3.485001983453125*^9}},
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"derf1dx", "=", 
  RowBox[{"Limit", "[", " ", 
   RowBox[{
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{"Evaluate", "[", 
       RowBox[{"f1", "[", "x", "]"}], "]"}], ",", "x"}], "]"}], " ", ",", " ", 
    RowBox[{"x", "\[Rule]", 
     FractionBox["16", "3"]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.484912499015625*^9, 3.484912547140625*^9}, 
   3.484914509015625*^9, 3.484916429015625*^9, {3.48491741003125*^9, 
   3.48491741365625*^9}, {3.484917496828125*^9, 3.4849175061875*^9}, {
   3.484975242015625*^9, 3.48497524375*^9}, {3.484979378046875*^9, 
   3.4849793979375*^9}, {3.48500195659375*^9, 3.4850019598125*^9}, {
   3.560538070318299*^9, 3.560538076744444*^9}, {3.560538350653234*^9, 
   3.560538355796355*^9}}],

Cell[BoxData["0.8046815187555842`"], "Output",
 CellChangeTimes->{3.577701683463237*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"derf2sx", "=", " ", 
  RowBox[{"Limit", "[", 
   RowBox[{
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{"Evaluate", "[", 
       RowBox[{"f2", "[", "x", "]"}], "]"}], ",", "x"}], "]"}], " ", ",", 
    RowBox[{"x", "\[Rule]", 
     FractionBox["16", "3"]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.484912499015625*^9, 3.484912565265625*^9}, 
   3.484914510296875*^9, 3.48491643084375*^9, {3.4849174166875*^9, 
   3.484917420078125*^9}, {3.48491749928125*^9, 3.484917501984375*^9}, {
   3.484975247296875*^9, 3.4849752493125*^9}, {3.484979400703125*^9, 
   3.484979430734375*^9}, {3.485001968375*^9, 3.48500197084375*^9}, {
   3.560538080261398*^9, 3.560538087728357*^9}, {3.560538357678804*^9, 
   3.560538360368493*^9}}],

Cell[BoxData["6.212247286321355`"], "Output",
 CellChangeTimes->{3.577701683490897*^9}]
}, Open  ]],

Cell["Part V", "Text",
 CellChangeTimes->{
  3.484992245703125*^9, {3.484992316015625*^9, 3.4849923314375*^9}, {
   3.48499253890625*^9, 3.484992628625*^9}, {3.484994235171875*^9, 
   3.484994236890625*^9}, {3.48499689084375*^9, 3.48499689559375*^9}, {
   3.486039583859375*^9, 3.486039584453125*^9}, {3.559482005654936*^9, 
   3.559482006444809*^9}, {3.572683638740938*^9, 3.572683640652047*^9}, {
   3.572683694861148*^9, 3.5726836965002413`*^9}},
 FontSize->36,
 FontColor->RGBColor[0, 0, 1],
 Background->RGBColor[1, 0.9, 0.8]],

Cell[TextData[{
 "We check that the reconstruction conincides with the result given by ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "."
}], "Text",
 CellChangeTimes->{{3.4822341378707695`*^9, 3.4822341540168734`*^9}, {
  3.48499855896875*^9, 3.48499856028125*^9}, {3.559508878093765*^9, 
  3.559508878656044*^9}, {3.559508923401692*^9, 3.559508937468286*^9}, {
  3.559541764068054*^9, 3.559541767750527*^9}, {3.559542684134254*^9, 
  3.559542715594304*^9}, {3.56053836865784*^9, 3.560538389643898*^9}},
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"Chop", "[", 
    RowBox[{
     RowBox[{"cubicSpline", "[", "x", "]"}], " ", "-", " ", 
     RowBox[{"f", "[", "x", "]"}]}], "]"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"x", ",", " ", "0", ",", " ", "14"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.559509211208383*^9, 3.559509211209626*^9}, {
   3.559541778864373*^9, 3.559541780206865*^9}, 3.55954274758951*^9, 
   3.56053840146544*^9, 3.560543220218763*^9}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxTTMoPSmViYGBwAGIQzbH7u/Bdi0o7BihYuDpF+b1SuD2Mv6l51cY9Sulw
/q78sxWLlcrh/H1P4+5MU2qH8w8sUO+boDQdznf8x53eq7QczmfSrbvcrbQd
zpeOf8C3UPoEnP/mYu+heS8uwvnyi57msS27Duev/39R9uf9u3D+irVLrY5d
fwjnqy1ak3717xM4v39tgK+h6As4n9HCuj32+ys4X5GzwOm8+Ds4f+marys6
Gj/A+foPGHkvvP8I5wuYbza0qv0M55edbW/g+fAFzjduZ5zA2PQNzk89c/L3
HJ4fCP8Gbp24oOYnnK/x0/XFMe7fiPB98DMjtOEPnL/4ddAqNpF/CPc3/XKP
W/Afzv+4+hE7fyc4OsGgb4WUT0MgI5z/1iVl6VIeJjifXf2qjtwRBP/MrBki
Gt3McH7wulzBZy4scH5b8NQ8Uz5WOL/Y7snP65cRfOWTLrP0etjg/Lqn32eJ
hbDD+bMX7tmwiY8DoX/xii8LjyL4382ez1Dq4YTzbbPMg8JdueB8Pf1b2bJ8
3HD+w8l9s6afRPD97bK+pzTywPmZVTO2HPbghfNdw260XWPiQ/j3cNbOqjMI
Pl+5ilTRJH44n/Pp9+N9qgJwfsJ1NuO1nQj+jJnzVqg+R/DX/fPcetxJEM6f
tUauyGgZgp+uVWP5nUkIYf5Hpo0t6Qh+Z9Tc/danEPxXkw/c8FEThvMVxXgX
qXUh+JYZj0qjniP4aswPf4b5iMD5Hx0+i9SuR/Dn+vVZ/eUWhfPTPmdWXglG
8AET++dN
      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQBGIQLb80SMCtQNSBAQqaTs//8OIsgn9oCkPGVk0xOP/G
sq5+r14E/3zH3IOWrxD8OZtvLv7oJw7nuzVqyl7eiOBflGNayMcnAecbsbJc
FSpC8Et29wkXnkfwJ4vovvyhJQnnd2z7kufZh+DHabj+//wKwed6vM8+3V8K
zp+ee7DLZC2Czzj7eo42pzSc7ygo/v9VDoKfFH5/NsspBD/y2YUXz/Rk4Hxd
iWtnPk1E8B9JpuyOeIfg56ZIR7UHycL5N+uimQU2IPhKNuudD3HLIex30jGx
zUfiSxjpC51B8MXNE2+tN5CH80/9WCxTPhnBj+/Kz5zxHsFPNTIyPqipAOd3
s380S45A8OXXWbJJtSH4m39usXm1EsEHAAKjan4=
      "]], LineBox[CompressedData["
1:eJxNz30s1AEYB/A74kzWEas471x3l92STTtOWDMSVt5q4ZiXC0fHkHK61bws
y/xBxk6kqHOhRklTO7McU0oZyZn5Q+flmpep65rjXLW13/ee7dmzzx/f7fu4
peXF8E1IJFLM3/13nbcb2C9fuQaT/s+Bbk6CfgnONt1cYB1xI9z3Vp1lGgYL
Y4WDW0Xw3SpKrkIKy+hLziFfYGbmV5aM4k74sCiW5OYHazW286GZcLCdmhot
gUvvmYRbjMGemsdR079gzhavs4LhQfjUhQSrxXj4aUrOqEcVXO1vHikagBPE
SzPiFbg+QznAt/ckPPjCpk0XBsd2JC8WiuCLub4b5G44UnLeEDAHdwluZSVZ
0QnvtGtmmFz49bMf1pbZ8DeeWfunJlhflOR/+h1c5j3GkuzAxXK5ah/7KP55
/vuRUyL8JCJU7lADqyOVc4o3cKOLdrhcDfc0MMwYNAb6XW2JuBYOH99mfO8q
hetV2pqaTjjr4Tl9+SzcYSJXJFsyCc+MC2uXOXC+n29/TA5ccr1SOtUMF7g4
NJPHjfKCYbWtHvZy7g2Y8mIR3mhjJnZcgh0/9E2mVMNcXmXUyAA8Uidwo67B
coly6IrTMcJSixp+SQSso8WnZYvhwMbUDPNueL2/bPD2ArxfxlY5WXsRtic7
UVMD4bo917qqfHg3PduB1wpPN3GFoR9hHbU4zmYCdq3s8Z83cm4enVLwGTYL
oT5omYJPri9OapSwJOiOb/syPNSnoAlX4GWWgey3CvvYFU1MqOH3q7xM3ZpR
/9oTkuifsDsl96ajBj5zQ8pfMXL9ZZqPWAuzuWbjsm04rieot1AHi+iixsAd
eJS6mT69C69VsM626uGDunRvwR7Mybt/yNcAJ6tmdw1G/gOVUxy0
      "]]}, {}}, {{}, {}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  Method->{},
  PlotRange->{{0, 14}, {-1., 1.}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{
  3.577701683536312*^9},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]]
},
AutoGeneratedPackage->None,
WindowSize->{1438, 813},
WindowMargins->{{145, Automatic}, {Automatic, 47}},
Magnification->1.5,
FrontEndVersion->"9.0 for Linux x86 (64-bit) (January 25, 2013)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[545, 20, 523, 12, 112, "Text"],
Cell[1071, 34, 5094, 101, 1071, "Text"],
Cell[CellGroupData[{
Cell[6190, 139, 243, 5, 45, "Input"],
Cell[6436, 146, 466, 10, 33, "Message"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6939, 161, 100, 1, 45, "Input"],
Cell[7042, 164, 126, 2, 45, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[7205, 171, 118, 2, 45, "Input"],
Cell[7326, 175, 195, 5, 45, "Output"]
}, Open  ]],
Cell[7536, 183, 265, 6, 45, "Input"],
Cell[7804, 191, 479, 9, 107, "Text"],
Cell[8286, 202, 682, 19, 75, "Text"],
Cell[8971, 223, 879, 22, 45, "Input"],
Cell[CellGroupData[{
Cell[9875, 249, 209, 4, 45, "Input"],
Cell[10087, 255, 70, 1, 45, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[10194, 261, 538, 10, 45, "Input"],
Cell[10735, 273, 270, 9, 45, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[11042, 287, 1017, 22, 104, "Input"],
Cell[12062, 311, 26839, 450, 368, 11544, 197, "CachedBoxData", "BoxData", \
"Output"]
}, Open  ]],
Cell[38916, 764, 482, 9, 107, "Text"],
Cell[39401, 775, 721, 14, 70, "Text"],
Cell[40125, 791, 606, 12, 47, "Text"],
Cell[CellGroupData[{
Cell[40756, 807, 257, 6, 45, "Input"],
Cell[41016, 815, 266, 9, 45, "Output"]
}, Open  ]],
Cell[41297, 827, 379, 11, 70, "Text"],
Cell[CellGroupData[{
Cell[41701, 842, 246, 4, 45, "Input"],
Cell[41950, 848, 254, 6, 45, "Output"]
}, Open  ]],
Cell[42219, 857, 284, 6, 69, "Text"],
Cell[CellGroupData[{
Cell[42528, 867, 419, 7, 45, "Input"],
Cell[42950, 876, 261, 6, 45, "Output"]
}, Open  ]],
Cell[43226, 885, 279, 6, 69, "Text"],
Cell[43508, 893, 391, 7, 45, "Input"],
Cell[43902, 902, 542, 11, 100, "Text"],
Cell[44447, 915, 209, 4, 69, "Text"],
Cell[44659, 921, 1176, 28, 81, "Input"],
Cell[45838, 951, 761, 22, 45, "Input"],
Cell[CellGroupData[{
Cell[46624, 977, 3268, 76, 365, "Input"],
Cell[49895, 1055, 107822, 1800, 361, 61690, 1042, "CachedBoxData", "BoxData", \
"Output"]
}, Open  ]],
Cell[157732, 2858, 307, 5, 70, "Text"],
Cell[CellGroupData[{
Cell[158064, 2867, 1101, 25, 133, "Input"],
Cell[159168, 2894, 15045, 391, 510, "Output"]
}, Open  ]],
Cell[174228, 3288, 1484, 42, 104, "Text"],
Cell[175715, 3332, 483, 9, 107, "Text"],
Cell[176201, 3343, 1181, 21, 126, "Text"],
Cell[177385, 3366, 699, 14, 69, "Text"],
Cell[CellGroupData[{
Cell[178109, 3384, 997, 20, 45, "Input"],
Cell[179109, 3406, 283, 7, 47, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[179429, 3418, 995, 21, 45, "Input"],
Cell[180427, 3441, 289, 7, 47, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[180753, 3453, 994, 20, 45, "Input"],
Cell[181750, 3475, 258, 6, 47, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[182045, 3486, 1094, 21, 45, "Input"],
Cell[183142, 3509, 183, 4, 47, "Output"]
}, Open  ]],
Cell[183340, 3516, 646, 11, 69, "Text"],
Cell[CellGroupData[{
Cell[184011, 3531, 1200, 23, 45, "Input"],
Cell[185214, 3556, 325, 7, 47, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[185576, 3568, 1083, 21, 45, "Input"],
Cell[186662, 3591, 323, 8, 47, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[187022, 3604, 1037, 20, 45, "Input"],
Cell[188062, 3626, 328, 7, 47, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[188427, 3638, 638, 15, 45, "Input"],
Cell[189068, 3655, 326, 8, 47, "Output"]
}, Open  ]],
Cell[189409, 3666, 693, 12, 69, "Text"],
Cell[CellGroupData[{
Cell[190127, 3682, 874, 18, 45, "Input"],
Cell[191004, 3702, 328, 7, 47, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[191369, 3714, 857, 18, 45, "Input"],
Cell[192229, 3734, 325, 8, 47, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[192591, 3747, 950, 19, 45, "Input"],
Cell[193544, 3768, 323, 7, 47, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[193904, 3780, 712, 16, 45, "Input"],
Cell[194619, 3798, 324, 8, 47, "Output"]
}, Open  ]],
Cell[194958, 3809, 511, 9, 69, "Text"],
Cell[CellGroupData[{
Cell[195494, 3822, 1143, 26, 75, "Input"],
Cell[196640, 3850, 18736, 325, 361, 7354, 137, "CachedBoxData", "BoxData", \
"Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[215413, 4180, 1050, 24, 45, "Input"],
Cell[216466, 4206, 27042, 463, 364, 11646, 209, "CachedBoxData", "BoxData", \
"Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[243545, 4674, 1085, 25, 45, "Input"],
Cell[244633, 4701, 29844, 509, 364, 13004, 231, "CachedBoxData", "BoxData", \
"Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[274514, 5215, 919, 23, 45, "Input"],
Cell[275436, 5240, 29902, 510, 364, 13469, 239, "CachedBoxData", "BoxData", \
"Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[305375, 5755, 985, 24, 45, "Input"],
Cell[306363, 5781, 26793, 460, 364, 11435, 206, "CachedBoxData", "BoxData", \
"Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[333193, 6246, 803, 21, 75, "Input"],
Cell[333999, 6269, 18745, 325, 361, 7167, 133, "CachedBoxData", "BoxData", \
"Output"]
}, Open  ]],
Cell[352759, 6597, 646, 12, 70, "Text"],
Cell[CellGroupData[{
Cell[353430, 6613, 312, 7, 45, "Input"],
Cell[353745, 6622, 2698, 73, 135, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[356480, 6700, 779, 15, 45, "Input"],
Cell[357262, 6717, 321, 7, 47, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[357620, 6729, 691, 14, 45, "Input"],
Cell[358314, 6745, 18546, 313, 364, 7609, 132, "CachedBoxData", "BoxData", \
"Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[376897, 7063, 263, 7, 45, "Input"],
Cell[377163, 7072, 320, 8, 47, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[377520, 7085, 695, 14, 45, "Input"],
Cell[378218, 7101, 20062, 337, 356, 7350, 127, "CachedBoxData", "BoxData", \
"Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[398317, 7443, 275, 7, 45, "Input"],
Cell[398595, 7452, 303, 7, 52, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[398935, 7464, 737, 14, 45, "Input"],
Cell[399675, 7480, 16066, 272, 371, 4088, 74, "CachedBoxData", "BoxData", \
"Output"]
}, Open  ]],
Cell[415756, 7755, 744, 12, 70, "Text"],
Cell[CellGroupData[{
Cell[416525, 7771, 1230, 27, 75, "Input"],
Cell[417758, 7800, 26668, 449, 372, 11349, 196, "CachedBoxData", "BoxData", \
"Output"]
}, Open  ]],
Cell[444441, 8252, 506, 10, 107, "Text"],
Cell[444950, 8264, 798, 17, 98, "Text"],
Cell[445751, 8283, 672, 11, 69, "Text"],
Cell[CellGroupData[{
Cell[446448, 8298, 659, 12, 45, "Input"],
Cell[447110, 8312, 2840, 78, 207, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[449987, 8395, 884, 19, 45, "Input"],
Cell[450874, 8416, 30885, 517, 339, 15533, 263, "CachedBoxData", "BoxData", \
"Output"]
}, Open  ]],
Cell[481774, 8936, 686, 11, 70, "Text"],
Cell[CellGroupData[{
Cell[482485, 8951, 529, 11, 45, "Input"],
Cell[483017, 8964, 2371, 68, 207, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[485425, 9037, 814, 18, 45, "Input"],
Cell[486242, 9057, 19949, 337, 340, 6346, 112, "CachedBoxData", "BoxData", \
"Output"]
}, Open  ]],
Cell[506206, 9397, 732, 12, 70, "Text"],
Cell[CellGroupData[{
Cell[506963, 9413, 587, 12, 45, "Input"],
Cell[507553, 9427, 2031, 59, 207, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[509621, 9491, 862, 19, 45, "Input"],
Cell[510486, 9512, 7206, 128, 346, 2680, 52, "CachedBoxData", "BoxData", \
"Output"]
}, Open  ]],
Cell[517707, 9643, 99, 2, 70, "Text"],
Cell[CellGroupData[{
Cell[517831, 9649, 467, 11, 45, "Input"],
Cell[518301, 9662, 88, 1, 45, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[518426, 9668, 478, 12, 45, "Input"],
Cell[518907, 9682, 105, 2, 45, "Output"]
}, Open  ]],
Cell[519027, 9687, 681, 15, 70, "Text"],
Cell[CellGroupData[{
Cell[519733, 9706, 811, 16, 45, "Input"],
Cell[520547, 9724, 88, 1, 45, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[520672, 9730, 792, 17, 45, "Input"],
Cell[521467, 9749, 88, 1, 45, "Output"]
}, Open  ]],
Cell[521570, 9753, 647, 12, 70, "Text"],
Cell[CellGroupData[{
Cell[522242, 9769, 754, 16, 81, "Input"],
Cell[522999, 9787, 88, 1, 45, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[523124, 9793, 752, 16, 81, "Input"],
Cell[523879, 9811, 87, 1, 45, "Output"]
}, Open  ]],
Cell[523981, 9815, 531, 10, 107, "Text"],
Cell[524515, 9827, 555, 12, 70, "Text"],
Cell[CellGroupData[{
Cell[525095, 9843, 478, 11, 45, "Input"],
Cell[525576, 9856, 6644, 119, 379, 2586, 51, "CachedBoxData", "BoxData", \
"Output"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
