(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     70399,       1685]
NotebookOptionsPosition[     66641,       1584]
NotebookOutlinePosition[     67026,       1601]
CellTagsIndexPosition[     66983,       1598]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["\<\
Evaluation time:
\[CapitalDelta]t < 5 s \
\>", "Text",
 CellChangeTimes->{
  3.484992245703125*^9, {3.484992316015625*^9, 3.4849923314375*^9}, {
   3.48499253890625*^9, 3.484992628625*^9}, {3.484994235171875*^9, 
   3.484994236890625*^9}, {3.48499689084375*^9, 3.48499689559375*^9}, {
   3.486039583859375*^9, 3.486039584453125*^9}, {3.559482005654936*^9, 
   3.559482006444809*^9}, {3.5726834909894867`*^9, 3.572683498155897*^9}},
 FontSize->18,
 FontColor->RGBColor[0, 0, 1],
 Background->RGBColor[1, 0.9, 0.8]],

Cell[TextData[{
 "Interpolation using B-splines of order 4 (i.e. degree 3)\n\n",
 StyleBox["Warning! \nIn Section 6.4, it is clearly stated that   order = \
degree + 1. \nIn Mathematica, the command InterpolationOrder refers to the \
degree of the interpolating polynomial,\ntherefore,  InterpolationOrder -> 2  \
considers parabolae, etc.\n",
  FontColor->RGBColor[0.5, 0, 0.5]],
 "\nIntroduction\n\nThe main purpose of this notebook is to examine the \
properties of the  ",
 Cell[BoxData[
  FormBox[
   RowBox[{"functions", " ", 
    SubsuperscriptBox["B", "i", "4"]}], TraditionalForm]]],
 "(x)  (B-splines of third degree, fourth order).\nTo this end, by means of \
the expression\n                          \n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"S", "(", "x", ")"}], " ", "=", " ", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"i", "=", "1"}], "M"], 
     RowBox[{
      SubscriptBox["\[Alpha]", "i"], " ", 
      RowBox[{
       SubsuperscriptBox["B", "i", "4"], "(", "x", ")"}]}]}]}], 
   TraditionalForm]]],
 ", \n\nwe interpolate the same set of points {",
 Cell[BoxData[
  FormBox[
   SubscriptBox["x", 
    RowBox[{"i", ","}]], TraditionalForm]]],
 " ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["f", "i"], TraditionalForm]]],
 "} given in the text (Chapter \\ref{chap:splines}, Section \
\\ref{subsec:uniform-cubic})\n\n In the first section we use the command \n \n\
 ",
 StyleBox["cubicSpline =  Interpolation[points, InterpolationOrder \[Rule] 3, \
Method \[Rule] \"Spline\"]",
  FontFamily->"Courier"],
 "\n\nIn the second section we access  the information contained in  \
cubicSpline, that is, the coefficients ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Alpha]", "i"], TraditionalForm]]],
 " of the splines and the set of knots.\n              \nIn the third  \
section we extract the polynomial representation of each Bspline and \
reconstruct the complete spline.\n\nIn the fourth  section we check the ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["C", "1"], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["C", "2"], TraditionalForm]]],
 "  and the boundary conditions of S(x).\n         \nIn the fifth  section we \
check that our reconstruction coincides with the one given by Mathematica."
}], "Text",
 CellChangeTimes->{{3.4822342910645547`*^9, 3.4822343209855466`*^9}, {
   3.4827529496875*^9, 3.482752986359375*^9}, {3.482753058375*^9, 
   3.48275329565625*^9}, {3.482754376203125*^9, 3.4827544480625*^9}, {
   3.48275486803125*^9, 3.482754928265625*^9}, {3.482755560515625*^9, 
   3.48275556246875*^9}, {3.4827556411875*^9, 3.48275569015625*^9}, {
   3.48351817559375*^9, 3.483518182875*^9}, {3.483518280890625*^9, 
   3.4835183170625*^9}, {3.484914080453125*^9, 3.48491409403125*^9}, {
   3.484982273*^9, 3.484982330890625*^9}, {3.48499031065625*^9, 
   3.48499031225*^9}, {3.484991693046875*^9, 3.4849918995*^9}, {
   3.484991929671875*^9, 3.484992071828125*^9}, {3.484992112015625*^9, 
   3.48499219953125*^9}, {3.484992274671875*^9, 3.484992288953125*^9}, {
   3.48499252521875*^9, 3.48499252659375*^9}, {3.484992681984375*^9, 
   3.484992822796875*^9}, {3.4849957348125*^9, 3.4849958199375*^9}, {
   3.484996916859375*^9, 3.484997034578125*^9}, {3.484998766484375*^9, 
   3.484998831421875*^9}, {3.484999638984375*^9, 3.48499968971875*^9}, {
   3.484999752609375*^9, 3.4849998213125*^9}, {3.485845938390625*^9, 
   3.485845955046875*^9}, 3.486032339453125*^9, {3.486037365875*^9, 
   3.48603750078125*^9}, {3.486037535953125*^9, 3.486037636859375*^9}, {
   3.48603782975*^9, 3.48603789246875*^9}, 3.486037925296875*^9, 
   3.48603796115625*^9, {3.486038164078125*^9, 3.486038197546875*^9}, {
   3.486038247203125*^9, 3.486038345859375*^9}, {3.486038501484375*^9, 
   3.486038610640625*^9}, {3.48603864065625*^9, 3.486038657*^9}, {
   3.486038689890625*^9, 3.48603873975*^9}, {3.486038935171875*^9, 
   3.486039040234375*^9}, {3.4860395724375*^9, 3.486039576578125*^9}, {
   3.4860401415625*^9, 3.486040176078125*^9}, {3.4876802559375*^9, 
   3.487680272515625*^9}, {3.487681597484375*^9, 3.487681605515625*^9}, {
   3.559481405755838*^9, 3.55948140707919*^9}, {3.559481466382803*^9, 
   3.559481506594187*^9}, {3.559481560546674*^9, 3.559481708779786*^9}, {
   3.55948203592665*^9, 3.559482044108379*^9}, {3.559508966468197*^9, 
   3.559508967354209*^9}, {3.559541621201445*^9, 3.559541633240987*^9}, {
   3.560536798026518*^9, 3.560536811979471*^9}, {3.560537311999555*^9, 
   3.560537316248664*^9}, {3.560537360395359*^9, 3.56053737909953*^9}, {
   3.560537712425122*^9, 3.560537789677993*^9}, {3.560539282328968*^9, 
   3.560539288987124*^9}, {3.560539840758474*^9, 3.560539862031093*^9}, {
   3.5605431803099*^9, 3.560543208706775*^9}, {3.572683467730157*^9, 
   3.572683474414539*^9}, {3.5726835294756885`*^9, 3.5726835304357433`*^9}, {
   3.575982434918497*^9, 3.5759824351975126`*^9}, {3.577114671842903*^9, 
   3.577114710124092*^9}, 3.577455598872048*^9, 3.5777015863854017`*^9, 
   3.577701640728661*^9},
 FontSize->16,
 FontColor->RGBColor[0, 0, 1],
 Background->RGBColor[1, 1, 0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"Remove", "[", "\"\<Global`*\>\"", "]"}], ";", 
  RowBox[{"$Line", "=", "0"}], ";"}]], "Input",
 CellChangeTimes->{{3.48351269165625*^9, 3.48351271565625*^9}, {
  3.5076381993481483`*^9, 3.50763820358489*^9}}],

Cell[BoxData["$Version"], "Input",
 CellChangeTimes->{{3.507638206475212*^9, 3.507638212763978*^9}}],

Cell[BoxData[
 RowBox[{"Date", "[", "]"}]], "Input",
 CellChangeTimes->{{3.507638216964425*^9, 3.507638218281106*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"SetOptions", "[", 
   RowBox[{"Plot", ",", 
    RowBox[{"PlotPoints", "\[Rule]", "150"}]}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.559509527491418*^9, 3.559509533105295*^9}, {
  3.559509660118734*^9, 3.559509664133732*^9}}],

Cell["Part I", "Text",
 CellChangeTimes->{
  3.484992245703125*^9, {3.484992316015625*^9, 3.4849923314375*^9}, {
   3.48499253890625*^9, 3.484992628625*^9}, {3.484994235171875*^9, 
   3.484994236890625*^9}, {3.48499689084375*^9, 3.48499689559375*^9}, {
   3.486039583859375*^9, 3.486039584453125*^9}, {3.559482005654936*^9, 
   3.559482006444809*^9}, {3.572683638740938*^9, 3.572683640652047*^9}},
 FontSize->36,
 FontColor->RGBColor[0, 0, 1],
 Background->RGBColor[1, 0.9, 0.8]],

Cell[TextData[{
 "Construction of the interpolating function S(x) over the points  {",
 Cell[BoxData[
  FormBox[
   SubscriptBox["x", 
    RowBox[{"i", ","}]], TraditionalForm]]],
 " ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["f", "i"], TraditionalForm]]],
 "} by means of Bsplines of order 4."
}], "Text",
 CellChangeTimes->{
  3.484992245703125*^9, {3.484992316015625*^9, 3.4849923314375*^9}, {
   3.48499253890625*^9, 3.484992628625*^9}, {3.484994235171875*^9, 
   3.484994236890625*^9}, {3.48499689084375*^9, 3.48499689559375*^9}, {
   3.486039583859375*^9, 3.486039584453125*^9}, {3.559482005654936*^9, 
   3.559482006444809*^9}},
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"points", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}], ",", "  ", 
     RowBox[{"{", 
      RowBox[{"2", ",", "2"}], "}"}], ",", "  ", 
     RowBox[{"{", 
      RowBox[{"5", ",", "3"}], "}"}], ",", "  ", 
     RowBox[{"{", 
      RowBox[{"9", ",", "5"}], "}"}], ",", "  ", 
     RowBox[{"{", 
      RowBox[{"11", ",", "2"}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"14", ",", "1"}], "}"}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.482465335703125*^9, 3.48246537171875*^9}, {
   3.482562224859375*^9, 3.482562705859375*^9}, {3.482563028953125*^9, 
   3.4825630511875*^9}, 3.48256308603125*^9, {3.48266181428125*^9, 
   3.482661845375*^9}, {3.482661878609375*^9, 3.48266189509375*^9}, {
   3.484992237328125*^9, 3.484992239*^9}, {3.559482056671697*^9, 
   3.559482058855683*^9}}],

Cell[BoxData[
 RowBox[{"numpoints", "=", 
  RowBox[{"Length", "[", "points", "]"}]}]], "Input",
 CellChangeTimes->{{3.487659246921875*^9, 3.48765925203125*^9}, {
  3.560537436229043*^9, 3.560537442018693*^9}}],

Cell[BoxData[
 RowBox[{"cubicSpline", "=", 
  RowBox[{"Interpolation", "[", 
   RowBox[{"points", ",", 
    RowBox[{"InterpolationOrder", "\[Rule]", "3"}], ",", 
    RowBox[{"Method", "\[Rule]", "\"\<Spline\>\""}]}], "]"}]}]], "Input",
 CellChangeTimes->{
  3.482232981299215*^9, 3.482563196046875*^9, {3.482662067734375*^9, 
   3.482662069859375*^9}, {3.482662414515625*^9, 3.48266242134375*^9}, 
   3.484991111609375*^9, {3.486039589421875*^9, 3.4860395903125*^9}, {
   3.55948212675018*^9, 3.559482132878461*^9}, 3.560543213083099*^9}],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"cubicSpline", "[", "x", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "14"}], "}"}], ",", 
   RowBox[{"AxesOrigin", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "1"}], ",", "0"}], "}"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"PlotRange", "\[Rule]", "All"}], ",", "\[IndentingNewLine]", 
   RowBox[{"Epilog", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Red", ",", 
      RowBox[{"PointSize", "[", "Medium", "]"}], ",", 
      RowBox[{"Point", "[", "points", "]"}]}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{
  3.482232990035215*^9, {3.482662078546875*^9, 3.482662109859375*^9}, {
   3.482662150546875*^9, 3.4826622134375*^9}, {3.484979612859375*^9, 
   3.484979664171875*^9}, {3.4849796941875*^9, 3.4849797615625*^9}, 
   3.484991112828125*^9, {3.559482848976316*^9, 3.55948284929403*^9}, {
   3.560540043240449*^9, 3.560540066401287*^9}, 3.560543216089972*^9, {
   3.5726838503600416`*^9, 3.572683850753064*^9}}],

Cell["Part II", "Text",
 CellChangeTimes->{
  3.484992245703125*^9, {3.484992316015625*^9, 3.4849923314375*^9}, {
   3.48499253890625*^9, 3.484992628625*^9}, {3.484994235171875*^9, 
   3.484994236890625*^9}, {3.48499689084375*^9, 3.48499689559375*^9}, {
   3.486039583859375*^9, 3.486039584453125*^9}, {3.559482005654936*^9, 
   3.559482006444809*^9}, {3.572683638740938*^9, 3.5726836619402647`*^9}},
 FontSize->36,
 FontColor->RGBColor[0, 0, 1],
 Background->RGBColor[1, 0.9, 0.8]],

Cell[TextData[{
 "Access to various information contained in the ",
 StyleBox["InterpolatingFunction.", "Input"]
}], "Text",
 CellChangeTimes->{{3.482233312453421*^9, 3.482233325558337*^9}, {
  3.482233750040195*^9, 3.482233753784411*^9}, {3.484993382796875*^9, 
  3.484993390234375*^9}, {3.484993463875*^9, 3.4849934725*^9}, {
  3.484993612375*^9, 3.48499369059375*^9}, {3.484993903390625*^9, 
  3.4849939055625*^9}, {3.48499398996875*^9, 3.484994000125*^9}, {
  3.484994033875*^9, 3.48499412828125*^9}, {3.484994219125*^9, 
  3.484994243046875*^9}, {3.48499690290625*^9, 3.484996904171875*^9}, {
  3.55948257750246*^9, 3.559482578679842*^9}},
 FontFamily->"Times New Roman",
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[TextData[{
 "The ",
 StyleBox["BSplineFunction ", "Input"],
 "is stored  in 4th place."
}], "Text",
 CellChangeTimes->{{3.482233312453421*^9, 3.482233325558337*^9}, {
   3.482233750040195*^9, 3.482233753784411*^9}, {3.484993382796875*^9, 
   3.484993390234375*^9}, {3.484993463875*^9, 3.4849934725*^9}, {
   3.484993612375*^9, 3.48499369059375*^9}, {3.484993903390625*^9, 
   3.4849939055625*^9}, {3.48499398996875*^9, 3.484994000125*^9}, {
   3.484994033875*^9, 3.48499412828125*^9}, 3.484994219125*^9, {
   3.4860324106875*^9, 3.486032443421875*^9}, {3.55948268237094*^9, 
   3.559482725244359*^9}}],

Cell[BoxData[
 RowBox[{"bspfun", "=", 
  RowBox[{"cubicSpline", "[", 
   RowBox[{"[", 
    RowBox[{"4", ",", "1"}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4822332962139254`*^9, 3.482233307867051*^9}, 
   3.484994515921875*^9, 3.560543218211531*^9}],

Cell[TextData[{
 "The coefficients ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Alpha]", "i"], TraditionalForm]]],
 " for the basis B-splinesbasis are named  \[OpenCurlyDoubleQuote]Control \
points\[CloseCurlyDoubleQuote]"
}], "Text",
 CellChangeTimes->{{3.559482737098605*^9, 3.55948274359533*^9}},
 FontFamily->"Times New Roman",
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{"coeff", "=", 
  RowBox[{"bspfun", "[", "\"\<ControlPoints\>\"", "]"}]}]], "Input",
 CellChangeTimes->{{3.4822343225455565`*^9, 3.4822343308448095`*^9}, 
   3.4849929160625*^9, {3.507638244287081*^9, 3.507638245209584*^9}}],

Cell["The set of knots being used", "Text",
 CellChangeTimes->{{3.4822343342300315`*^9, 3.4822343385356593`*^9}, {
  3.484993012875*^9, 3.48499302471875*^9}, {3.559482762046647*^9, 
  3.559482776161458*^9}},
 FontFamily->"Times New Roman",
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{"knotsx", "=", 
  RowBox[{"Flatten", "[", 
   RowBox[{"bspfun", "[", "\"\<Knots\>\"", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4822333526865635`*^9, 3.4822333562589407`*^9}, {
   3.4822337669515705`*^9, 3.482233768386853*^9}, {3.4822338392615557`*^9, 
   3.482233842178793*^9}, {3.482662276328125*^9, 3.482662277625*^9}, 
   3.48768167925*^9, {3.559482786385959*^9, 3.559482793290051*^9}}],

Cell["The degree, for later use", "Text",
 CellChangeTimes->{{3.4822343410950756`*^9, 3.482234344433497*^9}, {
  3.4849930594375*^9, 3.4849930729375*^9}, {3.559482957028283*^9, 
  3.55948296530249*^9}},
 FontFamily->"Times New Roman",
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"degx", " ", "=", " ", "3"}], ";"}]], "Input",
 CellChangeTimes->{{3.482233357163735*^9, 3.4822333657904797`*^9}, {
   3.482233770648984*^9, 3.4822337722246747`*^9}, {3.4822338341446466`*^9, 
   3.482233836235117*^9}, {3.482662458*^9, 3.482662458859375*^9}, 
   3.48768164940625*^9, {3.507638248113097*^9, 3.5076382557574263`*^9}, 
   3.559482968212733*^9}],

Cell["\<\
We are using non-uniform (thus non-uniform knots) degree 3 B-spline basis.
We plot the six basis splines. The internal knots are marked with \"\
\[FivePointedStar]\".\
\>", "Text",
 CellChangeTimes->{{3.482234042054359*^9, 3.482234050026061*^9}, {
   3.4849943335*^9, 3.484994358125*^9}, {3.48499459071875*^9, 
   3.484994612359375*^9}, 3.484994668703125*^9, {3.486032497859375*^9, 
   3.486032526109375*^9}, {3.559482989552015*^9, 3.559483009809551*^9}},
 FontFamily->"Times New Roman",
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell["Here are some shortcuts for commonly used symbols:", "Text",
 CellChangeTimes->{{3.559483086374864*^9, 3.559483123854011*^9}},
 FontFamily->"Times New Roman",
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[BoxData[{
 RowBox[{
  RowBox[{
  "symB1", "=", " ", 
   "\"\<\!\(\*SubsuperscriptBox[\(B\), \(1\), \(4\)]\)\>\""}], ";", " ", 
  RowBox[{
  "symB2", "=", " ", 
   "\"\<\!\(\*SubsuperscriptBox[\(B\), \(2\), \(4\)]\)\>\""}], ";", 
  RowBox[{
  "symB3", "=", " ", 
   "\"\<\!\(\*SubsuperscriptBox[\(B\), \(3\), \(4\)]\)\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
  "symB4", "=", " ", 
   "\"\<\!\(\*SubsuperscriptBox[\(B\), \(4\), \(4\)]\)\>\""}], ";", " ", 
  RowBox[{
  "symB5", "=", " ", 
   "\"\<\!\(\*SubsuperscriptBox[\(B\), \(5\), \(4\)]\)\>\""}], ";", 
  RowBox[{
  "symB6", "=", "\"\<\!\(\*SubsuperscriptBox[\(B\), \(6\), \(4\)]\)\>\""}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.483703373765625*^9, 3.483703378671875*^9}, {
  3.48370352328125*^9, 3.483703539609375*^9}, {3.4837036211875*^9, 
  3.4837036309375*^9}, {3.48370469346875*^9, 3.483704720125*^9}, {
  3.48663741703125*^9, 3.48663746434375*^9}, {3.487680374140625*^9, 
  3.487680400203125*^9}, {3.559483103609563*^9, 3.559483136534923*^9}, {
  3.55954262167305*^9, 3.559542650365658*^9}, {3.560537521909388*^9, 
  3.560537538006072*^9}, {3.560539350820756*^9, 3.560539360123719*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"symKnots", " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"Text", "[", 
      RowBox[{
       RowBox[{"Style", "[", 
        RowBox[{"\"\<\[FivePointedStar]\>\"", ",", "Medium"}], "]"}], ",", 
       "#"}], "]"}], "&"}], "/@", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"5.33", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"8.33", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"14", ",", "0"}], "}"}]}], "}"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.559486202627114*^9, 3.559486214635637*^9}, {
  3.559486301576712*^9, 3.559486302571568*^9}, {3.559486366049752*^9, 
  3.559486368770009*^9}}],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"Evaluate", "[", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"BSplineBasis", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"degx", ",", "knotsx"}], "}"}], ",", "k", ",", "x"}], "]"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{"k", ",", "0", ",", "5"}], "}"}]}], "]"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "14"}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"Epilog", "->", 
    RowBox[{"{", 
     RowBox[{"{", "\[IndentingNewLine]", 
      RowBox[{"symKnots", ",", "\[IndentingNewLine]", 
       RowBox[{"Text", "[", 
        RowBox[{"\"\<5.33\>\"", ",", 
         RowBox[{"{", 
          RowBox[{"5.33", ",", "0.05"}], "}"}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Text", "[", 
        RowBox[{"\"\<8.33\>\"", ",", 
         RowBox[{"{", 
          RowBox[{"8.3", ",", "0.05"}], "}"}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Text", "[", 
        RowBox[{"symB1", ",", 
         RowBox[{"{", 
          RowBox[{"0.6", ",", "0.9"}], "}"}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Text", "[", 
        RowBox[{"symB2", ",", 
         RowBox[{"{", 
          RowBox[{"2.5", ",", "0.6"}], "}"}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Text", "[", 
        RowBox[{"symB3", ",", 
         RowBox[{"{", 
          RowBox[{"5", ",", "0.7"}], "}"}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Text", "[", 
        RowBox[{"symB4", ",", 
         RowBox[{"{", 
          RowBox[{"8.5", ",", "0.7"}], "}"}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Text", "[", 
        RowBox[{"symB5", ",", 
         RowBox[{"{", 
          RowBox[{"11.5", ",", "0.6"}], "}"}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Text", "[", 
        RowBox[{"symB6", ",", 
         RowBox[{"{", 
          RowBox[{"13.4", ",", "0.9"}], "}"}]}], "]"}]}], "}"}], "}"}]}], ",",
    "\[IndentingNewLine]", 
   RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.4822338086527767`*^9, 3.4822338219915457`*^9}, {
   3.482233861491841*^9, 3.4822339121320906`*^9}, {3.48256328578125*^9, 
   3.48256328990625*^9}, {3.48256332328125*^9, 3.482563376203125*^9}, {
   3.48266249828125*^9, 3.4826625106875*^9}, {3.484916641671875*^9, 
   3.484916680765625*^9}, {3.484916723734375*^9, 3.4849167388125*^9}, {
   3.484916772609375*^9, 3.48491687671875*^9}, {3.484980861421875*^9, 
   3.48498086334375*^9}, {3.484994385328125*^9, 3.484994389234375*^9}, {
   3.48499455128125*^9, 3.4849945548125*^9}, {3.48500009903125*^9, 
   3.485000242453125*^9}, 3.4860324928125*^9, {3.48603720228125*^9, 
   3.4860372225*^9}, 3.486039667484375*^9, {3.487680361671875*^9, 
   3.4876803631875*^9}, {3.4876804413125*^9, 3.487680533640625*^9}, {
   3.487681650109375*^9, 3.487681679921875*^9}, {3.559483151130657*^9, 
   3.559483152567132*^9}, {3.559483214718173*^9, 3.55948326640926*^9}, {
   3.559483361302782*^9, 3.559483403205857*^9}, {3.559483433275409*^9, 
   3.559483690924403*^9}, {3.559483722491504*^9, 3.559483726791054*^9}, {
   3.559486306932803*^9, 3.559486317491908*^9}, {3.559509407502039*^9, 
   3.559509431374259*^9}}],

Cell["It is instructive to Piesewise expand  the basis functions.", "Text",
 CellChangeTimes->{{3.482234065314257*^9, 3.4822340765776014`*^9}, {
   3.48499443396875*^9, 3.484994447921875*^9}, 3.4849946855625*^9, {
   3.559483753556153*^9, 3.559483757594501*^9}},
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"bsplines", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"PiecewiseExpand", "[", 
      RowBox[{
       RowBox[{"BSplineBasis", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"degx", ",", "knotsx"}], "}"}], ",", "k", ",", "x"}], "]"}],
        ",", 
       RowBox[{"Method", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<OrderlessConditions\>\"", "\[Rule]", "False"}], 
         "}"}]}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"k", ",", "0", ",", "5"}], "}"}]}], "]"}]}], ";", 
  RowBox[{"bsplines", "//", "Column"}]}]], "Input",
 CellChangeTimes->{{3.482234083410489*^9, 3.482234133487131*^9}, {
  3.482662576265625*^9, 3.482662577359375*^9}, {3.4826639286875*^9, 
  3.482663929375*^9}, {3.487659209421875*^9, 3.487659210453125*^9}, {
  3.4876816508125*^9, 3.487681680515625*^9}, {3.559483782275836*^9, 
  3.55948380242433*^9}, {3.559484716440413*^9, 3.55948472752096*^9}, {
  3.559484888425267*^9, 3.559484889578448*^9}, {3.559485921092246*^9, 
  3.559485921113735*^9}, {3.560541380328013*^9, 3.560541381806736*^9}}],

Cell[TextData[{
 "We observe that, in the first interval ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{"0", ",", "3.5"}], ")"}], TraditionalForm]]],
 ", only four Bsplines ",
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["B", "1", "3"], TraditionalForm]],
  FontSize->10],
 StyleBox[", ",
  FontSize->10],
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["B", "2", "3"], TraditionalForm]],
  FontSize->10],
 StyleBox[", ",
  FontSize->10],
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["B", "3", "3"], TraditionalForm]],
  FontSize->10],
 StyleBox[", ",
  FontSize->10],
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["B", "4", "3"], TraditionalForm]],
  FontSize->10],
 " give a contibution. The same observation holds for every other interval."
}], "Text",
 CellChangeTimes->{{3.482664394578125*^9, 3.482664468984375*^9}, {
  3.482664514625*^9, 3.482664539265625*^9}, {3.48275498540625*^9, 
  3.48275501025*^9}, {3.482755052734375*^9, 3.482755109421875*^9}, {
  3.48497849896875*^9, 3.484978499578125*^9}, {3.484978533796875*^9, 
  3.484978604484375*^9}, {3.484978754390625*^9, 3.48497876734375*^9}, {
  3.484994730125*^9, 3.484994889828125*^9}, {3.48499492471875*^9, 
  3.484994988171875*^9}, {3.484995021609375*^9, 3.48499506625*^9}, {
  3.487659286171875*^9, 3.487659317546875*^9}, {3.4876805590625*^9, 
  3.487680561609375*^9}, {3.559483857982459*^9, 3.559483930729468*^9}, {
  3.5605406961833*^9, 3.560540696705807*^9}},
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell["Part III", "Text",
 CellChangeTimes->{
  3.484992245703125*^9, {3.484992316015625*^9, 3.4849923314375*^9}, {
   3.48499253890625*^9, 3.484992628625*^9}, {3.484994235171875*^9, 
   3.484994236890625*^9}, {3.48499689084375*^9, 3.48499689559375*^9}, {
   3.486039583859375*^9, 3.486039584453125*^9}, {3.559482005654936*^9, 
   3.559482006444809*^9}, {3.572683638740938*^9, 3.5726836695567007`*^9}},
 FontSize->36,
 FontColor->RGBColor[0, 0, 1],
 Background->RGBColor[1, 0.9, 0.8]],

Cell["\<\
It is instructive to extract the polynomial representation of the B-splines \
on each of the four subintervals formed by the knots and to reconstruct the \
interpolating spline by hand.
The Interpolating spline S(x), together with the first and second \
derivatives, are plotted.\
\>", "Text",
 CellChangeTimes->{{3.482664394578125*^9, 3.482664468984375*^9}, {
   3.482664514625*^9, 3.482664539265625*^9}, {3.48275498540625*^9, 
   3.48275501025*^9}, {3.482755052734375*^9, 3.482755109421875*^9}, {
   3.48497849896875*^9, 3.484978499578125*^9}, {3.484978533796875*^9, 
   3.484978604484375*^9}, {3.484978754390625*^9, 3.48497884175*^9}, {
   3.484978883515625*^9, 3.484978886390625*^9}, {3.48499516884375*^9, 
   3.484995178203125*^9}, {3.48499522409375*^9, 3.4849953056875*^9}, {
   3.484995706578125*^9, 3.484995708015625*^9}, {3.4849960660625*^9, 
   3.484996119171875*^9}, 3.4849968864375*^9, {3.559483984151433*^9, 
   3.559483985287563*^9}, {3.559484046686684*^9, 3.559484058960876*^9}, {
   3.559485250553541*^9, 3.559485282145678*^9}, {3.559508253977063*^9, 
   3.559508280060243*^9}},
 FontFamily->"Times New Roman",
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell["\<\
We extract the segments of the B-spline which give a contribution  on the \
first interval\
\>", "Text",
 CellChangeTimes->{{3.482664394578125*^9, 3.482664468984375*^9}, {
   3.482664514625*^9, 3.482664539265625*^9}, {3.48275498540625*^9, 
   3.48275501025*^9}, {3.482755052734375*^9, 3.482755109421875*^9}, {
   3.48497849896875*^9, 3.484978499578125*^9}, {3.484978533796875*^9, 
   3.484978604484375*^9}, {3.484978754390625*^9, 3.48497884175*^9}, {
   3.484978883515625*^9, 3.484978931140625*^9}, {3.48499782309375*^9, 
   3.4849978416875*^9}, {3.487678947921875*^9, 3.487679004125*^9}, 
   3.487680630375*^9},
 FontFamily->"Times New Roman",
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"bsplines", "[", 
   RowBox[{"[", 
    RowBox[{"1", ",", "1", ",", "1", ",", "1"}], "]"}], "]"}], 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     SuperscriptBox[
      SubscriptBox["B", "1"], "4"], " ", "0."}], " ", "\[LessEqual]", " ", 
    "x", " ", "<", " ", "5.33"}], " ", "*)"}]}]], "Input",
 CellChangeTimes->{{3.482664695234375*^9, 3.482664696796875*^9}, {
   3.484912448203125*^9, 3.4849124485625*^9}, {3.48491807028125*^9, 
   3.484918106625*^9}, {3.484918140140625*^9, 3.484918141765625*^9}, {
   3.48491841321875*^9, 3.484918450671875*^9}, {3.4849185378125*^9, 
   3.484918538265625*^9}, 3.484918575984375*^9, {3.48491869765625*^9, 
   3.484918698015625*^9}, {3.484918768078125*^9, 3.4849187769375*^9}, {
   3.48500047140625*^9, 3.485000475484375*^9}, {3.485001215421875*^9, 
   3.485001216484375*^9}, {3.559545478473512*^9, 3.559545488792449*^9}, {
   3.559545715734236*^9, 3.559545717192671*^9}, {3.56053938716565*^9, 
   3.560539394157857*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"bsplines", "[", 
   RowBox[{"[", 
    RowBox[{"2", ",", "1", ",", "1", ",", "1"}], "]"}], "]"}], 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     SuperscriptBox[
      SubscriptBox["B", "2"], "4"], " ", "0"}], " ", "\[LessEqual]", "  ", 
    "x", " ", "<", 
    StyleBox[" ",
     FontSize->24], "5.33"}], " ", "*)"}]}]], "Input",
 CellChangeTimes->{{3.4826639458125*^9, 3.48266394865625*^9}, {
   3.48266465525*^9, 3.4826646664375*^9}, {3.484918169609375*^9, 
   3.484918194828125*^9}, {3.484918550640625*^9, 3.484918569953125*^9}, {
   3.48491867809375*^9, 3.484918680265625*^9}, 3.484918746984375*^9, {
   3.484918778953125*^9, 3.48491878215625*^9}, 3.4850004820625*^9, {
   3.48500051653125*^9, 3.48500052084375*^9}, {3.48765934115625*^9, 
   3.48765934171875*^9}, {3.559545516390523*^9, 3.559545522277*^9}, {
   3.559545721059914*^9, 3.5595457221235*^9}, {3.560539399511015*^9, 
   3.560539399658458*^9}, {3.560539571199048*^9, 3.560539574145058*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"bsplines", "[", 
   RowBox[{"[", 
    RowBox[{"3", ",", "1", ",", "1", ",", "1"}], "]"}], "]"}], 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     SuperscriptBox[
      SubscriptBox["B", "3"], "4"], " ", "0"}], " ", "\[LessEqual]", "  ", 
    "x", " ", "<", " ", "5.33"}], " ", "*)"}], "    "}]], "Input",
 CellChangeTimes->{{3.4826639458125*^9, 3.48266394865625*^9}, {
   3.48266465525*^9, 3.4826646664375*^9}, {3.482664763515625*^9, 
   3.48266478965625*^9}, {3.484914455515625*^9, 3.484914455765625*^9}, {
   3.484918226015625*^9, 3.484918240453125*^9}, {3.484918629546875*^9, 
   3.4849186456875*^9}, {3.484918747921875*^9, 3.484918748234375*^9}, {
   3.48491878525*^9, 3.484918786640625*^9}, 3.485000486203125*^9, {
   3.4850005416875*^9, 3.4850005419375*^9}, {3.48500121725*^9, 
   3.48500121771875*^9}, {3.559545534734786*^9, 3.559545539163333*^9}, {
   3.559545726282887*^9, 3.559545727327804*^9}, {3.560539577802354*^9, 
   3.560539581603265*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"bsplines", "[", 
   RowBox[{"[", 
    RowBox[{"4", ",", "1", ",", "1", ",", "1"}], "]"}], "]"}], 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     SuperscriptBox[
      SubscriptBox["B", "4"], "4"], " ", "0"}], " ", "\[LessEqual]", "  ", 
    "x", " ", "<", " ", "5.33"}], " ", "*)"}], "    "}]], "Input",
 CellChangeTimes->{{3.4826639458125*^9, 3.48266394865625*^9}, {
   3.48266465525*^9, 3.4826646664375*^9}, {3.482664763515625*^9, 
   3.48266478965625*^9}, {3.484914455515625*^9, 3.484914455765625*^9}, {
   3.484918226015625*^9, 3.484918240453125*^9}, {3.484918629546875*^9, 
   3.4849186456875*^9}, {3.484918747921875*^9, 3.484918748234375*^9}, {
   3.48491878525*^9, 3.484918786640625*^9}, 3.485000486203125*^9, {
   3.4850005416875*^9, 3.4850005419375*^9}, {3.48500057615625*^9, 
   3.485000587609375*^9}, {3.487659345046875*^9, 3.487659345484375*^9}, {
   3.559545541057353*^9, 3.559545542526918*^9}, {3.559545579526224*^9, 
   3.559545585811461*^9}, {3.559545731237384*^9, 3.559545732188877*^9}, {
   3.560539585240372*^9, 3.560539587961415*^9}}],

Cell["...  on the second interval", "Text",
 CellChangeTimes->{{3.482664394578125*^9, 3.482664468984375*^9}, {
  3.482664514625*^9, 3.482664539265625*^9}, {3.48275498540625*^9, 
  3.48275501025*^9}, {3.482755052734375*^9, 3.482755109421875*^9}, {
  3.48497849896875*^9, 3.484978499578125*^9}, {3.484978533796875*^9, 
  3.484978604484375*^9}, {3.484978754390625*^9, 3.48497884175*^9}, {
  3.484978883515625*^9, 3.484978931140625*^9}, {3.48499782309375*^9, 
  3.4849978416875*^9}, {3.487678947921875*^9, 3.487679004125*^9}, {
  3.487679036984375*^9, 3.4876790456875*^9}},
 FontFamily->"Times New Roman",
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"bsplines", "[", 
   RowBox[{"[", 
    RowBox[{"2", ",", "1", ",", "2", ",", "1"}], "]"}], "]"}], 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     SuperscriptBox[
      SubscriptBox["B", "2"], "4"], " ", "5.33"}], " ", "\[LessEqual]", " ", 
    "x", " ", "<", " ", "8.33"}], " ", "*)"}]}]], "Input",
 CellChangeTimes->{{3.482664695234375*^9, 3.482664696796875*^9}, {
   3.484912448203125*^9, 3.4849124485625*^9}, {3.484917832671875*^9, 
   3.48491783290625*^9}, {3.48491790596875*^9, 3.484917977078125*^9}, {
   3.484918312125*^9, 3.484918321234375*^9}, {3.484918499265625*^9, 
   3.48491853634375*^9}, {3.484918573890625*^9, 3.48491857434375*^9}, 
   3.48491885628125*^9, {3.4849189955*^9, 3.48491899634375*^9}, 
   3.484975175890625*^9, {3.4850006569375*^9, 3.48500067240625*^9}, {
   3.485000754046875*^9, 3.48500075446875*^9}, {3.485000791125*^9, 
   3.485000791640625*^9}, {3.4850011061875*^9, 3.48500110915625*^9}, {
   3.4850012266875*^9, 3.48500122715625*^9}, {3.48765939428125*^9, 
   3.487659394609375*^9}, {3.559545600759519*^9, 3.559545604784223*^9}, {
   3.55954568711392*^9, 3.559545687975394*^9}, {3.560539592381041*^9, 
   3.560539596193262*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"bsplines", "[", 
   RowBox[{"[", 
    RowBox[{"3", ",", "1", ",", "2", ",", "1"}], "]"}], "]"}], 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     SuperscriptBox[
      SubscriptBox["B", "3"], "4"], " ", "5.33"}], " ", "\[LessEqual]", " ", 
    "x", " ", "<", " ", "8.33"}], " ", "*)"}]}]], "Input",
 CellChangeTimes->{{3.4826639458125*^9, 3.48266394865625*^9}, {
   3.48266465525*^9, 3.4826646664375*^9}, {3.482664763515625*^9, 
   3.48266478965625*^9}, {3.484914455515625*^9, 3.484914455765625*^9}, {
   3.484918029859375*^9, 3.484918030171875*^9}, {3.484918369875*^9, 
   3.48491837971875*^9}, {3.484918590390625*^9, 3.48491859365625*^9}, {
   3.484918886796875*^9, 3.48491889828125*^9}, {3.484918983734375*^9, 
   3.484919007453125*^9}, 3.48500067925*^9, {3.485001136671875*^9, 
   3.485001137125*^9}, {3.485001231328125*^9, 3.485001231765625*^9}, {
   3.4876593994375*^9, 3.487659399921875*^9}, {3.55954560659847*^9, 
   3.559545621751461*^9}, {3.559545682820032*^9, 3.559545683751814*^9}, {
   3.560539600100677*^9, 3.560539603048744*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"bsplines", "[", 
   RowBox[{"[", 
    RowBox[{"4", ",", "1", ",", "2", ",", "1"}], "]"}], "]"}], 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     SuperscriptBox[
      SubscriptBox["B", "4"], "4"], " ", "5.33"}], " ", "\[LessEqual]", " ", 
    "x", " ", "<", " ", "8.33"}], " ", "*)"}]}]], "Input",
 CellChangeTimes->{{3.4826639458125*^9, 3.48266394865625*^9}, {
   3.48266465525*^9, 3.4826646664375*^9}, {3.48266474965625*^9, 
   3.482664751828125*^9}, {3.48491439440625*^9, 3.484914451171875*^9}, {
   3.4849147040625*^9, 3.484914723890625*^9}, {3.48491894675*^9, 
   3.484918967484375*^9}, {3.484919010046875*^9, 3.484919011359375*^9}, {
   3.484919228046875*^9, 3.484919228421875*^9}, {3.48497494140625*^9, 
   3.484974942046875*^9}, 3.48500068178125*^9, {3.48500115834375*^9, 
   3.485001158703125*^9}, {3.487659403734375*^9, 3.4876594040625*^9}, {
   3.559545624323874*^9, 3.559545641792288*^9}, {3.559545678733473*^9, 
   3.559545679491757*^9}, {3.560539612775582*^9, 3.560539615375175*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"bsplines", "[", 
   RowBox[{"[", 
    RowBox[{"5", ",", "1", ",", "1", ",", "1"}], "]"}], "]"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     SuperscriptBox[
      SubscriptBox["B", "5"], "4"], " ", "5.33"}], " ", "\[LessEqual]", " ", 
    "x", " ", "<", " ", "8.33"}], " ", "*)"}]}]], "Input",
 CellChangeTimes->{{3.48500119525*^9, 3.48500119878125*^9}, {
  3.48500123746875*^9, 3.485001239875*^9}, {3.487659407296875*^9, 
  3.487659407375*^9}, {3.487659489296875*^9, 3.487659489703125*^9}, {
  3.559545644258776*^9, 3.559545673720457*^9}, {3.560539605774153*^9, 
  3.560539609469966*^9}}],

Cell["and  on the third interval", "Text",
 CellChangeTimes->{{3.482664394578125*^9, 3.482664468984375*^9}, {
  3.482664514625*^9, 3.482664539265625*^9}, {3.48275498540625*^9, 
  3.48275501025*^9}, {3.482755052734375*^9, 3.482755109421875*^9}, {
  3.48497849896875*^9, 3.484978499578125*^9}, {3.484978533796875*^9, 
  3.484978604484375*^9}, {3.484978754390625*^9, 3.48497884175*^9}, {
  3.484978883515625*^9, 3.484978931140625*^9}, {3.48499782309375*^9, 
  3.4849978416875*^9}, {3.487678947921875*^9, 3.487679004125*^9}, {
  3.487679036984375*^9, 3.4876790456875*^9}, {3.48768067259375*^9, 
  3.487680702234375*^9}},
 FontFamily->"Times New Roman",
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"bsplines", "[", 
   RowBox[{"[", 
    RowBox[{"3", ",", "1", ",", "3", ",", "1"}], "]"}], "]"}], 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     SuperscriptBox[
      SubscriptBox["B", "4"], "4"], " ", "8.33"}], " ", "\[LessEqual]", " ", 
    "x", " ", "<", " ", "14.0"}], " ", "*)"}], " "}]], "Input",
 CellChangeTimes->{{3.4826639458125*^9, 3.48266394865625*^9}, {
  3.48266465525*^9, 3.4826646664375*^9}, {3.48266474965625*^9, 
  3.482664751828125*^9}, {3.48491439440625*^9, 3.484914451171875*^9}, {
  3.484919309734375*^9, 3.484919313453125*^9}, {3.484919409390625*^9, 
  3.48491945521875*^9}, {3.484919517671875*^9, 3.4849195189375*^9}, {
  3.485001272859375*^9, 3.48500129928125*^9}, {3.487659426203125*^9, 
  3.487659426671875*^9}, {3.559545747894636*^9, 3.559545756676601*^9}, {
  3.560539619633887*^9, 3.560539622249725*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"bsplines", "[", 
   RowBox[{"[", 
    RowBox[{"4", ",", "1", ",", "3", ",", "1"}], "]"}], "]"}], 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     SuperscriptBox[
      SubscriptBox["B", "4"], "4"], "  ", "8.33"}], " ", "\[LessEqual]", " ", 
    "x", " ", "<", " ", "14.0"}], " ", "*)"}], " "}]], "Input",
 CellChangeTimes->{{3.4826639458125*^9, 3.48266394865625*^9}, {
   3.48266465525*^9, 3.4826646664375*^9}, {3.48266474965625*^9, 
   3.482664751828125*^9}, {3.48491439440625*^9, 3.484914451171875*^9}, {
   3.484919309734375*^9, 3.484919313453125*^9}, {3.484919409390625*^9, 
   3.48491945521875*^9}, {3.484919517671875*^9, 3.4849195189375*^9}, 
   3.48500130790625*^9, {3.485001362109375*^9, 3.48500136253125*^9}, {
   3.559545758537632*^9, 3.559545773190339*^9}, {3.560539625124831*^9, 
   3.560539627449423*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"bsplines", "[", 
   RowBox[{"[", 
    RowBox[{"5", ",", "1", ",", "2", ",", "1"}], "]"}], "]"}], 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     SuperscriptBox[
      SubscriptBox["B", "5"], "4"], "  ", "8.33"}], " ", "\[LessEqual]", " ", 
    "x", " ", "<", " ", "14.0"}], " ", "*)"}], " "}]], "Input",
 CellChangeTimes->{{3.4826639458125*^9, 3.48266394865625*^9}, {
   3.48266465525*^9, 3.4826646664375*^9}, {3.48266474965625*^9, 
   3.482664751828125*^9}, {3.48491439440625*^9, 3.484914451171875*^9}, {
   3.484919309734375*^9, 3.484919351984375*^9}, {3.48491950746875*^9, 
   3.484919512984375*^9}, {3.48491956040625*^9, 3.484919581984375*^9}, {
   3.484975095125*^9, 3.484975095609375*^9}, 3.48500130996875*^9, {
   3.48765943234375*^9, 3.487659432734375*^9}, {3.559545777453155*^9, 
   3.559545795679684*^9}, {3.560539630842718*^9, 3.560539631050738*^9}, {
   3.560539713421746*^9, 3.56053971446927*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"bsplines", "[", 
   RowBox[{"[", 
    RowBox[{"6", ",", "1", ",", "1", ",", "1"}], "]"}], "]"}], 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     SuperscriptBox[
      SubscriptBox["B", "6"], "4"], "  ", "8.33"}], " ", "\[LessEqual]", " ", 
    "x", " ", "<", " ", "14.0"}], " ", "*)"}], " "}]], "Input",
 CellChangeTimes->{{3.4826639458125*^9, 3.48266394865625*^9}, {
   3.48266465525*^9, 3.4826646664375*^9}, {3.48266474965625*^9, 
   3.482664751828125*^9}, {3.48491439440625*^9, 3.48491448825*^9}, {
   3.484919547640625*^9, 3.484919584640625*^9}, 3.485001312078125*^9, {
   3.559545799431747*^9, 3.559545812707259*^9}, {3.560539717606169*^9, 
   3.560539720621361*^9}}],

Cell["We plot the B-Splines separately", "Text",
 CellChangeTimes->{{3.482664394578125*^9, 3.482664468984375*^9}, {
   3.482664514625*^9, 3.482664539265625*^9}, {3.48275498540625*^9, 
   3.48275501025*^9}, {3.482755052734375*^9, 3.48275518615625*^9}, {
   3.4827552320625*^9, 3.48275526790625*^9}, {3.48499732775*^9, 
   3.48499733709375*^9}, {3.484997378734375*^9, 3.4849973836875*^9}, 
   3.48499786365625*^9, 3.559508299363243*^9},
 FontFamily->"Times New Roman",
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{"p1", "=", " ", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"bsplines", "[", 
     RowBox[{"[", "1", "]"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", "14"}], "}"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
    RowBox[{"Epilog", "->", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Text", "[", 
        RowBox[{
         RowBox[{"Style", "[", 
          RowBox[{"symB1", ",", "Medium"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"2", ",", "0.6"}], "}"}]}], "]"}], ",", " ", "symKnots"}], 
      "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4826639558125*^9, 3.48266397771875*^9}, {
  3.48498071790625*^9, 3.48498075084375*^9}, {3.4849971371875*^9, 
  3.484997151921875*^9}, {3.484997229890625*^9, 3.484997235328125*^9}, {
  3.487680759609375*^9, 3.487680814046875*^9}, {3.559485153716068*^9, 
  3.55948516247113*^9}, {3.559485441300609*^9, 3.559485451797678*^9}, {
  3.559485903809112*^9, 3.559485906463521*^9}, {3.559485979922824*^9, 
  3.559485988347174*^9}, {3.55948639520236*^9, 3.55948640479852*^9}, {
  3.559486454195708*^9, 3.559486456389125*^9}}],

Cell[BoxData[
 RowBox[{"p2", "=", " ", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"bsplines", "[", 
     RowBox[{"[", "2", "]"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", "14"}], "}"}], ",", 
    RowBox[{"Epilog", "->", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Text", "[", 
        RowBox[{
         RowBox[{"Style", "[", 
          RowBox[{"symB2", ",", "Medium"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"5", ",", "0.4"}], "}"}]}], "]"}], ",", " ", "symKnots"}], 
      "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4826639558125*^9, 3.482664008109375*^9}, {
   3.48498076878125*^9, 3.484980775265625*^9}, {3.484981148359375*^9, 
   3.48498114865625*^9}, 3.484997240046875*^9, 3.487680889640625*^9, {
   3.48768092903125*^9, 3.4876809698125*^9}, {3.559485893728352*^9, 
   3.559485898399949*^9}, {3.559485935629669*^9, 3.559486072261866*^9}, {
   3.559486413639844*^9, 3.559486417541002*^9}, {3.559509003934311*^9, 
   3.559509017314349*^9}, {3.559509548378906*^9, 3.559509550375968*^9}}],

Cell[BoxData[
 RowBox[{"p3", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"bsplines", "[", 
     RowBox[{"[", "3", "]"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", "14"}], "}"}], ",", 
    RowBox[{"Epilog", "->", 
     RowBox[{"{", " ", 
      RowBox[{
       RowBox[{"Text", "[", 
        RowBox[{
         RowBox[{"Style", "[", 
          RowBox[{"symB3", ",", "Medium"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"8", ",", "0.5"}], "}"}]}], "]"}], ",", "symKnots"}], 
      "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4826639558125*^9, 3.482664036125*^9}, {3.482664124*^9, 
   3.482664124828125*^9}, {3.482664276875*^9, 3.482664305078125*^9}, {
   3.484981143859375*^9, 3.48498116409375*^9}, 3.484997243734375*^9, {
   3.48768100396875*^9, 3.48768103378125*^9}, {3.487681065109375*^9, 
   3.487681097328125*^9}, {3.487681462046875*^9, 3.487681474953125*^9}, {
   3.559486430179135*^9, 3.559486450617174*^9}, {3.559486545945367*^9, 
   3.559486548398707*^9}, {3.559508987787552*^9, 3.559508993288877*^9}, 
   3.559509556704695*^9}],

Cell[BoxData[
 RowBox[{"p4", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"bsplines", "[", 
     RowBox[{"[", "4", "]"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", "14"}], "}"}], ",", 
    RowBox[{"Epilog", "->", 
     RowBox[{"{", " ", 
      RowBox[{
       RowBox[{"Text", "[", 
        RowBox[{
         RowBox[{"Style", "[", 
          RowBox[{"symB4", ",", "Medium"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"12", ",", "0.5"}], "}"}]}], "]"}], ",", "symKnots"}], 
      "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4826639558125*^9, 3.482664047625*^9}, {
   3.482664136953125*^9, 3.482664137453125*^9}, {3.484981178125*^9, 
   3.48498118625*^9}, 3.484997247609375*^9, 3.487681186453125*^9, {
   3.487681404734375*^9, 3.48768144290625*^9}, {3.559486511398406*^9, 
   3.559486539240104*^9}, {3.559509026755076*^9, 3.55950903234272*^9}, 
   3.559509562272065*^9}],

Cell[BoxData[
 RowBox[{"p5", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"bsplines", "[", 
     RowBox[{"[", "5", "]"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", "14"}], "}"}], ",", 
    RowBox[{"Epilog", "->", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Text", "[", 
        RowBox[{
         RowBox[{"Style", "[", 
          RowBox[{"symB5", ",", "Medium"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"9", ",", "0.4"}], "}"}]}], "]"}], ",", "symKnots"}], 
      "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4826639558125*^9, 3.482664047625*^9}, {
   3.482664136953125*^9, 3.482664137453125*^9}, {3.482664206484375*^9, 
   3.4826642243125*^9}, 3.4834992060625*^9, {3.484981192421875*^9, 
   3.48498120653125*^9}, 3.4849972503125*^9, {3.487681224390625*^9, 
   3.487681241140625*^9}, {3.487681364859375*^9, 3.4876813816875*^9}, {
   3.559486554526794*^9, 3.559486581728078*^9}, 3.559509044734654*^9, 
   3.559509568253172*^9}],

Cell[BoxData[
 RowBox[{"p6", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"bsplines", "[", 
     RowBox[{"[", "6", "]"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", "14"}], "}"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", "All"}], ",", "\[IndentingNewLine]", 
    RowBox[{"Epilog", "->", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Text", "[", 
        RowBox[{
         RowBox[{"Style", "[", 
          RowBox[{"symB6", ",", "Medium"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"12", ",", "0.6"}], "}"}]}], "]"}], ",", "symKnots"}], 
      "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.48498122121875*^9, 3.4849812251875*^9}, 
   3.484997263078125*^9, {3.4876812780625*^9, 3.487681359453125*^9}, {
   3.559486587100634*^9, 3.559486654206524*^9}}],

Cell["\<\
We reconstruct the spline and plot the resultant on each subdomain formed by \
the four knots\
\>", "Text",
 CellChangeTimes->{{3.482664394578125*^9, 3.482664468984375*^9}, {
   3.482664514625*^9, 3.482664539265625*^9}, {3.48275498540625*^9, 
   3.48275501025*^9}, {3.482755052734375*^9, 3.48275518615625*^9}, 
   3.484914425703125*^9, {3.484914587328125*^9, 3.484914590265625*^9}, {
   3.4849790056875*^9, 3.484979036765625*^9}, 3.48499291775*^9, {
   3.4849973990625*^9, 3.48499747065625*^9}, {3.484997518078125*^9, 
   3.484997519515625*^9}, {3.559508322045296*^9, 3.559508328452069*^9}},
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", "x_", "]"}], "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"coeff", ".", "bsplines"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.559507412758713*^9, 3.559507440327875*^9}, {
  3.559508155235904*^9, 3.559508183032079*^9}, {3.559542860157253*^9, 
  3.559542870016616*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"f1", "[", "x_", "]"}], "=", 
  RowBox[{
   RowBox[{"f", "[", "x", "]"}], "[", 
   RowBox[{"[", 
    RowBox[{"1", ",", "3", ",", "1"}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.482664798328125*^9, 3.482664876421875*^9}, {
  3.482665070609375*^9, 3.482665072234375*^9}, {3.484914595796875*^9, 
  3.48491461284375*^9}, {3.484917527796875*^9, 3.48491757125*^9}, {
  3.484992918484375*^9, 3.484992919515625*^9}, {3.48500146815625*^9, 
  3.485001540015625*^9}, {3.487659447484375*^9, 3.487659451*^9}, {
  3.559506917028267*^9, 3.559506956248039*^9}, {3.559507172287964*^9, 
  3.559507189532424*^9}, {3.559507232823027*^9, 3.559507245266136*^9}, {
  3.559507368146588*^9, 3.559507393065906*^9}, {3.559507496215718*^9, 
  3.559507537999896*^9}}],

Cell[BoxData[
 RowBox[{"segment1", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{"f1", "[", "x", "]"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", "5.33"}], "}"}]}], "]"}], " "}]], "Input",
 CellChangeTimes->{{3.4826639558125*^9, 3.48266397771875*^9}, {
   3.482664893203125*^9, 3.48266489575*^9}, {3.4826649806875*^9, 
   3.482664982765625*^9}, {3.482665113578125*^9, 3.482665156546875*^9}, {
   3.482665204203125*^9, 3.482665208359375*^9}, 3.4849145061875*^9, {
   3.48499787665625*^9, 3.484997877140625*^9}, {3.48499791696875*^9, 
   3.48499791890625*^9}, {3.485001522046875*^9, 3.485001524234375*^9}, 
   3.559507773199627*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"f2", "[", "x_", "]"}], "=", 
  RowBox[{
   RowBox[{"f", "[", "x", "]"}], "[", 
   RowBox[{"[", 
    RowBox[{"1", ",", "2", ",", "1"}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5595077287240868`*^9, 3.559507738690277*^9}}],

Cell[BoxData[
 RowBox[{"segment2", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{"f2", "[", "x", "]"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "5.33", ",", "8.33"}], "}"}]}], "]"}], " "}]], "Input",
 CellChangeTimes->{{3.4826639558125*^9, 3.48266397771875*^9}, {
   3.482664893203125*^9, 3.48266489575*^9}, {3.4826649806875*^9, 
   3.482664982765625*^9}, {3.482665113578125*^9, 3.482665156546875*^9}, {
   3.482665204203125*^9, 3.482665208359375*^9}, 3.4849145061875*^9, {
   3.484975271390625*^9, 3.484975284296875*^9}, {3.484997882078125*^9, 
   3.484997911578125*^9}, {3.4850017183125*^9, 3.485001726046875*^9}, 
   3.559507766721583*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"f3", "[", "x_", "]"}], "=", 
  RowBox[{
   RowBox[{"f", "[", "x", "]"}], "[", 
   RowBox[{"[", "2", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.559507913166298*^9, 3.559507936878832*^9}, {
  3.559507979912235*^9, 3.559508004442833*^9}}],

Cell[BoxData[
 RowBox[{"segment3", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{"f3", "[", "x", "]"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "8.33", ",", "14"}], "}"}]}], "]"}], " "}]], "Input",
 CellChangeTimes->{{3.4826639558125*^9, 3.48266397771875*^9}, {
   3.482664893203125*^9, 3.48266489575*^9}, {3.4826649806875*^9, 
   3.482664982765625*^9}, {3.482665113578125*^9, 3.482665156546875*^9}, {
   3.482665204203125*^9, 3.482665208359375*^9}, 3.4849145061875*^9, {
   3.484975271390625*^9, 3.484975284296875*^9}, {3.484975398203125*^9, 
   3.484975417578125*^9}, {3.48499788959375*^9, 3.484997906578125*^9}, {
   3.485001734640625*^9, 3.485001740125*^9}, 3.560542563061752*^9}],

Cell["We plot the complete spline", "Text",
 CellChangeTimes->{{3.482664394578125*^9, 3.482664468984375*^9}, {
   3.482664514625*^9, 3.482664539265625*^9}, {3.48275498540625*^9, 
   3.48275501025*^9}, {3.482755052734375*^9, 3.48275518615625*^9}, {
   3.48491260909375*^9, 3.484912650578125*^9}, 3.48491287253125*^9, {
   3.48497766284375*^9, 3.484977663578125*^9}, {3.484979246015625*^9, 
   3.4849792499375*^9}, {3.484979322359375*^9, 3.484979372375*^9}, {
   3.484979455421875*^9, 3.48497947915625*^9}, {3.559508376208751*^9, 
   3.559508474187669*^9}, {3.559509086440854*^9, 3.559509091388207*^9}, {
   3.55954171593937*^9, 3.559541724775205*^9}, {3.560537809989053*^9, 
   3.56053781902894*^9}},
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{"graphSx", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"f", "[", "x", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", "14"}], "}"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"Thickness", "[", "Medium", "]"}]}], ",", 
    RowBox[{"AxesOrigin", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "0"}], "}"}]}], ",", 
    RowBox[{"Epilog", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Red", ",", 
       RowBox[{"PointSize", "[", "Medium", "]"}], ",", 
       RowBox[{"Point", "[", "points", "]"}]}], "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{
  3.482232990035215*^9, {3.482662078546875*^9, 3.482662109859375*^9}, {
   3.482662150546875*^9, 3.4826622134375*^9}, {3.48266495928125*^9, 
   3.4826649904375*^9}, {3.484975777125*^9, 3.48497580125*^9}, {
   3.48497956090625*^9, 3.484979579671875*^9}, {3.48498021971875*^9, 
   3.48498023115625*^9}, {3.484997551734375*^9, 3.48499757775*^9}, {
   3.559508523791254*^9, 3.559508528181573*^9}, {3.559509062991074*^9, 
   3.559509065195182*^9}, {3.559509580866961*^9, 3.559509592355838*^9}, {
   3.560537826509241*^9, 3.560537836331844*^9}, {3.560538420771313*^9, 
   3.560538422492601*^9}}],

Cell["Part IV", "Text",
 CellChangeTimes->{
  3.484992245703125*^9, {3.484992316015625*^9, 3.4849923314375*^9}, {
   3.48499253890625*^9, 3.484992628625*^9}, {3.484994235171875*^9, 
   3.484994236890625*^9}, {3.48499689084375*^9, 3.48499689559375*^9}, {
   3.486039583859375*^9, 3.486039584453125*^9}, {3.559482005654936*^9, 
   3.559482006444809*^9}, {3.572683638740938*^9, 3.572683640652047*^9}, 
   3.572683680653335*^9},
 FontSize->36,
 FontColor->RGBColor[0, 0, 1],
 Background->RGBColor[1, 0.9, 0.8]],

Cell[TextData[{
 "We can check graphically and manually  the ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["C", "1"], TraditionalForm]]],
 " and boundary conditions.\nIt is verified that no boundary conditions are \
introduced."
}], "Text",
 CellChangeTimes->{{3.4849789611875*^9, 3.48497897071875*^9}, {
   3.484979148703125*^9, 3.484979160640625*^9}, {3.484979192*^9, 
   3.484979203421875*^9}, {3.4849961621875*^9, 3.4849962291875*^9}, {
   3.48499627365625*^9, 3.48499632746875*^9}, 3.484996906109375*^9, {
   3.486039064921875*^9, 3.486039067234375*^9}, {3.4860391213125*^9, 
   3.486039158296875*^9}, {3.487681808125*^9, 3.4876818221875*^9}, {
   3.559508547176159*^9, 3.559508553783866*^9}, 3.560537859615929*^9},
 FontFamily->"Times New Roman",
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell["First derivative of S(x)", "Text",
 CellChangeTimes->{{3.482664394578125*^9, 3.482664468984375*^9}, {
   3.482664514625*^9, 3.482664539265625*^9}, {3.48275498540625*^9, 
   3.48275501025*^9}, {3.482755052734375*^9, 3.48275518615625*^9}, {
   3.48491260909375*^9, 3.484912650578125*^9}, 3.48491287253125*^9, {
   3.48497766284375*^9, 3.484977663578125*^9}, {3.484979246015625*^9, 
   3.4849792499375*^9}, {3.484979322359375*^9, 3.484979372375*^9}, {
   3.484979455421875*^9, 3.48497947915625*^9}, {3.484980267109375*^9, 
   3.484980270515625*^9}, {3.484997590125*^9, 3.484997612640625*^9}},
 FontFamily->"Times New Roman",
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{"dSpline1", "=", " ", 
  RowBox[{"D", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{"f", "[", "x", "]"}], "]"}], ",", "x"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.484912715*^9, 3.484912771*^9}, {3.48491306615625*^9, 
  3.4849130966875*^9}, {3.484913129359375*^9, 3.484913129921875*^9}, {
  3.4849139203125*^9, 3.484913921921875*^9}, {3.48491610159375*^9, 
  3.48491611259375*^9}, {3.48497586496875*^9, 3.484975869640625*^9}, {
  3.559508572093324*^9, 3.559508573692653*^9}, {3.559508613621819*^9, 
  3.559508628182948*^9}, {3.559509119308342*^9, 3.559509120908365*^9}, {
  3.560537865460745*^9, 3.560537903545519*^9}}],

Cell[BoxData[
 RowBox[{"graD1", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{"dSpline1", ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", "14"}], "}"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"Thickness", "[", "Medium", "]"}]}], ",", 
    RowBox[{"AxesOrigin", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "0"}], "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{
  3.482232990035215*^9, {3.482662078546875*^9, 3.482662109859375*^9}, {
   3.482662150546875*^9, 3.4826622134375*^9}, {3.48266495928125*^9, 
   3.4826649904375*^9}, {3.484975777125*^9, 3.48497580125*^9}, {
   3.484975914828125*^9, 3.484975957578125*^9}, {3.484977919265625*^9, 
   3.48497795284375*^9}, {3.484978079421875*^9, 3.484978085875*^9}, {
   3.559508653656217*^9, 3.559508691211942*^9}, 3.559509599848436*^9, {
   3.560537878214731*^9, 3.56053790709599*^9}}],

Cell["Second derivative of S(x)", "Text",
 CellChangeTimes->{{3.482664394578125*^9, 3.482664468984375*^9}, {
   3.482664514625*^9, 3.482664539265625*^9}, {3.48275498540625*^9, 
   3.48275501025*^9}, {3.482755052734375*^9, 3.48275518615625*^9}, {
   3.48491260909375*^9, 3.484912650578125*^9}, 3.48491287253125*^9, {
   3.48497766284375*^9, 3.484977663578125*^9}, {3.484979246015625*^9, 
   3.4849792499375*^9}, {3.484979322359375*^9, 3.484979372375*^9}, {
   3.484979455421875*^9, 3.48497947915625*^9}, {3.484980267109375*^9, 
   3.484980270515625*^9}, {3.48498037325*^9, 3.4849803761875*^9}, {
   3.48499762365625*^9, 3.48499763034375*^9}},
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{"dSpline2", "=", " ", 
  RowBox[{"D", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{"f", "[", "x", "]"}], "]"}], ",", "x", ",", "x"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.484912715*^9, 3.484912771*^9}, {3.48491306615625*^9, 
  3.4849130966875*^9}, {3.484913129359375*^9, 3.484913129921875*^9}, {
  3.4849139203125*^9, 3.484913921921875*^9}, {3.48491610159375*^9, 
  3.48491611259375*^9}, {3.48497586496875*^9, 3.484975897078125*^9}, {
  3.560537886767688*^9, 3.560537909632371*^9}}],

Cell[BoxData[
 RowBox[{"graD2", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{"dSpline2", ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", "14"}], "}"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"Thickness", "[", "Medium", "]"}]}], ",", 
    RowBox[{"AxesOrigin", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "0"}], "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{
  3.482232990035215*^9, {3.482662078546875*^9, 3.482662109859375*^9}, {
   3.482662150546875*^9, 3.4826622134375*^9}, {3.48266495928125*^9, 
   3.4826649904375*^9}, {3.484975777125*^9, 3.48497580125*^9}, {
   3.484975914828125*^9, 3.484975991890625*^9}, {3.4849784160625*^9, 
   3.484978438015625*^9}, {3.559508709986929*^9, 3.55950871274996*^9}, {
   3.560537913978498*^9, 3.560537918782051*^9}}],

Cell["Third derivative of S(x)", "Text",
 CellChangeTimes->{{3.482664394578125*^9, 3.482664468984375*^9}, {
   3.482664514625*^9, 3.482664539265625*^9}, {3.48275498540625*^9, 
   3.48275501025*^9}, {3.482755052734375*^9, 3.48275518615625*^9}, {
   3.48491260909375*^9, 3.484912650578125*^9}, 3.48491287253125*^9, {
   3.48497766284375*^9, 3.484977663578125*^9}, {3.484979246015625*^9, 
   3.4849792499375*^9}, {3.484979322359375*^9, 3.484979372375*^9}, {
   3.484979455421875*^9, 3.48497947915625*^9}, {3.484980267109375*^9, 
   3.484980270515625*^9}, {3.48498037325*^9, 3.4849803761875*^9}, {
   3.48499762365625*^9, 3.48499763034375*^9}, {3.48500188915625*^9, 
   3.4850018921875*^9}},
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{"dSpline3", "=", " ", 
  RowBox[{"D", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{"f", "[", "x", "]"}], "]"}], ",", "x", ",", "x", ",", "x"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.484912715*^9, 3.484912771*^9}, {3.48491306615625*^9, 
  3.4849130966875*^9}, {3.484913129359375*^9, 3.484913129921875*^9}, {
  3.4849139203125*^9, 3.484913921921875*^9}, {3.48491610159375*^9, 
  3.48491611259375*^9}, {3.48497586496875*^9, 3.484975897078125*^9}, {
  3.48500189665625*^9, 3.485001903015625*^9}, {3.560537921993818*^9, 
  3.560537927310957*^9}}],

Cell[BoxData[
 RowBox[{"graD3", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{"dSpline3", ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", "14"}], "}"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"Thickness", "[", "Medium", "]"}]}], ",", 
    RowBox[{"AxesOrigin", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "0"}], "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{
  3.482232990035215*^9, {3.482662078546875*^9, 3.482662109859375*^9}, {
   3.482662150546875*^9, 3.4826622134375*^9}, {3.48266495928125*^9, 
   3.4826649904375*^9}, {3.484975777125*^9, 3.48497580125*^9}, {
   3.484975914828125*^9, 3.484975991890625*^9}, {3.4849784160625*^9, 
   3.484978438015625*^9}, {3.48500190496875*^9, 3.48500190940625*^9}, {
   3.559508726886991*^9, 3.559508759993059*^9}, {3.56053793165449*^9, 
   3.560537937368455*^9}}],

Cell["First and second derivatives at x = 0.", "Text",
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{"derD1f1x0", "=", " ", 
  RowBox[{"Limit", "[", 
   RowBox[{
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{"Evaluate", "[", 
       RowBox[{"f", "[", "x", "]"}], "]"}], ",", "x"}], "]"}], " ", ",", 
    RowBox[{"x", "\[Rule]", "0"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4849789611875*^9, 3.48497897071875*^9}, {
   3.484996362078125*^9, 3.484996404453125*^9}, 3.560537947540439*^9, {
   3.560538007026204*^9, 3.560538013044164*^9}}],

Cell[BoxData[
 RowBox[{"derD2f1x0", "=", " ", 
  RowBox[{"Limit", "[", 
   RowBox[{
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{"Evaluate", "[", 
       RowBox[{"f", "[", "x", "]"}], "]"}], ",", "x", ",", "x"}], "]"}], " ", 
    ",", 
    RowBox[{"x", "\[Rule]", "0"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4849789611875*^9, 3.484978974875*^9}, {
   3.48499639340625*^9, 3.48499640853125*^9}, 3.560537953536343*^9, {
   3.560538029006048*^9, 3.560538034752427*^9}}],

Cell[TextData[{
 "First and second derivatives at x=14, we approach ",
 Cell[BoxData[
  FormBox[
   RowBox[{"x", "=", "14"}], TraditionalForm]]],
 " from the left."
}], "Text",
 CellChangeTimes->{{3.482664394578125*^9, 3.482664468984375*^9}, {
   3.482664514625*^9, 3.482664539265625*^9}, {3.48275498540625*^9, 
   3.48275501025*^9}, {3.482755052734375*^9, 3.48275518615625*^9}, {
   3.48491260909375*^9, 3.484912650578125*^9}, 3.48491287253125*^9, {
   3.48497766284375*^9, 3.484977663578125*^9}, {3.484979246015625*^9, 
   3.4849792499375*^9}, {3.484996455*^9, 3.484996511484375*^9}, {
   3.560538260176859*^9, 3.560538303389987*^9}},
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{"derD1f4x14", "=", 
  RowBox[{"Limit", "[", " ", 
   RowBox[{
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{"Evaluate", "[", 
       RowBox[{"f", "[", "x", "]"}], "]"}], ",", "x"}], "]"}], " ", ",", " ", 
    RowBox[{"x", "\[Rule]", "14"}], ",", " ", 
    RowBox[{"Direction", "\[Rule]", "1"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.484912499015625*^9, 3.484912547140625*^9}, 
   3.484914509015625*^9, 3.484916429015625*^9, {3.48491741003125*^9, 
   3.48491741365625*^9}, {3.4849753231875*^9, 3.484975343109375*^9}, {
   3.484975489859375*^9, 3.48497549940625*^9}, {3.484996419484375*^9, 
   3.484996437296875*^9}, {3.485001927109375*^9, 3.4850019275*^9}, 
   3.560537975316038*^9, {3.560538040465978*^9, 3.560538045901245*^9}, {
   3.560538244889351*^9, 3.560538247914576*^9}}],

Cell[BoxData[
 RowBox[{"derD2f4x14", "=", " ", 
  RowBox[{"Limit", "[", 
   RowBox[{
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{"Evaluate", "[", 
       RowBox[{"f", "[", "x", "]"}], "]"}], ",", "x", ",", "x"}], "]"}], " ", 
    ",", 
    RowBox[{"x", "\[Rule]", "14"}], ",", 
    RowBox[{"Direction", "\[Rule]", "1"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.484912499015625*^9, 3.484912565265625*^9}, 
   3.484914510296875*^9, 3.48491643084375*^9, {3.4849174166875*^9, 
   3.484917420078125*^9}, {3.484975326515625*^9, 3.4849753331875*^9}, {
   3.48497550234375*^9, 3.484975511625*^9}, {3.48499642209375*^9, 
   3.48499642996875*^9}, {3.485001932015625*^9, 3.485001932484375*^9}, {
   3.560538051945494*^9, 3.560538061218772*^9}, {3.56053825488422*^9, 
   3.560538255172863*^9}}],

Cell["\<\
We verify continuity of first derivative at first internal knot (5.33)\
\>", "Text",
 CellChangeTimes->{{3.482664394578125*^9, 3.482664468984375*^9}, {
   3.482664514625*^9, 3.482664539265625*^9}, {3.48275498540625*^9, 
   3.48275501025*^9}, {3.482755052734375*^9, 3.48275518615625*^9}, {
   3.48491260909375*^9, 3.484912650578125*^9}, 3.48491287253125*^9, {
   3.48497766284375*^9, 3.484977663578125*^9}, {3.484979246015625*^9, 
   3.4849792499375*^9}, {3.484979322359375*^9, 3.484979372375*^9}, {
   3.48499652175*^9, 3.484996562421875*^9}, {3.48500198090625*^9, 
   3.485001983453125*^9}},
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{"derf1dx", "=", 
  RowBox[{"Limit", "[", " ", 
   RowBox[{
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{"Evaluate", "[", 
       RowBox[{"f1", "[", "x", "]"}], "]"}], ",", "x"}], "]"}], " ", ",", " ", 
    RowBox[{"x", "\[Rule]", 
     FractionBox["16", "3"]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.484912499015625*^9, 3.484912547140625*^9}, 
   3.484914509015625*^9, 3.484916429015625*^9, {3.48491741003125*^9, 
   3.48491741365625*^9}, {3.484917496828125*^9, 3.4849175061875*^9}, {
   3.484975242015625*^9, 3.48497524375*^9}, {3.484979378046875*^9, 
   3.4849793979375*^9}, {3.48500195659375*^9, 3.4850019598125*^9}, {
   3.560538070318299*^9, 3.560538076744444*^9}, {3.560538350653234*^9, 
   3.560538355796355*^9}}],

Cell[BoxData[
 RowBox[{"derf2sx", "=", " ", 
  RowBox[{"Limit", "[", 
   RowBox[{
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{"Evaluate", "[", 
       RowBox[{"f2", "[", "x", "]"}], "]"}], ",", "x"}], "]"}], " ", ",", 
    RowBox[{"x", "\[Rule]", 
     FractionBox["16", "3"]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.484912499015625*^9, 3.484912565265625*^9}, 
   3.484914510296875*^9, 3.48491643084375*^9, {3.4849174166875*^9, 
   3.484917420078125*^9}, {3.48491749928125*^9, 3.484917501984375*^9}, {
   3.484975247296875*^9, 3.4849752493125*^9}, {3.484979400703125*^9, 
   3.484979430734375*^9}, {3.485001968375*^9, 3.48500197084375*^9}, {
   3.560538080261398*^9, 3.560538087728357*^9}, {3.560538357678804*^9, 
   3.560538360368493*^9}}],

Cell["Part V", "Text",
 CellChangeTimes->{
  3.484992245703125*^9, {3.484992316015625*^9, 3.4849923314375*^9}, {
   3.48499253890625*^9, 3.484992628625*^9}, {3.484994235171875*^9, 
   3.484994236890625*^9}, {3.48499689084375*^9, 3.48499689559375*^9}, {
   3.486039583859375*^9, 3.486039584453125*^9}, {3.559482005654936*^9, 
   3.559482006444809*^9}, {3.572683638740938*^9, 3.572683640652047*^9}, {
   3.572683694861148*^9, 3.5726836965002413`*^9}},
 FontSize->36,
 FontColor->RGBColor[0, 0, 1],
 Background->RGBColor[1, 0.9, 0.8]],

Cell[TextData[{
 "We check that the reconstruction conincides with the result given by ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "."
}], "Text",
 CellChangeTimes->{{3.4822341378707695`*^9, 3.4822341540168734`*^9}, {
  3.48499855896875*^9, 3.48499856028125*^9}, {3.559508878093765*^9, 
  3.559508878656044*^9}, {3.559508923401692*^9, 3.559508937468286*^9}, {
  3.559541764068054*^9, 3.559541767750527*^9}, {3.559542684134254*^9, 
  3.559542715594304*^9}, {3.56053836865784*^9, 3.560538389643898*^9}},
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"Chop", "[", 
    RowBox[{
     RowBox[{"cubicSpline", "[", "x", "]"}], " ", "-", " ", 
     RowBox[{"f", "[", "x", "]"}]}], "]"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"x", ",", " ", "0", ",", " ", "14"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.559509211208383*^9, 3.559509211209626*^9}, {
   3.559541778864373*^9, 3.559541780206865*^9}, 3.55954274758951*^9, 
   3.56053840146544*^9, 3.560543220218763*^9}]
},
AutoGeneratedPackage->None,
WindowSize->{1438, 813},
WindowMargins->{{92, Automatic}, {Automatic, 40}},
Magnification->1.5,
FrontEndVersion->"9.0 for Linux x86 (64-bit) (January 25, 2013)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[545, 20, 523, 12, 112, "Text"],
Cell[1071, 34, 5094, 101, 1071, "Text"],
Cell[6168, 137, 243, 5, 45, "Input"],
Cell[6414, 144, 100, 1, 45, "Input"],
Cell[6517, 147, 118, 2, 45, "Input"],
Cell[6638, 151, 265, 6, 45, "Input"],
Cell[6906, 159, 479, 9, 107, "Text"],
Cell[7388, 170, 682, 19, 75, "Text"],
Cell[8073, 191, 879, 22, 45, "Input"],
Cell[8955, 215, 209, 4, 45, "Input"],
Cell[9167, 221, 538, 10, 45, "Input"],
Cell[9708, 233, 1017, 22, 104, "Input"],
Cell[10728, 257, 482, 9, 107, "Text"],
Cell[11213, 268, 721, 14, 103, "Text"],
Cell[11937, 284, 606, 12, 63, "Text"],
Cell[12546, 298, 257, 6, 64, "Input"],
Cell[12806, 306, 379, 11, 102, "Text"],
Cell[13188, 319, 246, 4, 64, "Input"],
Cell[13437, 325, 284, 6, 102, "Text"],
Cell[13724, 333, 419, 7, 64, "Input"],
Cell[14146, 342, 279, 6, 102, "Text"],
Cell[14428, 350, 391, 7, 64, "Input"],
Cell[14822, 359, 542, 11, 144, "Text"],
Cell[15367, 372, 209, 4, 102, "Text"],
Cell[15579, 378, 1176, 28, 111, "Input"],
Cell[16758, 408, 761, 22, 64, "Input"],
Cell[17522, 432, 3268, 76, 511, "Input"],
Cell[20793, 510, 307, 5, 102, "Text"],
Cell[21103, 517, 1101, 25, 106, "Input"],
Cell[22207, 544, 1484, 42, 106, "Text"],
Cell[23694, 588, 483, 9, 159, "Text"],
Cell[24180, 599, 1181, 21, 144, "Text"],
Cell[25364, 622, 699, 14, 102, "Text"],
Cell[26066, 638, 997, 20, 64, "Input"],
Cell[27066, 660, 995, 21, 64, "Input"],
Cell[28064, 683, 994, 20, 64, "Input"],
Cell[29061, 705, 1094, 21, 64, "Input"],
Cell[30158, 728, 646, 11, 102, "Text"],
Cell[30807, 741, 1200, 23, 64, "Input"],
Cell[32010, 766, 1083, 21, 64, "Input"],
Cell[33096, 789, 1037, 20, 64, "Input"],
Cell[34136, 811, 638, 15, 64, "Input"],
Cell[34777, 828, 693, 12, 102, "Text"],
Cell[35473, 842, 874, 18, 64, "Input"],
Cell[36350, 862, 857, 18, 64, "Input"],
Cell[37210, 882, 950, 19, 64, "Input"],
Cell[38163, 903, 712, 16, 64, "Input"],
Cell[38878, 921, 511, 9, 102, "Text"],
Cell[39392, 932, 1143, 26, 64, "Input"],
Cell[40538, 960, 1050, 24, 64, "Input"],
Cell[41591, 986, 1085, 25, 64, "Input"],
Cell[42679, 1013, 919, 23, 64, "Input"],
Cell[43601, 1038, 985, 24, 64, "Input"],
Cell[44589, 1064, 803, 21, 106, "Input"],
Cell[45395, 1087, 646, 12, 102, "Text"],
Cell[46044, 1101, 312, 7, 64, "Input"],
Cell[46359, 1110, 779, 15, 64, "Input"],
Cell[47141, 1127, 691, 14, 64, "Input"],
Cell[47835, 1143, 263, 7, 64, "Input"],
Cell[48101, 1152, 695, 14, 64, "Input"],
Cell[48799, 1168, 275, 7, 64, "Input"],
Cell[49077, 1177, 737, 14, 64, "Input"],
Cell[49817, 1193, 744, 12, 102, "Text"],
Cell[50564, 1207, 1230, 27, 64, "Input"],
Cell[51797, 1236, 506, 10, 159, "Text"],
Cell[52306, 1248, 798, 17, 144, "Text"],
Cell[53107, 1267, 672, 11, 102, "Text"],
Cell[53782, 1280, 659, 12, 64, "Input"],
Cell[54444, 1294, 884, 19, 64, "Input"],
Cell[55331, 1315, 686, 11, 102, "Text"],
Cell[56020, 1328, 529, 11, 64, "Input"],
Cell[56552, 1341, 814, 18, 64, "Input"],
Cell[57369, 1361, 732, 12, 102, "Text"],
Cell[58104, 1375, 587, 12, 64, "Input"],
Cell[58694, 1389, 862, 19, 64, "Input"],
Cell[59559, 1410, 99, 2, 102, "Text"],
Cell[59661, 1414, 467, 11, 64, "Input"],
Cell[60131, 1427, 478, 12, 64, "Input"],
Cell[60612, 1441, 681, 15, 102, "Text"],
Cell[61296, 1458, 811, 16, 64, "Input"],
Cell[62110, 1476, 792, 17, 64, "Input"],
Cell[62905, 1495, 647, 12, 102, "Text"],
Cell[63555, 1509, 754, 16, 105, "Input"],
Cell[64312, 1527, 752, 16, 105, "Input"],
Cell[65067, 1545, 531, 10, 159, "Text"],
Cell[65601, 1557, 555, 12, 102, "Text"],
Cell[66159, 1571, 478, 11, 64, "Input"]
}
]
*)

(* End of internal cache information *)
