(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[    110952,       2784]
NotebookOptionsPosition[    105800,       2629]
NotebookOutlinePosition[    106217,       2647]
CellTagsIndexPosition[    106174,       2644]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["\<\
Evaluation time:
\[CapitalDelta]t < 10 s \
\>", "Text",
 CellChangeTimes->{{3.487475426671875*^9, 3.4874754603125*^9}, {
   3.487585622453125*^9, 3.48758566153125*^9}, {3.48758703784375*^9, 
   3.487587065171875*^9}, {3.572683924846302*^9, 3.5726839549570246`*^9}, {
   3.5726840232289295`*^9, 3.572684030476344*^9}, 3.5726840765409784`*^9},
 FontFamily->"Times New Roman",
 FontSize->14,
 FontColor->RGBColor[0, 0, 1],
 Background->RGBColor[1, 0.9, 0.8]],

Cell[TextData[{
 "Two dimensional B-splines of order 3 (i.e. degree 2)\n\n",
 StyleBox["Warning! \nIn Section 6.4, it is clearly stated that   order = \
degree + 1. \nIn Mathematica, the command InterpolationOrder refers to the \
degree of the interpolating polynomial,\ntherefore,  InterpolationOrder -> 2  \
considers parabolae, etc.\n",
  FontColor->RGBColor[0.5, 0, 0.5]],
 "\nIntroduction\n\nTo understand how to construct  the two-dimensional \
tensor product spline interpolant \[CurlyRho](\[CurlyTheta],\[CurlyPhi]) (See \
Eq. \\ref{erre}), we start with an equivalent but  reduced set of points, \
given by\n\n                   {",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["x", "i"], " "}], TraditionalForm]]],
 ",  ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["y", "j"], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["z", "ij"], TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["}", 
    RowBox[{
     RowBox[{"i", "=", "1"}], ",", "6", " ", ","}], 
    RowBox[{
     RowBox[{"j", "=", "1"}], ",", "7"}]], TraditionalForm]]],
 "\n\n where the  ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["x", "i"], " "}], TraditionalForm]]],
 " and the ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["y", "j"], TraditionalForm]]],
 ", that we repeat here for our convenience, \n \n                     ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["x", "i"], " "}], TraditionalForm]]],
 "= 0, 2, 4.5, 9, 11, 14\n                     ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["y", "j"], "="}], TraditionalForm]]],
 "0, 3, 4, 8, 11, 13, 18\n                     \n are equal to those \
described at pag.  232 and the  ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["z", "ij"], TraditionalForm]]],
 " are arbitrarily chosen as:\n      \n",
 StyleBox["points = {\n\t{{0, 0}, 4},  {{2, 0}, 3},   {{4.5, 0}, 2},   {{9, \
0}, 4},   {{11, 0}, 3},  {{14, 0}, 1},\n\t{{0, 3}, 2},  {{2, 3}, 4},   {{4.5, \
3}, 3},   {{9, 3}, 1},   {{11, 3}, 4},  {{14, 3}, 2},\n\t{{0, 4}, 1},  {{2, \
4}, 3},   {{4.5, 4}, 1},   {{9, 4}, 3},   {{11, 4}, 2},  {{14, 4}, 3},\n\t\
{{0, 8}, 4},  {{2, 8}, 2},   {{4.5, 8}, 2},   {{9, 8}, 3},   {{11, 8}, 1},  \
{{14, 8}, 2},\n\t{{0, 11}, 3}, {{2, 11}, 1}, {{4.5, 11}, 4}, {{9, 11}, 2}, \
{{11, 11}, 3}, {{14, 11}, 1},\n\t{{0, 13}, 4}, {{2, 13}, 1}, {{4.5, 13}, 2}, \
{{9, 13}, 1}, {{11, 13}, 2}, {{14, 13}, 4},\n\t{{0, 18}, 1}, {{2, 18}, 3}, \
{{4.5, 18}, 2}, {{9, 18}, 2}, {{11, 18}, 4}, {{14, 18}, 3}\n\t}",
  FontFamily->"Courier"]
}], "Text",
 CellChangeTimes->{{3.4822342910645547`*^9, 3.4822343209855466`*^9}, {
   3.4827529496875*^9, 3.482752986359375*^9}, {3.482753058375*^9, 
   3.48275329565625*^9}, {3.482754376203125*^9, 3.4827544480625*^9}, {
   3.482893982625*^9, 3.48289398340625*^9}, {3.483792293875*^9, 
   3.4837923073125*^9}, {3.483792338578125*^9, 3.483792374296875*^9}, {
   3.48379240884375*^9, 3.48379245921875*^9}, {3.483792497421875*^9, 
   3.483792550125*^9}, {3.48379266728125*^9, 3.483792678921875*^9}, {
   3.48620778865625*^9, 3.486207796421875*^9}, {3.486207868984375*^9, 
   3.486207902421875*^9}, {3.486207996765625*^9, 3.48620804921875*^9}, {
   3.4862081176875*^9, 3.48620820034375*^9}, {3.4862082995*^9, 
   3.486208301734375*^9}, {3.486208366046875*^9, 3.48620837096875*^9}, {
   3.486208594421875*^9, 3.486208687953125*^9}, {3.486208736390625*^9, 
   3.4862090339375*^9}, {3.4862090731875*^9, 3.486209275921875*^9}, {
   3.48626873953125*^9, 3.48626880684375*^9}, 3.486913730038809*^9, {
   3.487584293765625*^9, 3.487584310984375*^9}, {3.487590570171875*^9, 
   3.4875907155625*^9}, {3.48759085221875*^9, 3.487590909375*^9}, {
   3.487590944078125*^9, 3.48759098471875*^9}, {3.487591064390625*^9, 
   3.48759111275*^9}, {3.48759114615625*^9, 3.4875912485*^9}, {
   3.487591335609375*^9, 3.48759133678125*^9}, {3.487591391625*^9, 
   3.487591392109375*^9}, {3.487591435671875*^9, 3.487591443734375*^9}, {
   3.560570126531762*^9, 3.560570200163167*^9}, {3.560570270030739*^9, 
   3.560570310995635*^9}, {3.572684057795906*^9, 3.5726840694445724`*^9}, {
   3.577114745539118*^9, 3.577114750002373*^9}, {3.5771147902346745`*^9, 
   3.5771147924027987`*^9}, {3.5774556158392797`*^9, 3.577455616822081*^9}, 
   3.5777018639910097`*^9},
 FontSize->14,
 FontColor->RGBColor[0, 0, 1],
 Background->RGBColor[1, 1, 0.85]],

Cell[TextData[{
 " In Part I the relevant interpolating function found by means of the \
command\n\n\t",
 StyleBox["Interpolation[points, InterpolationOrder \[Rule] 2, Method \[Rule] \
\"Spline\"]",
  FontFamily->"Courier"],
 "\n\nis 3D plotted.\n\nRemark: The Order in the  InterpolationOrder  refers \
to the degree of the polynomials composing the Bsplines       "
}], "Text",
 CellChangeTimes->{{3.4822342910645547`*^9, 3.4822343209855466`*^9}, {
   3.4827529496875*^9, 3.482752986359375*^9}, {3.482753058375*^9, 
   3.48275329565625*^9}, {3.482754376203125*^9, 3.4827544480625*^9}, {
   3.482893982625*^9, 3.48289398340625*^9}, {3.483792293875*^9, 
   3.4837923073125*^9}, {3.483792338578125*^9, 3.483792374296875*^9}, {
   3.48379240884375*^9, 3.48379245921875*^9}, {3.483792497421875*^9, 
   3.483792550125*^9}, {3.48379266728125*^9, 3.483792678921875*^9}, {
   3.48620778865625*^9, 3.486207796421875*^9}, {3.486207868984375*^9, 
   3.486207902421875*^9}, {3.486207996765625*^9, 3.48620804921875*^9}, {
   3.4862081176875*^9, 3.48620820034375*^9}, {3.4862082995*^9, 
   3.486208301734375*^9}, {3.486208366046875*^9, 3.48620837096875*^9}, {
   3.486208594421875*^9, 3.486208687953125*^9}, {3.486208736390625*^9, 
   3.486208956265625*^9}, 3.48620929246875*^9, {3.486209324234375*^9, 
   3.486209458078125*^9}, {3.486209551828125*^9, 3.486209589796875*^9}, {
   3.48758434553125*^9, 3.4875844256875*^9}, {3.487587478546875*^9, 
   3.487587483234375*^9}, {3.487591275859375*^9, 3.487591311421875*^9}, {
   3.560570344927095*^9, 3.560570357430906*^9}, {3.5726841063016806`*^9, 
   3.5726841078847713`*^9}},
 FontSize->14,
 FontColor->RGBColor[0, 0, 1],
 Background->RGBColor[1, 1, 0.85]],

Cell[TextData[{
 "In Part II we extract the information contained in the ",
 StyleBox["InterpolatingFunction", "Input",
  FontWeight->"Plain"],
 " and in the ",
 StyleBox["BSplineFunction, ", "Input",
  FontWeight->"Plain"],
 "in particular the polynomial expression of the",
 StyleBox[" ", "Input"],
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["B", "i", "3"], TraditionalForm]],
  Background->RGBColor[0.87, 0.94, 1]],
 "(x)",
 StyleBox[" ", "Input",
  FontWeight->"Plain"],
 "and",
 StyleBox[" ", "Input",
  FontWeight->"Plain"],
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["B", "j", "3"], TraditionalForm]],
  Background->RGBColor[0.87, 0.94, 1]],
 "(y) on each subdomaian are given."
}], "Text",
 CellChangeTimes->{{3.4822342910645547`*^9, 3.4822343209855466`*^9}, {
   3.4827529496875*^9, 3.482752986359375*^9}, {3.482753058375*^9, 
   3.48275329565625*^9}, {3.482754376203125*^9, 3.4827544480625*^9}, {
   3.482893982625*^9, 3.48289398340625*^9}, {3.483792293875*^9, 
   3.4837923073125*^9}, {3.483792338578125*^9, 3.483792374296875*^9}, {
   3.48379240884375*^9, 3.48379245921875*^9}, {3.483792497421875*^9, 
   3.483792550125*^9}, {3.48379266728125*^9, 3.483792678921875*^9}, {
   3.48620778865625*^9, 3.486207796421875*^9}, {3.486207868984375*^9, 
   3.486207902421875*^9}, {3.486207996765625*^9, 3.48620804921875*^9}, {
   3.4862081176875*^9, 3.48620820034375*^9}, {3.4862082995*^9, 
   3.486208301734375*^9}, {3.486208366046875*^9, 3.48620837096875*^9}, {
   3.486208594421875*^9, 3.486208687953125*^9}, {3.486208736390625*^9, 
   3.486208956265625*^9}, 3.48620929246875*^9, {3.486209324234375*^9, 
   3.486209458078125*^9}, {3.48627677321875*^9, 3.48627681325*^9}, {
   3.486276863046875*^9, 3.486276898796875*^9}, {3.48627699571875*^9, 
   3.486277014953125*^9}, {3.48627705409375*^9, 3.486277138859375*^9}, {
   3.486277176375*^9, 3.486277187828125*^9}, {3.560570403033384*^9, 
   3.560570479773999*^9}, {3.560572117627421*^9, 3.56057212110249*^9}, {
   3.5726841124240313`*^9, 3.572684114494149*^9}},
 FontSize->14,
 FontColor->RGBColor[0, 0, 1],
 Background->RGBColor[1, 1, 0.85]],

Cell["\<\
 In Part III we find the explicit representation of the polynomials in the \
cell 21.\
\>", "Text",
 CellChangeTimes->{{3.4822342910645547`*^9, 3.4822343209855466`*^9}, {
   3.4827529496875*^9, 3.482752986359375*^9}, {3.482753058375*^9, 
   3.48275329565625*^9}, {3.482754376203125*^9, 3.4827544480625*^9}, {
   3.482893982625*^9, 3.48289398340625*^9}, {3.483792293875*^9, 
   3.4837923073125*^9}, {3.483792338578125*^9, 3.483792374296875*^9}, {
   3.48379240884375*^9, 3.48379245921875*^9}, {3.483792497421875*^9, 
   3.483792550125*^9}, {3.48379266728125*^9, 3.483792678921875*^9}, {
   3.48620778865625*^9, 3.486207796421875*^9}, {3.486207868984375*^9, 
   3.486207902421875*^9}, {3.486207996765625*^9, 3.48620804921875*^9}, {
   3.4862081176875*^9, 3.48620820034375*^9}, {3.4862082995*^9, 
   3.486208301734375*^9}, {3.486208366046875*^9, 3.48620837096875*^9}, {
   3.486208594421875*^9, 3.486208687953125*^9}, {3.486208736390625*^9, 
   3.486208956265625*^9}, 3.48620929246875*^9, {3.486209324234375*^9, 
   3.486209458078125*^9}, {3.486209551828125*^9, 3.48620960775*^9}, {
   3.48627720390625*^9, 3.486277256*^9}, {3.487584456109375*^9, 
   3.487584607203125*^9}, {3.487584835953125*^9, 3.4875848463125*^9}, {
   3.5726841170852976`*^9, 3.572684120028466*^9}},
 FontSize->14,
 FontColor->RGBColor[0, 0, 1],
 Background->RGBColor[1, 1, 0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"Remove", "[", "\"\<Global`*\>\"", "]"}], ";", 
  RowBox[{"$Line", "=", "0"}], ";"}]], "Input",
 CellChangeTimes->{{3.485261693640625*^9, 3.48526171334375*^9}, {
  3.4869139757313623`*^9, 3.486913981880248*^9}, {3.507638313271984*^9, 
  3.507638315008041*^9}}],

Cell[BoxData["$Version"], "Input",
 CellChangeTimes->{{3.5076383180312147`*^9, 3.5076383199176826`*^9}}],

Cell[BoxData[
 RowBox[{"Date", "[", "]"}]], "Input",
 CellChangeTimes->{{3.507638323141736*^9, 3.507638324489011*^9}, {
  3.507726020156249*^9, 3.507726034373713*^9}, {3.56057051588954*^9, 
  3.560570518648476*^9}}],

Cell["Part I", "Text",
 CellChangeTimes->{{3.4822342910645547`*^9, 3.4822343209855466`*^9}, {
   3.4827529496875*^9, 3.482752986359375*^9}, {3.482753058375*^9, 
   3.48275329565625*^9}, {3.482754376203125*^9, 3.4827544480625*^9}, {
   3.482893982625*^9, 3.48289398340625*^9}, {3.483792293875*^9, 
   3.4837923073125*^9}, {3.483792338578125*^9, 3.483792374296875*^9}, {
   3.48379240884375*^9, 3.48379245921875*^9}, {3.483792497421875*^9, 
   3.483792550125*^9}, {3.48379266728125*^9, 3.483792678921875*^9}, {
   3.48620778865625*^9, 3.486207796421875*^9}, {3.486207868984375*^9, 
   3.486207902421875*^9}, {3.486207996765625*^9, 3.48620804921875*^9}, {
   3.4862081176875*^9, 3.48620820034375*^9}, {3.4862082995*^9, 
   3.486208301734375*^9}, {3.486208366046875*^9, 3.48620837096875*^9}, {
   3.486208594421875*^9, 3.486208687953125*^9}, {3.486208736390625*^9, 
   3.486208956265625*^9}, 3.48620929246875*^9, {3.486209324234375*^9, 
   3.486209458078125*^9}, {3.486209551828125*^9, 3.486209589796875*^9}, {
   3.486209642390625*^9, 3.48620964525*^9}, {3.486209969140625*^9, 
   3.486209987515625*^9}, {3.560570537690327*^9, 3.560570548273905*^9}, {
   3.5726841475730414`*^9, 3.5726841491561317`*^9}},
 FontFamily->"Times New Roman",
 FontSize->36,
 FontColor->RGBColor[0, 0, 1],
 Background->RGBColor[1, 0.9, 0.8]],

Cell[CellGroupData[{

Cell["Nodes to interpolate", "Text",
 CellChangeTimes->{{3.4822342910645547`*^9, 3.4822343209855466`*^9}, {
   3.4827529496875*^9, 3.482752986359375*^9}, {3.482753058375*^9, 
   3.48275329565625*^9}, {3.482754376203125*^9, 3.4827544480625*^9}, {
   3.482893982625*^9, 3.48289398340625*^9}, {3.483792293875*^9, 
   3.4837923073125*^9}, {3.483792338578125*^9, 3.483792374296875*^9}, {
   3.48379240884375*^9, 3.48379245921875*^9}, {3.483792497421875*^9, 
   3.483792550125*^9}, {3.48379266728125*^9, 3.483792678921875*^9}, {
   3.48620778865625*^9, 3.486207796421875*^9}, {3.486207868984375*^9, 
   3.486207902421875*^9}, {3.486207996765625*^9, 3.48620804921875*^9}, {
   3.4862081176875*^9, 3.48620820034375*^9}, {3.4862082995*^9, 
   3.486208301734375*^9}, {3.486208366046875*^9, 3.48620837096875*^9}, {
   3.486208594421875*^9, 3.486208687953125*^9}, {3.486208736390625*^9, 
   3.486208956265625*^9}, 3.48620929246875*^9, {3.486209324234375*^9, 
   3.486209458078125*^9}, {3.486209551828125*^9, 3.486209589796875*^9}, {
   3.486209642390625*^9, 3.48620964525*^9}, {3.486209969140625*^9, 
   3.486209987515625*^9}, {3.560570537690327*^9, 3.560570548273905*^9}},
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"points", "=", 
   RowBox[{"{", "\[IndentingNewLine]", "              ", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "0"}], "}"}], ",", "4"}], "}"}], ",", "  ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"2", ",", "0"}], "}"}], ",", "3"}], "}"}], ",", "   ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"4.5", ",", "0"}], "}"}], ",", "2"}], "}"}], ",", "   ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"9", ",", "0"}], "}"}], ",", "4"}], "}"}], ",", "   ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"11", ",", "0"}], "}"}], ",", "3"}], "}"}], ",", "  ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"14", ",", "0"}], "}"}], ",", "1"}], "}"}], ",", 
     "\[IndentingNewLine]", "              ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "3"}], "}"}], ",", "2"}], "}"}], ",", "  ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"2", ",", "3"}], "}"}], ",", "4"}], "}"}], ",", "   ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"4.5", ",", "3"}], "}"}], ",", "3"}], "}"}], ",", "   ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"9", ",", "3"}], "}"}], ",", "1"}], "}"}], ",", "   ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"11", ",", "3"}], "}"}], ",", "4"}], "}"}], ",", "  ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"14", ",", "3"}], "}"}], ",", "2"}], "}"}], ",", 
     "\[IndentingNewLine]", "              ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "4"}], "}"}], ",", "1"}], "}"}], ",", "  ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"2", ",", "4"}], "}"}], ",", "3"}], "}"}], ",", "   ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"4.5", ",", "4"}], "}"}], ",", "1"}], "}"}], ",", "   ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"9", ",", "4"}], "}"}], ",", "3"}], "}"}], ",", "   ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"11", ",", "4"}], "}"}], ",", "2"}], "}"}], ",", "  ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"14", ",", "4"}], "}"}], ",", "3"}], "}"}], ",", 
     "\[IndentingNewLine]", "              ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "8"}], "}"}], ",", "4"}], "}"}], ",", "  ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"2", ",", "8"}], "}"}], ",", "2"}], "}"}], ",", "   ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"4.5", ",", "8"}], "}"}], ",", "2"}], "}"}], ",", "   ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"9", ",", "8"}], "}"}], ",", "3"}], "}"}], ",", "   ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"11", ",", "8"}], "}"}], ",", "1"}], "}"}], ",", "  ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"14", ",", "8"}], "}"}], ",", "2"}], "}"}], ",", 
     "\[IndentingNewLine]", "              ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "11"}], "}"}], ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"2", ",", "11"}], "}"}], ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"4.5", ",", "11"}], "}"}], ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"9", ",", "11"}], "}"}], ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"11", ",", "11"}], "}"}], ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"14", ",", "11"}], "}"}], ",", "1"}], "}"}], ",", 
     "\[IndentingNewLine]", "              ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "13"}], "}"}], ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"2", ",", "13"}], "}"}], ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"4.5", ",", "13"}], "}"}], ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"9", ",", "13"}], "}"}], ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"11", ",", "13"}], "}"}], ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"14", ",", "13"}], "}"}], ",", "4"}], "}"}], ",", 
     "\[IndentingNewLine]", "              ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "18"}], "}"}], ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"2", ",", "18"}], "}"}], ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"4.5", ",", "18"}], "}"}], ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"9", ",", "18"}], "}"}], ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"11", ",", "18"}], "}"}], ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"14", ",", "18"}], "}"}], ",", "3"}], "}"}]}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.482465335703125*^9, 3.48246537171875*^9}, {
   3.482562224859375*^9, 3.482562705859375*^9}, {3.482563028953125*^9, 
   3.4825630511875*^9}, 3.48256308603125*^9, {3.48274999340625*^9, 
   3.4827499940625*^9}, {3.48275002615625*^9, 3.482750030578125*^9}, {
   3.482750075609375*^9, 3.48275015675*^9}, 3.48275022253125*^9, {
   3.483779765265625*^9, 3.483779949046875*^9}, {3.483781691734375*^9, 
   3.483781761984375*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"xmax", "=", " ", "14"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"ymax", "=", " ", "18"}], ";"}]}], "Input",
 CellChangeTimes->{{3.482753619328125*^9, 3.4827536233125*^9}, {
  3.486914746119903*^9, 3.486914751873159*^9}, {3.560570617824438*^9, 
  3.560570650003682*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"numpointx", "=", " ", "6"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"numpointy", "=", " ", "7"}], ";"}]}], "Input",
 CellChangeTimes->{{3.48275356478125*^9, 3.48275357521875*^9}, {
  3.5605706529477*^9, 3.56057066429456*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"numpointx", "*", "numpointy"}], "==", 
  RowBox[{"Length", "[", "points", "]"}]}]], "Input",
 CellChangeTimes->{{3.486914786251492*^9, 3.486914806176976*^9}}],

Cell["We construct the interpolating spline", "Text",
 CellChangeTimes->{{3.560570696287025*^9, 3.56057070214356*^9}},
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{"biparab", "=", 
  RowBox[{"Interpolation", "[", 
   RowBox[{"points", ",", 
    RowBox[{"InterpolationOrder", "\[Rule]", "2"}], ",", 
    RowBox[{"Method", "\[Rule]", "\"\<Spline\>\""}]}], "]"}]}]], "Input",
 CellChangeTimes->{
  3.482232981299215*^9, 3.482563196046875*^9, {3.486209513125*^9, 
   3.486209539484375*^9}, 3.4875854441875*^9, 3.487585482890625*^9}],

Cell["and plot the result", "Text",
 CellChangeTimes->{{3.560570704522552*^9, 3.560570707947321*^9}},
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{"gra3D", "=", 
  RowBox[{"Plot3D", "[", 
   RowBox[{
    RowBox[{"biparab", "[", 
     RowBox[{"x", ",", "y"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", "xmax"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"y", ",", "0", ",", "ymax"}], "}"}], ",", 
    RowBox[{"PlotPoints", "\[Rule]", "50"}]}], "]"}]}]], "Input",
 CellChangeTimes->{
  3.482232990035215*^9, {3.4826681219375*^9, 3.482668132734375*^9}, {
   3.48275020646875*^9, 3.482750206875*^9}, {3.482753649875*^9, 
   3.482753654828125*^9}, {3.48284233740625*^9, 3.4828423414375*^9}, 
   3.48758544496875*^9, 3.487585484046875*^9, {3.560570763746541*^9, 
   3.560570768472777*^9}}],

Cell["\<\
To see the distribution of the points on the interpolating function\
\>", "Text",
 CellChangeTimes->{{3.4822342910645547`*^9, 3.4822343209855466`*^9}, {
   3.48275347525*^9, 3.482753495546875*^9}, {3.48275367496875*^9, 
   3.482753697546875*^9}, {3.4828425655625*^9, 3.482842621578125*^9}, 
   3.486209781140625*^9, {3.486209813375*^9, 3.486209846828125*^9}},
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"pointsonsurface", "=", 
   RowBox[{"Partition", "[", 
    RowBox[{
     RowBox[{"Flatten", "[", "points", "]"}], ",", "3"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.48620747896875*^9, 3.48620748509375*^9}, {
   3.4862075360625*^9, 3.48620753715625*^9}, {3.486209722140625*^9, 
   3.486209747890625*^9}, {3.486209798609375*^9, 3.4862097993125*^9}, 
   3.560570732613148*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"ptred", " ", "=", " ", 
   RowBox[{"Graphics3D", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"PointSize", "[", "Medium", "]"}], ",", "Red", ",", 
      RowBox[{"Map", "[", 
       RowBox[{"Point", ",", "pointsonsurface"}], "]"}]}], "}"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.4789514035*^9, 3.478951410765625*^9}, {
   3.47895217884375*^9, 3.478952179640625*^9}, {3.482842314453125*^9, 
   3.482842317390625*^9}, {3.48284246646875*^9, 3.482842534890625*^9}, {
   3.483790840125*^9, 3.4837908405625*^9}, {3.486207542125*^9, 
   3.4862075441875*^9}, {3.4862076874375*^9, 3.486207702203125*^9}, 
   3.486209762578125*^9, {3.48620980215625*^9, 3.48620980278125*^9}, {
   3.560570737513406*^9, 3.560570749979792*^9}}],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"gra3D", ",", "ptred"}], "]"}]], "Input",
 CellChangeTimes->{{3.48284232540625*^9, 3.482842350421875*^9}}]
}, Open  ]],

Cell["Part II", "Text",
 CellChangeTimes->{{3.4822342910645547`*^9, 3.4822343209855466`*^9}, {
   3.4827529496875*^9, 3.482752986359375*^9}, {3.482753058375*^9, 
   3.48275329565625*^9}, {3.482754376203125*^9, 3.4827544480625*^9}, {
   3.482893982625*^9, 3.48289398340625*^9}, {3.483792293875*^9, 
   3.4837923073125*^9}, {3.483792338578125*^9, 3.483792374296875*^9}, {
   3.48379240884375*^9, 3.48379245921875*^9}, {3.483792497421875*^9, 
   3.483792550125*^9}, {3.48379266728125*^9, 3.483792678921875*^9}, {
   3.48620778865625*^9, 3.486207796421875*^9}, {3.486207868984375*^9, 
   3.486207902421875*^9}, {3.486207996765625*^9, 3.48620804921875*^9}, {
   3.4862081176875*^9, 3.48620820034375*^9}, {3.4862082995*^9, 
   3.486208301734375*^9}, {3.486208366046875*^9, 3.48620837096875*^9}, {
   3.486208594421875*^9, 3.486208687953125*^9}, {3.486208736390625*^9, 
   3.486208956265625*^9}, 3.48620929246875*^9, {3.486209324234375*^9, 
   3.486209458078125*^9}, {3.486209551828125*^9, 3.486209589796875*^9}, {
   3.486209642390625*^9, 3.48620964525*^9}, {3.486209969140625*^9, 
   3.486209987515625*^9}, {3.560570537690327*^9, 3.560570548273905*^9}, {
   3.5726841475730414`*^9, 3.5726841713564014`*^9}},
 FontFamily->"Times New Roman",
 FontSize->36,
 FontColor->RGBColor[0, 0, 1],
 Background->RGBColor[1, 0.9, 0.8]],

Cell[CellGroupData[{

Cell[TextData[{
 "Extraction of the information contained in the   ",
 StyleBox["InterpolatingFunction", "Input",
  FontWeight->"Plain"],
 ".The",
 StyleBox[" ", "Input"],
 StyleBox["BSplineFunction", "Input",
  FontWeight->"Plain"],
 " is stored in 4th place and contains:\n\n\tthe knots sequence\n\tthe \
control points (i.e., the coefficients which multiply the basis Bsplines)"
}], "Text",
 CellChangeTimes->{{3.4822342910645547`*^9, 3.4822343209855466`*^9}, {
   3.4827529496875*^9, 3.482752986359375*^9}, {3.482753058375*^9, 
   3.48275329565625*^9}, {3.482754376203125*^9, 3.4827544480625*^9}, {
   3.482893982625*^9, 3.48289398340625*^9}, {3.483792293875*^9, 
   3.4837923073125*^9}, {3.483792338578125*^9, 3.483792374296875*^9}, {
   3.48379240884375*^9, 3.48379245921875*^9}, {3.483792497421875*^9, 
   3.483792550125*^9}, {3.48379266728125*^9, 3.483792678921875*^9}, {
   3.48620778865625*^9, 3.486207796421875*^9}, {3.486207868984375*^9, 
   3.486207902421875*^9}, {3.486207996765625*^9, 3.48620804921875*^9}, {
   3.4862081176875*^9, 3.48620820034375*^9}, {3.4862082995*^9, 
   3.486208301734375*^9}, {3.486208366046875*^9, 3.48620837096875*^9}, {
   3.486208594421875*^9, 3.486208687953125*^9}, {3.486208736390625*^9, 
   3.486208956265625*^9}, 3.48620929246875*^9, {3.486209324234375*^9, 
   3.486209458078125*^9}, {3.486209551828125*^9, 3.486209589796875*^9}, {
   3.486209642390625*^9, 3.48620964525*^9}, 3.48621000946875*^9, {
   3.48621004990625*^9, 3.48621006371875*^9}, {3.486210107109375*^9, 
   3.486210116125*^9}, {3.48621022678125*^9, 3.486210379828125*^9}, {
   3.486268942453125*^9, 3.48626895521875*^9}, {3.560570791314747*^9, 
   3.560570838839578*^9}, {3.560570911985525*^9, 3.560570912393567*^9}},
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[TextData[{
 "Within ",
 StyleBox["InterpolatingFunction", "Input",
  FontWeight->"Plain"],
 ", the ",
 StyleBox["BSplineFunction", "Input",
  FontWeight->"Plain"],
 " is stored in 4th place."
}], "Text",
 CellChangeTimes->{{3.4822332770104485`*^9, 3.482233293561942*^9}, 
   3.482233328132321*^9},
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{"bspfun", "=", 
  RowBox[{"biparab", "[", 
   RowBox[{"[", 
    RowBox[{"4", ",", "1"}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4822332962139254`*^9, 3.482233307867051*^9}, 
   3.4875854465*^9, 3.4875854850625*^9}],

Cell[CellGroupData[{

Cell["Knots (each direction)", "Text",
 CellChangeTimes->{{3.4822343342300315`*^9, 3.4822343385356593`*^9}},
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"knotsx", ",", "knotsy"}], "}"}], "=", 
  RowBox[{"bspfun", "[", "\"\<Knots\>\"", "]"}]}]], "Input",
 CellChangeTimes->{{3.4822333526865635`*^9, 3.4822333562589407`*^9}, {
   3.4822337669515705`*^9, 3.482233768386853*^9}, {3.4822338392615557`*^9, 
   3.482233842178793*^9}, 3.487588374234375*^9, 3.487588410515625*^9}]
}, Open  ]],

Cell["We save the degree along each direction, for later use", "Text",
 CellChangeTimes->{{3.56057093756043*^9, 3.560570948605602*^9}},
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"degx", " ", "=", " ", "2"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"degy", "=", " ", "2"}], ";"}]}], "Input",
 CellChangeTimes->{{3.482233357163735*^9, 3.4822333657904797`*^9}, {
  3.482233770648984*^9, 3.4822337722246747`*^9}, {3.4822338341446466`*^9, 
  3.482233836235117*^9}, {3.48758830503125*^9, 3.48758833334375*^9}, {
  3.5076401213449097`*^9, 3.507640153569191*^9}, {3.560570916963021*^9, 
  3.560570928534137*^9}}],

Cell[CellGroupData[{

Cell[TextData[{
 "The basis splines along the x-direction.\nIn ",
 StyleBox["Mathematica,",
  FontSlant->"Italic"],
 "  the B-spline basis functions index ranges from 0 to numpointx - 1 (0 to \
5, in the present case).\nIn the text (Eq. \\ref{erre}) indexes are from 1 to \
numpointx. "
}], "Text",
 CellChangeTimes->{{3.482234042054359*^9, 3.482234050026061*^9}, {
  3.486210778890625*^9, 3.4862107795*^9}, {3.48627276459375*^9, 
  3.486272797140625*^9}, {3.486272834546875*^9, 3.4862728490625*^9}, {
  3.48627289346875*^9, 3.486272979265625*^9}, {3.560571004934988*^9, 
  3.560571075329417*^9}},
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{"graBx", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"BSplineBasis", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"degx", ",", "knotsx"}], "}"}], ",", "k", ",", "x"}], "]"}],
        ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "0", ",", 
         RowBox[{"numpointx", "-", "1"}]}], "}"}]}], "]"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", "xmax"}], "}"}], ",", 
    RowBox[{"Epilog", "\[Rule]", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Text", "[", 
        RowBox[{
         RowBox[{"Style", "[", "\"\<\[FivePointedStar]\>\"", "]"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"knotsx", "[", 
            RowBox[{"[", "1", "]"}], "]"}], ",", "0"}], "}"}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Text", "[", 
        RowBox[{
         RowBox[{"Style", "[", "\"\<\[FivePointedStar]\>\"", "]"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"knotsx", "[", 
            RowBox[{"[", "4", "]"}], "]"}], ",", "0"}], "}"}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Text", "[", 
        RowBox[{
         RowBox[{"Style", "[", "\"\<\[FivePointedStar]\>\"", "]"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"knotsx", "[", 
            RowBox[{"[", "5", "]"}], "]"}], ",", "0"}], "}"}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Text", "[", 
        RowBox[{
         RowBox[{"Style", "[", "\"\<\[FivePointedStar]\>\"", "]"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"knotsx", "[", 
            RowBox[{"[", "6", "]"}], "]"}], ",", "0"}], "}"}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Text", "[", 
        RowBox[{
         RowBox[{"Style", "[", "\"\<\[FivePointedStar]\>\"", "]"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"knotsx", "[", 
            RowBox[{"[", "7", "]"}], "]"}], ",", "0"}], "}"}]}], "]"}]}], 
      "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4822338086527767`*^9, 3.4822338219915457`*^9}, {
   3.482233861491841*^9, 3.4822339121320906`*^9}, {3.48256328578125*^9, 
   3.48256328990625*^9}, {3.48256332328125*^9, 3.482563376203125*^9}, {
   3.48275372340625*^9, 3.482753762765625*^9}, {3.486212356078125*^9, 
   3.486212361078125*^9}, {3.48628731065625*^9, 3.48628731121875*^9}, {
   3.48628752696875*^9, 3.486287565734375*^9}, {3.486287694453125*^9, 
   3.486287720109375*^9}, {3.48628775528125*^9, 3.486287859328125*^9}, 
   3.4875701741875*^9, 3.48758830603125*^9, {3.48758837509375*^9, 
   3.487588377390625*^9}, {3.560571106002075*^9, 3.560571129621839*^9}}]
}, Open  ]],

Cell[TextData[{
 "From the previous Graph we observe that, on each subdomain formed by the \
knots along the x-axis, only three Bsplines contribute.\nIt is instructive to \
use PiesewiseExpand to see the contributions of the Bsplines on each \
subdomain and observe that each Bspline is formed by certain segments the \
number of which depends on the supporting collapsed knots; for example,\n\n",
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["B", "1", "3"], TraditionalForm]]],
 "(x) is represented by only one segment as his support, in the interval \
[0,3.25] and contains a knot of multiplicity three; \n\n",
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["B", "2", "3"], TraditionalForm]]],
 "(x) is represented by two segments as his support, in the interval [0,6.75] \
and contains a knot of multiplicity two."
}], "Text",
 CellChangeTimes->{{3.48274951725*^9, 3.482749720109375*^9}, 
   3.483790968953125*^9, 3.48621228325*^9, {3.48621238409375*^9, 
   3.4862124078125*^9}, {3.48621244775*^9, 3.48621250175*^9}, {
   3.48621256440625*^9, 3.486212564578125*^9}, {3.4862125958125*^9, 
   3.486212772578125*^9}, {3.486212867046875*^9, 3.486212872671875*^9}, {
   3.486213008125*^9, 3.486213030125*^9}, {3.486213427515625*^9, 
   3.486213428109375*^9}, {3.48626900078125*^9, 3.4862690699375*^9}, {
   3.487573002609375*^9, 3.4875730191875*^9}, {3.4875730541875*^9, 
   3.487573360515625*^9}, {3.4875734386875*^9, 3.48757352740625*^9}, {
   3.487573608859375*^9, 3.48757385978125*^9}, {3.48758242346875*^9, 
   3.4875824265625*^9}, {3.560571151330203*^9, 3.560571219787533*^9}, {
   3.560572145754687*^9, 3.56057214866254*^9}},
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell["First, we see the structure of the Bsplines along the x-axis", "Text",
 CellChangeTimes->{{3.48274951725*^9, 3.482749720109375*^9}, 
   3.483790968953125*^9, 3.48621228325*^9, {3.48621238409375*^9, 
   3.4862124078125*^9}, {3.48621244775*^9, 3.48621250175*^9}, {
   3.48621256440625*^9, 3.486212564578125*^9}, {3.4862125958125*^9, 
   3.486212772578125*^9}, {3.486212867046875*^9, 3.486212872671875*^9}, {
   3.486213008125*^9, 3.486213030125*^9}, {3.486213427515625*^9, 
   3.486213428109375*^9}, {3.48626900078125*^9, 3.4862690699375*^9}, {
   3.486269330921875*^9, 3.486269364421875*^9}, 3.4875830434375*^9},
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{"segmentsX", "=", 
  RowBox[{"Column", "[", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"PiecewiseExpand", "[", 
      RowBox[{
       RowBox[{"BSplineBasis", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"degx", ",", "knotsx"}], "}"}], ",", "k", ",", "x"}], "]"}],
        ",", "\[IndentingNewLine]", 
       RowBox[{"Method", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<OrderlessConditions\>\"", "\[Rule]", "False"}], 
         "}"}]}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"k", ",", "0", ",", 
       RowBox[{"numpointx", "-", "1"}]}], "}"}]}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.482234083410489*^9, 3.482234133487131*^9}, {
   3.48266667146875*^9, 3.4826666721875*^9}, {3.482666727734375*^9, 
   3.482666730234375*^9}, {3.482753858546875*^9, 3.48275386278125*^9}, {
   3.486213448078125*^9, 3.486213452796875*^9}, {3.487571772359375*^9, 
   3.487571773578125*^9}, 3.487588307140625*^9, 3.48758837815625*^9}],

Cell[CellGroupData[{

Cell["\<\
We  extract the  polynomial pieces which compose  the Bsplines on the four \
intervals formed by the knots\
\>", "Text",
 CellChangeTimes->{{3.48274951725*^9, 3.482749720109375*^9}, 
   3.483790968953125*^9, {3.483791054625*^9, 3.483791081859375*^9}, {
   3.483869920046875*^9, 3.4838699436875*^9}, {3.483870111015625*^9, 
   3.4838701360625*^9}, {3.48387209359375*^9, 3.48387212775*^9}, {
   3.486213691265625*^9, 3.486214000984375*^9}, {3.48621452259375*^9, 
   3.486214567890625*^9}, {3.486214889078125*^9, 3.48621489025*^9}, 
   3.4862691073125*^9, {3.486273022546875*^9, 3.48627307203125*^9}, {
   3.486273112546875*^9, 3.486273127*^9}, {3.487583539359375*^9, 
   3.48758358525*^9}, {3.487583632375*^9, 3.4875836600625*^9}, {
   3.560571247794653*^9, 3.560571248213739*^9}, {3.560571288531059*^9, 
   3.560571292027026*^9}},
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{"segmentsX1", "=", 
  RowBox[{"Column", "[", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"PiecewiseExpand", "[", 
      RowBox[{
       RowBox[{"BSplineBasis", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"degx", ",", "knotsx"}], "}"}], ",", "k", ",", "x"}], "]"}],
        ",", 
       RowBox[{
        RowBox[{"knotsx", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "<", "x", "<", 
        RowBox[{"knotsx", "[", 
         RowBox[{"[", "4", "]"}], "]"}]}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"k", ",", "0", ",", 
       RowBox[{"numpointx", "-", "1"}]}], "}"}]}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.482234083410489*^9, 3.482234133487131*^9}, {
   3.48266667146875*^9, 3.4826666721875*^9}, {3.482666727734375*^9, 
   3.482666730234375*^9}, {3.482753858546875*^9, 3.48275386278125*^9}, {
   3.486213448078125*^9, 3.486213452796875*^9}, {3.486917263980238*^9, 
   3.486917270391406*^9}, {3.4869173278181543`*^9, 3.486917387090811*^9}, {
   3.486917512392194*^9, 3.486917539156995*^9}, {3.487574028234375*^9, 
   3.487574063625*^9}, 3.48758249775*^9, {3.4875825525625*^9, 
   3.487582552796875*^9}, 3.487588308171875*^9, {3.48758837890625*^9, 
   3.487588379796875*^9}},
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{"segmentsX2", "=", 
  RowBox[{"Column", "[", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"PiecewiseExpand", "[", 
      RowBox[{
       RowBox[{"BSplineBasis", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"degx", ",", "knotsx"}], "}"}], ",", "k", ",", "x"}], "]"}],
        ",", 
       RowBox[{
        RowBox[{"knotsx", "[", 
         RowBox[{"[", "4", "]"}], "]"}], "<", "x", "<", 
        RowBox[{"knotsx", "[", 
         RowBox[{"[", "5", "]"}], "]"}]}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"k", ",", "0", ",", 
       RowBox[{"numpointx", "-", "1"}]}], "}"}]}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.482234083410489*^9, 3.482234133487131*^9}, {
   3.48266667146875*^9, 3.4826666721875*^9}, {3.482666727734375*^9, 
   3.482666730234375*^9}, {3.482753858546875*^9, 3.48275386278125*^9}, {
   3.486213448078125*^9, 3.486213452796875*^9}, {3.486917263980238*^9, 
   3.486917270391406*^9}, {3.4869173278181543`*^9, 3.486917387090811*^9}, {
   3.486917512392194*^9, 3.486917539156995*^9}, {3.4869175993818913`*^9, 
   3.486917609010621*^9}, {3.487574076578125*^9, 3.487574092765625*^9}, 
   3.4875825011875*^9, {3.487582554859375*^9, 3.487582555046875*^9}, 
   3.48758830871875*^9, {3.487588380296875*^9, 3.487588381109375*^9}},
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{"segmentsX3", "=", 
  RowBox[{"Column", "[", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"PiecewiseExpand", "[", 
      RowBox[{
       RowBox[{"BSplineBasis", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"degx", ",", "knotsx"}], "}"}], ",", "k", ",", "x"}], "]"}],
        ",", 
       RowBox[{
        RowBox[{"knotsx", "[", 
         RowBox[{"[", "5", "]"}], "]"}], "<", "x", "<", 
        RowBox[{"knotsx", "[", 
         RowBox[{"[", "6", "]"}], "]"}]}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"k", ",", "0", ",", 
       RowBox[{"numpointx", "-", "1"}]}], "}"}]}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.482234083410489*^9, 3.482234133487131*^9}, {
   3.48266667146875*^9, 3.4826666721875*^9}, {3.482666727734375*^9, 
   3.482666730234375*^9}, {3.482753858546875*^9, 3.48275386278125*^9}, {
   3.486213448078125*^9, 3.486213452796875*^9}, {3.486917263980238*^9, 
   3.486917270391406*^9}, {3.4869173278181543`*^9, 3.486917387090811*^9}, {
   3.486917512392194*^9, 3.486917539156995*^9}, {3.4869175993818913`*^9, 
   3.486917641636529*^9}, {3.487582558984375*^9, 3.487582559171875*^9}, 
   3.48758830925*^9, {3.4875883815625*^9, 3.48758838240625*^9}},
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{"segmentsX4", "=", 
  RowBox[{"Column", "[", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"PiecewiseExpand", "[", 
      RowBox[{
       RowBox[{"BSplineBasis", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"degx", ",", "knotsx"}], "}"}], ",", "k", ",", "x"}], "]"}],
        ",", 
       RowBox[{
        RowBox[{"knotsx", "[", 
         RowBox[{"[", "6", "]"}], "]"}], "<", "x", "<", 
        RowBox[{"knotsx", "[", 
         RowBox[{"[", "9", "]"}], "]"}]}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"k", ",", "0", ",", 
       RowBox[{"numpointx", "-", "1"}]}], "}"}]}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.482234083410489*^9, 3.482234133487131*^9}, {
   3.48266667146875*^9, 3.4826666721875*^9}, {3.482666727734375*^9, 
   3.482666730234375*^9}, {3.482753858546875*^9, 3.48275386278125*^9}, {
   3.486213448078125*^9, 3.486213452796875*^9}, {3.486917263980238*^9, 
   3.486917270391406*^9}, {3.4869173278181543`*^9, 3.486917387090811*^9}, {
   3.486917512392194*^9, 3.486917539156995*^9}, {3.4869175993818913`*^9, 
   3.486917665074141*^9}, {3.486917706025968*^9, 3.486917706372406*^9}, {
   3.487582561109375*^9, 3.487582561265625*^9}, 3.48758830975*^9, {
   3.48758838284375*^9, 3.48758838365625*^9}},
 FontSize->14,
 Background->GrayLevel[0.85]]
}, Open  ]],

Cell[TextData[{
 "Here we plot the segments of the three Bsplines ",
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["B", "2", "3"], TraditionalForm]]],
 "(x),  ",
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["B", "3", "3"], TraditionalForm]]],
 "(x) and  ",
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["B", "4", "3"], TraditionalForm]]],
 "(x) which contribute in the interval [3.25, 6.75]."
}], "Text",
 CellChangeTimes->{{3.486918852330162*^9, 3.4869188669401493`*^9}, {
  3.487582891421875*^9, 3.487582988609375*^9}, {3.487583473671875*^9, 
  3.487583496375*^9}, {3.487583728234375*^9, 3.4875837371875*^9}, {
  3.560571311760378*^9, 3.560571327369373*^9}, {3.560572158958958*^9, 
  3.560572165245584*^9}},
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{"graBxknots45", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"BSplineBasis", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"degx", ",", "knotsx"}], "}"}], ",", "k", ",", "x"}], "]"}],
        ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "0", ",", 
         RowBox[{"numpointx", "-", "1"}]}], "}"}]}], "]"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", 
      RowBox[{"knotsx", "[", 
       RowBox[{"[", "4", "]"}], "]"}], ",", 
      RowBox[{"knotsx", "[", 
       RowBox[{"[", "5", "]"}], "]"}]}], "}"}], ",", " ", 
    RowBox[{"AxesOrigin", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"knotsx", "[", 
        RowBox[{"[", "4", "]"}], "]"}], ",", "0"}], "}"}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"Epilog", "\[Rule]", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Text", "[", 
        RowBox[{
         RowBox[{"Style", "[", "\"\<\[FivePointedStar]\>\"", "]"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"knotsx", "[", 
            RowBox[{"[", "4", "]"}], "]"}], ",", "0"}], "}"}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Text", "[", 
        RowBox[{
         RowBox[{"Style", "[", "\"\<\[FivePointedStar]\>\"", "]"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"knotsx", "[", 
            RowBox[{"[", "5", "]"}], "]"}], ",", "0"}], "}"}]}], "]"}]}], 
      "\[IndentingNewLine]", "}"}]}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.4822338086527767`*^9, 3.4822338219915457`*^9}, {
   3.482233861491841*^9, 3.4822339121320906`*^9}, {3.48256328578125*^9, 
   3.48256328990625*^9}, {3.48256332328125*^9, 3.482563376203125*^9}, {
   3.48275372340625*^9, 3.482753762765625*^9}, {3.486212356078125*^9, 
   3.486212361078125*^9}, {3.48628731065625*^9, 3.48628731121875*^9}, {
   3.48628752696875*^9, 3.486287565734375*^9}, {3.486287694453125*^9, 
   3.486287720109375*^9}, {3.48628775528125*^9, 3.486287859328125*^9}, {
   3.486918664833789*^9, 3.486918684542954*^9}, 3.487570232046875*^9, {
   3.4875722273125*^9, 3.4875722915*^9}, {3.4875828591875*^9, 
   3.487582865578125*^9}, {3.487583276609375*^9, 3.48758330140625*^9}, 
   3.4875883104375*^9, {3.487588384109375*^9, 3.487588386421875*^9}, {
   3.560571339878523*^9, 3.560571342001811*^9}},
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell["\<\
Second, we extract the structure of the Bsplines along the x-axis and proceed \
analogously as in the case for the x-axis.\
\>", "Text",
 CellChangeTimes->{{3.48274951725*^9, 3.482749720109375*^9}, 
   3.483790968953125*^9, 3.48621228325*^9, {3.48621238409375*^9, 
   3.4862124078125*^9}, {3.48621244775*^9, 3.48621250175*^9}, {
   3.48621256440625*^9, 3.486212564578125*^9}, {3.4862125958125*^9, 
   3.486212772578125*^9}, {3.486212867046875*^9, 3.486212872671875*^9}, {
   3.486213008125*^9, 3.486213030125*^9}, {3.486213427515625*^9, 
   3.486213428109375*^9}, {3.48626900078125*^9, 3.4862690699375*^9}, {
   3.486269330921875*^9, 3.486269364421875*^9}, {3.4875830434375*^9, 
   3.487583065140625*^9}, {3.4875838031875*^9, 3.487583845390625*^9}, {
   3.56057138250553*^9, 3.56057139719316*^9}},
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{"graBy", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"BSplineBasis", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"degy", ",", "knotsy"}], "}"}], ",", "l", ",", "y"}], "]"}],
        ",", 
       RowBox[{"{", 
        RowBox[{"l", ",", "0", ",", 
         RowBox[{"numpointy", "-", "1"}]}], "}"}]}], "]"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"y", ",", "0", ",", "ymax"}], "}"}], ",", 
    RowBox[{"Epilog", "\[Rule]", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Text", "[", 
        RowBox[{
         RowBox[{"Style", "[", "\"\<\[FivePointedStar]\>\"", "]"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"knotsy", "[", 
            RowBox[{"[", "1", "]"}], "]"}], ",", "0"}], "}"}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Text", "[", 
        RowBox[{
         RowBox[{"Style", "[", "\"\<\[FivePointedStar]\>\"", "]"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"knotsy", "[", 
            RowBox[{"[", "4", "]"}], "]"}], ",", "0"}], "}"}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Text", "[", 
        RowBox[{
         RowBox[{"Style", "[", "\"\<\[FivePointedStar]\>\"", "]"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"knotsy", "[", 
            RowBox[{"[", "5", "]"}], "]"}], ",", "0"}], "}"}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Text", "[", 
        RowBox[{
         RowBox[{"Style", "[", "\"\<\[FivePointedStar]\>\"", "]"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"knotsy", "[", 
            RowBox[{"[", "6", "]"}], "]"}], ",", "0"}], "}"}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Text", "[", 
        RowBox[{
         RowBox[{"Style", "[", "\"\<\[FivePointedStar]\>\"", "]"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"knotsy", "[", 
            RowBox[{"[", "7", "]"}], "]"}], ",", "0"}], "}"}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Text", "[", 
        RowBox[{
         RowBox[{"Style", "[", "\"\<\[FivePointedStar]\>\"", "]"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"knotsy", "[", 
            RowBox[{"[", "8", "]"}], "]"}], ",", "0"}], "}"}]}], "]"}]}], 
      "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4822339197761884`*^9, 3.4822339316947412`*^9}, {
   3.482572661375*^9, 3.48257267003125*^9}, {3.482666576171875*^9, 
   3.482666586796875*^9}, {3.48275027371875*^9, 3.482750281265625*^9}, {
   3.482753777171875*^9, 3.482753785234375*^9}, {3.486212364890625*^9, 
   3.48621236734375*^9}, {3.486287873984375*^9, 3.486287875171875*^9}, {
   3.486287947171875*^9, 3.486287994203125*^9}, 3.487570190203125*^9, 
   3.4875883339375*^9, {3.48758841546875*^9, 3.4875884191875*^9}, {
   3.560571401728435*^9, 3.560571422938473*^9}}],

Cell[BoxData[
 RowBox[{"segmentsY", "=", "\[IndentingNewLine]", 
  RowBox[{"Column", "[", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"PiecewiseExpand", "[", 
      RowBox[{
       RowBox[{"BSplineBasis", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"degy", ",", "knotsy"}], "}"}], ",", "k", ",", "y"}], "]"}],
        ",", "\[IndentingNewLine]", 
       RowBox[{"Method", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<OrderlessConditions\>\"", "\[Rule]", "False"}], 
         "}"}]}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"k", ",", "0", ",", 
       RowBox[{"numpointy", "-", "1"}]}], "}"}]}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.482234083410489*^9, 3.482234133487131*^9}, {
   3.482465106328125*^9, 3.48246510996875*^9}, {3.48246518215625*^9, 
   3.4824651833125*^9}, {3.482666737578125*^9, 3.4826667395*^9}, {
   3.482753427546875*^9, 3.48275342875*^9}, 3.482753866875*^9, {
   3.48621346525*^9, 3.4862134683125*^9}, {3.486918982048045*^9, 
   3.486919013638534*^9}, 3.486919046993183*^9, {3.487583169640625*^9, 
   3.487583172078125*^9}, 3.487588334484375*^9, 3.487588420171875*^9},
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{"segmentsY1", "=", "\[IndentingNewLine]", 
  RowBox[{"Column", "[", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"PiecewiseExpand", "[", 
      RowBox[{
       RowBox[{"BSplineBasis", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"degy", ",", "knotsy"}], "}"}], ",", "k", ",", "y"}], "]"}],
        ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"knotsy", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "<", "y", "<", 
        RowBox[{"knotsy", "[", 
         RowBox[{"[", "4", "]"}], "]"}]}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"k", ",", "0", ",", 
       RowBox[{"numpointy", "-", "1"}]}], "}"}]}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.482234083410489*^9, 3.482234133487131*^9}, {
   3.482465106328125*^9, 3.48246510996875*^9}, {3.48246518215625*^9, 
   3.4824651833125*^9}, {3.482666737578125*^9, 3.4826667395*^9}, {
   3.482753427546875*^9, 3.48275342875*^9}, 3.482753866875*^9, {
   3.48621346525*^9, 3.4862134683125*^9}, {3.486918982048045*^9, 
   3.486919013638534*^9}, 3.486919046993183*^9, {3.486919109859823*^9, 
   3.4869191150271597`*^9}, {3.48691917915466*^9, 3.4869191871341476`*^9}, {
   3.486919314319902*^9, 3.486919314466412*^9}, {3.487583331453125*^9, 
   3.48758333165625*^9}, 3.487588335171875*^9, {3.4875884206875*^9, 
   3.487588421859375*^9}},
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{"segmentsY2", "=", "\[IndentingNewLine]", 
  RowBox[{"Column", "[", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"PiecewiseExpand", "[", 
      RowBox[{
       RowBox[{"BSplineBasis", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"degy", ",", "knotsy"}], "}"}], ",", "k", ",", "y"}], "]"}],
        ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"knotsy", "[", 
         RowBox[{"[", "4", "]"}], "]"}], "<", "y", "<", 
        RowBox[{"knotsy", "[", 
         RowBox[{"[", "5", "]"}], "]"}]}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"k", ",", "0", ",", 
       RowBox[{"numpointy", "-", "1"}]}], "}"}]}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.482234083410489*^9, 3.482234133487131*^9}, {
   3.482465106328125*^9, 3.48246510996875*^9}, {3.48246518215625*^9, 
   3.4824651833125*^9}, {3.482666737578125*^9, 3.4826667395*^9}, {
   3.482753427546875*^9, 3.48275342875*^9}, 3.482753866875*^9, {
   3.48621346525*^9, 3.4862134683125*^9}, {3.486918982048045*^9, 
   3.486919013638534*^9}, 3.486919046993183*^9, {3.486919109859823*^9, 
   3.4869191150271597`*^9}, {3.48691917915466*^9, 3.4869191871341476`*^9}, {
   3.486919314319902*^9, 3.4869193353389463`*^9}, {3.487583333640625*^9, 
   3.487583333796875*^9}, 3.487588335703125*^9, {3.487588422375*^9, 
   3.487588423296875*^9}},
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{"segmentsY3", "=", "\[IndentingNewLine]", 
  RowBox[{"Column", "[", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"PiecewiseExpand", "[", 
      RowBox[{
       RowBox[{"BSplineBasis", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"degy", ",", "knotsy"}], "}"}], ",", "k", ",", "y"}], "]"}],
        ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"knotsy", "[", 
         RowBox[{"[", "5", "]"}], "]"}], "<", "y", "<", 
        RowBox[{"knotsy", "[", 
         RowBox[{"[", "6", "]"}], "]"}]}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"k", ",", "0", ",", 
       RowBox[{"numpointy", "-", "1"}]}], "}"}]}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.482234083410489*^9, 3.482234133487131*^9}, {
   3.482465106328125*^9, 3.48246510996875*^9}, {3.48246518215625*^9, 
   3.4824651833125*^9}, {3.482666737578125*^9, 3.4826667395*^9}, {
   3.482753427546875*^9, 3.48275342875*^9}, 3.482753866875*^9, {
   3.48621346525*^9, 3.4862134683125*^9}, {3.486918982048045*^9, 
   3.486919013638534*^9}, 3.486919046993183*^9, {3.486919109859823*^9, 
   3.4869191150271597`*^9}, {3.48691917915466*^9, 3.4869191871341476`*^9}, {
   3.486919314319902*^9, 3.486919356755468*^9}, {3.487583335546875*^9, 
   3.487583335734375*^9}, 3.48758833621875*^9, {3.48758842375*^9, 
   3.487588425015625*^9}},
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{"segmentsY4", "=", "\[IndentingNewLine]", 
  RowBox[{"Column", "[", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"PiecewiseExpand", "[", 
      RowBox[{
       RowBox[{"BSplineBasis", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"degy", ",", "knotsy"}], "}"}], ",", "k", ",", "y"}], "]"}],
        ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"knotsy", "[", 
         RowBox[{"[", "6", "]"}], "]"}], "<", "y", "<", 
        RowBox[{"knotsy", "[", 
         RowBox[{"[", "7", "]"}], "]"}]}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"k", ",", "0", ",", 
       RowBox[{"numpointy", "-", "1"}]}], "}"}]}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.482234083410489*^9, 3.482234133487131*^9}, {
   3.482465106328125*^9, 3.48246510996875*^9}, {3.48246518215625*^9, 
   3.4824651833125*^9}, {3.482666737578125*^9, 3.4826667395*^9}, {
   3.482753427546875*^9, 3.48275342875*^9}, 3.482753866875*^9, {
   3.48621346525*^9, 3.4862134683125*^9}, {3.486918982048045*^9, 
   3.486919013638534*^9}, 3.486919046993183*^9, {3.486919109859823*^9, 
   3.4869191150271597`*^9}, {3.48691917915466*^9, 3.4869191871341476`*^9}, {
   3.486919314319902*^9, 3.4869193725334997`*^9}, {3.487583337671875*^9, 
   3.487583355890625*^9}, 3.487588336734375*^9, {3.487588425625*^9, 
   3.487588426640625*^9}},
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{"segmentsY5", "=", "\[IndentingNewLine]", 
  RowBox[{"Column", "[", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"PiecewiseExpand", "[", 
      RowBox[{
       RowBox[{"BSplineBasis", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"degy", ",", "knotsy"}], "}"}], ",", "k", ",", "y"}], "]"}],
        ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"knotsy", "[", 
         RowBox[{"[", "7", "]"}], "]"}], "<", "y", "<", 
        RowBox[{"knotsy", "[", 
         RowBox[{"[", "10", "]"}], "]"}]}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"k", ",", "0", ",", 
       RowBox[{"numpointy", "-", "1"}]}], "}"}]}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.482234083410489*^9, 3.482234133487131*^9}, {
   3.482465106328125*^9, 3.48246510996875*^9}, {3.48246518215625*^9, 
   3.4824651833125*^9}, {3.482666737578125*^9, 3.4826667395*^9}, {
   3.482753427546875*^9, 3.48275342875*^9}, 3.482753866875*^9, {
   3.48621346525*^9, 3.4862134683125*^9}, {3.486918982048045*^9, 
   3.486919013638534*^9}, 3.486919046993183*^9, {3.486919109859823*^9, 
   3.4869191150271597`*^9}, {3.48691917915466*^9, 3.4869191871341476`*^9}, {
   3.486919314319902*^9, 3.486919389630548*^9}, {3.48758334084375*^9, 
   3.48758336003125*^9}, 3.48758833721875*^9, {3.487588427140625*^9, 
   3.48758842965625*^9}},
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[TextData[{
 "Here we extract the segments of the three Bsplines ",
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["B", "1", "3"], TraditionalForm]]],
 "(y),  ",
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["B", "2", "3"], TraditionalForm]]],
 "(y) and  ",
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["B", "3", "3"], TraditionalForm]]],
 "(y) which contribute in the interval [0, 3.5]."
}], "Text",
 CellChangeTimes->{{3.486918852330162*^9, 3.4869188669401493`*^9}, {
   3.487582891421875*^9, 3.487582988609375*^9}, {3.487583473671875*^9, 
   3.487583496375*^9}, {3.487583728234375*^9, 3.4875837371875*^9}, {
   3.487583887*^9, 3.48758390271875*^9}, {3.560571354492096*^9, 
   3.560571356132365*^9}, 3.560571458528028*^9, {3.560572095658512*^9, 
   3.560572101180015*^9}},
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{"graByresctricted", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"BSplineBasis", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"degy", ",", "knotsy"}], "}"}], ",", "l", ",", "y"}], "]"}],
        ",", 
       RowBox[{"{", 
        RowBox[{"l", ",", "0", ",", 
         RowBox[{"numpointy", "-", "1"}]}], "}"}]}], "]"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"y", ",", 
      RowBox[{"knotsy", "[", 
       RowBox[{"[", "1", "]"}], "]"}], ",", 
      RowBox[{"knotsy", "[", 
       RowBox[{"[", "4", "]"}], "]"}]}], "}"}], ",", 
    RowBox[{"Epilog", "\[Rule]", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Text", "[", 
        RowBox[{
         RowBox[{"Style", "[", "\"\<\[FivePointedStar]\>\"", "]"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"knotsy", "[", 
            RowBox[{"[", "1", "]"}], "]"}], ",", "0"}], "}"}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Text", "[", 
        RowBox[{
         RowBox[{"Style", "[", "\"\<\[FivePointedStar]\>\"", "]"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"knotsy", "[", 
            RowBox[{"[", "4", "]"}], "]"}], ",", "0"}], "}"}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Text", "[", 
        RowBox[{
         RowBox[{"Style", "[", "\"\<\[FivePointedStar]\>\"", "]"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"knotsy", "[", 
            RowBox[{"[", "5", "]"}], "]"}], ",", "0"}], "}"}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Text", "[", 
        RowBox[{
         RowBox[{"Style", "[", "\"\<\[FivePointedStar]\>\"", "]"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"knotsy", "[", 
            RowBox[{"[", "6", "]"}], "]"}], ",", "0"}], "}"}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Text", "[", 
        RowBox[{
         RowBox[{"Style", "[", "\"\<\[FivePointedStar]\>\"", "]"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"knotsy", "[", 
            RowBox[{"[", "7", "]"}], "]"}], ",", "0"}], "}"}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Text", "[", 
        RowBox[{
         RowBox[{"Style", "[", "\"\<\[FivePointedStar]\>\"", "]"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"knotsy", "[", 
            RowBox[{"[", "8", "]"}], "]"}], ",", "0"}], "}"}]}], "]"}]}], 
      "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4822339197761884`*^9, 3.4822339316947412`*^9}, {
   3.482572661375*^9, 3.48257267003125*^9}, {3.482666576171875*^9, 
   3.482666586796875*^9}, {3.48275027371875*^9, 3.482750281265625*^9}, {
   3.482753777171875*^9, 3.482753785234375*^9}, {3.486212364890625*^9, 
   3.48621236734375*^9}, {3.486287873984375*^9, 3.486287875171875*^9}, {
   3.486287947171875*^9, 3.486287994203125*^9}, {3.486919473926507*^9, 
   3.486919507274849*^9}, 3.4875702553125*^9, {3.487583246328125*^9, 
   3.48758325353125*^9}, 3.487588338046875*^9, {3.48758843040625*^9, 
   3.48758843384375*^9}, {3.560571467582536*^9, 3.560571477452225*^9}},
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell["\<\
We plot now the complet set of 2-D B-splines, obtained as a tensor product of \
one-dimensional B-splines.
The results depend on the hardware; try with different ImageSize\[Rule]xxx\
\>", "Text",
 CellChangeTimes->{{3.4822340608526*^9, 3.4822340628026247`*^9}, {
  3.48626953265625*^9, 3.486269536671875*^9}, {3.560571490689117*^9, 
  3.560571518833583*^9}, {3.5777020704634647`*^9, 3.577702126454336*^9}},
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{"Grid", "[", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"Plot3D", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"BSplineBasis", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"degx", ",", "knotsx"}], "}"}], ",", "k", ",", "u"}], "]"}], 
       RowBox[{"BSplineBasis", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"degy", ",", "knotsy"}], "}"}], ",", "l", ",", "v"}], 
        "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"u", ",", "0", ",", "xmax"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"v", ",", "0", ",", "ymax"}], "}"}], ",", 
      RowBox[{"ImageSize", "\[Rule]", "250"}], ",", 
      RowBox[{"(*", 
       RowBox[{
        RowBox[{"PlotRange", "\[Rule]", "All"}], ","}], "*)"}], 
      RowBox[{"Mesh", "\[Rule]", "None"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"k", ",", "0", ",", 
      RowBox[{"numpointx", "-", "1"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"l", ",", "0", ",", 
      RowBox[{"numpointy", "-", "1"}]}], "}"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.482233939916046*^9, 3.4822340281939793`*^9}, {
   3.482666604078125*^9, 3.48266665959375*^9}, {3.482750364671875*^9, 
   3.48275037621875*^9}, {3.482753823453125*^9, 3.482753848546875*^9}, {
   3.487588311078125*^9, 3.48758833878125*^9}, 3.487588386953125*^9, 
   3.487588434765625*^9, {3.560571522414401*^9, 3.560571530825317*^9}, {
   3.575686413689582*^9, 3.5756864353185387`*^9}, {3.575686521460009*^9, 
   3.575686528353158*^9}}],

Cell[CellGroupData[{

Cell["\<\
If we look at the  Control points (the coefficients used to build the \
interpolating spline), we have six lists each containing seven values\
\>", "Text",
 CellChangeTimes->{{3.482234275135853*^9, 3.482234286446925*^9}, {
  3.486271694609375*^9, 3.48627170903125*^9}, {3.48627179328125*^9, 
  3.48627182421875*^9}, {3.4862718919375*^9, 3.486271906734375*^9}, {
  3.4862719860625*^9, 3.486271986796875*^9}, {3.48627265415625*^9, 
  3.4862726565*^9}, {3.487584007796875*^9, 3.487584079578125*^9}, {
  3.560571552862703*^9, 3.560571586811153*^9}},
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{"cpts", "=", 
  RowBox[{"bspfun", "[", "\"\<ControlPoints\>\"", "]"}]}]], "Input",
 CellChangeTimes->{{3.4822343225455565`*^9, 3.4822343308448095`*^9}, {
  3.50764040650637*^9, 3.507640407507729*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["These values permit to reconstruct the interpolating spline", "Text",
 CellChangeTimes->{{3.4822341378707695`*^9, 3.4822341540168734`*^9}, {
  3.48627191121875*^9, 3.486271916921875*^9}, {3.486273237703125*^9, 
  3.486273247296875*^9}, {3.560571594504416*^9, 3.560571629614625*^9}, {
  3.560571739825481*^9, 3.560571751164975*^9}},
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"newbspfun", "[", 
    RowBox[{"x_", ",", "y_"}], "]"}], ":=", 
   RowBox[{"Sum", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"cpts", "[", 
       RowBox[{"[", 
        RowBox[{
         RowBox[{"i", "+", "1"}], ",", 
         RowBox[{"j", "+", "1"}]}], "]"}], "]"}], 
      RowBox[{"BSplineBasis", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"degx", ",", "knotsx"}], "}"}], ",", "i", ",", "x"}], "]"}], 
      RowBox[{"BSplineBasis", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"degy", ",", "knotsy"}], "}"}], ",", "j", ",", "y"}], 
       "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "0", ",", 
       RowBox[{"numpointx", "-", "1"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "0", ",", 
       RowBox[{"numpointy", "-", "1"}]}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.48223416885297*^9, 3.4822342224543147`*^9}, {
   3.4822344030128727`*^9, 3.482234426553424*^9}, {3.482667027640625*^9, 
   3.482667030890625*^9}, {3.48275041753125*^9, 3.48275041865625*^9}, {
   3.482753883703125*^9, 3.482753891421875*^9}, {3.487588311734375*^9, 
   3.4875883395*^9}, 3.487588387421875*^9, 3.487588435265625*^9, {
   3.560571758375555*^9, 3.560571778038277*^9}, {3.560571856482405*^9, 
   3.560571859991975*^9}}],

Cell[TextData[{
 "Remark : control points indexes are from 1 to 6 for x and  1 to 7  for y \
(as usual), while, as already oberved,  B-spline basis indexes used in ",
 StyleBox["BSplineBasis",
  FontFamily->"Courier"],
 " are from 0 to 5 (for x) and 0 to 6 (for y)"
}], "Text",
 CellChangeTimes->{{3.48627268203125*^9, 3.486272723703125*^9}, {
  3.48627326815625*^9, 3.48627326921875*^9}, {3.560571785694431*^9, 
  3.560571841961612*^9}},
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"newbspfun", "[", 
   RowBox[{"x", ",", "y"}], "]"}], "//", "TraditionalForm"}]], "Input",
 CellChangeTimes->{{3.482234622665385*^9, 3.482234628889825*^9}}],

Cell[TextData[{
 "We check that our reconstruction coincides with the result given by ",
 StyleBox["Mathematica",
  FontSlant->"Italic"]
}], "Text",
 CellChangeTimes->{{3.4822341378707695`*^9, 3.4822341540168734`*^9}, {
  3.48627191121875*^9, 3.486271916921875*^9}, {3.486273237703125*^9, 
  3.486273247296875*^9}, {3.48627393721875*^9, 3.486273948203125*^9}, {
  3.48627400290625*^9, 3.48627400571875*^9}, {3.560571876805533*^9, 
  3.560571892488682*^9}},
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{"Chop", "[", 
  RowBox[{"Plot3D", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"biparab", "[", 
      RowBox[{"x", ",", "y"}], "]"}], "-", 
     RowBox[{"newbspfun", "[", 
      RowBox[{"x", ",", "y"}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", "14"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"y", ",", "0", ",", " ", "18"}], "}"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.4822342242015257`*^9, 3.4822342345287924`*^9}, {
   3.482465981890625*^9, 3.48246599628125*^9}, {3.482669679296875*^9, 
   3.482669732984375*^9}, 3.482669787140625*^9, {3.4826698193125*^9, 
   3.482669871859375*^9}, {3.482669929125*^9, 3.482669952375*^9}, {
   3.482670156453125*^9, 3.482670336578125*^9}, {3.482670373453125*^9, 
   3.48267044571875*^9}, {3.482670483578125*^9, 3.482670528171875*^9}, {
   3.48267056446875*^9, 3.482670565890625*^9}, {3.48267063209375*^9, 
   3.482670661046875*^9}, {3.48267075003125*^9, 3.482670751953125*^9}, 
   3.482670797671875*^9, 3.482670829265625*^9, 3.48267086928125*^9, 
   3.482670912703125*^9, 3.483791468640625*^9, {3.48627349065625*^9, 
   3.486273498078125*^9}, {3.486273960328125*^9, 3.48627396815625*^9}, {
   3.48758537975*^9, 3.487585396953125*^9}, 3.487585447375*^9, 
   3.487585485890625*^9, {3.560571899298693*^9, 3.560571913017781*^9}}]
}, Open  ]]
}, Open  ]],

Cell["Part III", "Text",
 CellChangeTimes->{{3.4822342910645547`*^9, 3.4822343209855466`*^9}, {
   3.4827529496875*^9, 3.482752986359375*^9}, {3.482753058375*^9, 
   3.48275329565625*^9}, {3.482754376203125*^9, 3.4827544480625*^9}, {
   3.482893982625*^9, 3.48289398340625*^9}, {3.483792293875*^9, 
   3.4837923073125*^9}, {3.483792338578125*^9, 3.483792374296875*^9}, {
   3.48379240884375*^9, 3.48379245921875*^9}, {3.483792497421875*^9, 
   3.483792550125*^9}, {3.48379266728125*^9, 3.483792678921875*^9}, {
   3.48620778865625*^9, 3.486207796421875*^9}, {3.486207868984375*^9, 
   3.486207902421875*^9}, {3.486207996765625*^9, 3.48620804921875*^9}, {
   3.4862081176875*^9, 3.48620820034375*^9}, {3.4862082995*^9, 
   3.486208301734375*^9}, {3.486208366046875*^9, 3.48620837096875*^9}, {
   3.486208594421875*^9, 3.486208687953125*^9}, {3.486208736390625*^9, 
   3.486208956265625*^9}, 3.48620929246875*^9, {3.486209324234375*^9, 
   3.486209458078125*^9}, {3.486209551828125*^9, 3.486209589796875*^9}, {
   3.486209642390625*^9, 3.48620964525*^9}, {3.486209969140625*^9, 
   3.486209987515625*^9}, {3.560570537690327*^9, 3.560570548273905*^9}, {
   3.5726841475730414`*^9, 3.5726841491561317`*^9}, {3.5726841815009823`*^9, 
   3.572684182108017*^9}},
 FontFamily->"Times New Roman",
 FontSize->36,
 FontColor->RGBColor[0, 0, 1],
 Background->RGBColor[1, 0.9, 0.8]],

Cell[CellGroupData[{

Cell["\<\
We extract the polynomial surface relevant to the cell 21 in two ways

\t- by exploting the tensorial product of the BSplines
\t
\t- by finding the explicit polynomial representation.\
\>", "Text",
 CellChangeTimes->{{3.4822342910645547`*^9, 3.4822343209855466`*^9}, {
   3.4827529496875*^9, 3.482752986359375*^9}, {3.482753058375*^9, 
   3.48275329565625*^9}, {3.482754376203125*^9, 3.4827544480625*^9}, {
   3.482893982625*^9, 3.48289398340625*^9}, {3.483792293875*^9, 
   3.4837923073125*^9}, {3.483792338578125*^9, 3.483792374296875*^9}, {
   3.48379240884375*^9, 3.48379245921875*^9}, {3.483792497421875*^9, 
   3.483792550125*^9}, {3.48379266728125*^9, 3.483792678921875*^9}, {
   3.48620778865625*^9, 3.486207796421875*^9}, {3.486207868984375*^9, 
   3.486207902421875*^9}, {3.486207996765625*^9, 3.48620804921875*^9}, {
   3.4862081176875*^9, 3.48620820034375*^9}, {3.4862082995*^9, 
   3.486208301734375*^9}, {3.486208366046875*^9, 3.48620837096875*^9}, {
   3.486208594421875*^9, 3.486208687953125*^9}, {3.486208736390625*^9, 
   3.486208956265625*^9}, 3.48620929246875*^9, {3.486209324234375*^9, 
   3.486209458078125*^9}, {3.48627677321875*^9, 3.48627681325*^9}, {
   3.486276863046875*^9, 3.486276898796875*^9}, {3.48627699571875*^9, 
   3.486277014953125*^9}, {3.48627705409375*^9, 3.486277138859375*^9}, {
   3.486277176375*^9, 3.486277187828125*^9}, {3.48627734921875*^9, 
   3.486277395328125*^9}, {3.487584661296875*^9, 3.487584777421875*^9}, {
   3.48758500365625*^9, 3.48758513034375*^9}, {3.560571929899255*^9, 
   3.560571939957251*^9}},
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"newbspfun$cell21", "[", 
   RowBox[{"x_", ",", "y_"}], "]"}], ":=", 
  RowBox[{"Sum", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"cpts", "[", 
      RowBox[{"[", 
       RowBox[{
        RowBox[{"i", "+", "1"}], ",", 
        RowBox[{"j", "+", "1"}]}], "]"}], "]"}], 
     RowBox[{"BSplineBasis", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"degx", ",", "knotsx"}], "}"}], ",", "i", ",", "x"}], "]"}], 
     RowBox[{"BSplineBasis", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"degy", ",", "knotsy"}], "}"}], ",", "j", ",", "y"}], "]"}]}],
     ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "1", ",", "3"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "0", ",", "2"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.48223416885297*^9, 3.4822342224543147`*^9}, {
   3.4822344030128727`*^9, 3.482234426553424*^9}, {3.482667027640625*^9, 
   3.482667030890625*^9}, {3.48275041753125*^9, 3.48275041865625*^9}, {
   3.482753883703125*^9, 3.482753891421875*^9}, {3.486274165984375*^9, 
   3.4862741979375*^9}, {3.487588312234375*^9, 3.487588340328125*^9}, 
   3.4875883878125*^9, 3.487588435859375*^9, 3.560571959682774*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"newbspfun$cell21", "[", 
   RowBox[{"x", ",", "y"}], "]"}], "//", "TraditionalForm"}]], "Input",
 CellChangeTimes->{{3.482234622665385*^9, 3.482234628889825*^9}, 
   3.486274207375*^9, 3.560571972715022*^9}],

Cell[BoxData[
 RowBox[{"graph1", " ", "=", 
  RowBox[{"Plot3D", "[", 
   RowBox[{
    RowBox[{"newbspfun$cell21", "[", 
     RowBox[{"x", ",", "y"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "3.25", ",", "6.75"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"y", ",", "0", ",", "3.5"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4822342242015257`*^9, 3.4822342345287924`*^9}, {
   3.482465981890625*^9, 3.48246599628125*^9}, {3.48267008875*^9, 
   3.4826700995625*^9}, {3.482750988328125*^9, 3.48275099084375*^9}, {
   3.4827529060625*^9, 3.482752906953125*^9}, 3.483791530625*^9, {
   3.486274258078125*^9, 3.48627428515625*^9}, {3.486275227046875*^9, 
   3.486275272671875*^9}, {3.486275345671875*^9, 3.4862753560625*^9}, {
   3.487586979328125*^9, 3.487586986078125*^9}, 3.560571981070781*^9}],

Cell[CellGroupData[{

Cell[TextData[{
 "Contribution from ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SuperscriptBox[
      SubscriptBox["B", "21"], "3"], "(", 
     RowBox[{"x", ",", "y"}], ")"}], "=", 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       SubscriptBox["B", "2"], "3"], "(", "x", ")"}], " ", 
     RowBox[{
      SuperscriptBox[
       SubscriptBox["B", "1"], "3"], "(", "y", ")"}]}]}], TraditionalForm]]],
 "  -1-\n\nRemark: according to our notation,\n\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SuperscriptBox[
      SubscriptBox["B", "2"], "3"], "(", "x", ")"}], " ", "=", " ", 
    RowBox[{
     SubscriptBox["N", 
      RowBox[{"1", ",", "2"}]], "(", "x", ")"}]}], TraditionalForm]]],
 "\tand \t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SuperscriptBox[
      SubscriptBox["B", "1"], "3"], "(", "y", ")"}], " ", "=", " ", 
    RowBox[{
     SubscriptBox["N", 
      RowBox[{"0", ",", "2"}]], "(", "y", ")"}]}], TraditionalForm]]]
}], "Text",
 CellChangeTimes->{{3.4822341378707695`*^9, 3.4822341540168734`*^9}, {
   3.48627191121875*^9, 3.486271916921875*^9}, {3.486273237703125*^9, 
   3.486273247296875*^9}, {3.48627393721875*^9, 3.486273948203125*^9}, {
   3.48627400290625*^9, 3.48627400571875*^9}, {3.48627580659375*^9, 
   3.48627585678125*^9}, {3.48627741071875*^9, 3.486277413734375*^9}, {
   3.48733010359375*^9, 3.487330223296875*^9}, {3.487423140109375*^9, 
   3.487423141265625*^9}, {3.487424196171875*^9, 3.487424216984375*^9}, 
   3.487585238234375*^9, {3.487585950703125*^9, 3.487585952140625*^9}, {
   3.560571996450679*^9, 3.560572079095638*^9}, {3.560572536240236*^9, 
   3.560572588883807*^9}, {3.560573205775744*^9, 3.560573221723174*^9}, {
   3.560573832276558*^9, 3.560573845951761*^9}},
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"contr21", "[", 
   RowBox[{"x_", ",", "y_"}], "]"}], "=", 
  RowBox[{
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"newbspfun$cell21", "[", 
       RowBox[{"x", ",", "y"}], "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}], ",", 
     RowBox[{
      RowBox[{"x", ">", "3.25"}], "&&", 
      RowBox[{"x", "<", "6.75"}], "&&", 
      RowBox[{"y", ">", "0"}], "&&", 
      RowBox[{"y", "<", "3.5"}]}]}], "]"}], "//", "Expand"}]}]], "Input",
 CellChangeTimes->{{3.56057283048994*^9, 3.560572919455357*^9}, {
  3.560572955552676*^9, 3.560572956756007*^9}, {3.560573060216763*^9, 
  3.560573103219759*^9}, {3.560573224048472*^9, 3.560573225485383*^9}, {
  3.560573322912728*^9, 3.560573324568896*^9}}],

Cell[BoxData[
 RowBox[{"Plot3D", "[", 
  RowBox[{
   RowBox[{"Evaluate", "[", 
    RowBox[{"contr21", "[", 
     RowBox[{"x", ",", "y"}], "]"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "3.25", ",", "6.75"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"y", ",", "0", ",", "3.5"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.487329441375*^9, 3.48732948778125*^9}, {
   3.487329673640625*^9, 3.487329692640625*^9}, {3.487423937546875*^9, 
   3.487423956375*^9}, {3.48742401984375*^9, 3.487424042609375*^9}, {
   3.48747327934375*^9, 3.487473280796875*^9}, 3.48758530265625*^9, {
   3.560573229194232*^9, 3.560573229972187*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Contribution from ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SuperscriptBox[
      SubscriptBox["B", "31"], "3"], "(", 
     RowBox[{"x", ",", "y"}], ")"}], "=", 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       SubscriptBox["B", "3"], "3"], "(", "x", ")"}], " ", 
     RowBox[{
      SuperscriptBox[
       SubscriptBox["B", "1"], "3"], "(", "y", ")"}]}]}], TraditionalForm]]],
 " -2-"
}], "Text",
 CellChangeTimes->{{3.4822341378707695`*^9, 3.4822341540168734`*^9}, {
   3.48627191121875*^9, 3.486271916921875*^9}, {3.486273237703125*^9, 
   3.486273247296875*^9}, {3.48627393721875*^9, 3.486273948203125*^9}, {
   3.48627400290625*^9, 3.48627400571875*^9}, {3.48627580659375*^9, 
   3.48627585678125*^9}, {3.48627741071875*^9, 3.486277413734375*^9}, {
   3.48733010359375*^9, 3.487330223296875*^9}, {3.487423140109375*^9, 
   3.487423141265625*^9}, {3.487424196171875*^9, 3.487424216984375*^9}, {
   3.487424277515625*^9, 3.487424284703125*^9}, 3.4875852391875*^9, {
   3.487585957921875*^9, 3.487585959296875*^9}, 3.560573124867092*^9, {
   3.56057323666879*^9, 3.560573244293364*^9}, {3.560573848708654*^9, 
   3.560573858444392*^9}},
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"contr31", "[", 
   RowBox[{"x_", ",", "y_"}], "]"}], "=", 
  RowBox[{
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"newbspfun$cell21", "[", 
       RowBox[{"x", ",", "y"}], "]"}], "[", 
      RowBox[{"[", "2", "]"}], "]"}], ",", 
     RowBox[{
      RowBox[{"x", ">", "3.25"}], "&&", 
      RowBox[{"x", "<", "6.75"}], "&&", 
      RowBox[{"y", ">", "0"}], "&&", 
      RowBox[{"y", "<", "3.5"}]}]}], "]"}], "//", "Expand"}]}]], "Input",
 CellChangeTimes->{{3.56057283048994*^9, 3.560572919455357*^9}, {
  3.560572955552676*^9, 3.560572956756007*^9}, {3.560573060216763*^9, 
  3.560573103219759*^9}, {3.560573143528665*^9, 3.560573174338607*^9}, {
  3.560573248126502*^9, 3.560573270281691*^9}, {3.560573315024274*^9, 
  3.560573316696012*^9}}],

Cell[BoxData[
 RowBox[{"Plot3D", "[", 
  RowBox[{
   RowBox[{"Evaluate", "[", 
    RowBox[{"contr31", "[", 
     RowBox[{"x", ",", "y"}], "]"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "3.25", ",", "6.75"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"y", ",", "0", ",", "3.5"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.487329441375*^9, 3.48732948778125*^9}, {
   3.487329673640625*^9, 3.487329692640625*^9}, {3.487423937546875*^9, 
   3.487423956375*^9}, {3.487423991015625*^9, 3.48742399134375*^9}, 
   3.487424059296875*^9, 3.487473412359375*^9, 3.487585303984375*^9, {
   3.560573302334593*^9, 3.560573303665376*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Contribution from ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SuperscriptBox[
      SubscriptBox["B", "41"], "3"], "(", 
     RowBox[{"x", ",", "y"}], ")"}], "=", 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       SubscriptBox["B", "4"], "3"], "(", "x", ")"}], " ", 
     RowBox[{
      SuperscriptBox[
       SubscriptBox["B", "1"], "3"], "(", "y", ")"}]}]}], TraditionalForm]]],
 " -3-"
}], "Text",
 CellChangeTimes->{{3.4822341378707695`*^9, 3.4822341540168734`*^9}, {
   3.48627191121875*^9, 3.486271916921875*^9}, {3.486273237703125*^9, 
   3.486273247296875*^9}, {3.48627393721875*^9, 3.486273948203125*^9}, {
   3.48627400290625*^9, 3.48627400571875*^9}, {3.48627580659375*^9, 
   3.48627585678125*^9}, {3.48627741071875*^9, 3.486277413734375*^9}, {
   3.48733010359375*^9, 3.487330223296875*^9}, {3.487423140109375*^9, 
   3.487423141265625*^9}, {3.487424196171875*^9, 3.487424216984375*^9}, {
   3.487424277515625*^9, 3.487424284703125*^9}, 3.487424361234375*^9, 
   3.487585239765625*^9, {3.487585974390625*^9, 3.48758597634375*^9}, {
   3.560573391537911*^9, 3.560573399739361*^9}, {3.560573850123901*^9, 
   3.560573860323626*^9}},
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"contr41", "[", 
   RowBox[{"x_", ",", "y_"}], "]"}], "=", 
  RowBox[{
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"newbspfun$cell21", "[", 
       RowBox[{"x", ",", "y"}], "]"}], "[", 
      RowBox[{"[", "3", "]"}], "]"}], ",", 
     RowBox[{
      RowBox[{"x", ">", "3.25"}], "&&", 
      RowBox[{"x", "<", "6.75"}], "&&", 
      RowBox[{"y", ">", "0"}], "&&", 
      RowBox[{"y", "<", "3.5"}]}]}], "]"}], "//", "Expand"}]}]], "Input",
 CellChangeTimes->{{3.560573403413712*^9, 3.560573403545171*^9}, {
  3.560573482449944*^9, 3.560573482561228*^9}}],

Cell[BoxData[
 RowBox[{"Plot3D", "[", 
  RowBox[{
   RowBox[{"Evaluate", "[", 
    RowBox[{"contr41", "[", 
     RowBox[{"x", ",", "y"}], "]"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "3.25", ",", "6.75"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"y", ",", "0", ",", "3.5"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.487329441375*^9, 3.48732948778125*^9}, {
   3.487329673640625*^9, 3.487329692640625*^9}, {3.487423937546875*^9, 
   3.487423956375*^9}, {3.487423991015625*^9, 3.48742399134375*^9}, 
   3.487424059296875*^9, {3.487424479984375*^9, 3.48742448034375*^9}, 
   3.487473440734375*^9, 3.487585304875*^9, {3.560573420053903*^9, 
   3.56057342126974*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Contribution from ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SuperscriptBox[
      SubscriptBox["B", "22"], "3"], "(", 
     RowBox[{"x", ",", "y"}], ")"}], "=", 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       SubscriptBox["B", "2"], "3"], "(", "x", ")"}], " ", 
     RowBox[{
      SuperscriptBox[
       SubscriptBox["B", "2"], "3"], "(", "y", ")"}]}]}], TraditionalForm]]],
 " -4-"
}], "Text",
 CellChangeTimes->{{3.4822341378707695`*^9, 3.4822341540168734`*^9}, {
   3.48627191121875*^9, 3.486271916921875*^9}, {3.486273237703125*^9, 
   3.486273247296875*^9}, {3.48627393721875*^9, 3.486273948203125*^9}, {
   3.48627400290625*^9, 3.48627400571875*^9}, {3.48627580659375*^9, 
   3.48627585678125*^9}, {3.48627741071875*^9, 3.486277413734375*^9}, {
   3.48733010359375*^9, 3.487330223296875*^9}, {3.487423140109375*^9, 
   3.487423141265625*^9}, {3.487424196171875*^9, 3.487424216984375*^9}, 
   3.48742455525*^9, 3.487585240328125*^9, {3.487585985515625*^9, 
   3.48758598740625*^9}, {3.560573452962385*^9, 3.560573453925244*^9}, {
   3.560573528280475*^9, 3.560573540964615*^9}, {3.560573851743955*^9, 
   3.560573863406685*^9}},
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"contr22", "[", 
   RowBox[{"x_", ",", "y_"}], "]"}], "=", 
  RowBox[{
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"newbspfun$cell21", "[", 
       RowBox[{"x", ",", "y"}], "]"}], "[", 
      RowBox[{"[", "4", "]"}], "]"}], ",", 
     RowBox[{
      RowBox[{"x", ">", "3.25"}], "&&", 
      RowBox[{"x", "<", "6.75"}], "&&", 
      RowBox[{"y", ">", "0"}], "&&", 
      RowBox[{"y", "<", "3.5"}]}]}], "]"}], "//", "Expand"}]}]], "Input",
 CellChangeTimes->{{3.560573403413712*^9, 3.560573403545171*^9}, {
  3.560573450584753*^9, 3.560573451211631*^9}, {3.560573506196763*^9, 
  3.560573506343578*^9}, {3.560573586226798*^9, 3.560573586385355*^9}}],

Cell[BoxData[
 RowBox[{"Plot3D", "[", 
  RowBox[{
   RowBox[{"Evaluate", "[", 
    RowBox[{"contr22", "[", 
     RowBox[{"x", ",", "y"}], "]"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "3.25", ",", "6.75"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"y", ",", "0", ",", "3.5"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.487329441375*^9, 3.48732948778125*^9}, {
   3.487329673640625*^9, 3.487329692640625*^9}, {3.487423937546875*^9, 
   3.487423956375*^9}, {3.48742401984375*^9, 3.487424042609375*^9}, {
   3.487424636859375*^9, 3.48742463690625*^9}, 3.487585305734375*^9, {
   3.560573516251939*^9, 3.560573517719175*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Contribution from ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SuperscriptBox[
      SubscriptBox["B", "32"], "3"], "(", 
     RowBox[{"x", ",", "y"}], ")"}], "=", 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       SubscriptBox["B", "3"], "3"], "(", "x", ")"}], " ", 
     RowBox[{
      SuperscriptBox[
       SubscriptBox["B", "2"], "3"], "(", "y", ")"}]}]}], TraditionalForm]]],
 " -5-"
}], "Text",
 CellChangeTimes->{{3.4822341378707695`*^9, 3.4822341540168734`*^9}, {
   3.48627191121875*^9, 3.486271916921875*^9}, {3.486273237703125*^9, 
   3.486273247296875*^9}, {3.48627393721875*^9, 3.486273948203125*^9}, {
   3.48627400290625*^9, 3.48627400571875*^9}, {3.48627580659375*^9, 
   3.48627585678125*^9}, {3.48627741071875*^9, 3.486277413734375*^9}, {
   3.48733010359375*^9, 3.487330223296875*^9}, {3.487423140109375*^9, 
   3.487423141265625*^9}, {3.487424196171875*^9, 3.487424216984375*^9}, 
   3.48742455525*^9, 3.487424908*^9, 3.487585240859375*^9, {
   3.4875859934375*^9, 3.48758599490625*^9}, {3.560573624225024*^9, 
   3.560573630645225*^9}, {3.560573853578662*^9, 3.560573866164527*^9}},
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"contr32", "[", 
   RowBox[{"x_", ",", "y_"}], "]"}], "=", 
  RowBox[{
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"newbspfun$cell21", "[", 
       RowBox[{"x", ",", "y"}], "]"}], "[", 
      RowBox[{"[", "5", "]"}], "]"}], ",", 
     RowBox[{
      RowBox[{"x", ">", "3.25"}], "&&", 
      RowBox[{"x", "<", "6.75"}], "&&", 
      RowBox[{"y", ">", "0"}], "&&", 
      RowBox[{"y", "<", "3.5"}]}]}], "]"}], "//", "Expand"}]}]], "Input",
 CellChangeTimes->{{3.560573403413712*^9, 3.560573403545171*^9}, {
  3.560573450584753*^9, 3.560573451211631*^9}, {3.560573506196763*^9, 
  3.560573506343578*^9}, {3.560573601248015*^9, 3.560573601360728*^9}}],

Cell[BoxData[
 RowBox[{"Plot3D", "[", 
  RowBox[{
   RowBox[{"Evaluate", "[", 
    RowBox[{"contr32", "[", 
     RowBox[{"x", ",", "y"}], "]"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "3.25", ",", "6.75"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"y", ",", "0", ",", "3.5"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.487329441375*^9, 3.48732948778125*^9}, {
   3.487329673640625*^9, 3.487329692640625*^9}, {3.487423937546875*^9, 
   3.487423956375*^9}, {3.48742401984375*^9, 3.487424042609375*^9}, {
   3.487424636859375*^9, 3.48742463690625*^9}, {3.487424943328125*^9, 
   3.487424944*^9}, 3.4875853065625*^9, {3.560573610868739*^9, 
   3.56057361213666*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Contribution from ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SuperscriptBox[
      SubscriptBox["B", "42"], "3"], "(", 
     RowBox[{"x", ",", "y"}], ")"}], "=", 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       SubscriptBox["B", "4"], "3"], "(", "x", ")"}], " ", 
     RowBox[{
      SuperscriptBox[
       SubscriptBox["B", "2"], "3"], "(", "y", ")"}]}]}], TraditionalForm]]],
 " -6-"
}], "Text",
 CellChangeTimes->{{3.4822341378707695`*^9, 3.4822341540168734`*^9}, {
   3.48627191121875*^9, 3.486271916921875*^9}, {3.486273237703125*^9, 
   3.486273247296875*^9}, {3.48627393721875*^9, 3.486273948203125*^9}, {
   3.48627400290625*^9, 3.48627400571875*^9}, {3.48627580659375*^9, 
   3.48627585678125*^9}, {3.48627741071875*^9, 3.486277413734375*^9}, {
   3.48733010359375*^9, 3.487330223296875*^9}, {3.487423140109375*^9, 
   3.487423141265625*^9}, {3.487424196171875*^9, 3.487424216984375*^9}, 
   3.48742455525*^9, 3.487424908*^9, 3.487585240859375*^9, {
   3.4875859934375*^9, 3.48758599490625*^9}, {3.487586312640625*^9, 
   3.48758633396875*^9}, {3.56057364122001*^9, 3.560573644358577*^9}, {
   3.560573678943116*^9, 3.560573704048093*^9}, {3.560573855321417*^9, 
   3.560573868814116*^9}},
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"contr42", "[", 
   RowBox[{"x_", ",", "y_"}], "]"}], "=", 
  RowBox[{
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"newbspfun$cell21", "[", 
       RowBox[{"x", ",", "y"}], "]"}], "[", 
      RowBox[{"[", "6", "]"}], "]"}], ",", 
     RowBox[{
      RowBox[{"x", ">", "3.25"}], "&&", 
      RowBox[{"x", "<", "6.75"}], "&&", 
      RowBox[{"y", ">", "0"}], "&&", 
      RowBox[{"y", "<", "3.5"}]}]}], "]"}], "//", "Expand"}]}]], "Input",
 CellChangeTimes->{{3.560573403413712*^9, 3.560573403545171*^9}, {
  3.560573450584753*^9, 3.560573451211631*^9}, {3.560573506196763*^9, 
  3.560573506343578*^9}, {3.560573601248015*^9, 3.560573601360728*^9}, {
  3.560573669072866*^9, 3.560573692279132*^9}}],

Cell[BoxData[
 RowBox[{"Plot3D", "[", 
  RowBox[{
   RowBox[{"Evaluate", "[", 
    RowBox[{"contr42", "[", 
     RowBox[{"x", ",", "y"}], "]"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "3.25", ",", "6.75"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"y", ",", "0", ",", "3.5"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.487329441375*^9, 3.48732948778125*^9}, {
   3.487329673640625*^9, 3.487329692640625*^9}, {3.487423937546875*^9, 
   3.487423956375*^9}, {3.48742401984375*^9, 3.487424042609375*^9}, {
   3.487424636859375*^9, 3.48742463690625*^9}, {3.487424943328125*^9, 
   3.487424944*^9}, 3.4875853065625*^9, {3.487586411703125*^9, 
   3.487586412015625*^9}, {3.560573695236757*^9, 3.560573696428001*^9}}]
}, Open  ]],

Cell["\<\

\
\>", "Text",
 CellChangeTimes->{3.48758628459375*^9}],

Cell[CellGroupData[{

Cell[TextData[{
 "Contribution from ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SuperscriptBox[
      SubscriptBox["B", "23"], "3"], "(", 
     RowBox[{"x", ",", "y"}], ")"}], "=", 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       SubscriptBox["B", "2"], "3"], "(", "x", ")"}], " ", 
     RowBox[{
      SuperscriptBox[
       SubscriptBox["B", "3"], "3"], "(", "y", ")"}]}]}], TraditionalForm]]],
 " -7-"
}], "Text",
 CellChangeTimes->{{3.4822341378707695`*^9, 3.4822341540168734`*^9}, {
   3.48627191121875*^9, 3.486271916921875*^9}, {3.486273237703125*^9, 
   3.486273247296875*^9}, {3.48627393721875*^9, 3.486273948203125*^9}, {
   3.48627400290625*^9, 3.48627400571875*^9}, {3.48627580659375*^9, 
   3.48627585678125*^9}, {3.48627741071875*^9, 3.486277413734375*^9}, {
   3.48733010359375*^9, 3.487330223296875*^9}, {3.487423140109375*^9, 
   3.487423141265625*^9}, {3.487424196171875*^9, 3.487424216984375*^9}, 
   3.48742455525*^9, 3.487424908*^9, {3.4874251879375*^9, 
   3.48742520103125*^9}, {3.4874253899375*^9, 3.48742540259375*^9}, 
   3.487585241421875*^9, {3.4875860076875*^9, 3.487586010671875*^9}, {
   3.487586264875*^9, 3.487586265359375*^9}, {3.560573727003538*^9, 
   3.560573746395226*^9}, {3.560573873882269*^9, 3.560573874665484*^9}},
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"contr23", "[", 
   RowBox[{"x_", ",", "y_"}], "]"}], "=", 
  RowBox[{
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"newbspfun$cell21", "[", 
       RowBox[{"x", ",", "y"}], "]"}], "[", 
      RowBox[{"[", "7", "]"}], "]"}], ",", 
     RowBox[{
      RowBox[{"x", ">", "3.25"}], "&&", 
      RowBox[{"x", "<", "6.75"}], "&&", 
      RowBox[{"y", ">", "0"}], "&&", 
      RowBox[{"y", "<", "3.5"}]}]}], "]"}], "//", "Expand"}]}]], "Input",
 CellChangeTimes->{{3.560573403413712*^9, 3.560573403545171*^9}, {
  3.560573450584753*^9, 3.560573451211631*^9}, {3.560573506196763*^9, 
  3.560573506343578*^9}, {3.560573601248015*^9, 3.560573601360728*^9}, {
  3.560573669072866*^9, 3.560573692279132*^9}, {3.560573899291329*^9, 
  3.560573902912239*^9}}],

Cell[BoxData[
 RowBox[{"Plot3D", "[", 
  RowBox[{
   RowBox[{"Evaluate", "[", 
    RowBox[{"contr23", "[", 
     RowBox[{"x", ",", "y"}], "]"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "3.25", ",", "6.75"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"y", ",", "0", ",", "3.5"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.487329441375*^9, 3.48732948778125*^9}, {
   3.487329673640625*^9, 3.487329692640625*^9}, {3.487423937546875*^9, 
   3.487423956375*^9}, {3.48742401984375*^9, 3.487424042609375*^9}, {
   3.487424636859375*^9, 3.48742463690625*^9}, {3.487424943328125*^9, 
   3.487424944*^9}, {3.487472634890625*^9, 3.487472637203125*^9}, 
   3.487585307390625*^9, {3.560573907572669*^9, 3.560573907716293*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Contribution from  ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SuperscriptBox[
      SubscriptBox["B", "33"], "3"], "(", 
     RowBox[{"x", ",", "y"}], ")"}], "=", 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       SubscriptBox["B", "3"], "3"], "(", "x", ")"}], " ", 
     RowBox[{
      SuperscriptBox[
       SubscriptBox["B", "3"], "3"], "(", "y", ")"}]}]}], TraditionalForm]]],
 " -8-"
}], "Text",
 CellChangeTimes->{{3.4822341378707695`*^9, 3.4822341540168734`*^9}, {
   3.48627191121875*^9, 3.486271916921875*^9}, {3.486273237703125*^9, 
   3.486273247296875*^9}, {3.48627393721875*^9, 3.486273948203125*^9}, {
   3.48627400290625*^9, 3.48627400571875*^9}, {3.48627580659375*^9, 
   3.48627585678125*^9}, {3.48627741071875*^9, 3.486277413734375*^9}, {
   3.48733010359375*^9, 3.487330223296875*^9}, {3.487423140109375*^9, 
   3.487423141265625*^9}, {3.487424196171875*^9, 3.487424216984375*^9}, 
   3.48742455525*^9, 3.487424908*^9, {3.487425146921875*^9, 
   3.4874251854375*^9}, 3.487425236046875*^9, {3.48747523221875*^9, 
   3.4874752341875*^9}, 3.487585242*^9, {3.487586023921875*^9, 
   3.487586027640625*^9}, {3.4875862738125*^9, 3.487586274265625*^9}, {
   3.560573943370347*^9, 3.560573959137913*^9}},
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"contr33", "[", 
   RowBox[{"x_", ",", "y_"}], "]"}], "=", 
  RowBox[{
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"newbspfun$cell21", "[", 
       RowBox[{"x", ",", "y"}], "]"}], "[", 
      RowBox[{"[", "7", "]"}], "]"}], ",", 
     RowBox[{
      RowBox[{"x", ">", "3.25"}], "&&", 
      RowBox[{"x", "<", "6.75"}], "&&", 
      RowBox[{"y", ">", "0"}], "&&", 
      RowBox[{"y", "<", "3.5"}]}]}], "]"}], "//", "Expand"}]}]], "Input",
 CellChangeTimes->{{3.560573403413712*^9, 3.560573403545171*^9}, {
  3.560573450584753*^9, 3.560573451211631*^9}, {3.560573506196763*^9, 
  3.560573506343578*^9}, {3.560573601248015*^9, 3.560573601360728*^9}, {
  3.560573669072866*^9, 3.560573692279132*^9}, {3.560573899291329*^9, 
  3.560573902912239*^9}, {3.560573933292946*^9, 3.560573933760863*^9}}],

Cell[BoxData[
 RowBox[{"Plot3D", "[", 
  RowBox[{
   RowBox[{"Evaluate", "[", 
    RowBox[{"contr33", "[", 
     RowBox[{"x", ",", "y"}], "]"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "3.25", ",", "6.75"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"y", ",", "0", ",", "3.5"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.487329441375*^9, 3.48732948778125*^9}, {
   3.487329673640625*^9, 3.487329692640625*^9}, {3.487423937546875*^9, 
   3.487423956375*^9}, {3.48742401984375*^9, 3.487424042609375*^9}, {
   3.487424636859375*^9, 3.48742463690625*^9}, {3.487424943328125*^9, 
   3.487424944*^9}, {3.487472787875*^9, 3.487472787984375*^9}, 
   3.487585308171875*^9, {3.560573976971813*^9, 3.560573978336191*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Contribution from  ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SuperscriptBox[
      SubscriptBox["B", "43"], "3"], "(", 
     RowBox[{"x", ",", "y"}], ")"}], "=", 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       SubscriptBox["B", "4"], "3"], "(", "x", ")"}], " ", 
     RowBox[{
      SuperscriptBox[
       SubscriptBox["B", "3"], "3"], "(", "y", ")"}]}]}], TraditionalForm]]],
 " -9-"
}], "Text",
 CellChangeTimes->{{3.4822341378707695`*^9, 3.4822341540168734`*^9}, {
   3.48627191121875*^9, 3.486271916921875*^9}, {3.486273237703125*^9, 
   3.486273247296875*^9}, {3.48627393721875*^9, 3.486273948203125*^9}, {
   3.48627400290625*^9, 3.48627400571875*^9}, {3.48627580659375*^9, 
   3.48627585678125*^9}, {3.48627741071875*^9, 3.486277413734375*^9}, {
   3.48733010359375*^9, 3.487330223296875*^9}, {3.487423140109375*^9, 
   3.487423141265625*^9}, {3.487424196171875*^9, 3.487424216984375*^9}, 
   3.48742455525*^9, 3.487424908*^9, {3.48742520365625*^9, 
   3.487425228453125*^9}, 3.4875852426875*^9, {3.487586036390625*^9, 
   3.487586039125*^9}, {3.48758627775*^9, 3.487586278375*^9}, {
   3.560573989147547*^9, 3.560573998282027*^9}},
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{"x32", "=", 
   RowBox[{"PiecewiseExpand", "[", 
    RowBox[{
     RowBox[{"BSplineBasis", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"degx", ",", "knotsx"}], "}"}], ",", "3", ",", "x"}], "]"}], 
     ",", 
     RowBox[{"Method", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<OrderlessConditions\>\"", "\[Rule]", "False"}], "}"}]}]}],
     "]"}]}]}]], "Input",
 CellChangeTimes->{{3.487328857203125*^9, 3.48732891546875*^9}, {
   3.487329283171875*^9, 3.4873292838125*^9}, {3.48742315628125*^9, 
   3.487423173046875*^9}, {3.487476400015625*^9, 3.48747640334375*^9}, {
   3.5076407801684933`*^9, 3.507640782048654*^9}, 3.5076410907037163`*^9, {
   3.507641791842347*^9, 3.507641802178138*^9}, {3.5076420437612743`*^9, 
   3.507642056965554*^9}, {3.5076421459870872`*^9, 3.507642147692369*^9}, {
   3.507642367840342*^9, 3.5076423684290457`*^9}, {3.507642427633703*^9, 
   3.5076424282030277`*^9}, {3.507642606220871*^9, 3.507642620109704*^9}, {
   3.507642710719696*^9, 3.507642716796031*^9}}],

Cell[BoxData[
 RowBox[{"y22", "=", 
  RowBox[{"PiecewiseExpand", "[", 
   RowBox[{
    RowBox[{"BSplineBasis", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"degy", ",", "knotsy"}], "}"}], ",", "2", ",", "y"}], "]"}], 
    ",", 
    RowBox[{"Method", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<OrderlessConditions\>\"", "\[Rule]", "False"}], "}"}]}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.5076413804671583`*^9, 3.507641424484048*^9}, 
   3.507642176071506*^9, {3.507642374557438*^9, 3.507642375136229*^9}, {
   3.5076424341344023`*^9, 3.507642434734302*^9}, {3.507642914216853*^9, 
   3.507642919365522*^9}}],

Cell[BoxData[
 RowBox[{"x32", "[", 
  RowBox[{"[", 
   RowBox[{"1", ",", "1", ",", "1"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.487329287421875*^9, 3.487329320609375*^9}, {
  3.4874231620625*^9, 3.48742317528125*^9}, {3.48742492109375*^9, 
  3.48742492115625*^9}, {3.4874728295*^9, 3.487472841375*^9}, {
  3.48747731109375*^9, 3.4874773121875*^9}}],

Cell[BoxData[
 RowBox[{"y22", "[", 
  RowBox[{"[", 
   RowBox[{"1", ",", "1", ",", "1"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.487329287421875*^9, 3.48732934740625*^9}, {
  3.487423184609375*^9, 3.487423193140625*^9}, {3.487424630140625*^9, 
  3.4874246301875*^9}, {3.487472858125*^9, 3.4874728583125*^9}, {
  3.487475291421875*^9, 3.487475292*^9}, {3.487477316578125*^9, 
  3.487477317421875*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"contr3222", "[", 
   RowBox[{"x_", ",", "y_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"newbspfun$cella21", "[", 
      RowBox[{"x", ",", "y"}], "]"}], "[", 
     RowBox[{"[", 
      RowBox[{"9", ",", "1"}], "]"}], "]"}], " ", 
    RowBox[{"x32", "[", 
     RowBox[{"[", 
      RowBox[{"1", ",", "1", ",", "1"}], "]"}], "]"}], "*", 
    RowBox[{"y22", "[", 
     RowBox[{"[", 
      RowBox[{"1", ",", "1", ",", "1"}], "]"}], "]"}]}], "//", 
   "Expand"}]}]], "Input",
 CellChangeTimes->{{3.487329362890625*^9, 3.48732938684375*^9}, {
   3.487329423734375*^9, 3.487329436046875*^9}, {3.48732952375*^9, 
   3.487329528625*^9}, {3.487329559171875*^9, 3.4873295604375*^9}, {
   3.48742355396875*^9, 3.4874235681875*^9}, 3.48742361215625*^9, {
   3.4874239293125*^9, 3.48742394953125*^9}, {3.487424633609375*^9, 
   3.48742463365625*^9}, {3.48742467096875*^9, 3.4874246719375*^9}, {
   3.48742470909375*^9, 3.48742470990625*^9}, {3.487424927046875*^9, 
   3.487424934890625*^9}, {3.48747287328125*^9, 3.48747288740625*^9}, {
   3.48747391034375*^9, 3.487473928265625*^9}, {3.48747456321875*^9, 
   3.4874745640625*^9}, {3.48747529525*^9, 3.48747529571875*^9}, {
   3.487477328421875*^9, 3.48747733209375*^9}, 3.487585308609375*^9}],

Cell[BoxData[
 RowBox[{"Plot3D", "[", 
  RowBox[{
   RowBox[{"Evaluate", "[", 
    RowBox[{"contr3222", "[", 
     RowBox[{"x", ",", "y"}], "]"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "3.25", ",", "6.75"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"y", ",", "0", ",", "3.5"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.487329441375*^9, 3.48732948778125*^9}, {
   3.487329673640625*^9, 3.487329692640625*^9}, {3.487423937546875*^9, 
   3.487423956375*^9}, {3.48742401984375*^9, 3.487424042609375*^9}, {
   3.487424636859375*^9, 3.48742463690625*^9}, {3.487424943328125*^9, 
   3.487424944*^9}, {3.487472891453125*^9, 3.487472895015625*^9}, 
   3.487585309*^9}]
}, Open  ]],

Cell["Finally, under explicit polynomial representation  ", "Text",
 CellChangeTimes->{{3.487475426671875*^9, 3.4874754603125*^9}, {
  3.487585622453125*^9, 3.48758566153125*^9}},
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"contr21totpol", "[", 
   RowBox[{"x_", ",", "y_"}], "]"}], "=", " ", 
  RowBox[{
   RowBox[{"contr1202", "[", 
    RowBox[{"x", ",", "y"}], "]"}], " ", "+", " ", 
   RowBox[{"contr2202", "[", 
    RowBox[{"x", ",", "y"}], "]"}], " ", "+", " ", 
   RowBox[{"contr3202", "[", 
    RowBox[{"x", ",", "y"}], "]"}], " ", "+", "\[IndentingNewLine]", 
   "                                                    ", 
   RowBox[{"contr1212", "[", 
    RowBox[{"x", ",", "y"}], "]"}], " ", "+", " ", 
   RowBox[{"contr2212", "[", 
    RowBox[{"x", ",", "y"}], "]"}], " ", "+", " ", 
   RowBox[{"contr3212", "[", 
    RowBox[{"x", ",", "y"}], "]"}], " ", "+", "\[IndentingNewLine]", 
   "                                                     ", 
   RowBox[{"contr1222", "[", 
    RowBox[{"x", ",", "y"}], "]"}], " ", "+", " ", 
   RowBox[{"contr2222", "[", 
    RowBox[{"x", ",", "y"}], "]"}], " ", "+", " ", 
   RowBox[{"contr3222", "[", 
    RowBox[{"x", ",", "y"}], "]"}], " "}]}]], "Input",
 CellChangeTimes->{{3.487329441375*^9, 3.48732948778125*^9}, {
  3.487329673640625*^9, 3.487329692640625*^9}, {3.487423937546875*^9, 
  3.487423956375*^9}, {3.48742401984375*^9, 3.487424042609375*^9}, {
  3.487424636859375*^9, 3.48742463690625*^9}, {3.487424943328125*^9, 
  3.487424944*^9}, {3.487472891453125*^9, 3.487472895015625*^9}, {
  3.48747294890625*^9, 3.48747316265625*^9}, {3.487473967046875*^9, 
  3.487473975375*^9}, {3.487475366171875*^9, 3.487475370671875*^9}, {
  3.48758532434375*^9, 3.487585328890625*^9}, {3.487585697765625*^9, 
  3.487585701578125*^9}, {3.487585900765625*^9, 3.48758590784375*^9}}],

Cell[BoxData[
 RowBox[{"graph2", " ", "=", 
  RowBox[{"Plot3D", "[", 
   RowBox[{
    RowBox[{"contr21totpol", "[", 
     RowBox[{"x", ",", "y"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "3.25", ",", "6.75"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"y", ",", "0", ",", "3.5"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.487329441375*^9, 3.48732948778125*^9}, {
   3.487329673640625*^9, 3.487329692640625*^9}, {3.487423937546875*^9, 
   3.487423956375*^9}, {3.48742401984375*^9, 3.487424042609375*^9}, {
   3.487424636859375*^9, 3.48742463690625*^9}, {3.487424943328125*^9, 
   3.487424944*^9}, {3.487472891453125*^9, 3.487472895015625*^9}, {
   3.487474261625*^9, 3.487474283484375*^9}, 3.487585329640625*^9, {
   3.487585725*^9, 3.487585725421875*^9}, {3.487585761125*^9, 
   3.487585764453125*^9}, {3.487586996984375*^9, 3.487586999125*^9}}],

Cell[" graph1 and graph2 can be compared with graph3", "Text",
 CellChangeTimes->{{3.487475426671875*^9, 3.4874754603125*^9}, {
  3.487585622453125*^9, 3.48758566153125*^9}, {3.48758703784375*^9, 
  3.487587065171875*^9}, {3.572683924846302*^9, 3.5726839300135975`*^9}},
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{"graph3", "=", 
  RowBox[{"Plot3D", "[", 
   RowBox[{
    RowBox[{"biparab", "[", 
     RowBox[{"x", ",", "y"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "3.25", ",", "6.75"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"y", ",", "0", ",", "3.5"}], "}"}], ",", 
    RowBox[{"PlotPoints", "\[Rule]", "50"}]}], "]"}]}]], "Input",
 CellChangeTimes->{
  3.482232990035215*^9, {3.4826681219375*^9, 3.482668132734375*^9}, {
   3.48275020646875*^9, 3.482750206875*^9}, {3.482753649875*^9, 
   3.482753654828125*^9}, {3.48284233740625*^9, 3.4828423414375*^9}, 
   3.48758544496875*^9, 3.487585484046875*^9, {3.48758689475*^9, 
   3.4875869086875*^9}, {3.4875870074375*^9, 3.48758701103125*^9}}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"tfin", " ", "=", 
  RowBox[{"DateList", "[", "]"}]}]], "Input",
 CellChangeTimes->{{3.507638323141736*^9, 3.507638324489011*^9}, {
  3.507726020156249*^9, 3.507726052975444*^9}}],

Cell[BoxData[
 RowBox[{"\[CapitalDelta]t", " ", "=", " ", 
  RowBox[{"tfin", " ", "-", "tinit"}]}]], "Input",
 CellChangeTimes->{{3.50772605901812*^9, 3.507726072293767*^9}, 
   3.507726136730954*^9}]
},
AutoGeneratedPackage->None,
CellGrouping->Manual,
WindowSize->{1438, 813},
WindowMargins->{{144, Automatic}, {Automatic, 59}},
Magnification->1.5,
FrontEndVersion->"9.0 for Linux x86 (64-bit) (January 25, 2013)",
StyleDefinitions->"Zosi-direi-buono.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[557, 20, 465, 11, 98, "Text"],
Cell[1025, 33, 4354, 93, 955, "Text"],
Cell[5382, 128, 1690, 29, 249, "Text"],
Cell[7075, 159, 2102, 46, 110, "Text"],
Cell[9180, 207, 1358, 23, 70, "Text"],
Cell[10541, 232, 294, 6, 45, "Input"],
Cell[10838, 240, 104, 1, 45, "Input"],
Cell[10945, 243, 215, 4, 45, "Input"],
Cell[11163, 249, 1315, 21, 106, "Text"],
Cell[CellGroupData[{
Cell[12503, 274, 1206, 18, 70, "Text"],
Cell[13712, 294, 6088, 186, 249, "Input"],
Cell[19803, 482, 300, 7, 75, "Input"],
Cell[20106, 491, 256, 6, 75, "Input"],
Cell[20365, 499, 193, 4, 45, "Input"],
Cell[20561, 505, 163, 3, 70, "Text"],
Cell[20727, 510, 387, 8, 45, "Input"],
Cell[21117, 520, 146, 3, 70, "Text"],
Cell[21266, 525, 683, 16, 45, "Input"],
Cell[21952, 543, 414, 8, 70, "Text"],
Cell[22369, 553, 419, 10, 45, "Input"],
Cell[22791, 565, 769, 16, 45, "Input"],
Cell[23563, 583, 153, 3, 45, "Input"]
}, Open  ]],
Cell[23731, 589, 1316, 21, 106, "Text"],
Cell[CellGroupData[{
Cell[25072, 614, 1773, 31, 189, "Text"],
Cell[26848, 647, 347, 12, 71, "Text"],
Cell[27198, 661, 246, 6, 45, "Input"],
Cell[CellGroupData[{
Cell[27469, 671, 153, 3, 70, "Text"],
Cell[27625, 676, 369, 7, 45, "Input"]
}, Open  ]],
Cell[28009, 686, 180, 3, 70, "Text"],
Cell[28192, 691, 455, 9, 75, "Input"],
Cell[CellGroupData[{
Cell[28672, 704, 642, 14, 129, "Text"],
Cell[29317, 720, 2786, 68, 220, "Input"]
}, Open  ]],
Cell[32118, 791, 1677, 30, 289, "Text"],
Cell[33798, 823, 662, 10, 70, "Text"],
Cell[34463, 835, 997, 23, 75, "Input"],
Cell[CellGroupData[{
Cell[35485, 862, 884, 16, 70, "Text"],
Cell[36372, 880, 1291, 30, 136, "Input"],
Cell[37666, 912, 1346, 30, 136, "Input"],
Cell[39015, 944, 1270, 29, 136, "Input"],
Cell[40288, 975, 1321, 30, 136, "Input"]
}, Open  ]],
Cell[41624, 1008, 758, 21, 76, "Text"],
Cell[42385, 1031, 2488, 60, 264, "Input"],
Cell[44876, 1093, 852, 15, 70, "Text"],
Cell[45731, 1110, 2995, 75, 249, "Input"],
Cell[48729, 1187, 1192, 27, 136, "Input"],
Cell[49924, 1216, 1399, 31, 136, "Input"],
Cell[51326, 1249, 1401, 31, 136, "Input"],
Cell[52730, 1282, 1397, 31, 136, "Input"],
Cell[54130, 1315, 1401, 31, 136, "Input"],
Cell[55534, 1348, 1399, 31, 136, "Input"],
Cell[56936, 1381, 826, 22, 76, "Text"],
Cell[57765, 1405, 3274, 82, 296, "Input"],
Cell[61042, 1489, 461, 9, 100, "Text"],
Cell[61506, 1500, 1518, 37, 104, "Input"],
Cell[CellGroupData[{
Cell[63049, 1541, 600, 11, 100, "Text"],
Cell[63652, 1554, 223, 4, 45, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[63912, 1563, 382, 6, 70, "Text"],
Cell[64297, 1571, 1330, 34, 104, "Input"],
Cell[65630, 1607, 483, 11, 102, "Text"],
Cell[66116, 1620, 190, 4, 45, "Input"],
Cell[66309, 1626, 501, 11, 70, "Text"],
Cell[66813, 1639, 1323, 25, 45, "Input"]
}, Open  ]]
}, Open  ]],
Cell[68163, 1668, 1369, 22, 106, "Text"],
Cell[CellGroupData[{
Cell[69557, 1694, 1614, 28, 188, "Text"],
Cell[71174, 1724, 1195, 30, 104, "Input"],
Cell[72372, 1756, 242, 5, 45, "Input"],
Cell[72617, 1763, 817, 16, 45, "Input"],
Cell[CellGroupData[{
Cell[73459, 1783, 1806, 49, 199, "Text"],
Cell[75268, 1834, 755, 19, 75, "Input"],
Cell[76026, 1855, 640, 14, 45, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[76703, 1874, 1225, 30, 74, "Text"],
Cell[77931, 1906, 804, 20, 75, "Input"],
Cell[78738, 1928, 640, 14, 45, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[79415, 1947, 1227, 30, 74, "Text"],
Cell[80645, 1979, 612, 17, 75, "Input"],
Cell[81260, 1998, 685, 15, 45, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[81982, 2018, 1223, 30, 74, "Text"],
Cell[83208, 2050, 707, 18, 75, "Input"],
Cell[83918, 2070, 641, 14, 45, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[84596, 2089, 1187, 29, 74, "Text"],
Cell[85786, 2120, 707, 18, 75, "Input"],
Cell[86496, 2140, 682, 15, 45, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[87215, 2160, 1285, 31, 74, "Text"],
Cell[88503, 2193, 756, 19, 75, "Input"],
Cell[89262, 2214, 729, 15, 45, "Input"]
}, Open  ]],
Cell[90006, 2232, 66, 4, 76, "Text"],
Cell[CellGroupData[{
Cell[90097, 2240, 1325, 31, 74, "Text"],
Cell[91425, 2273, 805, 20, 75, "Input"],
Cell[92233, 2295, 731, 15, 45, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[93001, 2315, 1300, 31, 74, "Text"],
Cell[94304, 2348, 851, 20, 75, "Input"],
Cell[95158, 2370, 728, 15, 45, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[95923, 2390, 1228, 30, 74, "Text"],
Cell[97154, 2422, 1053, 22, 45, "Input"],
Cell[98210, 2446, 633, 16, 45, "Input"],
Cell[98846, 2464, 356, 7, 45, "Input"],
Cell[99205, 2473, 407, 8, 45, "Input"],
Cell[99615, 2483, 1285, 28, 45, "Input"],
Cell[100903, 2513, 681, 15, 96, "Input"]
}, Open  ]],
Cell[101599, 2531, 224, 4, 153, "Text"],
Cell[101826, 2537, 1633, 33, 220, "Input"],
Cell[103462, 2572, 870, 17, 96, "Input"],
Cell[104335, 2591, 315, 5, 153, "Text"],
Cell[104653, 2598, 723, 16, 96, "Input"]
}, Open  ]],
Cell[105391, 2617, 202, 4, 96, "Input"],
Cell[105596, 2623, 200, 4, 96, "Input"]
}
]
*)

(* End of internal cache information *)
