(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     42631,        852]
NotebookOptionsPosition[     41519,        810]
NotebookOutlinePosition[     41887,        826]
CellTagsIndexPosition[     41844,        823]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["\<\
This nb examines how  the ouput  of a second order linear system
depends on the natural frequency \[Omega]n, the damping factor  \[Zeta] and 
the Initial Conditions.\
\>", "Text",
 CellChangeTimes->{{3.489579710921875*^9, 3.489579718984375*^9}, {
  3.489579754421875*^9, 3.4895798570625*^9}, {3.489579910328125*^9, 
  3.48957998371875*^9}},
 FontSize->24,
 Background->RGBColor[0.9, 1, 1]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Remove", "[", "\"\<Global`*\>\"", "]"}], ";", 
  RowBox[{"$Line", "=", "0"}]}]], "Input",
 CellChangeTimes->{{3.489406524234375*^9, 3.48940656078125*^9}, 
   3.48940662253125*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Remove", "::", "rmnsm"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"There are no symbols matching \
\\\"\[NoBreak]\\!\\(\\\"Global`*\\\"\\)\[NoBreak]\\\". \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/Remove/rmnsm\\\", \
ButtonNote -> \\\"Remove::rmnsm\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.571982148623658*^9, 3.571984423565884*^9, 
  3.571984467483797*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.489646441375*^9, 3.571921082673484*^9, 
  3.5719211583645487`*^9, 3.571921429511116*^9, 3.571982148813757*^9, 
  3.57198442362225*^9, 3.571984467539311*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"SetOptions", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"Plot", ",", "ListPlot"}], "}"}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "600"}], ",", "\[IndentingNewLine]", " ", 
     RowBox[{"LabelStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}], ",", "Red", 
        ",", 
        RowBox[{"FontSize", "\[Rule]", "32"}]}], "}"}]}], ",", 
     RowBox[{"AxesStyle", "\[Rule]", 
      RowBox[{"Directive", "[", 
       RowBox[{"24", ",", 
        RowBox[{"Thickness", "[", "0.005", "]"}], ",", "Blue"}], "]"}]}]}], 
    "]"}], ";"}], "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{{3.571893688446418*^9, 3.571893720823801*^9}, {
  3.571893769281314*^9, 3.571893778333867*^9}, {3.571897057593268*^9, 
  3.571897058441244*^9}, {3.571897120614431*^9, 3.571897124212874*^9}, {
  3.571897252876203*^9, 3.5718972925170116`*^9}, {3.571897380576166*^9, 
  3.571897381622324*^9}, {3.571897598970675*^9, 3.57189760324011*^9}, {
  3.571897659591607*^9, 3.571897660968927*^9}, {3.571912117646233*^9, 
  3.571912118586385*^9}, {3.5719155776674633`*^9, 3.571915578126437*^9}},
 FontSize->18,
 Background->RGBColor[1, 1, 0.85]],

Cell[CellGroupData[{

Cell["\<\
Subcase 4 :  \[Zeta]   > 1    (eq. 5.2.42)\
\>", "Text",
 CellChangeTimes->{{3.489572376234375*^9, 3.4895724029375*^9}, {
  3.489572459359375*^9, 3.489572464203125*^9}, {3.4895725311875*^9, 
  3.4895725530625*^9}, {3.4895726841875*^9, 3.48957275271875*^9}, {
  3.571920899390747*^9, 3.571920902735676*^9}},
 FontSize->24,
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   SubscriptBox["x", "0"], "=", " ", ".1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   SubscriptBox[
    OverscriptBox["x", "."], "0"], "=", " ", "1.2"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Zeta]", " ", "=", " ", "1.3"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"f", "=", " ", "2"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   SubscriptBox["\[Omega]", "n"], "=", " ", 
   RowBox[{"2", " ", "\[Pi]", " ", "f"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.489406629609375*^9, 3.489406707953125*^9}, 
   3.489407198859375*^9, {3.489407245078125*^9, 3.48940730809375*^9}, {
   3.4894075081875*^9, 3.489407547046875*^9}, {3.48940764034375*^9, 
   3.4894076799375*^9}, {3.489407850390625*^9, 3.48940792928125*^9}, {
   3.489408593828125*^9, 3.489408811609375*^9}, {3.489408862921875*^9, 
   3.48940886628125*^9}, {3.489409203609375*^9, 3.489409207765625*^9}, {
   3.4894097105625*^9, 3.489410007234375*^9}, {3.489410051671875*^9, 
   3.48941014675*^9}, {3.489410179625*^9, 3.489410182640625*^9}, {
   3.489573274125*^9, 3.489573286046875*^9}, {3.48957333471875*^9, 
   3.4895733381875*^9}, {3.4895736060625*^9, 3.489573609734375*^9}, 
   3.4895786155*^9, {3.489646390203125*^9, 3.48964639615625*^9}, {
   3.489646431109375*^9, 3.48964643546875*^9}, {3.5719208140313683`*^9, 
   3.571920880879764*^9}, {3.571921015804723*^9, 3.57192106107207*^9}, 
   3.571921099018586*^9, 3.57192118699765*^9, 3.5719221753696423`*^9},
 FontSize->18]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  SubscriptBox["C", "1"], "=", 
  FractionBox[
   RowBox[{
    RowBox[{
     SubscriptBox["x", "0"], " ", 
     SubscriptBox["\[Omega]", "n"], " ", 
     RowBox[{"(", 
      RowBox[{"\[Zeta]", "  ", "+", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["\[Zeta]", "2"], "-", "1"}]]}], ")"}]}], "+", 
    SubscriptBox[
     OverscriptBox["x", "."], "0"]}], 
   RowBox[{"2", " ", 
    SubscriptBox["\[Omega]", "n"], " ", 
    SqrtBox[
     RowBox[{
      SuperscriptBox["\[Zeta]", "2"], "-", "1"}]], " "}]], " "}]], "Input",
 CellChangeTimes->{{3.489406629609375*^9, 3.489406707953125*^9}, 
   3.489407198859375*^9, {3.489407245078125*^9, 3.48940730809375*^9}, {
   3.4894075081875*^9, 3.489407547046875*^9}, {3.48940764034375*^9, 
   3.4894076799375*^9}, {3.489407850390625*^9, 3.48940792928125*^9}, {
   3.489408593828125*^9, 3.489408811609375*^9}, {3.489408862921875*^9, 
   3.48940886628125*^9}, {3.489409203609375*^9, 3.489409207765625*^9}, {
   3.4894097105625*^9, 3.489410007234375*^9}, {3.489410051671875*^9, 
   3.48941014675*^9}, {3.489410179625*^9, 3.489410182640625*^9}, {
   3.489573274125*^9, 3.489573286046875*^9}, {3.48957333471875*^9, 
   3.4895733381875*^9}, {3.4895736060625*^9, 3.489573609734375*^9}, 
   3.4895786155*^9, {3.489646390203125*^9, 3.48964639615625*^9}, {
   3.489646431109375*^9, 3.48964643546875*^9}, {3.5719208140313683`*^9, 
   3.571920880879764*^9}, {3.571921015804723*^9, 3.57192106107207*^9}, 
   3.571921099018586*^9, {3.57192118699765*^9, 3.571921200151537*^9}, {
   3.571921460893515*^9, 3.57192147392159*^9}, 3.571922179213875*^9},
 FontSize->18],

Cell[BoxData["0.18573081529655455`"], "Output",
 CellChangeTimes->{{3.5719211912456493`*^9, 3.571921207964202*^9}, 
   3.5719214296413803`*^9, 3.5719215294972258`*^9, 3.571982148894574*^9, 
   3.571984423771446*^9, 3.5719844676487427`*^9}]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   SubscriptBox["C", "2"], "=", 
   FractionBox[
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       SubscriptBox["x", "0"]}], " ", 
      SubscriptBox["\[Omega]", "n"], " ", 
      RowBox[{"(", 
       RowBox[{"\[Zeta]", "  ", "-", 
        SqrtBox[
         RowBox[{
          SuperscriptBox["\[Zeta]", "2"], "-", "1"}]]}], ")"}]}], "-", 
     SubscriptBox[
      OverscriptBox["x", "."], "0"]}], 
    RowBox[{"2", " ", 
     SubscriptBox["\[Omega]", "n"], " ", 
     SqrtBox[
      RowBox[{
       SuperscriptBox["\[Zeta]", "2"], "-", "1"}]], " "}]]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"g4", "[", "t_", "]"}], ":=", 
   RowBox[{
    RowBox[{
     SubscriptBox["C", "1"], "  ", 
     RowBox[{"Exp", "[", "  ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "\[Zeta]"}], "  ", "+", 
         SqrtBox[
          RowBox[{
           SuperscriptBox["\[Zeta]", "2"], "-", "1"}]]}], ")"}], 
       SubscriptBox["\[Omega]", "n"], "  ", "t"}], "]"}]}], "+", 
    RowBox[{
     SubscriptBox["C", "2"], "  ", 
     RowBox[{"Exp", "[", "  ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "\[Zeta]"}], "  ", "-", 
         SqrtBox[
          RowBox[{
           SuperscriptBox["\[Zeta]", "2"], "-", "1"}]]}], ")"}], " ", 
       SubscriptBox["\[Omega]", "n"], "  ", "t"}], "]"}]}]}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.489406629609375*^9, 3.489406707953125*^9}, 
   3.489407198859375*^9, {3.489407245078125*^9, 3.48940730809375*^9}, {
   3.4894075081875*^9, 3.489407547046875*^9}, {3.48940764034375*^9, 
   3.4894076799375*^9}, {3.489407850390625*^9, 3.48940792928125*^9}, {
   3.489408593828125*^9, 3.489408811609375*^9}, {3.489408862921875*^9, 
   3.48940886628125*^9}, {3.489409203609375*^9, 3.489409207765625*^9}, {
   3.4894097105625*^9, 3.489410007234375*^9}, {3.489410051671875*^9, 
   3.48941014675*^9}, {3.489410179625*^9, 3.489410182640625*^9}, {
   3.489573274125*^9, 3.489573286046875*^9}, {3.48957333471875*^9, 
   3.4895733381875*^9}, {3.4895736060625*^9, 3.489573609734375*^9}, 
   3.4895786155*^9, {3.489646390203125*^9, 3.48964639615625*^9}, {
   3.489646431109375*^9, 3.48964643546875*^9}, {3.5719208140313683`*^9, 
   3.571920880879764*^9}, {3.571921015804723*^9, 3.57192106107207*^9}, 
   3.571921099018586*^9, {3.57192118699765*^9, 3.571921222670463*^9}, {
   3.571921438276711*^9, 3.571921446120137*^9}, {3.571921481427124*^9, 
   3.5719214990823517`*^9}, 3.571982110291822*^9},
 FontSize->18],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"gra4", " ", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"g4", "[", "t", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", 
      RowBox[{"-", "0"}], ",", "1"}], "}"}], ",", 
    RowBox[{"ImageSize", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"700", ",", "800"}], "}"}]}], ",", "\[IndentingNewLine]", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", " ", 
      RowBox[{"\"\<t [s]\>\"", ",", " ", "\"\<amp [m]\>\""}], "  ", "}"}]}], 
    ",", "\[IndentingNewLine]", " ", 
    RowBox[{"PlotStyle", " ", "\[Rule]", " ", 
     RowBox[{"Thickness", "[", "0.004", "]"}]}], ",", "\[IndentingNewLine]", 
    RowBox[{"PlotLabel", "\[Rule]", 
     RowBox[{"Style", "[", 
      RowBox[{
      "\"\< \!\(\*SubscriptBox[\(C\), \(1\)]\)  Exp[  (-\[Zeta]  \
+\!\(\*SqrtBox[\(\*SuperscriptBox[\(\[Zeta]\), \(2\)] - \
1\)]\))\!\(\*SubscriptBox[\(\[Omega]\), \(n\)]\)  t] + \n                 \
\!\(\*SubscriptBox[\(C\), \(2\)]\)  Exp[  (-\[Zeta]  \
-\!\(\*SqrtBox[\(\*SuperscriptBox[\(\[Zeta]\), \(2\)] - 1\)]\)) \
\!\(\*SubscriptBox[\(\[Omega]\), \(n\)]\)  t]  \>\"", ",", "Blue", ",", 
       "30"}], "]"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.489406629609375*^9, 3.489406707953125*^9}, 
   3.489407198859375*^9, {3.489407245078125*^9, 3.48940730809375*^9}, {
   3.4894075081875*^9, 3.489407547046875*^9}, {3.48940764034375*^9, 
   3.4894076799375*^9}, {3.489407850390625*^9, 3.48940792928125*^9}, {
   3.489408593828125*^9, 3.489408811609375*^9}, {3.489408862921875*^9, 
   3.48940886628125*^9}, {3.489409203609375*^9, 3.489409207765625*^9}, {
   3.4894097105625*^9, 3.489410007234375*^9}, {3.489410051671875*^9, 
   3.48941014675*^9}, {3.489410179625*^9, 3.489410182640625*^9}, {
   3.489573274125*^9, 3.489573286046875*^9}, {3.48957333471875*^9, 
   3.4895733381875*^9}, {3.4895736060625*^9, 3.489573609734375*^9}, 
   3.4895786155*^9, {3.489646390203125*^9, 3.48964639615625*^9}, {
   3.489646431109375*^9, 3.48964643546875*^9}, {3.5719208140313683`*^9, 
   3.571920880879764*^9}, {3.571921015804723*^9, 3.57192106107207*^9}, {
   3.571921099018586*^9, 3.571921103798553*^9}, {3.5719214137544947`*^9, 
   3.571921417119095*^9}, {3.5719215136283083`*^9, 3.571921522869952*^9}, {
   3.571921580682869*^9, 3.571921685814435*^9}, {3.571921751706056*^9, 
   3.571921753567889*^9}, {3.571982116584848*^9, 3.5719821171005697`*^9}, {
   3.571982168730337*^9, 3.5719821963043528`*^9}, {3.571984409888345*^9, 
   3.571984418258066*^9}},
 FontSize->18],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], Thickness[0.004], LineBox[CompressedData["
1:eJwVk3k4lA0bxWUp+1J6Q9YsL5K0KSVnBmVXKEolSYslihaltyIjlbFE9nUG
WZJki5lnkvVLlgpR1uQToodKyBvffH/c1339/jvnPvdRcfO1P8XLw8NTzJ3/
b8tTo2+rxw4ayZ35D29SYiX4TeTOD8huRa7m8+P04kpsSU9IKZE1hY8JvUL7
VSWsWrqepcoeQIDYco/Ts5Vwcp8lHsi6QyZFYOrXvirUmchV1Kacxk5asvW+
U1XQU9399KeSBxpSA1KcrlVBcCiY4ajhA+1dtj+vMavQt/GOCV32IgYCFUyU
v1chNl2mWv3IJXj7h/OJCrBgKZFvyEm5jDHddOvCNSyUf2veRipdherGo3+v
MmQhonClpp3GDRjN/H35RhALGav3hd6TDcFtByum2xILgS3xdY5VISgwUQr+
KcaGI22QV/UIDavvqPLvlWdDdObCTVZKKBKn11lq72AjoCM2YELpLoxefeIV
PMeGQ3hf+fPqu8i1k9R6dJUNXVONmZAT9+Bev/q2cCgbwyUVFxSY9+H8YpFP
OY0Nu5iPnrYaEVj50Nru4Ws2dKxU8+QaIxCsF69/6j0bgnzeX0bORCJn1iH2
zyAbxysXi18ciMKRGLL+7gwbq7WidA/FRUOcxaOoKE+Al1ZqwxmJRuyV5V+h
TmBqsNtbbfsDVFwa36CrS+B1gkrBVNcD/Fb9tHQBBIIES/6+KxsLQyWKQNZx
Atpm0WHPzsfizYZjKV1nCLyj+Y71NMbChzoq1u5LQI1Pp0D38kN812lvVL1J
oJkqLHqo5SHCPHP0roUSuHRr1DtILQ7udzpKk+gEGv5k6Xa8iwMtsIVqmEzA
1/B25B+teFQ45rtyMgnIBJ6Y0giKB31apFE0l4DHnMKzqxsTwJLJDZMsJSD6
I26bUngi1Cz8fWpeESjbdCnO/HMibnkFnihrJeBy3mH2ws4k7Pg+9zygnUDR
pERl3WgSyvcZ0P16CRzS+Sb7DckoNhfnyx8kwOPVfG1NfDJU1we3lQwTsB8N
M/Tck4JWmQU7ygSBBY0zqTEpKXDsWTVXSxLIOrVnkf0jBREr5jrW/iAwM7Ss
WoKRit/Oliss5wmkqQwqG8ynQnhc0VTlXwJ7XTlBbvvTkBEXFdq6SCCh75pJ
2WIa2BkhA4/5OKDKH87qP5iOFGfxzn4BDsadtwsIFqZjlGEeMbqCg6Zm4RIZ
3gwon9MJaBLiQHHi6snCDRloi3i2GCLCgZ/I2CrjwxlQFHofLiPGQYP2obr3
IRnYbBMXThPnQM6y8aLX0wy4BM6fbpbgwNdDX52nNwNGqeIhk5Ic1IVld8au
yMTLj6TlmBQHMrnSoVpbMrEuv06leiUH3o239TkumVi+UHvObxUH1SPfR+zv
ZSLmqH4MjzQH0svd4r+UZSJHMWDGk8se6m/Nrn/KBMVn4VcxlzmmlDlJMQbk
z1nOd3J5pXtRbvYOBsJMhY51cfn0bcXDO90ZCNkyF1TOZRaDLtQWyYBewkyD
P5cla/6tPMli4MnPpbsSXHb/5OU5N8KAI7ld8x5Xz3OeHjn6SiZcbIf+fObq
FVW2fK1ixIQs6XFagcuuqAws92CC8fwEW5/rr8xFU8fqIRPa90IP63H9C9+I
7x2oZqJT7WWcMPc+LqnL6RcnmLCT0myu597zGfvSbiGZLIgGLbNzE+Vgee/w
ZKpJFpTW1wcOCnPgvOCQttk3C2vVFRkUbj5FcrW2jUlZCKqYkLnNze/Q4cyi
qeksnMm6ZfaUmzfZc0CYIZeNl3Mf3r1YxkGoi+ApB5NszJ8VSCxfIlBy0leu
PDYbAuH2fc4LBCxH1l06Q2RDsquxT5D7X4Nn37fJjGQjou+5QvovAuI+u2mB
23PA3B3uTJsmkD01NaDjmgOh/Tadnd8IGPpn7ewPy4HxuMV9Ce4/ewaITFE+
5mD/ek4aRgjUB39wXv7PI7h5ui8mfCBwVIBeVpH9CCWbMqYN3hP4foci6dH6
CK/o/Iv17wgo0x/Vv1bKxbasG2YZrwlcj7+kF12TC83ryxpOsglsfiy1XF4w
H+byQesckwi80q13bdHLh1Nr+O2ahwRciwNYNw7nY3P+rLNCNAF6+cD5T/n5
0FvU2pp+h8BodWFPjk0B5myvj3f7c/vUaVG8KeYxDhoxu20sCIgsBR01UyxC
387CPRfH2EjwcHLR2VsE0S7XaM3PbKh16LhK+RTBxqiH8raXDaO8rpM9RBHY
YoWHeN6wUZkXV1ah+xS/ak4afChjY9Jhgm3V+hRvjohsjrnJxsHc+Nf+Ys8g
PqZL8IuyoW73bbT2filahb8YTYqzcKXVAAk/K3F+ox1/YvFzrCmV6l+27AU+
n9hqscerHOVDJs1thjUwfPRDb4dQKWo8U9cenqhDc+Cm4KWPxZjR2C1ReK4R
BzaF/gpfKALvfIHkWvUmFAm8En1s/xj6S67lDk+aoT3y85UdNQ/NIVtbG7Tb
cPXFyNw7eg6Uor7O5317g62z6Ulbppj4OjvQ36n3DklqkfvW1mUia5zVJB7R
jrPbOoU3HU6HuMIjcni4A32Of2V5VSQj3KPsdIbae/hE+h+ULkvAL0rB8Nmb
XXj98uP0pbaHuLi5rvSv2m6YtqwQqPKIwcCTuvtvVT5iLqKfeUM+GgueHcla
13owsN89bmBXBNZTVyyeZvVC590Gp6Zv92DGUDlTvKYf1i+Si71r7uCKwvF1
n44O4EK9PidiHQ06EwdFumwGEWUhzZjtCsYqiSnBut+DMH9JJlswb4H/RXKR
asonyNSa7t2R8Q+8trI+CFkNwbBLTntM8RoKLNwyOL+GQHhJnziw+gpmvspJ
jsR9hpp1fWNj9EWUOZjxxZoO44Gyu2G3hh9umtPSS0eGofCrP+OLxnmo9Fl2
M2n/xf6hMu38Nm/s3B4SK7t5BB1BAbv9/TxwVLFtfln7CAxXXdb6kHcaM030
ofNBX9DYsqFU6c9JJPC7XLRXG4WpLe/sSMMJrOovY/DWjUKU0bLJuvg4BP4J
OmBwYQzxFWaE5O8j4MlzKRpaOY5EwzArrS+H4JdURF9ZM87twRZa5Y+DINaH
CUr5fMXFsbdZW085QMrSTydYfAJNtePaEWZ26N3wpv0qewK8zHpq8j+2eJoG
tWGXSUg2Xf9uoGyFY0X6UgqLk9izfWBKUc8ct2iZQb353yDZyqqePbIHhaMK
yeLWJByM36t38JsgLJXm2m9Lwne0OXfhtzHc7SfVn9iR6JGNNtWcNoY8m/3U
xolERsoMK6rPGPcijzSEu5GIHGO6ppUb46x+4rTwVRKjdwsN8j2MsS5E2nxF
DokIH+9Nfu1ULO64LtaVS6Km7/zr7U1UfJj8/C6ngMTnbi8d3pdURDmVHNtb
TMLH3s0g+wkVS9r2/jQ2idoFt51q96jofRuZxtdOoqLas4zPmIrnobMn2ztJ
0Gd7EqQNqIjddVyL2U2i38JSXluPCqts3VLjfhLHm+7PuylSURXQ8ipojISm
8UiTyAIFcRu2RdpNkJjMDvSifqfgwlDKARWShLStUGLgGAWa1t4D1T9JtNsx
ov90UcC/rCMrapbEFZ0Fpz1tFAyW7fJ0/U3C3vxLZnQDBWxP5ka9PyR+n5M8
N0RQEK8kMrO0RCIvWaViexkF/wMUO1xO
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["\"t [s]\"", TraditionalForm], 
    FormBox["\"amp [m]\"", TraditionalForm]},
  AxesOrigin->{0, 0},
  AxesStyle->Directive[24, 
    Thickness[0.005], 
    RGBColor[0, 0, 1]],
  ImageSize->{700, 800},
  LabelStyle->{FontFamily -> "Helvetica", 
    RGBColor[1, 0, 0], FontSize -> 32},
  Method->{},
  PlotLabel->FormBox[
    StyleBox[
    "\" \\!\\(\\*SubscriptBox[\\(C\\), \\(1\\)]\\)  Exp[  (-\[Zeta]  \
+\\!\\(\\*SqrtBox[\\(\\*SuperscriptBox[\\(\[Zeta]\\), \\(2\\)] - 1\\)]\\))\\!\
\\(\\*SubscriptBox[\\(\[Omega]\\), \\(n\\)]\\)  t] + \\n                 \
\\!\\(\\*SubscriptBox[\\(C\\), \\(2\\)]\\)  Exp[  (-\[Zeta]  \
-\\!\\(\\*SqrtBox[\\(\\*SuperscriptBox[\\(\[Zeta]\\), \\(2\\)] - 1\\)]\\)) \
\\!\\(\\*SubscriptBox[\\(\[Omega]\\), \\(n\\)]\\)  t]  \"", 
     RGBColor[0, 0, 1], 30, StripOnInput -> False], TraditionalForm],
  PlotRange->{{0, 1}, {0., 0.11750551244155549`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{
  3.571921765291553*^9, {3.571982148969597*^9, 3.571982199503545*^9}, 
   3.571984423870233*^9, 
   3.571984467743465*^9},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Export", "[", 
  RowBox[{
  "\"\</home/zosi/Book-Mathematica/nb-chap5-Fig/Chap5-Fig-5-11-zetagreat1.jpg\
\>\"", ",", " ", "gra4", " ", ",", "\"\<JPG\>\""}], "]"}]], "Input",
 CellChangeTimes->{{3.489572376234375*^9, 3.4895724029375*^9}, {
   3.489572482796875*^9, 3.4895724946875*^9}, 3.4895793945*^9, 
   3.489579443234375*^9, {3.48957950396875*^9, 3.4895795488125*^9}, {
   3.489645409875*^9, 3.4896454715*^9}, {3.571911566667901*^9, 
   3.571911580869019*^9}, {3.5719118673190403`*^9, 3.571911868519342*^9}, {
   3.571912314398628*^9, 3.571912326395692*^9}, {3.5719129307876368`*^9, 
   3.5719129403749743`*^9}, {3.571914699439974*^9, 3.57191470466334*^9}, {
   3.571914736879774*^9, 3.571914737242505*^9}, {3.571918888180777*^9, 
   3.571918889505721*^9}, {3.5719209431051903`*^9, 3.571920968714665*^9}, {
   3.5719217725802937`*^9, 3.571921773018326*^9}, {3.571982122787944*^9, 
   3.571982137761508*^9}},
 FontSize->24,
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData["\<\"/home/zosi/Book-Mathematica/nb-chap5-Fig/Chap5-Fig-5-11-\
zetagreat1.jpg\"\>"], "Output",
 CellChangeTimes->{
  3.571921722236846*^9, 3.571921781647397*^9, 3.571921841539145*^9, {
   3.571982150972204*^9, 3.571982204564406*^9}, 3.571984425623239*^9, 
   3.57198446949129*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Export", "[", 
  RowBox[{
  "\"\</home/zosi/Book-Mathematica/nb-chap5-Fig/Chap5-Fig-5-11-zetagreat1.pdf\
\>\"", ",", " ", "gra4", " ", ",", "\"\<pdf\>\""}], "]"}]], "Input",
 CellChangeTimes->{{3.489572376234375*^9, 3.4895724029375*^9}, {
   3.489572482796875*^9, 3.4895724946875*^9}, 3.4895793945*^9, 
   3.489579443234375*^9, {3.48957950396875*^9, 3.4895795488125*^9}, {
   3.489645409875*^9, 3.4896454715*^9}, {3.571911566667901*^9, 
   3.571911580869019*^9}, {3.5719118673190403`*^9, 3.571911868519342*^9}, {
   3.571912314398628*^9, 3.571912326395692*^9}, {3.571914710456629*^9, 
   3.5719147402064667`*^9}, {3.5719188924197702`*^9, 3.571918893050078*^9}, {
   3.5719209546566257`*^9, 3.571920974273616*^9}, {3.571921775675104*^9, 
   3.571921775744755*^9}, {3.571982143378798*^9, 3.571982143960178*^9}},
 FontSize->24,
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData["\<\"/home/zosi/Book-Mathematica/nb-chap5-Fig/Chap5-Fig-5-11-\
zetagreat1.pdf\"\>"], "Output",
 CellChangeTimes->{
  3.5719217226406612`*^9, 3.571921783396978*^9, 3.571921841740889*^9, {
   3.5719821528256187`*^9, 3.5719822047465267`*^9}, 3.57198442736049*^9, 
   3.571984471209446*^9}]
}, Open  ]]
},
CellGrouping->Manual,
WindowSize->{874, 608},
WindowMargins->{{257, Automatic}, {37, Automatic}},
FrontEndVersion->"9.0 for Linux x86 (64-bit) (January 25, 2013)",
StyleDefinitions->"Zosi-direi-buono.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[545, 20, 399, 9, 93, "Text"],
Cell[CellGroupData[{
Cell[969, 33, 214, 5, 24, "Input"],
Cell[1186, 40, 513, 11, 18, "Message"],
Cell[1702, 53, 206, 3, 24, "Output"]
}, Open  ]],
Cell[1923, 59, 1240, 27, 107, "Input"],
Cell[CellGroupData[{
Cell[3188, 90, 369, 8, 44, "Text"],
Cell[3560, 100, 1519, 31, 117, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5116, 136, 1621, 35, 99, "Input"],
Cell[6740, 173, 239, 3, 24, "Output"]
}, Open  ]],
Cell[6994, 179, 2545, 66, 158, "Input"],
Cell[CellGroupData[{
Cell[9564, 249, 2486, 46, 169, "Input"],
Cell[12053, 297, 26905, 454, 611, 4892, 91, "CachedBoxData", "BoxData", \
"Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[38995, 756, 987, 17, 102, "Input"],
Cell[39985, 775, 293, 5, 24, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[40315, 785, 886, 15, 102, "Input"],
Cell[41204, 802, 299, 5, 24, "Output"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
